Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.



135
136
137
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


128
129
130
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 128

def code
  @code
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


133
134
135
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 133

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



140
141
142
143
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 140

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @language = args[:language] if args.key?(:language)
end