Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a FunctionCall made based on model prediction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionResponse

Returns a new instance of GoogleCloudAiplatformV1FunctionResponse.



259
260
261
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The name of the function to call. Matches FunctionDeclaration.name and FunctionCall.name. Corresponds to the JSON property name

Returns:

  • (String)


236
237
238
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 236

def name
  @name
end

#partsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponsePart>

Optional. Ordered Parts that constitute a function response. Parts may have different IANA MIME types. Corresponds to the JSON property parts



242
243
244
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 242

def parts
  @parts
end

#responseHash<String,Object>

Required. The function response in JSON object format. Use "output" key to specify function output and "error" key to specify error details (if any). If " output" and "error" keys are not specified, then whole "response" is treated as function output. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


250
251
252
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 250

def response
  @response
end

#schedulingString

Optional. Specifies how the response should be scheduled in the conversation. Only applicable to NON_BLOCKING function calls, is ignored otherwise. Defaults to WHEN_IDLE. Corresponds to the JSON property scheduling

Returns:

  • (String)


257
258
259
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 257

def scheduling
  @scheduling
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



264
265
266
267
268
269
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 264

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parts = args[:parts] if args.key?(:parts)
  @response = args[:response] if args.key?(:response)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
end