Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Part

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A datatype containing media that is part of a multi-part Content message. A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. For media types that are not text, Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Part

Returns a new instance of GoogleCloudAiplatformV1Part.



457
458
459
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1CodeExecutionResult

Result of executing the ExecutableCode. Generated only when the CodeExecution tool is used. Corresponds to the JSON property codeExecutionResult



386
387
388
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 386

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1ExecutableCode

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated. Corresponds to the JSON property executableCode



394
395
396
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 394

def executable_code
  @executable_code
end

#file_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FileData

URI-based data. A FileData message contains a URI pointing to data of a specific media type. It is used to represent images, audio, and video stored in Google Cloud Storage. Corresponds to the JSON property fileData



401
402
403
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 401

def file_data
  @file_data
end

#function_callGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionCall

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values. Corresponds to the JSON property functionCall



408
409
410
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 408

def function_call
  @function_call
end

#function_responseGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponse

The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a FunctionCall made based on model prediction. Corresponds to the JSON property functionResponse



416
417
418
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 416

def function_response
  @function_response
end

#inline_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Blob

A content blob. A Blob contains data of a specific media type. It is used to represent images, audio, and video. Corresponds to the JSON property inlineData



422
423
424
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 422

def inline_data
  @inline_data
end

#media_resolutionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1PartMediaResolution

per part media resolution. Media resolution for the input media. Corresponds to the JSON property mediaResolution



427
428
429
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 427

def media_resolution
  @media_resolution
end

#textString

Optional. The text content of the part. When sent from the VSCode Gemini Code Assist extension, references to @mentioned items will be converted to markdown boldface text. For example @my-repo will be converted to and sent as **my- repo** by the IDE agent. Corresponds to the JSON property text

Returns:

  • (String)


435
436
437
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 435

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates whether the part represents the model's thought process or reasoning. Corresponds to the JSON property thought

Returns:

  • (Boolean)


441
442
443
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 441

def thought
  @thought
end

#thought_signatureString

Optional. An opaque signature for the thought so it can be reused in subsequent requests. Corresponds to the JSON property thoughtSignature NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


449
450
451
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 449

def thought_signature
  @thought_signature
end

#video_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1VideoMetadata

Provides metadata for a video, including the start and end offsets for clipping and the frame rate. Corresponds to the JSON property videoMetadata



455
456
457
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 455

def 
  @video_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 462

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file_data = args[:file_data] if args.key?(:file_data)
  @function_call = args[:function_call] if args.key?(:function_call)
  @function_response = args[:function_response] if args.key?(:function_response)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @media_resolution = args[:media_resolution] if args.key?(:media_resolution)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
  @thought_signature = args[:thought_signature] if args.key?(:thought_signature)
  @video_metadata = args[:video_metadata] if args.key?(:video_metadata)
end