Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Provides metadata for a video, including the start and end offsets for clipping and the frame rate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VideoMetadata

Returns a new instance of GoogleCloudAiplatformV1VideoMetadata.



570
571
572
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. The end offset of the video. Corresponds to the JSON property endOffset

Returns:

  • (String)


557
558
559
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 557

def end_offset
  @end_offset
end

#fpsFloat

Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0]. Corresponds to the JSON property fps

Returns:

  • (Float)


563
564
565
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 563

def fps
  @fps
end

#start_offsetString

Optional. The start offset of the video. Corresponds to the JSON property startOffset

Returns:

  • (String)


568
569
570
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 568

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



575
576
577
578
579
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 575

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end