Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainAgentTransfer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Represents an event indicating the transfer of a conversation to a different agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainAgentTransfer

Returns a new instance of GoogleCloudCesV1mainAgentTransfer.



42
43
44
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 42

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. Display name of the agent. Corresponds to the JSON property displayName

Returns:

  • (String)


33
34
35
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 33

def display_name
  @display_name
end

#target_agentString

Required. The agent to which the conversation is being transferred. The agent will handle the conversation from this point forward. Format: projects/ project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertytargetAgent`

Returns:

  • (String)


40
41
42
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 40

def target_agent
  @target_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47
48
49
50
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 47

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @target_agent = args[:target_agent] if args.key?(:target_agent)
end