Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A message within a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainMessage

Returns a new instance of GoogleCloudCesV1mainMessage.



782
783
784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunksArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainChunk>

Optional. Content of the message as a series of chunks. Corresponds to the JSON property chunks



769
770
771
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 769

def chunks
  @chunks
end

#event_timeString

Optional. Timestamp when the message was sent or received. Should not be used if the message is part of an example. Corresponds to the JSON property eventTime

Returns:

  • (String)


775
776
777
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 775

def event_time
  @event_time
end

#roleString

Optional. The role within the conversation, e.g., user, agent. Corresponds to the JSON property role

Returns:

  • (String)


780
781
782
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 780

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



787
788
789
790
791
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 787

def update!(**args)
  @chunks = args[:chunks] if args.key?(:chunks)
  @event_time = args[:event_time] if args.key?(:event_time)
  @role = args[:role] if args.key?(:role)
end