Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A span is a unit of work or a single operation during the request processing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainSpan

Returns a new instance of GoogleCloudCesV1mainSpan.



828
829
830
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Object>

Output only. Key-value attributes associated with the span. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,Object>)


801
802
803
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 801

def attributes
  @attributes
end

#child_spansArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan>

Output only. The child spans that are nested under this span. Corresponds to the JSON property childSpans



806
807
808
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 806

def child_spans
  @child_spans
end

#durationString

Output only. The duration of the span. Corresponds to the JSON property duration

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 811

def duration
  @duration
end

#end_timeString

Output only. The end time of the span. Corresponds to the JSON property endTime

Returns:

  • (String)


816
817
818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 816

def end_time
  @end_time
end

#nameString

Output only. The name of the span. Corresponds to the JSON property name

Returns:

  • (String)


821
822
823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 821

def name
  @name
end

#start_timeString

Output only. The start time of the span. Corresponds to the JSON property startTime

Returns:

  • (String)


826
827
828
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 826

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



833
834
835
836
837
838
839
840
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 833

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @child_spans = args[:child_spans] if args.key?(:child_spans)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end