Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request for the client or the agent to execute the specified tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainToolCall

Returns a new instance of GoogleCloudCesV1mainToolCall.



331
332
333
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_nameString

Output only. Human-readable name of the agent that issued this call, e.g. " Contract Architect". Empty when the root agent issued it. Corresponds to the JSON property agentName

Returns:

  • (String)


294
295
296
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 294

def agent_name
  @agent_name
end

#argsHash<String,Object>

Optional. The input parameters and values for the tool in JSON object format. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


299
300
301
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 299

def args
  @args
end

#display_nameString

Output only. Display name of the tool. Corresponds to the JSON property displayName

Returns:

  • (String)


304
305
306
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 304

def display_name
  @display_name
end

#idString

Optional. The unique identifier of the tool call. If populated, the client should return the execution result with the matching ID in ToolResponse. Corresponds to the JSON property id

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 310

def id
  @id
end

#parent_tool_call_idString

Output only. The id of the tool call that caused this one, when it was issued by a sub-agent working on behalf of a parent call. Empty for top-level calls. Lets a client group a sub-agent's work under the call that started it instead of rendering every step as a sibling. Corresponds to the JSON property parentToolCallId

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 318

def parent_tool_call_id
  @parent_tool_call_id
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool` Corresponds to the JSON propertytool`

Returns:

  • (String)


324
325
326
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 324

def tool
  @tool
end

#toolset_toolGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



329
330
331
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 329

def toolset_tool
  @toolset_tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



336
337
338
339
340
341
342
343
344
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 336

def update!(**args)
  @agent_name = args[:agent_name] if args.key?(:agent_name)
  @args = args[:args] if args.key?(:args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @parent_tool_call_id = args[:parent_tool_call_id] if args.key?(:parent_tool_call_id)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
end