Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Analysis
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Analysis
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The analysis resource.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnalysisResult
The result of an analysis.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#request_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Analysis
constructor
A new instance of GoogleCloudContactcenterinsightsV1Analysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Analysis
Returns a new instance of GoogleCloudContactcenterinsightsV1Analysis.
435 436 437 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnalysisResult
The result of an analysis.
Corresponds to the JSON property analysisResult
411 412 413 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 411 def analysis_result @analysis_result end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
416 417 418 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 416 def annotator_selector @annotator_selector end |
#create_time ⇒ String
Output only. The time at which the analysis was created, which occurs when the
long-running operation completes.
Corresponds to the JSON property createTime
422 423 424 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 422 def create_time @create_time end |
#name ⇒ String
Immutable. The resource name of the analysis. Format: projects/project/
locations/location/conversations/conversation/analyses/analysis
Corresponds to the JSON property name
428 429 430 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 428 def name @name end |
#request_time ⇒ String
Output only. The time at which the analysis was requested.
Corresponds to the JSON property requestTime
433 434 435 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 433 def request_time @request_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
440 441 442 443 444 445 446 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 440 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) end |