Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ArticleSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist Article Suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ArticleSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1ArticleSuggestionData.



1467
1468
1469
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The system's confidence score that this article is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


1437
1438
1439
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1437

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the Article Suggestion and the document that it originates from. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


1443
1444
1445
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1443

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


1449
1450
1451
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1449

def query_record
  @query_record
end

#sourceString

The knowledge document that this answer was extracted from. Format: projects/ project/knowledgeBases/knowledge_base/documents/document Corresponds to the JSON property source

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1455

def source
  @source
end

#titleString

Article title. Corresponds to the JSON property title

Returns:

  • (String)


1460
1461
1462
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1460

def title
  @title
end

#uriString

Article URI. Corresponds to the JSON property uri

Returns:

  • (String)


1465
1466
1467
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1465

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1472
1473
1474
1475
1476
1477
1478
1479
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1472

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @source = args[:source] if args.key?(:source)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end