Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AssessmentRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The CCAI Insights project wide assessment rule. This assessment rule will be applied to all conversations from the previous sampling cycle that match the sample rule defined in the assessment rule. One project can have multiple assessment rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AssessmentRule

Returns a new instance of GoogleCloudContactcenterinsightsV1AssessmentRule.



1045
1046
1047
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

If true, apply this rule to conversations. Otherwise, this rule is inactive. Corresponds to the JSON property active

Returns:

  • (Boolean)


1011
1012
1013
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1011

def active
  @active
end

#create_timeString

Output only. The time at which this assessment rule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1017
1018
1019
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1017

def create_time
  @create_time
end

#display_nameString

Display Name of the assessment rule. Corresponds to the JSON property displayName

Returns:

  • (String)


1022
1023
1024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1022

def display_name
  @display_name
end

#nameString

Identifier. The resource name of the assessment rule. Format: projects/ project/locations/location/assessmentRules/assessment_rule Corresponds to the JSON property name

Returns:

  • (String)


1028
1029
1030
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1028

def name
  @name
end

#sample_ruleGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule

Message for sampling conversations. Corresponds to the JSON property sampleRule



1033
1034
1035
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1033

def sample_rule
  @sample_rule
end

#schedule_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo

Message for schedule info. Corresponds to the JSON property scheduleInfo



1038
1039
1040
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1038

def schedule_info
  @schedule_info
end

#update_timeString

Output only. The most recent time at which this assessment rule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1043

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1050
1051
1052
1053
1054
1055
1056
1057
1058
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1050

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @sample_rule = args[:sample_rule] if args.key?(:sample_rule)
  @schedule_info = args[:schedule_info] if args.key?(:schedule_info)
  @update_time = args[:update_time] if args.key?(:update_time)
end