Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AuthorizedView
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AuthorizedView
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An AuthorizedView represents a view of accessible Insights resources (for example, Conversation and Scorecard). Who have read access to the AuthorizedView resource will have access to these Insight resources as well.
Instance Attribute Summary collapse
-
#conversation_filter ⇒ String
A filter to reduce conversation results to a specific subset.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display Name.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AuthorizedView
constructor
A new instance of GoogleCloudContactcenterinsightsV1AuthorizedView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AuthorizedView
Returns a new instance of GoogleCloudContactcenterinsightsV1AuthorizedView.
1206 1207 1208 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_filter ⇒ String
A filter to reduce conversation results to a specific subset. The
AuthorizedView's assigned permission (read/write) could be applied to the
subset of conversations. If conversation_filter is empty, there is no
restriction on the conversations that the AuthorizedView can access. Having *
authorizedViews.get* access to the AuthorizedView means having the same read/
write access to the Conversations (as well as metadata/annotations linked to
the conversation) that this AuthorizedView has.
Corresponds to the JSON property conversationFilter
1182 1183 1184 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1182 def conversation_filter @conversation_filter end |
#create_time ⇒ String
Output only. The time at which the authorized view was created.
Corresponds to the JSON property createTime
1187 1188 1189 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1187 def create_time @create_time end |
#display_name ⇒ String
Display Name. Limit 64 characters.
Corresponds to the JSON property displayName
1192 1193 1194 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1192 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of the AuthorizedView. Format: projects/project
/locations/location/authorizedViewSets/authorized_view_set/authorizedViews/
authorized_view
Corresponds to the JSON property name
1199 1200 1201 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1199 def name @name end |
#update_time ⇒ String
Output only. The most recent time at which the authorized view was updated.
Corresponds to the JSON property updateTime
1204 1205 1206 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1204 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1211 def update!(**args) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |