Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Rule for auto-labeling conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRule

Returns a new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRule.



1280
1281
1282
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Whether the rule is active. Corresponds to the JSON property active

Returns:

  • (Boolean)


1233
1234
1235
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1233

def active
  @active
end

#conditionsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition>

Conditions to apply for auto-labeling the label_key. Representing sequential block of if .. else if .. else statements. The value of the first matching condition will be used. Corresponds to the JSON property conditions



1241
1242
1243
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1241

def conditions
  @conditions
end

#create_timeString

Output only. The time at which this rule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1246

def create_time
  @create_time
end

#descriptionString

The description of the rule. Corresponds to the JSON property description

Returns:

  • (String)


1251
1252
1253
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1251

def description
  @description
end

#display_nameString

The user-provided display name of the rule. Corresponds to the JSON property displayName

Returns:

  • (String)


1256
1257
1258
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1256

def display_name
  @display_name
end

#label_keyString

The label key. This is also the auto_labeling_rule in the resource name. Only settable if label_key_type is LABEL_KEY_TYPE_CUSTOM. Corresponds to the JSON property labelKey

Returns:

  • (String)


1262
1263
1264
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1262

def label_key
  @label_key
end

#label_key_typeString

The type of the label key. Corresponds to the JSON property labelKeyType

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1267

def label_key_type
  @label_key_type
end

#nameString

Identifier. The resource name of the auto-labeling rule. Format: projects/ project/locations/location/autoLabelingRules/auto_labeling_rule Corresponds to the JSON property name

Returns:

  • (String)


1273
1274
1275
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1273

def name
  @name
end

#update_timeString

Output only. The most recent time at which the rule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1278
1279
1280
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1278

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1285

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @label_key = args[:label_key] if args.key?(:label_key)
  @label_key_type = args[:label_key_type] if args.key?(:label_key_type)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end