Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for a bulk analyze conversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsMetadata.



1405
1406
1407
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_analyses_countFixnum

The number of requested analyses that have completed successfully so far. Corresponds to the JSON property completedAnalysesCount

Returns:

  • (Fixnum)


1364
1365
1366
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1364

def completed_analyses_count
  @completed_analyses_count
end

#create_timeString

The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1369

def create_time
  @create_time
end

#end_timeString

The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1374

def end_time
  @end_time
end

#failed_analyses_countFixnum

The number of requested analyses that have failed so far. Corresponds to the JSON property failedAnalysesCount

Returns:

  • (Fixnum)


1379
1380
1381
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1379

def failed_analyses_count
  @failed_analyses_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during bulk analyze operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



1385
1386
1387
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1385

def partial_errors
  @partial_errors
end

#relabelBoolean Also known as: relabel?

Output only. If true, the labeling rules will be re-evaluated for the conversations. Corresponds to the JSON property relabel

Returns:

  • (Boolean)


1391
1392
1393
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1391

def relabel
  @relabel
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest

The request to analyze conversations in bulk. Corresponds to the JSON property request



1397
1398
1399
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1397

def request
  @request
end

#total_requested_analyses_countFixnum

Total number of analyses requested. Computed by the number of conversations returned by filter multiplied by analysis_percentage in the request. Corresponds to the JSON property totalRequestedAnalysesCount

Returns:

  • (Fixnum)


1403
1404
1405
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1403

def total_requested_analyses_count
  @total_requested_analyses_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1410

def update!(**args)
  @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @relabel = args[:relabel] if args.key?(:relabel)
  @request = args[:request] if args.key?(:request)
  @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count)
end