Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to analyze conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest.



1453
1454
1455
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_percentageFloat

Required. Percentage of selected conversation to analyze, between [0, 100]. Corresponds to the JSON property analysisPercentage

Returns:

  • (Float)


1429
1430
1431
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1429

def analysis_percentage
  @analysis_percentage
end

#annotator_selectorGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector

Selector of all available annotators and phrase matchers to run. Corresponds to the JSON property annotatorSelector



1434
1435
1436
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1434

def annotator_selector
  @annotator_selector
end

#filterString

Required. Filter used to select the subset of conversations to analyze. Corresponds to the JSON property filter

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1439

def filter
  @filter
end

#parentString

Required. The parent resource to create analyses in. Corresponds to the JSON property parent

Returns:

  • (String)


1444
1445
1446
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1444

def parent
  @parent
end

#relabelBoolean Also known as: relabel?

Optional. If true, the labeling rules will be re-evaluated for the conversations. Corresponds to the JSON property relabel

Returns:

  • (Boolean)


1450
1451
1452
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1450

def relabel
  @relabel
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1458
1459
1460
1461
1462
1463
1464
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1458

def update!(**args)
  @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage)
  @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector)
  @filter = args[:filter] if args.key?(:filter)
  @parent = args[:parent] if args.key?(:parent)
  @relabel = args[:relabel] if args.key?(:relabel)
end