Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk delete conversations operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during bulk delete conversations operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata.
1517 1518 1519 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
1499 1500 1501 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1499 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
1504 1505 1506 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1504 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during bulk delete conversations operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
1510 1511 1512 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1510 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
Corresponds to the JSON property request
1515 1516 1517 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1515 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1522 1523 1524 1525 1526 1527 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1522 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |