Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest.



1557
1558
1559
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


1537
1538
1539
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1537

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


1543
1544
1545
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1543

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


1549
1550
1551
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1549

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


1555
1556
1557
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1555

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1562
1563
1564
1565
1566
1567
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1562

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end