Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for the BulkDownloadFeedbackLabel endpoint.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata.
2100 2101 2102 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
2077 2078 2079 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2077 def create_time @create_time end |
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
Corresponds to the JSON property downloadStats
2082 2083 2084 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2082 def download_stats @download_stats end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
2087 2088 2089 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2087 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
2093 2094 2095 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2093 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Corresponds to the JSON property request
2098 2099 2100 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2098 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2105 2106 2107 2108 2109 2110 2111 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2105 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @download_stats = args[:download_stats] if args.key?(:download_stats) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |