Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request for the BulkDownloadFeedbackLabel endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest.



1788
1789
1790
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_filterString

Optional. Filter parent conversations to download feedback labels for. When specified, the feedback labels will be downloaded for the conversations that match the filter. If template_qa_scorecard_id is set, all the conversations that match the filter will be paired with the questions under the scorecard for labeling. Corresponds to the JSON property conversationFilter

Returns:

  • (String)


1744
1745
1746
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1744

def conversation_filter
  @conversation_filter
end

#feedback_label_typeString

Optional. The type of feedback labels that will be downloaded. Corresponds to the JSON property feedbackLabelType

Returns:

  • (String)


1749
1750
1751
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1749

def feedback_label_type
  @feedback_label_type
end

#filterString

Optional. A filter to reduce results to a specific subset. Supports disjunctions (OR) and conjunctions (AND). Supported fields: * issue_model_id

  • qa_question_id * qa_scorecard_id * min_create_time * max_create_time
  • min_update_time * max_update_time * feedback_label_type: QUALITY_AI, TOPIC_MODELING Corresponds to the JSON property filter

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1758

def filter
  @filter
end

#gcs_destinationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination

Google Cloud Storage Object details to write the feedback labels to. Corresponds to the JSON property gcsDestination



1763
1764
1765
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1763

def gcs_destination
  @gcs_destination
end

#max_download_countFixnum

Optional. Limits the maximum number of feedback labels that will be downloaded. The first N feedback labels will be downloaded. Corresponds to the JSON property maxDownloadCount

Returns:

  • (Fixnum)


1769
1770
1771
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1769

def max_download_count
  @max_download_count
end

#parentString

Required. The parent resource for new feedback labels. Corresponds to the JSON property parent

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1774

def parent
  @parent
end

#sheets_destinationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination

Google Sheets document details to write the feedback labels to. Corresponds to the JSON property sheetsDestination



1779
1780
1781
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1779

def sheets_destination
  @sheets_destination
end

#template_qa_scorecard_idArray<String>

Optional. If set, a template for labeling conversations and scorecard questions will be created from the conversation_filter and the questions under the scorecard(s). The feedback label filter will be ignored. Corresponds to the JSON property templateQaScorecardId

Returns:

  • (Array<String>)


1786
1787
1788
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1786

def template_qa_scorecard_id
  @template_qa_scorecard_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1793

def update!(**args)
  @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter)
  @feedback_label_type = args[:feedback_label_type] if args.key?(:feedback_label_type)
  @filter = args[:filter] if args.key?(:filter)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @max_download_count = args[:max_download_count] if args.key?(:max_download_count)
  @parent = args[:parent] if args.key?(:parent)
  @sheets_destination = args[:sheets_destination] if args.key?(:sheets_destination)
  @template_qa_scorecard_id = args[:template_qa_scorecard_id] if args.key?(:template_qa_scorecard_id)
end