Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Google Sheets document details to get the feedback label file from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource.



1428
1429
1430
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spreadsheet_uriString

Required. The Google Sheets document to write the feedback labels to. Retrieved from Google Sheets URI. E.g. https://docs.google.com/spreadsheets/d/ 1234567890 The spreadsheet must be shared with the Insights P4SA. Corresponds to the JSON property spreadsheetUri

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1426

def spreadsheet_uri
  @spreadsheet_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1433
1434
1435
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1433

def update!(**args)
  @spreadsheet_uri = args[:spreadsheet_uri] if args.key?(:spreadsheet_uri)
end