Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The response for calculating conversation statistics.
Instance Attribute Summary collapse
-
#average_duration ⇒ String
The average duration of all conversations.
-
#average_turn_count ⇒ Fixnum
The average number of turns per conversation.
-
#conversation_count ⇒ Fixnum
The total number of conversations.
-
#conversation_count_time_series ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
A time series representing conversations over time.
-
#custom_highlighter_matches ⇒ Hash<String,Fixnum>
A map associating each custom highlighter resource name with its respective number of matches in the set of conversations.
-
#issue_matches ⇒ Hash<String,Fixnum>
A map associating each issue resource name with its respective number of matches in the set of conversations.
-
#issue_matches_stats ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats>
A map associating each issue resource name with its respective number of matches in the set of conversations.
-
#smart_highlighter_matches ⇒ Hash<String,Fixnum>
A map associating each smart highlighter display name with its respective number of matches in the set of conversations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponse
constructor
A new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponse
Returns a new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponse.
2038 2039 2040 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_duration ⇒ String
The average duration of all conversations. The average is calculated using
only conversations that have a time duration.
Corresponds to the JSON property averageDuration
1995 1996 1997 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1995 def average_duration @average_duration end |
#average_turn_count ⇒ Fixnum
The average number of turns per conversation.
Corresponds to the JSON property averageTurnCount
2000 2001 2002 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2000 def average_turn_count @average_turn_count end |
#conversation_count ⇒ Fixnum
The total number of conversations.
Corresponds to the JSON property conversationCount
2005 2006 2007 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2005 def conversation_count @conversation_count end |
#conversation_count_time_series ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
A time series representing conversations over time.
Corresponds to the JSON property conversationCountTimeSeries
2010 2011 2012 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2010 def conversation_count_time_series @conversation_count_time_series end |
#custom_highlighter_matches ⇒ Hash<String,Fixnum>
A map associating each custom highlighter resource name with its respective
number of matches in the set of conversations.
Corresponds to the JSON property customHighlighterMatches
2016 2017 2018 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2016 def custom_highlighter_matches @custom_highlighter_matches end |
#issue_matches ⇒ Hash<String,Fixnum>
A map associating each issue resource name with its respective number of
matches in the set of conversations. Key has the format: projects//locations//
issueModels//issues/ Deprecated, use issue_matches_stats field instead.
Corresponds to the JSON property issueMatches
2023 2024 2025 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2023 def issue_matches @issue_matches end |
#issue_matches_stats ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats>
A map associating each issue resource name with its respective number of
matches in the set of conversations. Key has the format: projects//locations//
issueModels//issues/
Corresponds to the JSON property issueMatchesStats
2030 2031 2032 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2030 def issue_matches_stats @issue_matches_stats end |
#smart_highlighter_matches ⇒ Hash<String,Fixnum>
A map associating each smart highlighter display name with its respective
number of matches in the set of conversations.
Corresponds to the JSON property smartHighlighterMatches
2036 2037 2038 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2036 def smart_highlighter_matches @smart_highlighter_matches end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2043 def update!(**args) @average_duration = args[:average_duration] if args.key?(:average_duration) @average_turn_count = args[:average_turn_count] if args.key?(:average_turn_count) @conversation_count = args[:conversation_count] if args.key?(:conversation_count) @conversation_count_time_series = args[:conversation_count_time_series] if args.key?(:conversation_count_time_series) @custom_highlighter_matches = args[:custom_highlighter_matches] if args.key?(:custom_highlighter_matches) @issue_matches = args[:issue_matches] if args.key?(:issue_matches) @issue_matches_stats = args[:issue_matches_stats] if args.key?(:issue_matches_stats) @smart_highlighter_matches = args[:smart_highlighter_matches] if args.key?(:smart_highlighter_matches) end |