Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CES diagnostic information.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
-
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CesTurnAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1CesTurnAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CesTurnAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1CesTurnAnnotation.
2677 2678 2679 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
Corresponds to the JSON property messages
2670 2671 2672 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2670 def @messages end |
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
2675 2676 2677 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2675 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2682 2683 2684 2685 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2682 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |