Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request data for visualizing the dataset in the chart.
Instance Attribute Summary collapse
-
#generative_insights ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights
Request that use natural language query to generate the chart.
-
#query_metrics ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetrics
Request data that use the existing QueryMetrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ChartDataSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1ChartDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ChartDataSource
Returns a new instance of GoogleCloudContactcenterinsightsV1ChartDataSource.
2813 2814 2815 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generative_insights ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights
Request that use natural language query to generate the chart.
Corresponds to the JSON property generativeInsights
2806 2807 2808 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2806 def generative_insights @generative_insights end |
#query_metrics ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetrics
Request data that use the existing QueryMetrics.
Corresponds to the JSON property queryMetrics
2811 2812 2813 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2811 def query_metrics @query_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2818 2819 2820 2821 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2818 def update!(**args) @generative_insights = args[:generative_insights] if args.key?(:generative_insights) @query_metrics = args[:query_metrics] if args.key?(:query_metrics) end |