Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Info for correlating across conversations.
Instance Attribute Summary collapse
-
#correlation_types ⇒ Array<String>
Output only.
-
#full_conversation_correlation_id ⇒ String
Output only.
-
#merged_full_conversation_correlation_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo.
2717 2718 2719 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2717 def initialize(**args) update!(**args) end |
Instance Attribute Details
#correlation_types ⇒ Array<String>
Output only. The correlation types of this conversation. A single conversation
can have multiple correlation types. For example a conversation that only has
a single segment is both a SEGMENT and a FULL_CONVERSATION.
Corresponds to the JSON property correlationTypes
2703 2704 2705 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2703 def correlation_types @correlation_types end |
#full_conversation_correlation_id ⇒ String
Output only. The full conversation correlation id this conversation is a
segment of.
Corresponds to the JSON property fullConversationCorrelationId
2709 2710 2711 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2709 def full_conversation_correlation_id @full_conversation_correlation_id end |
#merged_full_conversation_correlation_id ⇒ String
Output only. The full conversation correlation id this conversation is a
merged conversation of.
Corresponds to the JSON property mergedFullConversationCorrelationId
2715 2716 2717 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2715 def merged_full_conversation_correlation_id @merged_full_conversation_correlation_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2722 2723 2724 2725 2726 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2722 def update!(**args) @correlation_types = args[:correlation_types] if args.key?(:correlation_types) @full_conversation_correlation_id = args[:full_conversation_correlation_id] if args.key?(:full_conversation_correlation_id) @merged_full_conversation_correlation_id = args[:merged_full_conversation_correlation_id] if args.key?(:merged_full_conversation_correlation_id) end |