Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataOptions
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Options for configuring what metadata is included in the conversation data used in QAI and Discovery Engine.
Instance Attribute Summary collapse
-
#include_dialogflow_interaction_data ⇒ Boolean
(also: #include_dialogflow_interaction_data?)
Whether to include the per turn Dialogflow interaction data in conversation transcript.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataOptions
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationDataOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataOptions
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationDataOptions.
2214 2215 2216 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_dialogflow_interaction_data ⇒ Boolean Also known as: include_dialogflow_interaction_data?
Whether to include the per turn Dialogflow interaction data in conversation
transcript.
Corresponds to the JSON property includeDialogflowInteractionData
2211 2212 2213 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2211 def include_dialogflow_interaction_data @include_dialogflow_interaction_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2219 2220 2221 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2219 def update!(**args) @include_dialogflow_interaction_data = args[:include_dialogflow_interaction_data] if args.key?(:include_dialogflow_interaction_data) end |