Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation source, which is a combination of transcript and audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataSource

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationDataSource.



2871
2872
2873
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialogflow_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowSource

A Dialogflow source of conversation data. Corresponds to the JSON property dialogflowSource



2851
2852
2853
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2851

def dialogflow_source
  @dialogflow_source
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource

A Cloud Storage source of conversation data. Corresponds to the JSON property gcsSource



2856
2857
2858
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2856

def gcs_source
  @gcs_source
end

#metadata_uriString

Cloud Storage URI that points to a file that contains the conversation metadata. Corresponds to the JSON property metadataUri

Returns:

  • (String)


2862
2863
2864
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2862

def 
  @metadata_uri
end

#turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>

Cloud Storage URIs that points to files that contain the conversation audio for each turn. Assume the order of the URIs is the same as the order of the transcript turns. Corresponds to the JSON property turnLevelAudios



2869
2870
2871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2869

def turn_level_audios
  @turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2876
2877
2878
2879
2880
2881
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2876

def update!(**args)
  @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri)
  @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios)
end