Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationLevelSentiment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationLevelSentiment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
One channel of conversation-level sentiment data.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
The channel of the audio that the data applies to.
-
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationLevelSentiment
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationLevelSentiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationLevelSentiment
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationLevelSentiment.
3336 3337 3338 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
The channel of the audio that the data applies to.
Corresponds to the JSON property channelTag
3329 3330 3331 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3329 def channel_tag @channel_tag end |
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentimentData
3334 3335 3336 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3334 def sentiment_data @sentiment_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3341 3342 3343 3344 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3341 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data) end |