Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation metadata related to quality management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationQualityMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationQualityMetadata.



3034
3035
3036
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_infoArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo>

Information about agents involved in the call. Corresponds to the JSON property agentInfo



3012
3013
3014
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3012

def agent_info
  @agent_info
end

#customer_satisfaction_ratingFixnum

An arbitrary integer value indicating the customer's satisfaction rating. Corresponds to the JSON property customerSatisfactionRating

Returns:

  • (Fixnum)


3017
3018
3019
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3017

def customer_satisfaction_rating
  @customer_satisfaction_rating
end

#feedback_labelsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FeedbackLabel>

Input only. The feedback labels associated with the conversation. Corresponds to the JSON property feedbackLabels



3022
3023
3024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3022

def feedback_labels
  @feedback_labels
end

An arbitrary string value specifying the menu path the customer took. Corresponds to the JSON property menuPath

Returns:

  • (String)


3027
3028
3029
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3027

def menu_path
  @menu_path
end

#wait_durationString

The amount of time the customer waited to connect with an agent. Corresponds to the JSON property waitDuration

Returns:

  • (String)


3032
3033
3034
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3032

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3039
3040
3041
3042
3043
3044
3045
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3039

def update!(**args)
  @agent_info = args[:agent_info] if args.key?(:agent_info)
  @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating)
  @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels)
  @menu_path = args[:menu_path] if args.key?(:menu_path)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end