Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation summarization suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.



3185
3186
3187
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property answerRecord

Returns:

  • (String)


3149
3150
3151
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3149

def answer_record
  @answer_record
end

#confidenceFloat

The confidence score of the summarization. Corresponds to the JSON property confidence

Returns:

  • (Float)


3154
3155
3156
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3154

def confidence
  @confidence
end

#conversation_modelString

The name of the model that generates this summary. Format: projects/project/ locations/location/conversationModels/conversation_model Corresponds to the JSON property conversationModel

Returns:

  • (String)


3160
3161
3162
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3160

def conversation_model
  @conversation_model
end

#generator_idString

Agent Assist generator ID. Corresponds to the JSON property generatorId

Returns:

  • (String)


3165
3166
3167
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3165

def generator_id
  @generator_id
end

#metadataHash<String,String>

A map that contains metadata about the summarization and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


3171
3172
3173
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3171

def 
  @metadata
end

#textString

The summarization content that is concatenated into one string. Corresponds to the JSON property text

Returns:

  • (String)


3176
3177
3178
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3176

def text
  @text
end

#text_sectionsHash<String,String>

The summarization content that is divided into sections. The key is the section's name and the value is the section's content. There is no specific format for the key or value. Corresponds to the JSON property textSections

Returns:

  • (Hash<String,String>)


3183
3184
3185
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3183

def text_sections
  @text_sections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3190
3191
3192
3193
3194
3195
3196
3197
3198
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3190

def update!(**args)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @confidence = args[:confidence] if args.key?(:confidence)
  @conversation_model = args[:conversation_model] if args.key?(:conversation_model)
  @generator_id = args[:generator_id] if args.key?(:generator_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @text = args[:text] if args.key?(:text)
  @text_sections = args[:text_sections] if args.key?(:text_sections)
end