Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A configuration that defines how to correlate conversations for a given a given project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1CorrelationConfig.



3385
3386
3387
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the correlation config was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3367
3368
3369
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3367

def create_time
  @create_time
end

#full_conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationTypeConfig

A list of correlation rules for a given correlation type. Corresponds to the JSON property fullConversationConfig



3372
3373
3374
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3372

def full_conversation_config
  @full_conversation_config
end

#nameString

Immutable. Identifier. The resource name of the correlation config. Format: projects/project/locations/location/correlationConfig Corresponds to the JSON property name

Returns:

  • (String)


3378
3379
3380
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3378

def name
  @name
end

#update_timeString

Output only. The time at which the correlation config was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3383
3384
3385
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3383

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3390
3391
3392
3393
3394
3395
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3390

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @full_conversation_config = args[:full_conversation_config] if args.key?(:full_conversation_config)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end