Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.
3693 3694 3695 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
3660 3661 3662 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3660 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
3665 3666 3667 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3665 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
3670 3671 3672 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3670 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
3676 3677 3678 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3676 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
3681 3682 3683 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3681 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
3686 3687 3688 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3686 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
3691 3692 3693 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3691 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3698 3699 3700 3701 3702 3703 3704 3705 3706 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3698 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |