Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.
Instance Attribute Summary collapse
-
#agent_display_name ⇒ String
ces agent display name (e.g., "Steering", "Billing").
-
#agent_id ⇒ String
ces agent id to diagnose.
-
#app_id ⇒ String
Required.
-
#app_version ⇒ String
Optional.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#filter ⇒ String
Optional.
-
#full_report ⇒ Boolean
(also: #full_report?)
Optional.
-
#group_id ⇒ String
Optional.
-
#instructions ⇒ String
Optional.
-
#max_steps ⇒ Fixnum
Optional.
-
#metric_type ⇒ String
Optional.
-
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1OutputConfig
Configuration for where to export or return the analysis findings.
-
#parent ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#task_query ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest.
4558 4559 4560 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_display_name ⇒ String
ces agent display name (e.g., "Steering", "Billing").
Corresponds to the JSON property agentDisplayName
4463 4464 4465 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4463 def agent_display_name @agent_display_name end |
#agent_id ⇒ String
ces agent id to diagnose.
Corresponds to the JSON property agentId
4468 4469 4470 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4468 def agent_id @agent_id end |
#app_id ⇒ String
Required. The CES App ID.
Corresponds to the JSON property appId
4473 4474 4475 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4473 def app_id @app_id end |
#app_version ⇒ String
Optional. Optional but highly recommended. ces app version. If provided,
specific version of agent instruction will be retrieved. If empty or set to '-'
, will use the latest draft version of instruction.
Corresponds to the JSON property appVersion
4480 4481 4482 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4480 def app_version @app_version end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. Deprecated: If true, the request will be validated and a simulation
of the analysis will be performed without actually executing the task. This
field is unused. Use validate_only instead.
Corresponds to the JSON property dryRun
4487 4488 4489 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4487 def dry_run @dry_run end |
#filter ⇒ String
Optional. AIP-160 compliant filter for selecting target conversations.
Corresponds to the JSON property filter
4493 4494 4495 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4493 def filter @filter end |
#full_report ⇒ Boolean Also known as: full_report?
Optional. Deprecated: If true, the agent will generate a full diagnostic
report for all sub-agents. Subagent reporting configuration is unused. The
final diagnostic details are already persisted inside the Diagnostic resource
instead.
Corresponds to the JSON property fullReport
4501 4502 4503 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4501 def full_report @full_report end |
#group_id ⇒ String
Optional. A unique identifier used to group multiple diagnostic requests
triggered under the same run batch or cron job.
Corresponds to the JSON property groupId
4508 4509 4510 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4508 def group_id @group_id end |
#instructions ⇒ String
Optional. Deprecated: Specific instructions for the agent. Use app_id and
subagent fields instead.
Corresponds to the JSON property instructions
4514 4515 4516 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4514 def instructions @instructions end |
#max_steps ⇒ Fixnum
Optional. The maximum number of steps the agent can take during the execution
of the task. Defaults to 10.
Corresponds to the JSON property maxSteps
4520 4521 4522 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4520 def max_steps @max_steps end |
#metric_type ⇒ String
Optional. The type of metric being diagnosed.
Corresponds to the JSON property metricType
4525 4526 4527 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4525 def metric_type @metric_type end |
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1OutputConfig
Configuration for where to export or return the analysis findings.
Corresponds to the JSON property outputConfig
4530 4531 4532 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4530 def output_config @output_config end |
#parent ⇒ String
Required. The parent resource where the analysis will be performed.
Corresponds to the JSON property parent
4535 4536 4537 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4535 def parent @parent end |
#request_id ⇒ String
Optional. Required. A unique ID that identifies the request. If the service
receives two DiagnoseConversationsRequests with the same request_id, then
the second request will be ignored; instead, the response of the first request
will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9),
underscores (_), and hyphens (-). The maximum length is 40 characters.
Corresponds to the JSON property requestId
4544 4545 4546 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4544 def request_id @request_id end |
#task_query ⇒ String
Optional. A natural language description of the analysis goal or question.
Corresponds to the JSON property taskQuery
4549 4550 4551 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4549 def task_query @task_query end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If true, the request will only be validated (permissions, filter
syntax, etc.) without actually triggering the analysis.
Corresponds to the JSON property validateOnly
4555 4556 4557 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4555 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4563 def update!(**args) @agent_display_name = args[:agent_display_name] if args.key?(:agent_display_name) @agent_id = args[:agent_id] if args.key?(:agent_id) @app_id = args[:app_id] if args.key?(:app_id) @app_version = args[:app_version] if args.key?(:app_version) @dry_run = args[:dry_run] if args.key?(:dry_run) @filter = args[:filter] if args.key?(:filter) @full_report = args[:full_report] if args.key?(:full_report) @group_id = args[:group_id] if args.key?(:group_id) @instructions = args[:instructions] if args.key?(:instructions) @max_steps = args[:max_steps] if args.key?(:max_steps) @metric_type = args[:metric_type] if args.key?(:metric_type) @output_config = args[:output_config] if args.key?(:output_config) @parent = args[:parent] if args.key?(:parent) @request_id = args[:request_id] if args.key?(:request_id) @task_query = args[:task_query] if args.key?(:task_query) @validate_only = args[:validate_only] if args.key?(:validate_only) end |