Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Diagnostic

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The diagnostic resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Diagnostic

Returns a new instance of GoogleCloudContactcenterinsightsV1Diagnostic.



4682
4683
4684
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_display_nameString

Output only. The display name of the agent associated with the diagnostic. Corresponds to the JSON property agentDisplayName

Returns:

  • (String)


4634
4635
4636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4634

def agent_display_name
  @agent_display_name
end

#agent_idString

Output only. The ID of the agent associated with the diagnostic. Corresponds to the JSON property agentId

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4639

def agent_id
  @agent_id
end

#analysis_summaryString

Output only. The complete sequence of thoughts and actions taken by the agent. Corresponds to the JSON property analysisSummary

Returns:

  • (String)


4644
4645
4646
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4644

def analysis_summary
  @analysis_summary
end

#app_idString

Output only. The application ID associated with the diagnostic. Corresponds to the JSON property appId

Returns:

  • (String)


4649
4650
4651
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4649

def app_id
  @app_id
end

#app_versionString

Output only. The application version associated with the diagnostic. Corresponds to the JSON property appVersion

Returns:

  • (String)


4654
4655
4656
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4654

def app_version
  @app_version
end

#conversation_filterString

Output only. The filter used to select the conversations that were included in the diagnostic. Corresponds to the JSON property conversationFilter

Returns:

  • (String)


4660
4661
4662
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4660

def conversation_filter
  @conversation_filter
end

#create_timeString

Output only. The time at which the diagnostic was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4665
4666
4667
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4665

def create_time
  @create_time
end

#group_create_timeString

Output only. The timestamp when the group was created. Corresponds to the JSON property groupCreateTime

Returns:

  • (String)


4670
4671
4672
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4670

def group_create_time
  @group_create_time
end

#nameString

Immutable. Identifier. The resource name of the diagnostic. Corresponds to the JSON property name

Returns:

  • (String)


4675
4676
4677
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4675

def name
  @name
end

#reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport

A diagnostic report containing loss patterns and problematic slice stats. Corresponds to the JSON property report



4680
4681
4682
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4680

def report
  @report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4687

def update!(**args)
  @agent_display_name = args[:agent_display_name] if args.key?(:agent_display_name)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @analysis_summary = args[:analysis_summary] if args.key?(:analysis_summary)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_version = args[:app_version] if args.key?(:app_version)
  @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter)
  @create_time = args[:create_time] if args.key?(:create_time)
  @group_create_time = args[:group_create_time] if args.key?(:group_create_time)
  @name = args[:name] if args.key?(:name)
  @report = args[:report] if args.key?(:report)
end