Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for an export insights operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata.



4473
4474
4475
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_export_countFixnum

The number of conversations that were exported successfully. Corresponds to the JSON property completedExportCount

Returns:

  • (Fixnum)


4445
4446
4447
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4445

def completed_export_count
  @completed_export_count
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4450
4451
4452
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4450

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


4455
4456
4457
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4455

def end_time
  @end_time
end

#failed_export_countFixnum

The number of conversations that failed to be exported. Corresponds to the JSON property failedExportCount

Returns:

  • (Fixnum)


4460
4461
4462
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4460

def failed_export_count
  @failed_export_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Partial errors during export operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



4466
4467
4468
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4466

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

The request to export insights. Corresponds to the JSON property request



4471
4472
4473
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4471

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4478
4479
4480
4481
4482
4483
4484
4485
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4478

def update!(**args)
  @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
end