Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to export insights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest.



4663
4664
4665
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_destinationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination

A BigQuery Table Reference. Corresponds to the JSON property bigQueryDestination



4633
4634
4635
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4633

def big_query_destination
  @big_query_destination
end

#export_schema_versionString

Optional. Version of the export schema. Corresponds to the JSON property exportSchemaVersion

Returns:

  • (String)


4638
4639
4640
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4638

def export_schema_version
  @export_schema_version
end

#filterString

A filter to reduce results to a specific subset. Useful for exporting conversations with specific properties. Corresponds to the JSON property filter

Returns:

  • (String)


4644
4645
4646
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4644

def filter
  @filter
end

#kms_keyString

A fully qualified KMS key name for BigQuery tables protected by CMEK. Format: projects/project/locations/location/keyRings/keyring/cryptoKeys/key/ cryptoKeyVersions/version Corresponds to the JSON property kmsKey

Returns:

  • (String)


4651
4652
4653
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4651

def kms_key
  @kms_key
end

#parentString

Required. The parent resource to export data from. Corresponds to the JSON property parent

Returns:

  • (String)


4656
4657
4658
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4656

def parent
  @parent
end

#write_dispositionString

Options for what to do if the destination table already exists. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


4661
4662
4663
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4661

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4668
4669
4670
4671
4672
4673
4674
4675
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4668

def update!(**args)
  @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination)
  @export_schema_version = args[:export_schema_version] if args.key?(:export_schema_version)
  @filter = args[:filter] if args.key?(:filter)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @parent = args[:parent] if args.key?(:parent)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end