Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Agent Assist frequently-asked-question answer data.
Instance Attribute Summary collapse
-
#answer ⇒ String
The piece of text from the
sourceknowledge base document. -
#confidence_score ⇒ Float
The system's confidence score that this answer is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain).
-
#metadata ⇒ Hash<String,String>
Map that contains metadata about the FAQ answer and the document that it originates from.
-
#query_record ⇒ String
The name of the answer record.
-
#question ⇒ String
The corresponding FAQ question.
-
#source ⇒ String
The knowledge document that this answer was extracted from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1FaqAnswerData
constructor
A new instance of GoogleCloudContactcenterinsightsV1FaqAnswerData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1FaqAnswerData
Returns a new instance of GoogleCloudContactcenterinsightsV1FaqAnswerData.
4822 4823 4824 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer ⇒ String
The piece of text from the source knowledge base document.
Corresponds to the JSON property answer
4790 4791 4792 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4790 def answer @answer end |
#confidence_score ⇒ Float
The system's confidence score that this answer is a good match for this
conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely
certain).
Corresponds to the JSON property confidenceScore
4797 4798 4799 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4797 def confidence_score @confidence_score end |
#metadata ⇒ Hash<String,String>
Map that contains metadata about the FAQ answer and the document that it
originates from.
Corresponds to the JSON property metadata
4803 4804 4805 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4803 def @metadata end |
#query_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property queryRecord
4809 4810 4811 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4809 def query_record @query_record end |
#question ⇒ String
The corresponding FAQ question.
Corresponds to the JSON property question
4814 4815 4816 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4814 def question @question end |
#source ⇒ String
The knowledge document that this answer was extracted from. Format: projects/
project/knowledgeBases/knowledge_base/documents/document.
Corresponds to the JSON property source
4820 4821 4822 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4820 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4827 4828 4829 4830 4831 4832 4833 4834 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4827 def update!(**args) @answer = args[:answer] if args.key?(:answer) @confidence_score = args[:confidence_score] if args.key?(:confidence_score) @metadata = args[:metadata] if args.key?(:metadata) @query_record = args[:query_record] if args.key?(:query_record) @question = args[:question] if args.key?(:question) @source = args[:source] if args.key?(:source) end |