Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1GcsSource.



4965
4966
4967
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Immutable. Deprecated: Use audio_uris instead. Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


4950
4951
4952
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4950

def audio_uri
  @audio_uri
end

#audio_urisArray<String>

Immutable. Cloud Storage URIs that point to files that contain the conversation audio. Supports both single audio files and multi-leg session recordings (e.g., call transfers, rolling recording buffers). Corresponds to the JSON property audioUris

Returns:

  • (Array<String>)


4957
4958
4959
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4957

def audio_uris
  @audio_uris
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


4963
4964
4965
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4963

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4970
4971
4972
4973
4974
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4970

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @audio_uris = args[:audio_uris] if args.key?(:audio_uris)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end