Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscript
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscript
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation transcript for the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
Output only.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscript
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscript
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscript.
4365 4366 4367 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
4348 4349 4350 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4348 def conversation_id @conversation_id end |
#create_time ⇒ String
Output only. The create time of the conversation.
Corresponds to the JSON property createTime
4353 4354 4355 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4353 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
4358 4359 4360 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4358 def @messages end |
#update_time ⇒ String
Output only. The update time of the conversation.
Corresponds to the JSON property updateTime
4363 4364 4365 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4363 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4370 4371 4372 4373 4374 4375 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4370 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |