Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage.



5103
5104
5105
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_specHash<String,Object>

Chart spec from LLM Corresponds to the JSON property chartSpec

Returns:

  • (Hash<String,Object>)


5081
5082
5083
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5081

def chart_spec
  @chart_spec
end

#generated_sql_queryString

Raw SQL from LLM, before templatization Corresponds to the JSON property generatedSqlQuery

Returns:

  • (String)


5086
5087
5088
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5086

def generated_sql_query
  @generated_sql_query
end

#text_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessageTextOutput

A text output message from the system. Corresponds to the JSON property textMessage



5091
5092
5093
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5091

def text_message
  @text_message
end

#user_provided_chart_specHash<String,Object>

Optional. User provided chart spec Corresponds to the JSON property userProvidedChartSpec

Returns:

  • (Hash<String,Object>)


5096
5097
5098
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5096

def user_provided_chart_spec
  @user_provided_chart_spec
end

#user_provided_sql_queryString

Optional. User provided SQL query Corresponds to the JSON property userProvidedSqlQuery

Returns:

  • (String)


5101
5102
5103
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5101

def user_provided_sql_query
  @user_provided_sql_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5108
5109
5110
5111
5112
5113
5114
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5108

def update!(**args)
  @chart_spec = args[:chart_spec] if args.key?(:chart_spec)
  @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query)
  @text_message = args[:text_message] if args.key?(:text_message)
  @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec)
  @user_provided_sql_query = args[:user_provided_sql_query] if args.key?(:user_provided_sql_query)
end