Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A wrapper for system messages per turn.
Instance Attribute Summary collapse
-
#system_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage>
A message from the system in response to the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages.
4496 4497 4498 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#system_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage>
A message from the system in response to the user.
Corresponds to the JSON property systemMessages
4494 4495 4496 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4494 def @system_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4501 4502 4503 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4501 def update!(**args) @system_messages = args[:system_messages] if args.key?(:system_messages) end |