Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The user message.
Instance Attribute Summary collapse
-
#text ⇒ String
A message from the user that is interacting with the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage.
4515 4516 4517 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#text ⇒ String
A message from the user that is interacting with the system.
Corresponds to the JSON property text
4513 4514 4515 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4513 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4520 4521 4522 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4520 def update!(**args) @text = args[:text] if args.key?(:text) end |