Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation used to generate the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
The create time of the conversation.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
The update time of the conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation.
6111 6112 6113 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
6094 6095 6096 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6094 def conversation_id @conversation_id end |
#create_time ⇒ String
The create time of the conversation.
Corresponds to the JSON property createTime
6099 6100 6101 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6099 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
6104 6105 6106 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6104 def @messages end |
#update_time ⇒ String
The update time of the conversation.
Corresponds to the JSON property updateTime
6109 6110 6111 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6109 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6116 6117 6118 6119 6120 6121 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6116 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |