Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The user message.
Instance Attribute Summary collapse
-
#text ⇒ String
A message from the user that is interacting with the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage.
4745 4746 4747 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#text ⇒ String
A message from the user that is interacting with the system.
Corresponds to the JSON property text
4743 4744 4745 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4743 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4750 4751 4752 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4750 def update!(**args) @text = args[:text] if args.key?(:text) end |