Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for generative insights.
Instance Attribute Summary collapse
-
#error_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
The error message when the generative insights request fails.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsMetadata.
6251 6252 6253 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
The error message when the generative insights request fails.
Corresponds to the JSON property errorMessages
6249 6250 6251 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6249 def @error_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6256 6257 6258 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6256 def update!(**args) @error_messages = args[:error_messages] if args.key?(:error_messages) end |