Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsResponseGenerativeResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Wrapper for storing the generative response for a chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsResponseGenerativeResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsResponseGenerativeResponse.



5565
5566
5567
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_specHash<String,Object>

The chart spec for the data. This will be specified in the vega-lite or vega format. Corresponds to the JSON property chartSpec

Returns:

  • (Hash<String,Object>)


5544
5545
5546
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5544

def chart_spec
  @chart_spec
end

#generated_sql_queryString

The generated SQL query from the LLM. Will be populated during the chart building phase. The generated SQL will be cached in the corresponding chart resource. Corresponds to the JSON property generatedSqlQuery

Returns:

  • (String)


5551
5552
5553
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5551

def generated_sql_query
  @generated_sql_query
end

#text_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsResponseGenerativeResponseTextOutput

Wrapper for text output. Corresponds to the JSON property textMessage



5556
5557
5558
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5556

def text_message
  @text_message
end

#text_outputString

The text output from the LLM. Will be populated during the chart building phase. For a reloaded chart, this will NOT be populated. May contain THOUGHT or a FINAL response or some in-progress response. Corresponds to the JSON property textOutput

Returns:

  • (String)


5563
5564
5565
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5563

def text_output
  @text_output
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5570
5571
5572
5573
5574
5575
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5570

def update!(**args)
  @chart_spec = args[:chart_spec] if args.key?(:chart_spec)
  @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query)
  @text_message = args[:text_message] if args.key?(:text_message)
  @text_output = args[:text_output] if args.key?(:text_output)
end