Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsMetadataIngestConversationsStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for IngestConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IngestConversationsMetadataIngestConversationsStats

Returns a new instance of GoogleCloudContactcenterinsightsV1IngestConversationsMetadataIngestConversationsStats.



5756
5757
5758
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duplicates_skipped_countFixnum

Output only. The number of objects skipped because another conversation with the same transcript uri had already been ingested. Corresponds to the JSON property duplicatesSkippedCount

Returns:

  • (Fixnum)


5737
5738
5739
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5737

def duplicates_skipped_count
  @duplicates_skipped_count
end

#failed_ingest_countFixnum

Output only. The number of objects which were unable to be ingested due to errors. The errors are populated in the partial_errors field. Corresponds to the JSON property failedIngestCount

Returns:

  • (Fixnum)


5743
5744
5745
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5743

def failed_ingest_count
  @failed_ingest_count
end

#processed_object_countFixnum

Output only. The number of objects processed during the ingest operation. Corresponds to the JSON property processedObjectCount

Returns:

  • (Fixnum)


5748
5749
5750
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5748

def processed_object_count
  @processed_object_count
end

#successful_ingest_countFixnum

Output only. The number of new conversations added during this ingest operation. Corresponds to the JSON property successfulIngestCount

Returns:

  • (Fixnum)


5754
5755
5756
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5754

def successful_ingest_count
  @successful_ingest_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5761
5762
5763
5764
5765
5766
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5761

def update!(**args)
  @duplicates_skipped_count = args[:duplicates_skipped_count] if args.key?(:duplicates_skipped_count)
  @failed_ingest_count = args[:failed_ingest_count] if args.key?(:failed_ingest_count)
  @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count)
  @successful_ingest_count = args[:successful_ingest_count] if args.key?(:successful_ingest_count)
end