Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Configuration for Cloud Storage bucket sources.
Instance Attribute Summary collapse
-
#audio_bucket_uri ⇒ String
Optional.
-
#bucket_object_type ⇒ String
Optional.
-
#bucket_uri ⇒ String
Optional.
-
#custom_metadata_keys ⇒ Array<String>
Optional.
-
#metadata_bucket_uri ⇒ String
Optional.
-
#transcript_bucket_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource
Returns a new instance of GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource.
6132 6133 6134 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_bucket_uri ⇒ String
Optional. The Cloud Storage path to the conversation audio file. Note that: [1]
Audio files will be transcribed if not already. [2] Audio files and
transcript files must be in separate buckets / folders. [3] A source file and
its corresponding audio file must share the same name to be properly ingested,
E.g. gs://bucket/transcript/conversation1.json and gs://bucket/audio/
conversation1.mp3.
Corresponds to the JSON property audioBucketUri
6091 6092 6093 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6091 def audio_bucket_uri @audio_bucket_uri end |
#bucket_object_type ⇒ String
Optional. Specifies the type of the objects in bucket_uri. Avoid passing
this. This is inferred from the transcript_bucket_uri, audio_bucket_uri.
Corresponds to the JSON property bucketObjectType
6097 6098 6099 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6097 def bucket_object_type @bucket_object_type end |
#bucket_uri ⇒ String
Optional. The Cloud Storage bucket containing source objects. Avoid passing
this. Pass this through one of transcript_bucket_uri or audio_bucket_uri.
Corresponds to the JSON property bucketUri
6103 6104 6105 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6103 def bucket_uri @bucket_uri end |
#custom_metadata_keys ⇒ Array<String>
Optional. Custom keys to extract as conversation labels from metadata files in
metadata_bucket_uri. Keys not included in this field will be ignored. Note
that there is a limit of 100 labels per conversation.
Corresponds to the JSON property customMetadataKeys
6110 6111 6112 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6110 def @custom_metadata_keys end |
#metadata_bucket_uri ⇒ String
Optional. The Cloud Storage path to the conversation metadata. Note that: [1]
Metadata files are expected to be in JSON format. [2] Metadata and source
files (transcripts or audio) must be in separate buckets / folders. [3] A
source file and its corresponding metadata file must share the same name to be
properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/
metadata/conversation1.json.
Corresponds to the JSON property metadataBucketUri
6120 6121 6122 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6120 def @metadata_bucket_uri end |
#transcript_bucket_uri ⇒ String
Optional. The Cloud Storage path to the conversation transcripts. Note that: [
1] Transcript files are expected to be in JSON format. [2] Transcript, audio,
metadata files must be in separate buckets / folders. [3] A source file and
its corresponding metadata file must share the same name to be properly
ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/metadata/
conversation1.json.
Corresponds to the JSON property transcriptBucketUri
6130 6131 6132 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6130 def transcript_bucket_uri @transcript_bucket_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6137 6138 6139 6140 6141 6142 6143 6144 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6137 def update!(**args) @audio_bucket_uri = args[:audio_bucket_uri] if args.key?(:audio_bucket_uri) @bucket_object_type = args[:bucket_object_type] if args.key?(:bucket_object_type) @bucket_uri = args[:bucket_uri] if args.key?(:bucket_uri) @custom_metadata_keys = args[:custom_metadata_keys] if args.key?(:custom_metadata_keys) @metadata_bucket_uri = args[:metadata_bucket_uri] if args.key?(:metadata_bucket_uri) @transcript_bucket_uri = args[:transcript_bucket_uri] if args.key?(:transcript_bucket_uri) end |