Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IntentMatchData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The data for an intent match. Represents an intent match for a text segment in the conversation. A text segment can be part of a sentence, a complete sentence, or an utterance with multiple sentences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IntentMatchData

Returns a new instance of GoogleCloudContactcenterinsightsV1IntentMatchData.



6953
6954
6955
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intent_unique_idString

The id of the matched intent. Can be used to retrieve the corresponding intent information. Corresponds to the JSON property intentUniqueId

Returns:

  • (String)


6951
6952
6953
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6951

def intent_unique_id
  @intent_unique_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6958
6959
6960
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6958

def update!(**args)
  @intent_unique_id = args[:intent_unique_id] if args.key?(:intent_unique_id)
end