Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Issue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Issue

Returns a new instance of GoogleCloudContactcenterinsightsV1Issue.



6033
6034
6035
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6004
6005
6006
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6004

def create_time
  @create_time
end

#display_descriptionString

Representative description of the issue. Corresponds to the JSON property displayDescription

Returns:

  • (String)


6009
6010
6011
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6009

def display_description
  @display_description
end

#display_nameString

The representative name for the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


6014
6015
6016
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6014

def display_name
  @display_name
end

#nameString

Immutable. The resource name of the issue. Format: projects/project/ locations/location/issueModels/issue_model/issues/issue Corresponds to the JSON property name

Returns:

  • (String)


6020
6021
6022
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6020

def name
  @name
end

#sample_utterancesArray<String>

Output only. Resource names of the sample representative utterances that match to this issue. Corresponds to the JSON property sampleUtterances

Returns:

  • (Array<String>)


6026
6027
6028
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6026

def sample_utterances
  @sample_utterances
end

#update_timeString

Output only. The most recent time that this issue was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6031
6032
6033
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6031

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6038
6039
6040
6041
6042
6043
6044
6045
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6038

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_description = args[:display_description] if args.key?(:display_description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances)
  @update_time = args[:update_time] if args.key?(:update_time)
end