Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue model resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The representative name for the issue model.
-
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
-
#issue_count ⇒ Fixnum
Output only.
-
#language_code ⇒ String
Language of the model.
-
#model_type ⇒ String
Type of the model.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats
Aggregated statistics about an issue model.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModel
constructor
A new instance of GoogleCloudContactcenterinsightsV1IssueModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModel
Returns a new instance of GoogleCloudContactcenterinsightsV1IssueModel.
6302 6303 6304 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue model was created.
Corresponds to the JSON property createTime
6254 6255 6256 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6254 def create_time @create_time end |
#display_name ⇒ String
The representative name for the issue model.
Corresponds to the JSON property displayName
6259 6260 6261 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6259 def display_name @display_name end |
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
Corresponds to the JSON property inputDataConfig
6264 6265 6266 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6264 def input_data_config @input_data_config end |
#issue_count ⇒ Fixnum
Output only. Number of issues in this issue model.
Corresponds to the JSON property issueCount
6269 6270 6271 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6269 def issue_count @issue_count end |
#language_code ⇒ String
Language of the model.
Corresponds to the JSON property languageCode
6274 6275 6276 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6274 def language_code @language_code end |
#model_type ⇒ String
Type of the model.
Corresponds to the JSON property modelType
6279 6280 6281 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6279 def model_type @model_type end |
#name ⇒ String
Immutable. The resource name of the issue model. Format: projects/project/
locations/location/issueModels/issue_model
Corresponds to the JSON property name
6285 6286 6287 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6285 def name @name end |
#state ⇒ String
Output only. State of the model.
Corresponds to the JSON property state
6290 6291 6292 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6290 def state @state end |
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats
Aggregated statistics about an issue model.
Corresponds to the JSON property trainingStats
6295 6296 6297 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6295 def training_stats @training_stats end |
#update_time ⇒ String
Output only. The most recent time at which the issue model was updated.
Corresponds to the JSON property updateTime
6300 6301 6302 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6300 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 6317 6318 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6307 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @input_data_config = args[:input_data_config] if args.key?(:input_data_config) @issue_count = args[:issue_count] if args.key?(:issue_count) @language_code = args[:language_code] if args.key?(:language_code) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @training_stats = args[:training_stats] if args.key?(:training_stats) @update_time = args[:update_time] if args.key?(:update_time) end |