Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ListDashboardsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response of listing dashboards.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ListDashboardsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1ListDashboardsResponse.



6069
6070
6071
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dashboardsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dashboard>

The dashboards under the parent. Corresponds to the JSON property dashboards



6060
6061
6062
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6060

def dashboards
  @dashboards
end

#next_page_tokenString

The value returned by the last ListDashboardsResponse. This value indicates that this is a continuation of a prior ListDashboards call and that the system should return the next page of data. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6067
6068
6069
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6067

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6074
6075
6076
6077
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6074

def update!(**args)
  @dashboards = args[:dashboards] if args.key?(:dashboards)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end