Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPatternLink

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A link to a conversation or bot instruction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1LossPatternLink

Returns a new instance of GoogleCloudContactcenterinsightsV1LossPatternLink.



7959
7960
7961
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

A link to a bot instruction. Corresponds to the JSON property botInstructionLink



7932
7933
7934
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7932

def bot_instruction_link
  @bot_instruction_link
end

A link to a conversation. Corresponds to the JSON property conversationLink



7937
7938
7939
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7937

def conversation_link
  @conversation_link
end

#end_byte_indexFixnum

The end byte index of the highlighted text (exclusive). Corresponds to the JSON property endByteIndex

Returns:

  • (Fixnum)


7942
7943
7944
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7942

def end_byte_index
  @end_byte_index
end

#highlighted_textString

The text that is highlighted. (populated for debugging purposes) Corresponds to the JSON property highlightedText

Returns:

  • (String)


7947
7948
7949
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7947

def highlighted_text
  @highlighted_text
end

#location_typeString

The location type. Corresponds to the JSON property locationType

Returns:

  • (String)


7952
7953
7954
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7952

def location_type
  @location_type
end

#start_byte_indexFixnum

The start byte index of the highlighted text (inclusive). Corresponds to the JSON property startByteIndex

Returns:

  • (Fixnum)


7957
7958
7959
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7957

def start_byte_index
  @start_byte_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7964
7965
7966
7967
7968
7969
7970
7971
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7964

def update!(**args)
  @bot_instruction_link = args[:bot_instruction_link] if args.key?(:bot_instruction_link)
  @conversation_link = args[:conversation_link] if args.key?(:conversation_link)
  @end_byte_index = args[:end_byte_index] if args.key?(:end_byte_index)
  @highlighted_text = args[:highlighted_text] if args.key?(:highlighted_text)
  @location_type = args[:location_type] if args.key?(:location_type)
  @start_byte_index = args[:start_byte_index] if args.key?(:start_byte_index)
end