Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricDefinition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A definition for a metric to be calculated during analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1MetricDefinition

Returns a new instance of GoogleCloudContactcenterinsightsV1MetricDefinition.



6874
6875
6876
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The user-visible name of the metric (e.g., "Containment Rate"). Corresponds to the JSON property displayName

Returns:

  • (String)


6866
6867
6868
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6866

def display_name
  @display_name
end

#source_idString

Output only. The resource name of the underlying Insights primitive (e.g., Tag or QaQuestion) used to calculate this metric. Corresponds to the JSON property sourceId

Returns:

  • (String)


6872
6873
6874
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6872

def source_id
  @source_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6879
6880
6881
6882
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6879

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @source_id = args[:source_id] if args.key?(:source_id)
end