Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1NoteConversationTurnNote
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1NoteConversationTurnNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A note about a conversation turn.
Instance Attribute Summary collapse
-
#turn_index ⇒ Fixnum
The conversation turn index that the note is associated with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1NoteConversationTurnNote
constructor
A new instance of GoogleCloudContactcenterinsightsV1NoteConversationTurnNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1NoteConversationTurnNote
Returns a new instance of GoogleCloudContactcenterinsightsV1NoteConversationTurnNote.
5061 5062 5063 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#turn_index ⇒ Fixnum
The conversation turn index that the note is associated with.
Corresponds to the JSON property turnIndex
5059 5060 5061 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5059 def turn_index @turn_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5066 5067 5068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5066 def update!(**args) @turn_index = args[:turn_index] if args.key?(:turn_index) end |