Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1NoteQaQuestionNote
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1NoteQaQuestionNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A note about a QA question.
Instance Attribute Summary collapse
-
#qa_question ⇒ String
The question resource that the note is associated with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1NoteQaQuestionNote
constructor
A new instance of GoogleCloudContactcenterinsightsV1NoteQaQuestionNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1NoteQaQuestionNote
Returns a new instance of GoogleCloudContactcenterinsightsV1NoteQaQuestionNote.
5080 5081 5082 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#qa_question ⇒ String
The question resource that the note is associated with.
Corresponds to the JSON property qaQuestion
5078 5079 5080 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5078 def qa_question @qa_question end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5085 5086 5087 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5085 def update!(**args) @qa_question = args[:qa_question] if args.key?(:qa_question) end |