Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The data for a phrase match rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatchRule

Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatchRule.



8377
8378
8379
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig

Configuration information of a phrase match rule. Corresponds to the JSON property config



8363
8364
8365
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8363

def config
  @config
end

#negatedBoolean Also known as: negated?

Specifies whether the phrase must be missing from the transcript segment or present in the transcript segment. Corresponds to the JSON property negated

Returns:

  • (Boolean)


8369
8370
8371
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8369

def negated
  @negated
end

#queryString

Required. The phrase to be matched. Corresponds to the JSON property query

Returns:

  • (String)


8375
8376
8377
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8375

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8382
8383
8384
8385
8386
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8382

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @negated = args[:negated] if args.key?(:negated)
  @query = args[:query] if args.key?(:query)
end