Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The phrase matcher resource.
Instance Attribute Summary collapse
-
#activation_update_time ⇒ String
Output only.
-
#active ⇒ Boolean
(also: #active?)
Applies the phrase matcher only when it is active.
-
#display_name ⇒ String
The human-readable name of the phrase matcher.
-
#name ⇒ String
The resource name of the phrase matcher.
-
#phrase_match_rule_groups ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>
A list of phase match rule groups that are included in this matcher.
-
#revision_create_time ⇒ String
Output only.
-
#revision_id ⇒ String
Output only.
-
#role_match ⇒ String
The role whose utterances the phrase matcher should be matched against.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
-
#version_tag ⇒ String
The customized version tag to use for the phrase matcher.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher
constructor
A new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher
Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.
7170 7171 7172 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_update_time ⇒ String
Output only. The most recent time at which the activation status was updated.
Corresponds to the JSON property activationUpdateTime
7109 7110 7111 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7109 def activation_update_time @activation_update_time end |
#active ⇒ Boolean Also known as: active?
Applies the phrase matcher only when it is active.
Corresponds to the JSON property active
7114 7115 7116 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7114 def active @active end |
#display_name ⇒ String
The human-readable name of the phrase matcher.
Corresponds to the JSON property displayName
7120 7121 7122 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7120 def display_name @display_name end |
#name ⇒ String
The resource name of the phrase matcher. Format: projects/project/locations/
location/phraseMatchers/phrase_matcher
Corresponds to the JSON property name
7126 7127 7128 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7126 def name @name end |
#phrase_match_rule_groups ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>
A list of phase match rule groups that are included in this matcher.
Corresponds to the JSON property phraseMatchRuleGroups
7131 7132 7133 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7131 def phrase_match_rule_groups @phrase_match_rule_groups end |
#revision_create_time ⇒ String
Output only. The timestamp of when the revision was created. It is also the
create time when a new matcher is added.
Corresponds to the JSON property revisionCreateTime
7137 7138 7139 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7137 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Output only. Immutable. The revision ID of the phrase matcher. A new revision
is committed whenever the matcher is changed, except when it is activated or
deactivated. A server generated random ID will be used. Example: locations/
global/phraseMatchers/my-first-matcher@1234567
Corresponds to the JSON property revisionId
7145 7146 7147 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7145 def revision_id @revision_id end |
#role_match ⇒ String
The role whose utterances the phrase matcher should be matched against. If the
role is ROLE_UNSPECIFIED it will be matched against any utterances in the
transcript.
Corresponds to the JSON property roleMatch
7152 7153 7154 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7152 def role_match @role_match end |
#type ⇒ String
Required. The type of this phrase matcher.
Corresponds to the JSON property type
7157 7158 7159 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7157 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the phrase matcher was updated.
Corresponds to the JSON property updateTime
7162 7163 7164 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7162 def update_time @update_time end |
#version_tag ⇒ String
The customized version tag to use for the phrase matcher. If not specified, it
will default to revision_id.
Corresponds to the JSON property versionTag
7168 7169 7170 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7168 def version_tag @version_tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 7186 7187 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7175 def update!(**args) @activation_update_time = args[:activation_update_time] if args.key?(:activation_update_time) @active = args[:active] if args.key?(:active) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @phrase_match_rule_groups = args[:phrase_match_rule_groups] if args.key?(:phrase_match_rule_groups) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @role_match = args[:role_match] if args.key?(:role_match) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @version_tag = args[:version_tag] if args.key?(:version_tag) end |