Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A single question to be scored by the Insights QA feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestion

Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestion.



7585
7586
7587
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abbreviationString

Short, descriptive string, used in the UI where it's not practical to display the full question body. E.g., "Greeting". Corresponds to the JSON property abbreviation

Returns:

  • (String)


7507
7508
7509
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7507

def abbreviation
  @abbreviation
end

#answer_choicesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice>

A list of valid answers to the question, which the LLM must choose from. Corresponds to the JSON property answerChoices



7512
7513
7514
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7512

def answer_choices
  @answer_choices
end

#answer_instructionsString

Instructions describing how to determine the answer. Corresponds to the JSON property answerInstructions

Returns:

  • (String)


7517
7518
7519
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7517

def answer_instructions
  @answer_instructions
end

#create_timeString

Output only. The time at which this question was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7522
7523
7524
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7522

def create_time
  @create_time
end

#metricsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionMetrics

A wrapper representing metrics calculated against a test-set on a LLM that was fine tuned for this question. Corresponds to the JSON property metrics



7528
7529
7530
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7528

def metrics
  @metrics
end

#nameString

Identifier. The resource name of the question. Format: projects/project/ locations/location/qaScorecards/qa_scorecard/revisions/revision/ qaQuestions/qa_question Corresponds to the JSON property name

Returns:

  • (String)


7535
7536
7537
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7535

def name
  @name
end

#orderFixnum

Defines the order of the question within its parent scorecard revision. Corresponds to the JSON property order

Returns:

  • (Fixnum)


7540
7541
7542
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7540

def order
  @order
end

#predefined_question_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionPredefinedQuestionConfig

Configuration for a predefined question. This field will only be set if the Question Type is predefined. Corresponds to the JSON property predefinedQuestionConfig



7546
7547
7548
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7546

def predefined_question_config
  @predefined_question_config
end

#qa_question_data_optionsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions

Options for configuring the data used to generate the QA question. Corresponds to the JSON property qaQuestionDataOptions



7551
7552
7553
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7551

def qa_question_data_options
  @qa_question_data_options
end

#question_bodyString

Question text. E.g., "Did the agent greet the customer?" Corresponds to the JSON property questionBody

Returns:

  • (String)


7556
7557
7558
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7556

def question_body
  @question_body
end

#question_typeString

The type of question. Corresponds to the JSON property questionType

Returns:

  • (String)


7561
7562
7563
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7561

def question_type
  @question_type
end

#tagsArray<String>

Questions are tagged for categorization and scoring. Tags can either be: - Default Tags: These are predefined categories. They are identified by their string value (e.g., "BUSINESS", "COMPLIANCE", and "CUSTOMER"). - Custom Tags: These are user-defined categories. They are identified by their full resource name (e.g., projects/project/locations/location/qaQuestionTags/ qa_question_tag). Both default and custom tags are used to group questions and to influence the scoring of each question. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


7572
7573
7574
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7572

def tags
  @tags
end

#tuning_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata

Metadata about the tuning operation for the question. Will only be set if a scorecard containing this question has been tuned. Corresponds to the JSON property tuningMetadata



7578
7579
7580
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7578

def 
  @tuning_metadata
end

#update_timeString

Output only. The most recent time at which the question was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7583
7584
7585
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7583

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7590
7591
7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7590

def update!(**args)
  @abbreviation = args[:abbreviation] if args.key?(:abbreviation)
  @answer_choices = args[:answer_choices] if args.key?(:answer_choices)
  @answer_instructions = args[:answer_instructions] if args.key?(:answer_instructions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @order = args[:order] if args.key?(:order)
  @predefined_question_config = args[:predefined_question_config] if args.key?(:predefined_question_config)
  @qa_question_data_options = args[:qa_question_data_options] if args.key?(:qa_question_data_options)
  @question_body = args[:question_body] if args.key?(:question_body)
  @question_type = args[:question_type] if args.key?(:question_type)
  @tags = args[:tags] if args.key?(:tags)
  @tuning_metadata = args[:tuning_metadata] if args.key?(:tuning_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end