Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message representing a possible answer to the question.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#key ⇒ String
A short string used as an identifier.
-
#na_value ⇒ Boolean
(also: #na_value?)
A value of "Not Applicable (N/A)".
-
#num_value ⇒ Float
Numerical value.
-
#score ⇒ Float
Numerical score of the answer, used for generating the overall score of a QaScorecardResult.
-
#str_value ⇒ String
String value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.
7688 7689 7690 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
7656 7657 7658 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7656 def bool_value @bool_value end |
#key ⇒ String
A short string used as an identifier.
Corresponds to the JSON property key
7662 7663 7664 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7662 def key @key end |
#na_value ⇒ Boolean Also known as: na_value?
A value of "Not Applicable (N/A)". If provided, this field may only be set to
true. If a question receives this answer, it will be excluded from any score
calculations.
Corresponds to the JSON property naValue
7669 7670 7671 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7669 def na_value @na_value end |
#num_value ⇒ Float
Numerical value.
Corresponds to the JSON property numValue
7675 7676 7677 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7675 def num_value @num_value end |
#score ⇒ Float
Numerical score of the answer, used for generating the overall score of a
QaScorecardResult. If the answer uses na_value, this field is unused.
Corresponds to the JSON property score
7681 7682 7683 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7681 def score @score end |
#str_value ⇒ String
String value.
Corresponds to the JSON property strValue
7686 7687 7688 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7686 def str_value @str_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7693 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @key = args[:key] if args.key?(:key) @na_value = args[:na_value] if args.key?(:na_value) @num_value = args[:num_value] if args.key?(:num_value) @score = args[:score] if args.key?(:score) @str_value = args[:str_value] if args.key?(:str_value) end |