Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata about the tuning operation for the question. Will only be set if a scorecard containing this question has been tuned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata.



7664
7665
7666
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_validation_warningsArray<String>

A list of any applicable data validation warnings about the question's feedback labels. Corresponds to the JSON property datasetValidationWarnings

Returns:

  • (Array<String>)


7651
7652
7653
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7651

def dataset_validation_warnings
  @dataset_validation_warnings
end

#total_valid_label_countFixnum

Total number of valid labels provided for the question at the time of tuining. Corresponds to the JSON property totalValidLabelCount

Returns:

  • (Fixnum)


7656
7657
7658
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7656

def total_valid_label_count
  @total_valid_label_count
end

#tuning_errorString

Error status of the tuning operation for the question. Will only be set if the tuning operation failed. Corresponds to the JSON property tuningError

Returns:

  • (String)


7662
7663
7664
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7662

def tuning_error
  @tuning_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7669
7670
7671
7672
7673
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7669

def update!(**args)
  @dataset_validation_warnings = args[:dataset_validation_warnings] if args.key?(:dataset_validation_warnings)
  @total_valid_label_count = args[:total_valid_label_count] if args.key?(:total_valid_label_count)
  @tuning_error = args[:tuning_error] if args.key?(:tuning_error)
end