Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A QaScorecard represents a collection of questions to be scored during analysis.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A text description explaining the intent of the scorecard.
-
#display_name ⇒ String
The user-specified display name of the scorecard.
-
#is_default ⇒ Boolean
(also: #is_default?)
Whether the scorecard is the default one for the project.
-
#name ⇒ String
Identifier.
-
#source ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecard
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaScorecard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecard
Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecard.
7713 7714 7715 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this scorecard was created.
Corresponds to the JSON property createTime
7678 7679 7680 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7678 def create_time @create_time end |
#description ⇒ String
A text description explaining the intent of the scorecard.
Corresponds to the JSON property description
7683 7684 7685 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7683 def description @description end |
#display_name ⇒ String
The user-specified display name of the scorecard.
Corresponds to the JSON property displayName
7688 7689 7690 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7688 def display_name @display_name end |
#is_default ⇒ Boolean Also known as: is_default?
Whether the scorecard is the default one for the project. A default scorecard
cannot be deleted and will always appear first in scorecard selector.
Corresponds to the JSON property isDefault
7694 7695 7696 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7694 def is_default @is_default end |
#name ⇒ String
Identifier. The scorecard name. Format: projects/project/locations/location
/qaScorecards/qa_scorecard
Corresponds to the JSON property name
7701 7702 7703 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7701 def name @name end |
#source ⇒ String
Output only. The source of the scorecard.
Corresponds to the JSON property source
7706 7707 7708 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7706 def source @source end |
#update_time ⇒ String
Output only. The most recent time at which the scorecard was updated.
Corresponds to the JSON property updateTime
7711 7712 7713 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7711 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7718 7719 7720 7721 7722 7723 7724 7725 7726 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7718 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @is_default = args[:is_default] if args.key?(:is_default) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |