Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response for querying metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsResponse.



9428
9429
9430
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Required. The location of the data. "projects/project/locations/location" Corresponds to the JSON property location

Returns:

  • (String)


9403
9404
9405
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9403

def location
  @location
end

#macro_average_sliceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSlice

A slice contains a total and (if the request specified a time granularity) a time series of metric values. Each slice contains a unique combination of the cardinality of dimensions from the request. For example, if the request specifies a single ISSUE dimension and it has a cardinality of 2 (i.e. the data used to compute the metrics has 2 issues in total), the response will have 2 slices: * Slice 1 -> dimensions=[Issue 1] * Slice 2 -> dimensions=[ Issue 2] Corresponds to the JSON property macroAverageSlice



9414
9415
9416
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9414

def macro_average_slice
  @macro_average_slice
end

#slicesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSlice>

A slice contains a total and (if the request specified a time granularity) a time series of metric values. Each slice contains a unique combination of the cardinality of dimensions from the request. Corresponds to the JSON property slices



9421
9422
9423
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9421

def slices
  @slices
end

#update_timeString

The metrics last update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


9426
9427
9428
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9426

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9433
9434
9435
9436
9437
9438
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9433

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @macro_average_slice = args[:macro_average_slice] if args.key?(:macro_average_slice)
  @slices = args[:slices] if args.key?(:slices)
  @update_time = args[:update_time] if args.key?(:update_time)
end