Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A data point contains the metric values mapped to an interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint

Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint.



8341
8342
8343
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_measureGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasure

The measure related to conversations. Corresponds to the JSON property conversationMeasure



8326
8327
8328
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8326

def conversation_measure
  @conversation_measure
end

#dialogflow_interaction_measureGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointDialogflowInteractionMeasure

The measure related to dialogflow interactions. Corresponds to the JSON property dialogflowInteractionMeasure



8331
8332
8333
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8331

def dialogflow_interaction_measure
  @dialogflow_interaction_measure
end

#intervalGoogle::Apis::ContactcenterinsightsV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



8339
8340
8341
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8339

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8346
8347
8348
8349
8350
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8346

def update!(**args)
  @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure)
  @dialogflow_interaction_measure = args[:dialogflow_interaction_measure] if args.key?(:dialogflow_interaction_measure)
  @interval = args[:interval] if args.key?(:interval)
end