Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The measure related to conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasure

Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasure.



6281
6282
6283
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_agent_sentiment_scoreFloat

The average agent's sentiment score. Corresponds to the JSON property averageAgentSentimentScore

Returns:

  • (Float)


6228
6229
6230
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6228

def average_agent_sentiment_score
  @average_agent_sentiment_score
end

#average_client_sentiment_scoreFloat

The average client's sentiment score. Corresponds to the JSON property averageClientSentimentScore

Returns:

  • (Float)


6233
6234
6235
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6233

def average_client_sentiment_score
  @average_client_sentiment_score
end

#average_customer_satisfaction_ratingFloat

The average customer satisfaction rating. Corresponds to the JSON property averageCustomerSatisfactionRating

Returns:

  • (Float)


6238
6239
6240
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6238

def average_customer_satisfaction_rating
  @average_customer_satisfaction_rating
end

#average_durationString

The average duration. Corresponds to the JSON property averageDuration

Returns:

  • (String)


6243
6244
6245
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6243

def average_duration
  @average_duration
end

#average_qa_normalized_scoreFloat

The average normalized QA score for a scorecard. When computing the average across a set of conversations, if a conversation has been evaluated with multiple revisions of a scorecard, only the latest revision results will be used. Will exclude 0's in average calculation. Will be only populated if the request specifies a dimension of QA_SCORECARD_ID. Corresponds to the JSON property averageQaNormalizedScore

Returns:

  • (Float)


6252
6253
6254
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6252

def average_qa_normalized_score
  @average_qa_normalized_score
end

#average_qa_question_normalized_scoreFloat

Average QA normalized score averaged for questions averaged across all revisions of the parent scorecard. Will be only populated if the request specifies a dimension of QA_QUESTION_ID. Corresponds to the JSON property averageQaQuestionNormalizedScore

Returns:

  • (Float)


6259
6260
6261
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6259

def average_qa_question_normalized_score
  @average_qa_question_normalized_score
end

#average_silence_percentageFloat

The average silence percentage. Corresponds to the JSON property averageSilencePercentage

Returns:

  • (Float)


6264
6265
6266
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6264

def average_silence_percentage
  @average_silence_percentage
end

#average_turn_countFloat

The average turn count. Corresponds to the JSON property averageTurnCount

Returns:

  • (Float)


6269
6270
6271
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6269

def average_turn_count
  @average_turn_count
end

#conversation_countFixnum

The conversation count. Corresponds to the JSON property conversationCount

Returns:

  • (Fixnum)


6274
6275
6276
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6274

def conversation_count
  @conversation_count
end

#qa_tag_scoresArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasureQaTagScore>

Average QA normalized score for all the tags. Corresponds to the JSON property qaTagScores



6279
6280
6281
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6279

def qa_tag_scores
  @qa_tag_scores
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6286

def update!(**args)
  @average_agent_sentiment_score = args[:average_agent_sentiment_score] if args.key?(:average_agent_sentiment_score)
  @average_client_sentiment_score = args[:average_client_sentiment_score] if args.key?(:average_client_sentiment_score)
  @average_customer_satisfaction_rating = args[:average_customer_satisfaction_rating] if args.key?(:average_customer_satisfaction_rating)
  @average_duration = args[:average_duration] if args.key?(:average_duration)
  @average_qa_normalized_score = args[:average_qa_normalized_score] if args.key?(:average_qa_normalized_score)
  @average_qa_question_normalized_score = args[:average_qa_question_normalized_score] if args.key?(:average_qa_question_normalized_score)
  @average_silence_percentage = args[:average_silence_percentage] if args.key?(:average_silence_percentage)
  @average_turn_count = args[:average_turn_count] if args.key?(:average_turn_count)
  @conversation_count = args[:conversation_count] if args.key?(:conversation_count)
  @qa_tag_scores = args[:qa_tag_scores] if args.key?(:qa_tag_scores)
end