Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1RuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1RuntimeAnnotation.



9058
9059
9060
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


8991
8992
8993
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8991

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



8996
8997
8998
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8996

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



9001
9002
9003
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9001

def article_suggestion
  @article_suggestion
end

#ces_end_session_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesEndSessionAnnotation

The CES end session annotation. Corresponds to the JSON property cesEndSessionAnnotation



9006
9007
9008
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9006

def ces_end_session_annotation
  @ces_end_session_annotation
end

#ces_turn_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation

The CES diagnostic information. Corresponds to the JSON property cesTurnAnnotation



9011
9012
9013
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9011

def ces_turn_annotation
  @ces_turn_annotation
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



9016
9017
9018
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9016

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9021
9022
9023
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9021

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



9026
9027
9028
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9026

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



9031
9032
9033
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9031

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



9036
9037
9038
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9036

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



9041
9042
9043
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9041

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



9046
9047
9048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9046

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



9051
9052
9053
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9051

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



9056
9057
9058
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9056

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9063

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation)
  @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end