Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to sample conversations to a dataset.
Instance Attribute Summary collapse
-
#destination_dataset ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic) Corresponds to the JSON property
destinationDataset. -
#parent ⇒ String
Required.
-
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1SampleConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1SampleConversationsRequest.
6694 6695 6696 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_dataset ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
Dataset resource represents a collection of conversations that may be bounded (
Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic
Dataset, e.g. live traffic, or agent training traffic)
Corresponds to the JSON property destinationDataset
6682 6683 6684 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6682 def destination_dataset @destination_dataset end |
#parent ⇒ String
Required. The parent resource of the dataset.
Corresponds to the JSON property parent
6687 6688 6689 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6687 def parent @parent end |
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
Corresponds to the JSON property sampleRule
6692 6693 6694 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6692 def sample_rule @sample_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6699 6700 6701 6702 6703 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6699 def update!(**args) @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset) @parent = args[:parent] if args.key?(:parent) @sample_rule = args[:sample_rule] if args.key?(:sample_rule) end |