Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Default configuration when creating Analyses in Insights.
Instance Attribute Summary collapse
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#runtime_integration_analysis_percentage ⇒ Float
Percentage of conversations created using Dialogflow runtime integration to analyze automatically, between [0, 100].
-
#upload_conversation_analysis_percentage ⇒ Float
Percentage of conversations created using the UploadConversation endpoint to analyze automatically, between [0, 100].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
constructor
A new instance of GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
Returns a new instance of GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig.
9376 9377 9378 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
9362 9363 9364 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9362 def annotator_selector @annotator_selector end |
#runtime_integration_analysis_percentage ⇒ Float
Percentage of conversations created using Dialogflow runtime integration to
analyze automatically, between [0, 100].
Corresponds to the JSON property runtimeIntegrationAnalysisPercentage
9368 9369 9370 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9368 def runtime_integration_analysis_percentage @runtime_integration_analysis_percentage end |
#upload_conversation_analysis_percentage ⇒ Float
Percentage of conversations created using the UploadConversation endpoint to
analyze automatically, between [0, 100].
Corresponds to the JSON property uploadConversationAnalysisPercentage
9374 9375 9376 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9374 def upload_conversation_analysis_percentage @upload_conversation_analysis_percentage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9381 9382 9383 9384 9385 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9381 def update!(**args) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @runtime_integration_analysis_percentage = args[:runtime_integration_analysis_percentage] if args.key?(:runtime_integration_analysis_percentage) @upload_conversation_analysis_percentage = args[:upload_conversation_analysis_percentage] if args.key?(:upload_conversation_analysis_percentage) end |