Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist Smart Compose suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData.



7070
7071
7072
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The system's confidence score that this suggestion is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


7051
7052
7053
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7051

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the Smart Compose suggestion and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


7057
7058
7059
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7057

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


7063
7064
7065
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7063

def query_record
  @query_record
end

#suggestionString

The content of the suggestion. Corresponds to the JSON property suggestion

Returns:

  • (String)


7068
7069
7070
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7068

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7075
7076
7077
7078
7079
7080
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7075

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end