Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartReplyData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist Smart Reply data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SmartReplyData

Returns a new instance of GoogleCloudContactcenterinsightsV1SmartReplyData.



10851
10852
10853
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The system's confidence score that this reply is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


10832
10833
10834
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10832

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the Smart Reply and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


10838
10839
10840
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10838

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


10844
10845
10846
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10844

def query_record
  @query_record
end

#replyString

The content of the reply. Corresponds to the JSON property reply

Returns:

  • (String)


10849
10850
10851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10849

def reply
  @reply
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10856
10857
10858
10859
10860
10861
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10856

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @reply = args[:reply] if args.key?(:reply)
end