Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Statistics for TestCorrelationConfig operation.
Instance Attribute Summary collapse
-
#conversation_correlation_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError>
A list of errors that occurred during correlation, one for each conversation that failed.
-
#correlated_conversations_count ⇒ Fixnum
The number of conversations correlated.
-
#failed_conversations_count ⇒ Fixnum
The number of conversations that failed correlation.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the operation output to be incomplete.
-
#sampled_conversations_count ⇒ Fixnum
The number of conversations sampled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStats
Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStats.
10269 10270 10271 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_correlation_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError>
A list of errors that occurred during correlation, one for each conversation
that failed.
Corresponds to the JSON property conversationCorrelationErrors
10246 10247 10248 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10246 def conversation_correlation_errors @conversation_correlation_errors end |
#correlated_conversations_count ⇒ Fixnum
The number of conversations correlated.
Corresponds to the JSON property correlatedConversationsCount
10251 10252 10253 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10251 def @correlated_conversations_count end |
#failed_conversations_count ⇒ Fixnum
The number of conversations that failed correlation.
Corresponds to the JSON property failedConversationsCount
10256 10257 10258 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10256 def failed_conversations_count @failed_conversations_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
10262 10263 10264 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10262 def partial_errors @partial_errors end |
#sampled_conversations_count ⇒ Fixnum
The number of conversations sampled.
Corresponds to the JSON property sampledConversationsCount
10267 10268 10269 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10267 def sampled_conversations_count @sampled_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10274 10275 10276 10277 10278 10279 10280 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10274 def update!(**args) @conversation_correlation_errors = args[:conversation_correlation_errors] if args.key?(:conversation_correlation_errors) @correlated_conversations_count = args[:correlated_conversations_count] if args.key?(:correlated_conversations_count) @failed_conversations_count = args[:failed_conversations_count] if args.key?(:failed_conversations_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @sampled_conversations_count = args[:sampled_conversations_count] if args.key?(:sampled_conversations_count) end |