Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to test correlation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest.



9987
9988
9989
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequestConversations

Wrapper for a list of conversations. Corresponds to the JSON property conversations



9963
9964
9965
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9963

def conversations
  @conversations
end

#correlation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig

A configuration that defines how to correlate conversations for a given a given project. Corresponds to the JSON property correlationConfig



9969
9970
9971
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9969

def correlation_config
  @correlation_config
end

#filterString

Optional. Filter to select conversations to test correlation against. Conversations matching this filter will be sampled based on start time. The most recent max_sample_count conversations will be selected. If no conversations match the filter, the request will fail with an INVALID_ARGUMENT error. Corresponds to the JSON property filter

Returns:

  • (String)


9978
9979
9980
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9978

def filter
  @filter
end

#max_sample_countFixnum

Optional. The maximum number of conversations to sample when using the filter . If not set, defaults to 1000. Values greater than 1000 are coerced to 1000. This field is ignored if conversations is provided. Corresponds to the JSON property maxSampleCount

Returns:

  • (Fixnum)


9985
9986
9987
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9985

def max_sample_count
  @max_sample_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9992
9993
9994
9995
9996
9997
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9992

def update!(**args)
  @conversations = args[:conversations] if args.key?(:conversations)
  @correlation_config = args[:correlation_config] if args.key?(:correlation_config)
  @filter = args[:filter] if args.key?(:filter)
  @max_sample_count = args[:max_sample_count] if args.key?(:max_sample_count)
end