Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The response of testing correlation config.
Instance Attribute Summary collapse
-
#detailed_results ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
Wrapper for detailed, step-by-step results.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the operation output to be incomplete.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponse
constructor
A new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponse
Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponse.
9193 9194 9195 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detailed_results ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
Wrapper for detailed, step-by-step results.
Corresponds to the JSON property detailedResults
9185 9186 9187 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9185 def detailed_results @detailed_results end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
9191 9192 9193 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9191 def partial_errors @partial_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9198 9199 9200 9201 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9198 def update!(**args) @detailed_results = args[:detailed_results] if args.key?(:detailed_results) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) end |