Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Wrapper for detailed, step-by-step results.
Instance Attribute Summary collapse
-
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
-
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
constructor
A new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults.
10059 10060 10061 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
Corresponds to the JSON property constraintResults
10052 10053 10054 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10052 def constraint_results @constraint_results end |
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Corresponds to the JSON property joinKeyResults
10057 10058 10059 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10057 def join_key_results @join_key_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10064 10065 10066 10067 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10064 def update!(**args) @constraint_results = args[:constraint_results] if args.key?(:constraint_results) @join_key_results = args[:join_key_results] if args.key?(:join_key_results) end |