Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UpdateQaQuestionTagRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request for updating a QaQuestionTag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1UpdateQaQuestionTagRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1UpdateQaQuestionTagRequest.



7311
7312
7313
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#qa_question_tagGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTag

A tag is a resource which aims to categorize a set of questions across multiple scorecards, e.g., "Customer Satisfaction","Billing", etc. Corresponds to the JSON property qaQuestionTag



7301
7302
7303
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7301

def qa_question_tag
  @qa_question_tag
end

#update_maskString

Optional. The list of fields to be updated. All possible fields can be updated by passing *, or a subset of the following updateable fields can be provided:

  • qa_question_tag_name - the name of the tag * qa_question_ids - the list of questions the tag applies to Corresponds to the JSON property updateMask

Returns:

  • (String)


7309
7310
7311
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7309

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7316
7317
7318
7319
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7316

def update!(**args)
  @qa_question_tag = args[:qa_question_tag] if args.key?(:qa_question_tag)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end