Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1View
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1View
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The View resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The human-readable display name of the view.
-
#name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#value ⇒ String
A filter to reduce conversation results to a specific subset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1View
constructor
A new instance of GoogleCloudContactcenterinsightsV1View.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1View
Returns a new instance of GoogleCloudContactcenterinsightsV1View.
10157 10158 10159 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this view was created.
Corresponds to the JSON property createTime
10133 10134 10135 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10133 def create_time @create_time end |
#display_name ⇒ String
The human-readable display name of the view.
Corresponds to the JSON property displayName
10138 10139 10140 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10138 def display_name @display_name end |
#name ⇒ String
Immutable. The resource name of the view. Format: projects/project/locations/
location/views/view
Corresponds to the JSON property name
10144 10145 10146 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10144 def name @name end |
#update_time ⇒ String
Output only. The most recent time at which the view was updated.
Corresponds to the JSON property updateTime
10149 10150 10151 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10149 def update_time @update_time end |
#value ⇒ String
A filter to reduce conversation results to a specific subset. Refer to https://
cloud.google.com/contact-center/insights/docs/filtering for details.
Corresponds to the JSON property value
10155 10156 10157 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10155 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10162 10163 10164 10165 10166 10167 10168 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10162 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @value = args[:value] if args.key?(:value) end |