Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Selector of all available annotators and phrase matchers to run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.



10697
10698
10699
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#issue_modelsArray<String>

The issue model to run. If not provided, the most recently deployed topic model will be used. The provided issue model will only be used for inference if the issue model is deployed and if run_issue_model_annotator is set to true. If more than one issue model is provided, only the first provided issue model will be used for inference. Corresponds to the JSON property issueModels

Returns:

  • (Array<String>)


10613
10614
10615
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10613

def issue_models
  @issue_models
end

#phrase_matchersArray<String>

The list of phrase matchers to run. If not provided, all active phrase matchers will be used. If inactive phrase matchers are provided, they will not be used. Phrase matchers will be run only if run_phrase_matcher_annotator is set to true. Format: projects/project/locations/location/phraseMatchers/ phrase_matcher Corresponds to the JSON property phraseMatchers

Returns:

  • (Array<String>)


10622
10623
10624
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10622

def phrase_matchers
  @phrase_matchers
end

#qa_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorQaConfig

Configuration for the QA feature. Corresponds to the JSON property qaConfig



10627
10628
10629
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10627

def qa_config
  @qa_config
end

#run_auto_labeling_annotatorBoolean Also known as: run_auto_labeling_annotator?

Optional. Whether to run the auto-labeling annotator. If true, the auto- labeling annotator will be run. This is a non-billable operation designed for fixing or backfilling custom labels. Corresponds to the JSON property runAutoLabelingAnnotator

Returns:

  • (Boolean)


10634
10635
10636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10634

def run_auto_labeling_annotator
  @run_auto_labeling_annotator
end

#run_entity_annotatorBoolean Also known as: run_entity_annotator?

Whether to run the entity annotator. Corresponds to the JSON property runEntityAnnotator

Returns:

  • (Boolean)


10640
10641
10642
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10640

def run_entity_annotator
  @run_entity_annotator
end

#run_intent_annotatorBoolean Also known as: run_intent_annotator?

Whether to run the intent annotator. Corresponds to the JSON property runIntentAnnotator

Returns:

  • (Boolean)


10646
10647
10648
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10646

def run_intent_annotator
  @run_intent_annotator
end

#run_interruption_annotatorBoolean Also known as: run_interruption_annotator?

Whether to run the interruption annotator. Corresponds to the JSON property runInterruptionAnnotator

Returns:

  • (Boolean)


10652
10653
10654
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10652

def run_interruption_annotator
  @run_interruption_annotator
end

#run_issue_model_annotatorBoolean Also known as: run_issue_model_annotator?

Whether to run the issue model annotator. A model should have already been deployed for this to take effect. Corresponds to the JSON property runIssueModelAnnotator

Returns:

  • (Boolean)


10659
10660
10661
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10659

def run_issue_model_annotator
  @run_issue_model_annotator
end

#run_phrase_matcher_annotatorBoolean Also known as: run_phrase_matcher_annotator?

Whether to run the active phrase matcher annotator(s). Corresponds to the JSON property runPhraseMatcherAnnotator

Returns:

  • (Boolean)


10665
10666
10667
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10665

def run_phrase_matcher_annotator
  @run_phrase_matcher_annotator
end

#run_qa_annotatorBoolean Also known as: run_qa_annotator?

Whether to run the QA annotator. Corresponds to the JSON property runQaAnnotator

Returns:

  • (Boolean)


10671
10672
10673
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10671

def run_qa_annotator
  @run_qa_annotator
end

#run_sentiment_annotatorBoolean Also known as: run_sentiment_annotator?

Whether to run the sentiment annotator. Corresponds to the JSON property runSentimentAnnotator

Returns:

  • (Boolean)


10677
10678
10679
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10677

def run_sentiment_annotator
  @run_sentiment_annotator
end

#run_silence_annotatorBoolean Also known as: run_silence_annotator?

Whether to run the silence annotator. Corresponds to the JSON property runSilenceAnnotator

Returns:

  • (Boolean)


10683
10684
10685
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10683

def run_silence_annotator
  @run_silence_annotator
end

#run_summarization_annotatorBoolean Also known as: run_summarization_annotator?

Whether to run the summarization annotator. Corresponds to the JSON property runSummarizationAnnotator

Returns:

  • (Boolean)


10689
10690
10691
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10689

def run_summarization_annotator
  @run_summarization_annotator
end

#summarization_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorSummarizationConfig

Configuration for summarization. Corresponds to the JSON property summarizationConfig



10695
10696
10697
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10695

def summarization_config
  @summarization_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10702
10703
10704
10705
10706
10707
10708
10709
10710
10711
10712
10713
10714
10715
10716
10717
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10702

def update!(**args)
  @issue_models = args[:issue_models] if args.key?(:issue_models)
  @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers)
  @qa_config = args[:qa_config] if args.key?(:qa_config)
  @run_auto_labeling_annotator = args[:run_auto_labeling_annotator] if args.key?(:run_auto_labeling_annotator)
  @run_entity_annotator = args[:run_entity_annotator] if args.key?(:run_entity_annotator)
  @run_intent_annotator = args[:run_intent_annotator] if args.key?(:run_intent_annotator)
  @run_interruption_annotator = args[:run_interruption_annotator] if args.key?(:run_interruption_annotator)
  @run_issue_model_annotator = args[:run_issue_model_annotator] if args.key?(:run_issue_model_annotator)
  @run_phrase_matcher_annotator = args[:run_phrase_matcher_annotator] if args.key?(:run_phrase_matcher_annotator)
  @run_qa_annotator = args[:run_qa_annotator] if args.key?(:run_qa_annotator)
  @run_sentiment_annotator = args[:run_sentiment_annotator] if args.key?(:run_sentiment_annotator)
  @run_silence_annotator = args[:run_silence_annotator] if args.key?(:run_silence_annotator)
  @run_summarization_annotator = args[:run_summarization_annotator] if args.key?(:run_summarization_annotator)
  @summarization_config = args[:summarization_config] if args.key?(:summarization_config)
end