Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The feedback that the customer has about a certain answer in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback.



10578
10579
10580
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clickedBoolean Also known as: clicked?

Indicates whether an answer or item was clicked by the human agent. Corresponds to the JSON property clicked

Returns:

  • (Boolean)


10563
10564
10565
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10563

def clicked
  @clicked
end

#correctness_levelString

The correctness level of an answer. Corresponds to the JSON property correctnessLevel

Returns:

  • (String)


10569
10570
10571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10569

def correctness_level
  @correctness_level
end

#displayedBoolean Also known as: displayed?

Indicates whether an answer or item was displayed to the human agent in the agent desktop UI. Corresponds to the JSON property displayed

Returns:

  • (Boolean)


10575
10576
10577
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10575

def displayed
  @displayed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10583
10584
10585
10586
10587
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10583

def update!(**args)
  @clicked = args[:clicked] if args.key?(:clicked)
  @correctness_level = args[:correctness_level] if args.key?(:correctness_level)
  @displayed = args[:displayed] if args.key?(:displayed)
end