Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist Article Suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData.



10864
10865
10866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The system's confidence score that this article is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


10834
10835
10836
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10834

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the Article Suggestion and the document that it originates from. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


10840
10841
10842
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10840

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


10846
10847
10848
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10846

def query_record
  @query_record
end

#sourceString

The knowledge document that this answer was extracted from. Format: projects/ project/knowledgeBases/knowledge_base/documents/document Corresponds to the JSON property source

Returns:

  • (String)


10852
10853
10854
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10852

def source
  @source
end

#titleString

Article title. Corresponds to the JSON property title

Returns:

  • (String)


10857
10858
10859
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10857

def title
  @title
end

#uriString

Article URI. Corresponds to the JSON property uri

Returns:

  • (String)


10862
10863
10864
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10862

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10869
10870
10871
10872
10873
10874
10875
10876
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10869

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @source = args[:source] if args.key?(:source)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end