Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversations in bulk.
Instance Attribute Summary collapse
-
#analysis_percentage ⇒ Float
Required.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#filter ⇒ String
Required.
-
#parent ⇒ String
Required.
-
#relabel ⇒ Boolean
(also: #relabel?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest.
10734 10735 10736 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_percentage ⇒ Float
Required. Percentage of selected conversation to analyze, between [0, 100].
Corresponds to the JSON property analysisPercentage
10710 10711 10712 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10710 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
10715 10716 10717 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10715 def annotator_selector @annotator_selector end |
#filter ⇒ String
Required. Filter used to select the subset of conversations to analyze.
Corresponds to the JSON property filter
10720 10721 10722 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10720 def filter @filter end |
#parent ⇒ String
Required. The parent resource to create analyses in.
Corresponds to the JSON property parent
10725 10726 10727 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10725 def parent @parent end |
#relabel ⇒ Boolean Also known as: relabel?
Optional. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
10731 10732 10733 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10731 def relabel @relabel end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10739 10740 10741 10742 10743 10744 10745 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10739 def update!(**args) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @filter = args[:filter] if args.key?(:filter) @parent = args[:parent] if args.key?(:parent) @relabel = args[:relabel] if args.key?(:relabel) end |