Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.



11079
11080
11081
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


11059
11060
11061
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11059

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


11065
11066
11067
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11065

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


11071
11072
11073
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11071

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


11077
11078
11079
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11077

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11084
11085
11086
11087
11088
11089
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11084

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end