Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CallAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A piece of metadata that applies to a window of a call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CallAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CallAnnotation.



12421
12422
12423
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationEndBoundary



12364
12365
12366
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12364

def annotation_end_boundary
  @annotation_end_boundary
end

#annotation_start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationStartBoundary



12369
12370
12371
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12369

def annotation_start_boundary
  @annotation_start_boundary
end

#channel_tagFixnum

The channel of the audio where the annotation occurs. For single-channel audio, this field is not populated. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


12375
12376
12377
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12375

def channel_tag
  @channel_tag
end

#entity_mention_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1EntityMentionData

The data for an entity mention annotation. This represents a mention of an Entity in the conversation. Corresponds to the JSON property entityMentionData



12381
12382
12383
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12381

def entity_mention_data
  @entity_mention_data
end

#hold_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1HoldData

The data for a hold annotation. Corresponds to the JSON property holdData



12386
12387
12388
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12386

def hold_data
  @hold_data
end

#intent_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IntentMatchData

The data for an intent match. Represents an intent match for a text segment in the conversation. A text segment can be part of a sentence, a complete sentence, or an utterance with multiple sentences. Corresponds to the JSON property intentMatchData



12393
12394
12395
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12393

def intent_match_data
  @intent_match_data
end

#interruption_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InterruptionData

The data for an interruption annotation. Corresponds to the JSON property interruptionData



12398
12399
12400
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12398

def interruption_data
  @interruption_data
end

#issue_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueMatchData

The data for an issue match annotation. Corresponds to the JSON property issueMatchData



12403
12404
12405
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12403

def issue_match_data
  @issue_match_data
end

#phrase_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData

The data for a matched phrase matcher. Represents information identifying a phrase matcher for a given match. Corresponds to the JSON property phraseMatchData



12409
12410
12411
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12409

def phrase_match_data
  @phrase_match_data
end

#sentiment_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentimentData



12414
12415
12416
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12414

def sentiment_data
  @sentiment_data
end

#silence_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SilenceData

The data for a silence annotation. Corresponds to the JSON property silenceData



12419
12420
12421
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12419

def silence_data
  @silence_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12426

def update!(**args)
  @annotation_end_boundary = args[:annotation_end_boundary] if args.key?(:annotation_end_boundary)
  @annotation_start_boundary = args[:annotation_start_boundary] if args.key?(:annotation_start_boundary)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @entity_mention_data = args[:entity_mention_data] if args.key?(:entity_mention_data)
  @hold_data = args[:hold_data] if args.key?(:hold_data)
  @intent_match_data = args[:intent_match_data] if args.key?(:intent_match_data)
  @interruption_data = args[:interruption_data] if args.key?(:interruption_data)
  @issue_match_data = args[:issue_match_data] if args.key?(:issue_match_data)
  @phrase_match_data = args[:phrase_match_data] if args.key?(:phrase_match_data)
  @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data)
  @silence_data = args[:silence_data] if args.key?(:silence_data)
end