Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CES diagnostic information.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
-
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation.
12407 12408 12409 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12407 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
Corresponds to the JSON property messages
12400 12401 12402 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12400 def @messages end |
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
12405 12406 12407 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12405 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12412 12413 12414 12415 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12412 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |