Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResultRuleConstraintResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResultRuleConstraintResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The result of a single constraint rule on the pair of conversations.
Instance Attribute Summary collapse
-
#constraint_met ⇒ Boolean
(also: #constraint_met?)
Whether the constraint expression evaluated to true for (A, B) or (B, A).
-
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#rule_id ⇒ String
The rule ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResultRuleConstraintResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResultRuleConstraintResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResultRuleConstraintResult
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResultRuleConstraintResult.
11360 11361 11362 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_met ⇒ Boolean Also known as: constraint_met?
Whether the constraint expression evaluated to true for (A, B) or (B, A).
Corresponds to the JSON property constraintMet
11342 11343 11344 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11342 def constraint_met @constraint_met end |
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
11353 11354 11355 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11353 def error @error end |
#rule_id ⇒ String
The rule ID.
Corresponds to the JSON property ruleId
11358 11359 11360 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11358 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11365 11366 11367 11368 11369 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11365 def update!(**args) @constraint_met = args[:constraint_met] if args.key?(:constraint_met) @error = args[:error] if args.key?(:error) @rule_id = args[:rule_id] if args.key?(:rule_id) end |