Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Conversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Conversation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Conversation.



11501
11502
11503
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


11380
11381
11382
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11380

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



11385
11386
11387
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11385

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



11390
11391
11392
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11390

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11395
11396
11397
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11395

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



11400
11401
11402
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11400

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



11407
11408
11409
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11407

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


11412
11413
11414
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11412

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


11418
11419
11420
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11418

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11424
11425
11426
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11424

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


11429
11430
11431
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11429

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis

The analysis resource. Corresponds to the JSON property latestAnalysis



11434
11435
11436
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11434

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



11439
11440
11441
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11439

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


11444
11445
11446
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11444

def medium
  @medium
end

#metadata_jsonString

Optional. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


11451
11452
11453
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11451

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


11457
11458
11459
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11457

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


11462
11463
11464
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11462

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



11467
11468
11469
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11467

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



11473
11474
11475
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11473

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


11478
11479
11480
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11478

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



11483
11484
11485
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11483

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


11489
11490
11491
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11489

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


11494
11495
11496
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11494

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11499
11500
11501
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11499

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11506

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end