Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Info for correlating across conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo.



12765
12766
12767
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#correlation_typesArray<String>

Output only. The correlation types of this conversation. A single conversation can have multiple correlation types. For example a conversation that only has a single segment is both a SEGMENT and a FULL_CONVERSATION. Corresponds to the JSON property correlationTypes

Returns:

  • (Array<String>)


12751
12752
12753
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12751

def correlation_types
  @correlation_types
end

#full_conversation_correlation_idString

Output only. The full conversation correlation id this conversation is a segment of. Corresponds to the JSON property fullConversationCorrelationId

Returns:

  • (String)


12757
12758
12759
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12757

def full_conversation_correlation_id
  @full_conversation_correlation_id
end

#merged_full_conversation_correlation_idString

Output only. The full conversation correlation id this conversation is a merged conversation of. Corresponds to the JSON property mergedFullConversationCorrelationId

Returns:

  • (String)


12763
12764
12765
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12763

def merged_full_conversation_correlation_id
  @merged_full_conversation_correlation_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12770
12771
12772
12773
12774
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12770

def update!(**args)
  @correlation_types = args[:correlation_types] if args.key?(:correlation_types)
  @full_conversation_correlation_id = args[:full_conversation_correlation_id] if args.key?(:full_conversation_correlation_id)
  @merged_full_conversation_correlation_id = args[:merged_full_conversation_correlation_id] if args.key?(:merged_full_conversation_correlation_id)
end