Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation source, which is a combination of transcript and audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource.



11681
11682
11683
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialogflow_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowSource

A Dialogflow source of conversation data. Corresponds to the JSON property dialogflowSource



11661
11662
11663
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11661

def dialogflow_source
  @dialogflow_source
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource

A Cloud Storage source of conversation data. Corresponds to the JSON property gcsSource



11666
11667
11668
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11666

def gcs_source
  @gcs_source
end

#metadata_uriString

Cloud Storage URI that points to a file that contains the conversation metadata. Corresponds to the JSON property metadataUri

Returns:

  • (String)


11672
11673
11674
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11672

def 
  @metadata_uri
end

#turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSourceTurnLevelAudio>

Cloud Storage URIs that points to files that contain the conversation audio for each turn. Assume the order of the URIs is the same as the order of the transcript turns. Corresponds to the JSON property turnLevelAudios



11679
11680
11681
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11679

def turn_level_audios
  @turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11686
11687
11688
11689
11690
11691
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11686

def update!(**args)
  @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri)
  @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios)
end