Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation metadata related to quality management.
Instance Attribute Summary collapse
-
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
-
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
-
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel>
Input only.
-
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
-
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata.
11796 11797 11798 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
Corresponds to the JSON property agentInfo
11774 11775 11776 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11774 def agent_info @agent_info end |
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
Corresponds to the JSON property customerSatisfactionRating
11779 11780 11781 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11779 def @customer_satisfaction_rating end |
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel>
Input only. The feedback labels associated with the conversation.
Corresponds to the JSON property feedbackLabels
11784 11785 11786 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11784 def feedback_labels @feedback_labels end |
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
Corresponds to the JSON property menuPath
11789 11790 11791 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11789 def @menu_path end |
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Corresponds to the JSON property waitDuration
11794 11795 11796 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11794 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11801 11802 11803 11804 11805 11806 11807 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11801 def update!(**args) @agent_info = args[:agent_info] if args.key?(:agent_info) @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @menu_path = args[:menu_path] if args.key?(:menu_path) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |