Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A segment of a full transcript.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment.



11848
11849
11850
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_tagFixnum

For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel. For audioChannelCount = N, its output values can range from '1' to 'N'. A channel tag of 0 indicates that the audio is mono. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


11799
11800
11801
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11799

def channel_tag
  @channel_tag
end

#confidenceFloat

A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A default value of 0.0 indicates that the value is unset. Corresponds to the JSON property confidence

Returns:

  • (Float)


11805
11806
11807
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11805

def confidence
  @confidence
end

#dialogflow_segment_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Metadata from Dialogflow relating to the current transcript segment. Corresponds to the JSON property dialogflowSegmentMetadata



11810
11811
11812
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11810

def 
  @dialogflow_segment_metadata
end

#language_codeString

The language code of this segment as a BCP-47 language tag. Example: "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


11816
11817
11818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11816

def language_code
  @language_code
end

#message_timeString

The time that the message occurred, if provided. Corresponds to the JSON property messageTime

Returns:

  • (String)


11821
11822
11823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11821

def message_time
  @message_time
end

#segment_participantGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant

The call participant speaking for a given utterance. Corresponds to the JSON property segmentParticipant



11826
11827
11828
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11826

def segment_participant
  @segment_participant
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



11831
11832
11833
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11831

def sentiment
  @sentiment
end

#textString

The text of this segment. Corresponds to the JSON property text

Returns:

  • (String)


11836
11837
11838
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11836

def text
  @text
end

#turn_level_audioGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSourceTurnLevelAudio

A wrapper for holding the audio for any given turn. Corresponds to the JSON property turnLevelAudio



11841
11842
11843
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11841

def turn_level_audio
  @turn_level_audio
end

#wordsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo>

A list of the word-specific information for each word in the segment. Corresponds to the JSON property words



11846
11847
11848
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11846

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11853
11854
11855
11856
11857
11858
11859
11860
11861
11862
11863
11864
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11853

def update!(**args)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @confidence = args[:confidence] if args.key?(:confidence)
  @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata)
  @language_code = args[:language_code] if args.key?(:language_code)
  @message_time = args[:message_time] if args.key?(:message_time)
  @segment_participant = args[:segment_participant] if args.key?(:segment_participant)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @text = args[:text] if args.key?(:text)
  @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio)
  @words = args[:words] if args.key?(:words)
end