Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Word-level info for words in a transcript.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word.
-
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total conversation.
-
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total conversation.
-
#word ⇒ String
The word itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo.
12156 12157 12158 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
12137 12138 12139 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12137 def confidence @confidence end |
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property endOffset
12143 12144 12145 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12143 def end_offset @end_offset end |
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property startOffset
12149 12150 12151 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12149 def start_offset @start_offset end |
#word ⇒ String
The word itself. Includes punctuation marks that surround the word.
Corresponds to the JSON property word
12154 12155 12156 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12154 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12161 12162 12163 12164 12165 12166 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12161 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |