Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for a create analysis operation.
Instance Attribute Summary collapse
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#conversation ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CreateAnalysisOperationMetadata.
11229 11230 11231 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
11212 11213 11214 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11212 def annotator_selector @annotator_selector end |
#conversation ⇒ String
Output only. The Conversation that this Analysis Operation belongs to.
Corresponds to the JSON property conversation
11217 11218 11219 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11217 def conversation @conversation end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
11222 11223 11224 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11222 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
11227 11228 11229 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11227 def end_time @end_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11234 11235 11236 11237 11238 11239 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11234 def update!(**args) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @conversation = args[:conversation] if args.key?(:conversation) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) end |