Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1EntityMentionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The data for an entity mention annotation. This represents a mention of an Entity in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1EntityMentionData

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1EntityMentionData.



14654
14655
14656
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_unique_idString

The key of this entity in conversation entities. Can be used to retrieve the exact Entity this mention is attached to. Corresponds to the JSON property entityUniqueId

Returns:

  • (String)


14642
14643
14644
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14642

def entity_unique_id
  @entity_unique_id
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



14647
14648
14649
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14647

def sentiment
  @sentiment
end

#typeString

The type of the entity mention. Corresponds to the JSON property type

Returns:

  • (String)


14652
14653
14654
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14652

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14659
14660
14661
14662
14663
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14659

def update!(**args)
  @entity_unique_id = args[:entity_unique_id] if args.key?(:entity_unique_id)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @type = args[:type] if args.key?(:type)
end