Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GcsSource.



13503
13504
13505
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Immutable. Deprecated: Use audio_uris instead. Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


13488
13489
13490
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13488

def audio_uri
  @audio_uri
end

#audio_urisArray<String>

Immutable. Cloud Storage URIs that point to files that contain the conversation audio. Supports both single audio files and multi-leg session recordings (e.g., call transfers, rolling recording buffers). Corresponds to the JSON property audioUris

Returns:

  • (Array<String>)


13495
13496
13497
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13495

def audio_uris
  @audio_uris
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


13501
13502
13503
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13501

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13508
13509
13510
13511
13512
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13508

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @audio_uris = args[:audio_uris] if args.key?(:audio_uris)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end