Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A wrapper for system messages per turn.
Instance Attribute Summary collapse
-
#system_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessage>
A message from the system in response to the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages.
15089 15090 15091 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#system_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessage>
A message from the system in response to the user.
Corresponds to the JSON property systemMessages
15087 15088 15089 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15087 def @system_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15094 15095 15096 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15094 def update!(**args) @system_messages = args[:system_messages] if args.key?(:system_messages) end |