Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for generative insights.
Instance Attribute Summary collapse
-
#error_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
The error message when the generative insights request fails.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightsMetadata.
12735 12736 12737 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
The error message when the generative insights request fails.
Corresponds to the JSON property errorMessages
12733 12734 12735 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12733 def @error_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12740 12741 12742 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12740 def update!(**args) @error_messages = args[:error_messages] if args.key?(:error_messages) end |