Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for IngestConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats.



13031
13032
13033
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duplicates_skipped_countFixnum

Output only. The number of objects skipped because another conversation with the same transcript uri had already been ingested. Corresponds to the JSON property duplicatesSkippedCount

Returns:

  • (Fixnum)


13012
13013
13014
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13012

def duplicates_skipped_count
  @duplicates_skipped_count
end

#failed_ingest_countFixnum

Output only. The number of objects which were unable to be ingested due to errors. The errors are populated in the partial_errors field. Corresponds to the JSON property failedIngestCount

Returns:

  • (Fixnum)


13018
13019
13020
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13018

def failed_ingest_count
  @failed_ingest_count
end

#processed_object_countFixnum

Output only. The number of objects processed during the ingest operation. Corresponds to the JSON property processedObjectCount

Returns:

  • (Fixnum)


13023
13024
13025
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13023

def processed_object_count
  @processed_object_count
end

#successful_ingest_countFixnum

Output only. The number of new conversations added during this ingest operation. Corresponds to the JSON property successfulIngestCount

Returns:

  • (Fixnum)


13029
13030
13031
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13029

def successful_ingest_count
  @successful_ingest_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13036
13037
13038
13039
13040
13041
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13036

def update!(**args)
  @duplicates_skipped_count = args[:duplicates_skipped_count] if args.key?(:duplicates_skipped_count)
  @failed_ingest_count = args[:failed_ingest_count] if args.key?(:failed_ingest_count)
  @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count)
  @successful_ingest_count = args[:successful_ingest_count] if args.key?(:successful_ingest_count)
end