Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configuration that applies to all conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig.



10557
10558
10559
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_channelFixnum

Optional. Indicates which of the channels, 1 or 2, contains the agent. Note that this must be set for conversations to be properly displayed and analyzed. Corresponds to the JSON property agentChannel

Returns:

  • (Fixnum)


10542
10543
10544
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10542

def agent_channel
  @agent_channel
end

#agent_idString

Optional. An opaque, user-specified string representing a human agent who handled all conversations in the import. Note that this will be overridden if per-conversation metadata is provided through the metadata_bucket_uri. Corresponds to the JSON property agentId

Returns:

  • (String)


10549
10550
10551
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10549

def agent_id
  @agent_id
end

#customer_channelFixnum

Optional. Indicates which of the channels, 1 or 2, contains the agent. Note that this must be set for conversations to be properly displayed and analyzed. Corresponds to the JSON property customerChannel

Returns:

  • (Fixnum)


10555
10556
10557
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10555

def customer_channel
  @customer_channel
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10562
10563
10564
10565
10566
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10562

def update!(**args)
  @agent_channel = args[:agent_channel] if args.key?(:agent_channel)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @customer_channel = args[:customer_channel] if args.key?(:customer_channel)
end