Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for initializing a location-level encryption specification.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecMetadata.
15663 15664 15665 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
15645 15646 15647 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15645 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
15650 15651 15652 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15650 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation
output to be incomplete.
Corresponds to the JSON property partialErrors
15656 15657 15658 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15656 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Corresponds to the JSON property request
15661 15662 15663 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15661 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15668 15669 15670 15671 15672 15673 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15668 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |