Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Issue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Issue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_description ⇒ String
Representative description of the issue.
-
#display_name ⇒ String
The representative name for the issue.
-
#name ⇒ String
Immutable.
-
#sample_utterances ⇒ Array<String>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Issue
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Issue
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Issue.
14137 14138 14139 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue was created.
Corresponds to the JSON property createTime
14108 14109 14110 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14108 def create_time @create_time end |
#display_description ⇒ String
Representative description of the issue.
Corresponds to the JSON property displayDescription
14113 14114 14115 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14113 def display_description @display_description end |
#display_name ⇒ String
The representative name for the issue.
Corresponds to the JSON property displayName
14118 14119 14120 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14118 def display_name @display_name end |
#name ⇒ String
Immutable. The resource name of the issue. Format: projects/project/
locations/location/issueModels/issue_model/issues/issue
Corresponds to the JSON property name
14124 14125 14126 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14124 def name @name end |
#sample_utterances ⇒ Array<String>
Output only. Resource names of the sample representative utterances that match
to this issue.
Corresponds to the JSON property sampleUtterances
14130 14131 14132 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14130 def sample_utterances @sample_utterances end |
#update_time ⇒ String
Output only. The most recent time that this issue was updated.
Corresponds to the JSON property updateTime
14135 14136 14137 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14135 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14142 14143 14144 14145 14146 14147 14148 14149 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14142 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_description = args[:display_description] if args.key?(:display_description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances) @update_time = args[:update_time] if args.key?(:update_time) end |