Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue model resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The representative name for the issue model.
-
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
-
#issue_count ⇒ Fixnum
Output only.
-
#language_code ⇒ String
Language of the model.
-
#model_type ⇒ String
Type of the model.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStats
Aggregated statistics about an issue model.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IssueModel
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1IssueModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IssueModel
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IssueModel.
13536 13537 13538 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue model was created.
Corresponds to the JSON property createTime
13488 13489 13490 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13488 def create_time @create_time end |
#display_name ⇒ String
The representative name for the issue model.
Corresponds to the JSON property displayName
13493 13494 13495 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13493 def display_name @display_name end |
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
Corresponds to the JSON property inputDataConfig
13498 13499 13500 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13498 def input_data_config @input_data_config end |
#issue_count ⇒ Fixnum
Output only. Number of issues in this issue model.
Corresponds to the JSON property issueCount
13503 13504 13505 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13503 def issue_count @issue_count end |
#language_code ⇒ String
Language of the model.
Corresponds to the JSON property languageCode
13508 13509 13510 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13508 def language_code @language_code end |
#model_type ⇒ String
Type of the model.
Corresponds to the JSON property modelType
13513 13514 13515 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13513 def model_type @model_type end |
#name ⇒ String
Immutable. The resource name of the issue model. Format: projects/project/
locations/location/issueModels/issue_model
Corresponds to the JSON property name
13519 13520 13521 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13519 def name @name end |
#state ⇒ String
Output only. State of the model.
Corresponds to the JSON property state
13524 13525 13526 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13524 def state @state end |
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStats
Aggregated statistics about an issue model.
Corresponds to the JSON property trainingStats
13529 13530 13531 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13529 def training_stats @training_stats end |
#update_time ⇒ String
Output only. The most recent time at which the issue model was updated.
Corresponds to the JSON property updateTime
13534 13535 13536 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13534 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13541 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @input_data_config = args[:input_data_config] if args.key?(:input_data_config) @issue_count = args[:issue_count] if args.key?(:issue_count) @language_code = args[:language_code] if args.key?(:language_code) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @training_stats = args[:training_stats] if args.key?(:training_stats) @update_time = args[:update_time] if args.key?(:update_time) end |