Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Aggregated statistics about an issue.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Display name of the issue.
-
#issue ⇒ String
Issue resource.
-
#labeled_conversations_count ⇒ Fixnum
Number of conversations attached to the issue at this point in time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IssueModelLabelStatsIssueStats.
11065 11066 11067 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Display name of the issue.
Corresponds to the JSON property displayName
11052 11053 11054 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11052 def display_name @display_name end |
#issue ⇒ String
Issue resource. Format: projects/project/locations/location/issueModels/
issue_model/issues/issue
Corresponds to the JSON property issue
11058 11059 11060 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11058 def issue @issue end |
#labeled_conversations_count ⇒ Fixnum
Number of conversations attached to the issue at this point in time.
Corresponds to the JSON property labeledConversationsCount
11063 11064 11065 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11063 def labeled_conversations_count @labeled_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11070 11071 11072 11073 11074 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11070 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @issue = args[:issue] if args.key?(:issue) @labeled_conversations_count = args[:labeled_conversations_count] if args.key?(:labeled_conversations_count) end |