Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPattern

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A loss pattern of a virtual agent and suggested fixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1LossPattern

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1LossPattern.



16167
16168
16169
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idsArray<String>

Output only. A list of conversation IDs that match this loss pattern. Corresponds to the JSON property conversationIds

Returns:

  • (Array<String>)


16130
16131
16132
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16130

def conversation_ids
  @conversation_ids
end

#descriptionString

Output only. A markdown description of the loss pattern. Corresponds to the JSON property description

Returns:

  • (String)


16135
16136
16137
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16135

def description
  @description
end

#display_nameString

Output only. The display name of the loss pattern. Corresponds to the JSON property displayName

Returns:

  • (String)


16140
16141
16142
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16140

def display_name
  @display_name
end

#examplesString

Output only. A markdown of loss pattern examples. Corresponds to the JSON property examples

Returns:

  • (String)


16145
16146
16147
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16145

def examples
  @examples
end

#idString

Output only. The unique identifier for the loss pattern. Corresponds to the JSON property id

Returns:

  • (String)


16150
16151
16152
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16150

def id
  @id
end

Output only. A list of links to conversations or bot instructions. Corresponds to the JSON property links



16155
16156
16157
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16155

def links
  @links
end

#percentageFloat

Output only. The percentage of conversations that match this loss pattern. Corresponds to the JSON property percentage

Returns:

  • (Float)


16160
16161
16162
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16160

def percentage
  @percentage
end

#suggested_fixesString

Output only. A markdown description of the suggested fixes. Corresponds to the JSON property suggestedFixes

Returns:

  • (String)


16165
16166
16167
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16165

def suggested_fixes
  @suggested_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16172
16173
16174
16175
16176
16177
16178
16179
16180
16181
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16172

def update!(**args)
  @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @links = args[:links] if args.key?(:links)
  @percentage = args[:percentage] if args.key?(:percentage)
  @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes)
end