Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1MetricValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Deprecated: MetricValue is no longer used for diagnostics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1MetricValue

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1MetricValue.



16437
16438
16439
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationsArray<String>

Output only. The list of conversation names that contributed to this metric ( hits). Format: projects/project/locations/location/conversations/ conversation` Corresponds to the JSON propertyconversations`

Returns:

  • (Array<String>)


16402
16403
16404
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16402

def conversations
  @conversations
end

#display_nameString

Output only. The user-visible name of the metric (e.g., "Containment Rate"). Corresponds to the JSON property displayName

Returns:

  • (String)


16407
16408
16409
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16407

def display_name
  @display_name
end

#hit_countFixnum

Output only. The number of positive matches (hits) for this metric. Corresponds to the JSON property hitCount

Returns:

  • (Fixnum)


16412
16413
16414
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16412

def hit_count
  @hit_count
end

#metric_typeString

Output only. Deprecated: The type of the metric. Metrics for Outcome Based Insights derived from QueryMetrics. Corresponds to the JSON property metricType

Returns:

  • (String)


16418
16419
16420
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16418

def metric_type
  @metric_type
end

#source_idString

Output only. The resource name of the underlying Insights primitive (e.g., Tag or QaQuestion) used to calculate this metric. Corresponds to the JSON property sourceId

Returns:

  • (String)


16424
16425
16426
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16424

def source_id
  @source_id
end

#total_countFixnum

Output only. The total number of items evaluated for this metric. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


16429
16430
16431
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16429

def total_count
  @total_count
end

#valueFloat

Output only. The calculated value of the metric (usually a ratio or rate 0.0 - 1.0). Corresponds to the JSON property value

Returns:

  • (Float)


16435
16436
16437
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16435

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16442
16443
16444
16445
16446
16447
16448
16449
16450
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16442

def update!(**args)
  @conversations = args[:conversations] if args.key?(:conversations)
  @display_name = args[:display_name] if args.key?(:display_name)
  @hit_count = args[:hit_count] if args.key?(:hit_count)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @source_id = args[:source_id] if args.key?(:source_id)
  @total_count = args[:total_count] if args.key?(:total_count)
  @value = args[:value] if args.key?(:value)
end