Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An answer to a QaQuestion.
Instance Attribute Summary collapse
-
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources.
-
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#conversation ⇒ String
The conversation the answer applies to.
-
#qa_question ⇒ String
The QaQuestion answered by this answer.
-
#question_body ⇒ String
Question text.
-
#tags ⇒ Array<String>
User-defined list of arbitrary tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
14712 14713 14714 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific
source type, e.g., all system-generated answer sources, or all manual edit
answer sources.
Corresponds to the JSON property answerSources
14682 14683 14684 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14682 def answer_sources @answer_sources end |
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property answerValue
14688 14689 14690 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14688 def answer_value @answer_value end |
#conversation ⇒ String
The conversation the answer applies to.
Corresponds to the JSON property conversation
14693 14694 14695 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14693 def conversation @conversation end |
#qa_question ⇒ String
The QaQuestion answered by this answer.
Corresponds to the JSON property qaQuestion
14698 14699 14700 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14698 def qa_question @qa_question end |
#question_body ⇒ String
Question text. E.g., "Did the agent greet the customer?"
Corresponds to the JSON property questionBody
14703 14704 14705 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14703 def question_body @question_body end |
#tags ⇒ Array<String>
User-defined list of arbitrary tags. Matches the value from QaScorecard.
ScorecardQuestion.tags. Used for grouping/organization and for weighting the
score of each answer.
Corresponds to the JSON property tags
14710 14711 14712 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14710 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14717 14718 14719 14720 14721 14722 14723 14724 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14717 def update!(**args) @answer_sources = args[:answer_sources] if args.key?(:answer_sources) @answer_value = args[:answer_value] if args.key?(:answer_value) @conversation = args[:conversation] if args.key?(:conversation) @qa_question = args[:qa_question] if args.key?(:qa_question) @question_body = args[:question_body] if args.key?(:question_body) @tags = args[:tags] if args.key?(:tags) end |