Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue.



14812
14813
14814
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


14763
14764
14765
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14763

def bool_value
  @bool_value
end

#keyString

A short string used as an identifier. Matches the value used in QaQuestion. AnswerChoice.key. Corresponds to the JSON property key

Returns:

  • (String)


14770
14771
14772
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14770

def key
  @key
end

#na_valueBoolean Also known as: na_value?

A value of "Not Applicable (N/A)". Should only ever be true. Corresponds to the JSON property naValue

Returns:

  • (Boolean)


14775
14776
14777
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14775

def na_value
  @na_value
end

#normalized_scoreFloat

Output only. Normalized score of the questions. Calculated as score / potential_score. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


14782
14783
14784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14782

def normalized_score
  @normalized_score
end

#num_valueFloat

Numerical value. Corresponds to the JSON property numValue

Returns:

  • (Float)


14787
14788
14789
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14787

def num_value
  @num_value
end

#potential_scoreFloat

Output only. The maximum potential score of the question. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


14792
14793
14794
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14792

def potential_score
  @potential_score
end

#scoreFloat

Output only. Numerical score of the answer. Corresponds to the JSON property score

Returns:

  • (Float)


14797
14798
14799
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14797

def score
  @score
end

#skip_valueBoolean Also known as: skip_value?

Output only. A value of "Skip". If provided, this field may only be set to true. If a question receives this answer, it will be excluded from any score calculations. This would mean that the question was not evaluated. Corresponds to the JSON property skipValue

Returns:

  • (Boolean)


14804
14805
14806
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14804

def skip_value
  @skip_value
end

#str_valueString

String value. Corresponds to the JSON property strValue

Returns:

  • (String)


14810
14811
14812
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14810

def str_value
  @str_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14817
14818
14819
14820
14821
14822
14823
14824
14825
14826
14827
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14817

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @key = args[:key] if args.key?(:key)
  @na_value = args[:na_value] if args.key?(:na_value)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @num_value = args[:num_value] if args.key?(:num_value)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @score = args[:score] if args.key?(:score)
  @skip_value = args[:skip_value] if args.key?(:skip_value)
  @str_value = args[:str_value] if args.key?(:str_value)
end