Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
ID of the agent that handled the conversation.
-
#conversation ⇒ String
The conversation scored by this result.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_answers ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer>
Set of QaAnswers represented in the result.
-
#qa_scorecard_revision ⇒ String
The QaScorecardRevision scored by this result.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result, incorporating any manual edits if they exist.
-
#score_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource>
List of all individual score sets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult.
15001 15002 15003 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
ID of the agent that handled the conversation.
Corresponds to the JSON property agentId
14945 14946 14947 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14945 def agent_id @agent_id end |
#conversation ⇒ String
The conversation scored by this result.
Corresponds to the JSON property conversation
14950 14951 14952 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14950 def conversation @conversation end |
#create_time ⇒ String
Output only. The timestamp that the revision was created.
Corresponds to the JSON property createTime
14955 14956 14957 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14955 def create_time @create_time end |
#name ⇒ String
Identifier. The name of the scorecard result. Format: projects/project/
locations/location/qaScorecardResults/qa_scorecard_result
Corresponds to the JSON property name
14961 14962 14963 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14961 def name @name end |
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score. Any
manual edits are included if they exist.
Corresponds to the JSON property normalizedScore
14967 14968 14969 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14967 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
14973 14974 14975 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14973 def potential_score @potential_score end |
#qa_answers ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer>
Set of QaAnswers represented in the result.
Corresponds to the JSON property qaAnswers
14978 14979 14980 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14978 def qa_answers @qa_answers end |
#qa_scorecard_revision ⇒ String
The QaScorecardRevision scored by this result.
Corresponds to the JSON property qaScorecardRevision
14983 14984 14985 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14983 def qa_scorecard_revision @qa_scorecard_revision end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
14988 14989 14990 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14988 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result, incorporating any manual edits if
they exist.
Corresponds to the JSON property score
14994 14995 14996 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14994 def score @score end |
#score_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource>
List of all individual score sets.
Corresponds to the JSON property scoreSources
14999 15000 15001 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14999 def score_sources @score_sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15006 15007 15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15006 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @conversation = args[:conversation] if args.key?(:conversation) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_answers = args[:qa_answers] if args.key?(:qa_answers) @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @score_sources = args[:score_sources] if args.key?(:score_sources) end |