Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.
Instance Attribute Summary collapse
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result.
-
#source_type ⇒ String
What created the score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource.
15090 15091 15092 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
Corresponds to the JSON property normalizedScore
15067 15068 15069 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15067 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
15073 15074 15075 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15073 def potential_score @potential_score end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
15078 15079 15080 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15078 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result.
Corresponds to the JSON property score
15083 15084 15085 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15083 def score @score end |
#source_type ⇒ String
What created the score.
Corresponds to the JSON property sourceType
15088 15089 15090 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15088 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15095 15096 15097 15098 15099 15100 15101 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15095 def update!(**args) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @source_type = args[:source_type] if args.key?(:source_type) end |