Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response for querying metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponse.



11607
11608
11609
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Required. The location of the data. "projects/project/locations/location" Corresponds to the JSON property location

Returns:

  • (String)


11582
11583
11584
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11582

def location
  @location
end

#macro_average_sliceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSlice

A slice contains a total and (if the request specified a time granularity) a time series of metric values. Each slice contains a unique combination of the cardinality of dimensions from the request. For example, if the request specifies a single ISSUE dimension and it has a cardinality of 2 (i.e. the data used to compute the metrics has 2 issues in total), the response will have 2 slices: * Slice 1 -> dimensions=[Issue 1] * Slice 2 -> dimensions=[ Issue 2] Corresponds to the JSON property macroAverageSlice



11593
11594
11595
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11593

def macro_average_slice
  @macro_average_slice
end

#slicesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSlice>

A slice contains a total and (if the request specified a time granularity) a time series of metric values. Each slice contains a unique combination of the cardinality of dimensions from the request. Corresponds to the JSON property slices



11600
11601
11602
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11600

def slices
  @slices
end

#update_timeString

The metrics last update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


11605
11606
11607
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11605

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11612
11613
11614
11615
11616
11617
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11612

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @macro_average_slice = args[:macro_average_slice] if args.key?(:macro_average_slice)
  @slices = args[:slices] if args.key?(:slices)
  @update_time = args[:update_time] if args.key?(:update_time)
end