Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSlice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A slice contains a total and (if the request specified a time granularity) a time series of metric values. Each slice contains a unique combination of the cardinality of dimensions from the request. For example, if the request specifies a single ISSUE dimension and it has a cardinality of 2 (i.e. the data used to compute the metrics has 2 issues in total), the response will have 2 slices: * Slice 1 -> dimensions=[Issue 1] * Slice 2 -> dimensions=[ Issue 2]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSlice

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSlice.



11645
11646
11647
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dimension>

A unique combination of dimensions that this slice represents. Corresponds to the JSON property dimensions



11633
11634
11635
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11633

def dimensions
  @dimensions
end

#time_seriesGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceTimeSeries

A time series of metric values. Corresponds to the JSON property timeSeries



11638
11639
11640
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11638

def time_series
  @time_series
end

#totalGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint

A data point contains the metric values mapped to an interval. Corresponds to the JSON property total



11643
11644
11645
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11643

def total
  @total
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11650
11651
11652
11653
11654
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11650

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @time_series = args[:time_series] if args.key?(:time_series)
  @total = args[:total] if args.key?(:total)
end