Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SampleConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SampleConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to sample conversations to a dataset.
Instance Attribute Summary collapse
-
#destination_dataset ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic) Corresponds to the JSON property
destinationDataset. -
#parent ⇒ String
Required.
-
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SampleRule
Message for sampling conversations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1SampleConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1SampleConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1SampleConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1SampleConversationsRequest.
12085 12086 12087 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_dataset ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
Dataset resource represents a collection of conversations that may be bounded (
Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic
Dataset, e.g. live traffic, or agent training traffic)
Corresponds to the JSON property destinationDataset
12073 12074 12075 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12073 def destination_dataset @destination_dataset end |
#parent ⇒ String
Required. The parent resource of the dataset.
Corresponds to the JSON property parent
12078 12079 12080 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12078 def parent @parent end |
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SampleRule
Message for sampling conversations.
Corresponds to the JSON property sampleRule
12083 12084 12085 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12083 def sample_rule @sample_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12090 12091 12092 12093 12094 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12090 def update!(**args) @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset) @parent = args[:parent] if args.key?(:parent) @sample_rule = args[:sample_rule] if args.key?(:sample_rule) end |