Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An error that occurred during correlation for a specific conversation.
Instance Attribute Summary collapse
-
#conversation ⇒ String
The conversation resource name that had an error during correlation.
-
#status ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError.
16350 16351 16352 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation ⇒ String
The conversation resource name that had an error during correlation.
Corresponds to the JSON property conversation
16338 16339 16340 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16338 def conversation @conversation end |
#status ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
16348 16349 16350 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16348 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16355 16356 16357 16358 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16355 def update!(**args) @conversation = args[:conversation] if args.key?(:conversation) @status = args[:status] if args.key?(:status) end |