Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The response of testing correlation config.
Instance Attribute Summary collapse
-
#detailed_results ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
Wrapper for detailed, step-by-step results.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the operation output to be incomplete.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponse
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponse
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponse.
15391 15392 15393 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detailed_results ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
Wrapper for detailed, step-by-step results.
Corresponds to the JSON property detailedResults
15383 15384 15385 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15383 def detailed_results @detailed_results end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
15389 15390 15391 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15389 def partial_errors @partial_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15396 15397 15398 15399 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15396 def update!(**args) @detailed_results = args[:detailed_results] if args.key?(:detailed_results) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) end |