Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Wrapper for detailed, step-by-step results.
Instance Attribute Summary collapse
-
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
-
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults.
16157 16158 16159 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
Corresponds to the JSON property constraintResults
16150 16151 16152 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16150 def constraint_results @constraint_results end |
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Corresponds to the JSON property joinKeyResults
16155 16156 16157 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16155 def join_key_results @join_key_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16162 16163 16164 16165 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16162 def update!(**args) @constraint_results = args[:constraint_results] if args.key?(:constraint_results) @join_key_results = args[:join_key_results] if args.key?(:join_key_results) end |