Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an UploadConversation operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata.



16571
16572
16573
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_operationString

Output only. The operation name for a successfully created analysis operation, if any. Corresponds to the JSON property analysisOperation

Returns:

  • (String)


16543
16544
16545
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16543

def analysis_operation
  @analysis_operation
end

#applied_redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property appliedRedactionConfig



16554
16555
16556
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16554

def applied_redaction_config
  @applied_redaction_config
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


16559
16560
16561
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16559

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


16564
16565
16566
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16564

def end_time
  @end_time
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1UploadConversationRequest

Request to upload a conversation. Corresponds to the JSON property request



16569
16570
16571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16569

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16576
16577
16578
16579
16580
16581
16582
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16576

def update!(**args)
  @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation)
  @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @request = args[:request] if args.key?(:request)
end