Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The analysis resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnalysis

Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnalysis.



16671
16672
16673
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysisResult

The result of an analysis. Corresponds to the JSON property analysisResult



16647
16648
16649
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16647

def analysis_result
  @analysis_result
end

#annotator_selectorGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector

Selector of all available annotators and phrase matchers to run. Corresponds to the JSON property annotatorSelector



16652
16653
16654
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16652

def annotator_selector
  @annotator_selector
end

#create_timeString

Output only. The time at which the analysis was created, which occurs when the long-running operation completes. Corresponds to the JSON property createTime

Returns:

  • (String)


16658
16659
16660
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16658

def create_time
  @create_time
end

#nameString

Immutable. The resource name of the analysis. Format: projects/project/ locations/location/conversations/conversation/analyses/analysis Corresponds to the JSON property name

Returns:

  • (String)


16664
16665
16666
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16664

def name
  @name
end

#request_timeString

Output only. The time at which the analysis was requested. Corresponds to the JSON property requestTime

Returns:

  • (String)


16669
16670
16671
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16669

def request_time
  @request_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16676
16677
16678
16679
16680
16681
16682
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16676

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
end