Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The feedback that the customer has about a certain answer in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnswerFeedback

Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnswerFeedback.



18952
18953
18954
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clickedBoolean Also known as: clicked?

Indicates whether an answer or item was clicked by the human agent. Corresponds to the JSON property clicked

Returns:

  • (Boolean)


18937
18938
18939
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18937

def clicked
  @clicked
end

#correctness_levelString

The correctness level of an answer. Corresponds to the JSON property correctnessLevel

Returns:

  • (String)


18943
18944
18945
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18943

def correctness_level
  @correctness_level
end

#displayedBoolean Also known as: displayed?

Indicates whether an answer or item was displayed to the human agent in the agent desktop UI. Corresponds to the JSON property displayed

Returns:

  • (Boolean)


18949
18950
18951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18949

def displayed
  @displayed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18957
18958
18959
18960
18961
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18957

def update!(**args)
  @clicked = args[:clicked] if args.key?(:clicked)
  @correctness_level = args[:correctness_level] if args.key?(:correctness_level)
  @displayed = args[:displayed] if args.key?(:displayed)
end