Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist Article Suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainArticleSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1mainArticleSuggestionData.



18893
18894
18895
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The system's confidence score that this article is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


18863
18864
18865
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18863

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the Article Suggestion and the document that it originates from. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


18869
18870
18871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18869

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


18875
18876
18877
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18875

def query_record
  @query_record
end

#sourceString

The knowledge document that this answer was extracted from. Format: projects/ project/knowledgeBases/knowledge_base/documents/document Corresponds to the JSON property source

Returns:

  • (String)


18881
18882
18883
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18881

def source
  @source
end

#titleString

Article title. Corresponds to the JSON property title

Returns:

  • (String)


18886
18887
18888
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18886

def title
  @title
end

#uriString

Article URI. Corresponds to the JSON property uri

Returns:

  • (String)


18891
18892
18893
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18891

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18898
18899
18900
18901
18902
18903
18904
18905
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18898

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @source = args[:source] if args.key?(:source)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end