Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest.



17275
17276
17277
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


17255
17256
17257
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17255

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


17261
17262
17263
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17261

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


17267
17268
17269
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17267

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


17273
17274
17275
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17273

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17280
17281
17282
17283
17284
17285
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17280

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end