Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for the BulkDeleteFeedbackLabels endpoint.
Instance Attribute Summary collapse
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during deletion operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsRequest
Request for the BulkDeleteFeedbackLabels endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsMetadata.
13182 13183 13184 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during deletion operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
13175 13176 13177 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13175 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteFeedbackLabelsRequest
Request for the BulkDeleteFeedbackLabels endpoint.
Corresponds to the JSON property request
13180 13181 13182 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13180 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13187 13188 13189 13190 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13187 def update!(**args) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |