Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Google Sheets document details to write the feedback labels to.
Instance Attribute Summary collapse
-
#sheet_title ⇒ String
Optional.
-
#spreadsheet_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination.
17343 17344 17345 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sheet_title ⇒ String
Optional. The title of the new sheet to write the feedback labels to.
Corresponds to the JSON property sheetTitle
17332 17333 17334 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17332 def sheet_title @sheet_title end |
#spreadsheet_uri ⇒ String
Required. The Google Sheets document to write the feedback labels to.
Retrieved from Google Sheets URI. E.g. https://docs.google.com/spreadsheets/d/
1234567890 The spreadsheet must be shared with the Insights P4SA. The
spreadsheet ID written to will be returned as file_names in the
BulkDownloadFeedbackLabelsMetadata.
Corresponds to the JSON property spreadsheetUri
17341 17342 17343 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17341 def spreadsheet_uri @spreadsheet_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17348 17349 17350 17351 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17348 def update!(**args) @sheet_title = args[:sheet_title] if args.key?(:sheet_title) @spreadsheet_uri = args[:spreadsheet_uri] if args.key?(:spreadsheet_uri) end |