Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CES diagnostic information.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
-
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation.
19570 19571 19572 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
Corresponds to the JSON property messages
19563 19564 19565 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19563 def @messages end |
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
19568 19569 19570 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19568 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19575 19576 19577 19578 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19575 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |