Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The result of a single constraint rule on the pair of conversations.
Instance Attribute Summary collapse
-
#constraint_met ⇒ Boolean
(also: #constraint_met?)
Whether the constraint expression evaluated to true for (A, B) or (B, A).
-
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#rule_id ⇒ String
The rule ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult.
17804 17805 17806 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_met ⇒ Boolean Also known as: constraint_met?
Whether the constraint expression evaluated to true for (A, B) or (B, A).
Corresponds to the JSON property constraintMet
17786 17787 17788 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17786 def constraint_met @constraint_met end |
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
17797 17798 17799 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17797 def error @error end |
#rule_id ⇒ String
The rule ID.
Corresponds to the JSON property ruleId
17802 17803 17804 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17802 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17809 17810 17811 17812 17813 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17809 def update!(**args) @constraint_met = args[:constraint_met] if args.key?(:constraint_met) @error = args[:error] if args.key?(:error) @rule_id = args[:rule_id] if args.key?(:rule_id) end |