Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Info for correlating across conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo.



18957
18958
18959
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#correlation_typesArray<String>

Output only. The correlation types of this conversation. A single conversation can have multiple correlation types. For example a conversation that only has a single segment is both a SEGMENT and a FULL_CONVERSATION. Corresponds to the JSON property correlationTypes

Returns:

  • (Array<String>)


18943
18944
18945
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18943

def correlation_types
  @correlation_types
end

#full_conversation_correlation_idString

Output only. The full conversation correlation id this conversation is a segment of. Corresponds to the JSON property fullConversationCorrelationId

Returns:

  • (String)


18949
18950
18951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18949

def full_conversation_correlation_id
  @full_conversation_correlation_id
end

#merged_full_conversation_correlation_idString

Output only. The full conversation correlation id this conversation is a merged conversation of. Corresponds to the JSON property mergedFullConversationCorrelationId

Returns:

  • (String)


18955
18956
18957
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18955

def merged_full_conversation_correlation_id
  @merged_full_conversation_correlation_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18962
18963
18964
18965
18966
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18962

def update!(**args)
  @correlation_types = args[:correlation_types] if args.key?(:correlation_types)
  @full_conversation_correlation_id = args[:full_conversation_correlation_id] if args.key?(:full_conversation_correlation_id)
  @merged_full_conversation_correlation_id = args[:merged_full_conversation_correlation_id] if args.key?(:merged_full_conversation_correlation_id)
end