Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A message representing the transcript of a conversation.
Instance Attribute Summary collapse
-
#transcript_segments ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment>
A list of sequential transcript segments that comprise the conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscript
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscript
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscript.
14068 14069 14070 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#transcript_segments ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment>
A list of sequential transcript segments that comprise the conversation.
Corresponds to the JSON property transcriptSegments
14066 14067 14068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14066 def transcript_segments @transcript_segments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14073 14074 14075 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14073 def update!(**args) @transcript_segments = args[:transcript_segments] if args.key?(:transcript_segments) end |