Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A segment of a full transcript.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel.
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment.
-
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
-
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag.
-
#message_time ⇒ String
The time that the message occurred, if provided.
-
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationParticipant
The call participant speaking for a given utterance.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
-
#text ⇒ String
The text of this segment.
-
#turn_level_audio ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
-
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment.
18476 18477 18478 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number
corresponding to the audio from that channel. For audioChannelCount = N, its
output values can range from '1' to 'N'. A channel tag of 0 indicates that the
audio is mono.
Corresponds to the JSON property channelTag
18427 18428 18429 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18427 def channel_tag @channel_tag end |
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
18433 18434 18435 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18433 def confidence @confidence end |
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
Corresponds to the JSON property dialogflowSegmentMetadata
18438 18439 18440 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18438 def @dialogflow_segment_metadata end |
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag. Example: "en-US".
Corresponds to the JSON property languageCode
18444 18445 18446 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18444 def language_code @language_code end |
#message_time ⇒ String
The time that the message occurred, if provided.
Corresponds to the JSON property messageTime
18449 18450 18451 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18449 def @message_time end |
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationParticipant
The call participant speaking for a given utterance.
Corresponds to the JSON property segmentParticipant
18454 18455 18456 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18454 def segment_participant @segment_participant end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
18459 18460 18461 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18459 def sentiment @sentiment end |
#text ⇒ String
The text of this segment.
Corresponds to the JSON property text
18464 18465 18466 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18464 def text @text end |
#turn_level_audio ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
Corresponds to the JSON property turnLevelAudio
18469 18470 18471 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18469 def turn_level_audio @turn_level_audio end |
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Corresponds to the JSON property words
18474 18475 18476 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18474 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18481 18482 18483 18484 18485 18486 18487 18488 18489 18490 18491 18492 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18481 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @confidence = args[:confidence] if args.key?(:confidence) @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata) @language_code = args[:language_code] if args.key?(:language_code) @message_time = args[:message_time] if args.key?(:message_time) @segment_participant = args[:segment_participant] if args.key?(:segment_participant) @sentiment = args[:sentiment] if args.key?(:sentiment) @text = args[:text] if args.key?(:text) @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio) @words = args[:words] if args.key?(:words) end |