Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata from Dialogflow relating to the current transcript segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata.



19489
19490
19491
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#smart_reply_allowlist_coveredBoolean Also known as: smart_reply_allowlist_covered?

Whether the transcript segment was covered under the configured smart reply allowlist in Agent Assist. Corresponds to the JSON property smartReplyAllowlistCovered

Returns:

  • (Boolean)


19486
19487
19488
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19486

def smart_reply_allowlist_covered
  @smart_reply_allowlist_covered
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19494
19495
19496
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19494

def update!(**args)
  @smart_reply_allowlist_covered = args[:smart_reply_allowlist_covered] if args.key?(:smart_reply_allowlist_covered)
end