Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Word-level info for words in a transcript.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word.
-
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total conversation.
-
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total conversation.
-
#word ⇒ String
The word itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo.
18543 18544 18545 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
18524 18525 18526 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18524 def confidence @confidence end |
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property endOffset
18530 18531 18532 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18530 def end_offset @end_offset end |
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property startOffset
18536 18537 18538 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18536 def start_offset @start_offset end |
#word ⇒ String
The word itself. Includes punctuation marks that surround the word.
Corresponds to the JSON property word
18541 18542 18543 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18541 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18548 18549 18550 18551 18552 18553 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18548 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |