Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDataset

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDataset.



18804
18805
18806
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


18771
18772
18773
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18771

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


18776
18777
18778
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18776

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


18781
18782
18783
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18781

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


18787
18788
18789
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18787

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


18792
18793
18794
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18792

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


18797
18798
18799
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18797

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


18802
18803
18804
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18802

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18809
18810
18811
18812
18813
18814
18815
18816
18817
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18809

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end