Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for a DiagnoseConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata.



20982
20983
20984
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20933
20934
20935
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20933

def create_time
  @create_time
end

#diagnostic_reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport

A diagnostic report containing loss patterns and problematic slice stats. Corresponds to the JSON property diagnosticReport



20938
20939
20940
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20938

def diagnostic_report
  @diagnostic_report
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


20943
20944
20945
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20943

def end_time
  @end_time
end

#full_reportBoolean Also known as: full_report?

Output only. If true, the agent generated a full diagnostic report for all sub- agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


20949
20950
20951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20949

def full_report
  @full_report
end

#latest_stepGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep

A step in the agent's reasoning process (Trajectory Step). Corresponds to the JSON property latestStep



20955
20956
20957
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20955

def latest_step
  @latest_step
end

#metric_typeString

Output only. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


20960
20961
20962
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20960

def metric_type
  @metric_type
end

#partial_trajectoriesArray<String>

Output only. Deprecated: Use partial_trajectory_steps instead. Output only. The intermediate trajectory updates (partial trajectory). Corresponds to the JSON property partialTrajectories

Returns:

  • (Array<String>)


20966
20967
20968
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20966

def partial_trajectories
  @partial_trajectories
end

#partial_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>

Output only. The intermediate trajectory updates. This can be used for live progress tracking of the agent's thoughts and actions as it works through the analysis. Corresponds to the JSON property partialTrajectorySteps



20973
20974
20975
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20973

def partial_trajectory_steps
  @partial_trajectory_steps
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution. Corresponds to the JSON property request



20980
20981
20982
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20980

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20987
20988
20989
20990
20991
20992
20993
20994
20995
20996
20997
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20987

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report)
  @end_time = args[:end_time] if args.key?(:end_time)
  @full_report = args[:full_report] if args.key?(:full_report)
  @latest_step = args[:latest_step] if args.key?(:latest_step)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories)
  @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps)
  @request = args[:request] if args.key?(:request)
end