Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.
Instance Attribute Summary collapse
-
#agent_display_name ⇒ String
ces agent display name (e.g., "Steering", "Billing").
-
#agent_id ⇒ String
ces agent id to diagnose.
-
#app_id ⇒ String
Required.
-
#app_version ⇒ String
Optional.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#filter ⇒ String
Optional.
-
#full_report ⇒ Boolean
(also: #full_report?)
Optional.
-
#group_id ⇒ String
Optional.
-
#instructions ⇒ String
Optional.
-
#max_steps ⇒ Fixnum
Optional.
-
#metric_type ⇒ String
Optional.
-
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainOutputConfig
Configuration for where to export or return the analysis findings.
-
#parent ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#task_query ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest.
21104 21105 21106 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_display_name ⇒ String
ces agent display name (e.g., "Steering", "Billing").
Corresponds to the JSON property agentDisplayName
21009 21010 21011 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21009 def agent_display_name @agent_display_name end |
#agent_id ⇒ String
ces agent id to diagnose.
Corresponds to the JSON property agentId
21014 21015 21016 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21014 def agent_id @agent_id end |
#app_id ⇒ String
Required. The CES App ID.
Corresponds to the JSON property appId
21019 21020 21021 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21019 def app_id @app_id end |
#app_version ⇒ String
Optional. Optional but highly recommended. ces app version. If provided,
specific version of agent instruction will be retrieved. If empty or set to '-'
, will use the latest draft version of instruction.
Corresponds to the JSON property appVersion
21026 21027 21028 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21026 def app_version @app_version end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. Deprecated: If true, the request will be validated and a simulation
of the analysis will be performed without actually executing the task. This
field is unused. Use validate_only instead.
Corresponds to the JSON property dryRun
21033 21034 21035 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21033 def dry_run @dry_run end |
#filter ⇒ String
Optional. AIP-160 compliant filter for selecting target conversations.
Corresponds to the JSON property filter
21039 21040 21041 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21039 def filter @filter end |
#full_report ⇒ Boolean Also known as: full_report?
Optional. Deprecated: If true, the agent will generate a full diagnostic
report for all sub-agents. Subagent reporting configuration is unused. The
final diagnostic details are already persisted inside the Diagnostic resource
instead.
Corresponds to the JSON property fullReport
21047 21048 21049 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21047 def full_report @full_report end |
#group_id ⇒ String
Optional. A unique identifier used to group multiple diagnostic requests
triggered under the same run batch or cron job.
Corresponds to the JSON property groupId
21054 21055 21056 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21054 def group_id @group_id end |
#instructions ⇒ String
Optional. Deprecated: Specific instructions for the agent. Use app_id and
subagent fields instead.
Corresponds to the JSON property instructions
21060 21061 21062 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21060 def instructions @instructions end |
#max_steps ⇒ Fixnum
Optional. The maximum number of steps the agent can take during the execution
of the task. Defaults to 10.
Corresponds to the JSON property maxSteps
21066 21067 21068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21066 def max_steps @max_steps end |
#metric_type ⇒ String
Optional. The type of metric being diagnosed.
Corresponds to the JSON property metricType
21071 21072 21073 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21071 def metric_type @metric_type end |
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainOutputConfig
Configuration for where to export or return the analysis findings.
Corresponds to the JSON property outputConfig
21076 21077 21078 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21076 def output_config @output_config end |
#parent ⇒ String
Required. The parent resource where the analysis will be performed.
Corresponds to the JSON property parent
21081 21082 21083 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21081 def parent @parent end |
#request_id ⇒ String
Optional. Required. A unique ID that identifies the request. If the service
receives two DiagnoseConversationsRequests with the same request_id, then
the second request will be ignored; instead, the response of the first request
will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9),
underscores (_), and hyphens (-). The maximum length is 40 characters.
Corresponds to the JSON property requestId
21090 21091 21092 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21090 def request_id @request_id end |
#task_query ⇒ String
Optional. A natural language description of the analysis goal or question.
Corresponds to the JSON property taskQuery
21095 21096 21097 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21095 def task_query @task_query end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If true, the request will only be validated (permissions, filter
syntax, etc.) without actually triggering the analysis.
Corresponds to the JSON property validateOnly
21101 21102 21103 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21101 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21109 21110 21111 21112 21113 21114 21115 21116 21117 21118 21119 21120 21121 21122 21123 21124 21125 21126 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21109 def update!(**args) @agent_display_name = args[:agent_display_name] if args.key?(:agent_display_name) @agent_id = args[:agent_id] if args.key?(:agent_id) @app_id = args[:app_id] if args.key?(:app_id) @app_version = args[:app_version] if args.key?(:app_version) @dry_run = args[:dry_run] if args.key?(:dry_run) @filter = args[:filter] if args.key?(:filter) @full_report = args[:full_report] if args.key?(:full_report) @group_id = args[:group_id] if args.key?(:group_id) @instructions = args[:instructions] if args.key?(:instructions) @max_steps = args[:max_steps] if args.key?(:max_steps) @metric_type = args[:metric_type] if args.key?(:metric_type) @output_config = args[:output_config] if args.key?(:output_config) @parent = args[:parent] if args.key?(:parent) @request_id = args[:request_id] if args.key?(:request_id) @task_query = args[:task_query] if args.key?(:task_query) @validate_only = args[:validate_only] if args.key?(:validate_only) end |