Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response from a DiagnoseConversations request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse.



21160
21161
21162
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

Output only. Deprecated: Output only. The final, high-level answer or diagnostic summary returned by the Sherlock worker is deprecated. The persistent analysis summary is stored inside the Diagnostic resource instead. Corresponds to the JSON property answer

Returns:

  • (String)


21138
21139
21140
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21138

def answer
  @answer
end

#export_uriString

Output only. Deprecated: Output only. If an external destination was requested, the URI of the exported data is deprecated. The persistent diagnostic details are stored inside the Diagnostic resource instead. Corresponds to the JSON property exportUri

Returns:

  • (String)


21145
21146
21147
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21145

def export_uri
  @export_uri
end

#full_trajectoriesArray<String>

Output only. Deprecated: Use full_trajectory_steps instead. Output only. The complete sequence of thoughts and actions (full trajectory). Corresponds to the JSON property fullTrajectories

Returns:

  • (Array<String>)


21151
21152
21153
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21151

def full_trajectories
  @full_trajectories
end

#full_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>

Output only. Deprecated: Output only. The complete sequence of thoughts and actions taken by the agent is deprecated under LRO response completions. Use the persistent details inside the Diagnostic resource instead. Corresponds to the JSON property fullTrajectorySteps



21158
21159
21160
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21158

def full_trajectory_steps
  @full_trajectory_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21165
21166
21167
21168
21169
21170
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21165

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @export_uri = args[:export_uri] if args.key?(:export_uri)
  @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories)
  @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps)
end