Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A diagnostic report containing loss patterns and problematic slice stats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnosticReport

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnosticReport.



21203
21204
21205
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_slicesHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportConversationSlice>

Output only. A map of conversation slices used in the report. Corresponds to the JSON property conversationSlices



21180
21181
21182
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21180

def conversation_slices
  @conversation_slices
end

#intent_statsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportIntentStats>

Output only. Deprecated: Intent breakdowns are no longer used. Corresponds to the JSON property intentStats



21185
21186
21187
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21185

def intent_stats
  @intent_stats
end

#loss_patternsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern>

Output only. A list of loss patterns identified for the entire project/dataset. Corresponds to the JSON property lossPatterns



21190
21191
21192
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21190

def loss_patterns
  @loss_patterns
end

#metricsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue>

Output only. Deprecated: The type of the metric. Metrics for Outcome Based Insights derived from QueryMetrics. Corresponds to the JSON property metrics



21196
21197
21198
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21196

def metrics
  @metrics
end

#reportString

Output only. The final report in markdown format. Corresponds to the JSON property report

Returns:

  • (String)


21201
21202
21203
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21201

def report
  @report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21208
21209
21210
21211
21212
21213
21214
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21208

def update!(**args)
  @conversation_slices = args[:conversation_slices] if args.key?(:conversation_slices)
  @intent_stats = args[:intent_stats] if args.key?(:intent_stats)
  @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns)
  @metrics = args[:metrics] if args.key?(:metrics)
  @report = args[:report] if args.key?(:report)
end