Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Dialogflow source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDialogflowSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDialogflowSource.



14644
14645
14646
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


14635
14636
14637
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14635

def audio_uri
  @audio_uri
end

#dialogflow_conversationString

Output only. The name of the Dialogflow conversation that this conversation resource is derived from. Format: projects/project/locations/location/ conversations/conversation Corresponds to the JSON property dialogflowConversation

Returns:

  • (String)


14642
14643
14644
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14642

def dialogflow_conversation
  @dialogflow_conversation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14649
14650
14651
14652
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14649

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @dialogflow_conversation = args[:dialogflow_conversation] if args.key?(:dialogflow_conversation)
end