Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimension
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimension
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.
Instance Attribute Summary collapse
-
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionAgentDimensionMetadata
Metadata about the agent dimension.
-
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
-
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
-
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
-
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
-
#dimension_key ⇒ String
The key of the dimension.
-
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionIssueDimensionMetadata
Metadata about the issue dimension.
-
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionLabelDimensionMetadata
Metadata about conversation labels.
-
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
-
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension.
-
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
-
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDimension
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDimension
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDimension.
19066 19067 19068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionAgentDimensionMetadata
Metadata about the agent dimension.
Corresponds to the JSON property agentDimensionMetadata
19008 19009 19010 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19008 def @agent_dimension_metadata end |
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
Corresponds to the JSON property clientSentimentCategoryDimensionMetadata
19013 19014 19015 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19013 def @client_sentiment_category_dimension_metadata end |
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
Corresponds to the JSON property conversationProfileDimensionMetadata
19018 19019 19020 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19018 def @conversation_profile_dimension_metadata end |
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata
19023 19024 19025 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19023 def @conversational_agents_playbook_dimension_metadata end |
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
Corresponds to the JSON property conversationalAgentsToolDimensionMetadata
19028 19029 19030 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19028 def @conversational_agents_tool_dimension_metadata end |
#dimension_key ⇒ String
The key of the dimension.
Corresponds to the JSON property dimensionKey
19033 19034 19035 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19033 def dimension_key @dimension_key end |
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionIssueDimensionMetadata
Metadata about the issue dimension.
Corresponds to the JSON property issueDimensionMetadata
19038 19039 19040 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19038 def @issue_dimension_metadata end |
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionLabelDimensionMetadata
Metadata about conversation labels.
Corresponds to the JSON property labelDimensionMetadata
19043 19044 19045 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19043 def @label_dimension_metadata end |
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
Corresponds to the JSON property mediumDimensionMetadata
19048 19049 19050 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19048 def @medium_dimension_metadata end |
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension. This is useful for showing
the answer distribution for questions for a given scorecard.
Corresponds to the JSON property qaQuestionAnswerDimensionMetadata
19054 19055 19056 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19054 def @qa_question_answer_dimension_metadata end |
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
Corresponds to the JSON property qaQuestionDimensionMetadata
19059 19060 19061 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19059 def @qa_question_dimension_metadata end |
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Corresponds to the JSON property qaScorecardDimensionMetadata
19064 19065 19066 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19064 def @qa_scorecard_dimension_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19071 19072 19073 19074 19075 19076 19077 19078 19079 19080 19081 19082 19083 19084 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19071 def update!(**args) @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata) @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata) @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata) @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata) @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata) @dimension_key = args[:dimension_key] if args.key?(:dimension_key) @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata) @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata) @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata) @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata) @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata) @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata) end |