Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEncryptionSpec
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEncryptionSpec
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A customer-managed encryption key specification that can be applied to all
created resources (e.g. Conversation).
Instance Attribute Summary collapse
-
#kms_key ⇒ String
Required.
-
#name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainEncryptionSpec
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainEncryptionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainEncryptionSpec
Returns a new instance of GoogleCloudContactcenterinsightsV1mainEncryptionSpec.
21625 21626 21627 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key ⇒ String
Required. The name of customer-managed encryption key that is used to secure a
resource and its sub-resources. If empty, the resource is secured by our
default encryption key. Only the key in the same location as this resource is
allowed to be used for encryption. Format: projects/project/locations/
location/keyRings/keyRing/cryptoKeys/key`
Corresponds to the JSON propertykmsKey`
21617 21618 21619 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21617 def kms_key @kms_key end |
#name ⇒ String
Immutable. The resource name of the encryption key specification resource.
Format: projects/project/locations/location/encryptionSpec
Corresponds to the JSON property name
21623 21624 21625 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21623 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21630 21631 21632 21633 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21630 def update!(**args) @kms_key = args[:kms_key] if args.key?(:kms_key) @name = args[:name] if args.key?(:name) end |