Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEntityMentionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The data for an entity mention annotation. This represents a mention of an Entity in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainEntityMentionData

Returns a new instance of GoogleCloudContactcenterinsightsV1mainEntityMentionData.



15158
15159
15160
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_unique_idString

The key of this entity in conversation entities. Can be used to retrieve the exact Entity this mention is attached to. Corresponds to the JSON property entityUniqueId

Returns:

  • (String)


15146
15147
15148
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15146

def entity_unique_id
  @entity_unique_id
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



15151
15152
15153
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15151

def sentiment
  @sentiment
end

#typeString

The type of the entity mention. Corresponds to the JSON property type

Returns:

  • (String)


15156
15157
15158
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15156

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15163
15164
15165
15166
15167
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15163

def update!(**args)
  @entity_unique_id = args[:entity_unique_id] if args.key?(:entity_unique_id)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @type = args[:type] if args.key?(:type)
end