Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to export insights.
Instance Attribute Summary collapse
-
#big_query_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination
A BigQuery Table Reference.
-
#export_schema_version ⇒ String
Optional.
-
#filter ⇒ String
A filter to reduce results to a specific subset.
-
#kms_key ⇒ String
A fully qualified KMS key name for BigQuery tables protected by CMEK.
-
#parent ⇒ String
Required.
-
#write_disposition ⇒ String
Options for what to do if the destination table already exists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest.
19602 19603 19604 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination
A BigQuery Table Reference.
Corresponds to the JSON property bigQueryDestination
19572 19573 19574 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19572 def big_query_destination @big_query_destination end |
#export_schema_version ⇒ String
Optional. Version of the export schema.
Corresponds to the JSON property exportSchemaVersion
19577 19578 19579 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19577 def export_schema_version @export_schema_version end |
#filter ⇒ String
A filter to reduce results to a specific subset. Useful for exporting
conversations with specific properties.
Corresponds to the JSON property filter
19583 19584 19585 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19583 def filter @filter end |
#kms_key ⇒ String
A fully qualified KMS key name for BigQuery tables protected by CMEK. Format:
projects/project/locations/location/keyRings/keyring/cryptoKeys/key/
cryptoKeyVersions/version
Corresponds to the JSON property kmsKey
19590 19591 19592 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19590 def kms_key @kms_key end |
#parent ⇒ String
Required. The parent resource to export data from.
Corresponds to the JSON property parent
19595 19596 19597 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19595 def parent @parent end |
#write_disposition ⇒ String
Options for what to do if the destination table already exists.
Corresponds to the JSON property writeDisposition
19600 19601 19602 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19600 def write_disposition @write_disposition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19607 19608 19609 19610 19611 19612 19613 19614 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19607 def update!(**args) @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination) @export_schema_version = args[:export_schema_version] if args.key?(:export_schema_version) @filter = args[:filter] if args.key?(:filter) @kms_key = args[:kms_key] if args.key?(:kms_key) @parent = args[:parent] if args.key?(:parent) @write_disposition = args[:write_disposition] if args.key?(:write_disposition) end |