Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A BigQuery Table Reference.
Instance Attribute Summary collapse
-
#dataset ⇒ String
Required.
-
#project_id ⇒ String
A project ID or number.
-
#table ⇒ String
The BigQuery table name to which the insights data should be written.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination
Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination.
19698 19699 19700 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset ⇒ String
Required. The name of the BigQuery dataset that the snapshot result should be
exported to. If this dataset does not exist, the export call returns an
INVALID_ARGUMENT error.
Corresponds to the JSON property dataset
19683 19684 19685 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19683 def dataset @dataset end |
#project_id ⇒ String
A project ID or number. If specified, then export will attempt to write data
to this project instead of the resource project. Otherwise, the resource
project will be used.
Corresponds to the JSON property projectId
19690 19691 19692 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19690 def project_id @project_id end |
#table ⇒ String
The BigQuery table name to which the insights data should be written. If this
table does not exist, the export call returns an INVALID_ARGUMENT error.
Corresponds to the JSON property table
19696 19697 19698 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19696 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19703 19704 19705 19706 19707 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19703 def update!(**args) @dataset = args[:dataset] if args.key?(:dataset) @project_id = args[:project_id] if args.key?(:project_id) @table = args[:table] if args.key?(:table) end |