Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainGcsSource.



19947
19948
19949
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Immutable. Deprecated: Use audio_uris instead. Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


19932
19933
19934
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19932

def audio_uri
  @audio_uri
end

#audio_urisArray<String>

Immutable. Cloud Storage URIs that point to files that contain the conversation audio. Supports both single audio files and multi-leg session recordings (e.g., call transfers, rolling recording buffers). Corresponds to the JSON property audioUris

Returns:

  • (Array<String>)


19939
19940
19941
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19939

def audio_uris
  @audio_uris
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


19945
19946
19947
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19945

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19952
19953
19954
19955
19956
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19952

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @audio_uris = args[:audio_uris] if args.key?(:audio_uris)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end