Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The user message.
Instance Attribute Summary collapse
-
#text ⇒ String
A message from the user that is interacting with the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage.
19016 19017 19018 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#text ⇒ String
A message from the user that is interacting with the system.
Corresponds to the JSON property text
19014 19015 19016 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19014 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19021 19022 19023 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19021 def update!(**args) @text = args[:text] if args.key?(:text) end |