Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for generative insights.
Instance Attribute Summary collapse
-
#error_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
The error message when the generative insights request fails.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightsMetadata.
19035 19036 19037 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
The error message when the generative insights request fails.
Corresponds to the JSON property errorMessages
19033 19034 19035 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19033 def @error_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19040 19041 19042 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19040 def update!(**args) @error_messages = args[:error_messages] if args.key?(:error_messages) end |