Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for IngestConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats.



22736
22737
22738
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duplicates_skipped_countFixnum

Output only. The number of objects skipped because another conversation with the same transcript uri had already been ingested. Corresponds to the JSON property duplicatesSkippedCount

Returns:

  • (Fixnum)


22717
22718
22719
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22717

def duplicates_skipped_count
  @duplicates_skipped_count
end

#failed_ingest_countFixnum

Output only. The number of objects which were unable to be ingested due to errors. The errors are populated in the partial_errors field. Corresponds to the JSON property failedIngestCount

Returns:

  • (Fixnum)


22723
22724
22725
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22723

def failed_ingest_count
  @failed_ingest_count
end

#processed_object_countFixnum

Output only. The number of objects processed during the ingest operation. Corresponds to the JSON property processedObjectCount

Returns:

  • (Fixnum)


22728
22729
22730
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22728

def processed_object_count
  @processed_object_count
end

#successful_ingest_countFixnum

Output only. The number of new conversations added during this ingest operation. Corresponds to the JSON property successfulIngestCount

Returns:

  • (Fixnum)


22734
22735
22736
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22734

def successful_ingest_count
  @successful_ingest_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22741
22742
22743
22744
22745
22746
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22741

def update!(**args)
  @duplicates_skipped_count = args[:duplicates_skipped_count] if args.key?(:duplicates_skipped_count)
  @failed_ingest_count = args[:failed_ingest_count] if args.key?(:failed_ingest_count)
  @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count)
  @successful_ingest_count = args[:successful_ingest_count] if args.key?(:successful_ingest_count)
end