Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for initializing a location-level encryption specification.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata.
20688 20689 20690 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
20670 20671 20672 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20670 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
20675 20676 20677 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20675 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation
output to be incomplete.
Corresponds to the JSON property partialErrors
20681 20682 20683 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20681 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Corresponds to the JSON property request
20686 20687 20688 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20686 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20693 20694 20695 20696 20697 20698 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20693 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |