Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to initialize a location-level encryption specification.
Instance Attribute Summary collapse
-
#encryption_spec ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEncryptionSpec
A customer-managed encryption key specification that can be applied to all created resources (e.g.
Conversation).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest.
16005 16006 16007 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_spec ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEncryptionSpec
A customer-managed encryption key specification that can be applied to all
created resources (e.g. Conversation).
Corresponds to the JSON property encryptionSpec
16003 16004 16005 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16003 def encryption_spec @encryption_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16010 16011 16012 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16010 def update!(**args) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) end |