Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue model resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModel

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModel.



20887
20888
20889
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue model was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20839
20840
20841
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20839

def create_time
  @create_time
end

#display_nameString

The representative name for the issue model. Corresponds to the JSON property displayName

Returns:

  • (String)


20844
20845
20846
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20844

def display_name
  @display_name
end

#input_data_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig

Configs for the input data used to create the issue model. Corresponds to the JSON property inputDataConfig



20849
20850
20851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20849

def input_data_config
  @input_data_config
end

#issue_countFixnum

Output only. Number of issues in this issue model. Corresponds to the JSON property issueCount

Returns:

  • (Fixnum)


20854
20855
20856
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20854

def issue_count
  @issue_count
end

#language_codeString

Language of the model. Corresponds to the JSON property languageCode

Returns:

  • (String)


20859
20860
20861
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20859

def language_code
  @language_code
end

#model_typeString

Type of the model. Corresponds to the JSON property modelType

Returns:

  • (String)


20864
20865
20866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20864

def model_type
  @model_type
end

#nameString

Immutable. The resource name of the issue model. Format: projects/project/ locations/location/issueModels/issue_model Corresponds to the JSON property name

Returns:

  • (String)


20870
20871
20872
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20870

def name
  @name
end

#stateString

Output only. State of the model. Corresponds to the JSON property state

Returns:

  • (String)


20875
20876
20877
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20875

def state
  @state
end

#training_statsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats

Aggregated statistics about an issue model. Corresponds to the JSON property trainingStats



20880
20881
20882
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20880

def training_stats
  @training_stats
end

#update_timeString

Output only. The most recent time at which the issue model was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


20885
20886
20887
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20885

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20892
20893
20894
20895
20896
20897
20898
20899
20900
20901
20902
20903
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20892

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @input_data_config = args[:input_data_config] if args.key?(:input_data_config)
  @issue_count = args[:issue_count] if args.key?(:issue_count)
  @language_code = args[:language_code] if args.key?(:language_code)
  @model_type = args[:model_type] if args.key?(:model_type)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @training_stats = args[:training_stats] if args.key?(:training_stats)
  @update_time = args[:update_time] if args.key?(:update_time)
end