Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Configs for the input data used to create the issue model.
Instance Attribute Summary collapse
-
#filter ⇒ String
A filter to reduce the conversations used for training the model to a specific subset.
-
#medium ⇒ String
Medium of conversations used in training data.
-
#training_conversations_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig.
19878 19879 19880 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
A filter to reduce the conversations used for training the model to a specific
subset. Refer to https://cloud.google.com/contact-center/insights/docs/
filtering for details.
Corresponds to the JSON property filter
19864 19865 19866 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19864 def filter @filter end |
#medium ⇒ String
Medium of conversations used in training data. This field is being deprecated.
To specify the medium to be used in training a new issue model, set the
medium field on filter.
Corresponds to the JSON property medium
19871 19872 19873 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19871 def medium @medium end |
#training_conversations_count ⇒ Fixnum
Output only. Number of conversations used in training. Output only.
Corresponds to the JSON property trainingConversationsCount
19876 19877 19878 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19876 def training_conversations_count @training_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19883 19884 19885 19886 19887 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19883 def update!(**args) @filter = args[:filter] if args.key?(:filter) @medium = args[:medium] if args.key?(:medium) @training_conversations_count = args[:training_conversations_count] if args.key?(:training_conversations_count) end |