Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Aggregated statistics about an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats.



21027
21028
21029
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzed_conversations_countFixnum

Number of conversations the issue model has analyzed at this point in time. Corresponds to the JSON property analyzedConversationsCount

Returns:

  • (Fixnum)


21014
21015
21016
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21014

def analyzed_conversations_count
  @analyzed_conversations_count
end

#issue_statsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats>

Statistics on each issue. Key is the issue's resource name. Corresponds to the JSON property issueStats



21019
21020
21021
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21019

def issue_stats
  @issue_stats
end

#unclassified_conversations_countFixnum

Number of analyzed conversations for which no issue was applicable at this point in time. Corresponds to the JSON property unclassifiedConversationsCount

Returns:

  • (Fixnum)


21025
21026
21027
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21025

def unclassified_conversations_count
  @unclassified_conversations_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21032
21033
21034
21035
21036
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21032

def update!(**args)
  @analyzed_conversations_count = args[:analyzed_conversations_count] if args.key?(:analyzed_conversations_count)
  @issue_stats = args[:issue_stats] if args.key?(:issue_stats)
  @unclassified_conversations_count = args[:unclassified_conversations_count] if args.key?(:unclassified_conversations_count)
end