Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Aggregated statistics about an issue.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Display name of the issue.
-
#issue ⇒ String
Issue resource.
-
#labeled_conversations_count ⇒ Fixnum
Number of conversations attached to the issue at this point in time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats.
21059 21060 21061 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Display name of the issue.
Corresponds to the JSON property displayName
21046 21047 21048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21046 def display_name @display_name end |
#issue ⇒ String
Issue resource. Format: projects/project/locations/location/issueModels/
issue_model/issues/issue
Corresponds to the JSON property issue
21052 21053 21054 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21052 def issue @issue end |
#labeled_conversations_count ⇒ Fixnum
Number of conversations attached to the issue at this point in time.
Corresponds to the JSON property labeledConversationsCount
21057 21058 21059 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21057 def labeled_conversations_count @labeled_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21064 21065 21066 21067 21068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21064 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @issue = args[:issue] if args.key?(:issue) @labeled_conversations_count = args[:labeled_conversations_count] if args.key?(:labeled_conversations_count) end |