Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A loss pattern of a virtual agent and suggested fixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainLossPattern

Returns a new instance of GoogleCloudContactcenterinsightsV1mainLossPattern.



23480
23481
23482
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idsArray<String>

Output only. A list of conversation IDs that match this loss pattern. Corresponds to the JSON property conversationIds

Returns:

  • (Array<String>)


23443
23444
23445
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23443

def conversation_ids
  @conversation_ids
end

#descriptionString

Output only. A markdown description of the loss pattern. Corresponds to the JSON property description

Returns:

  • (String)


23448
23449
23450
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23448

def description
  @description
end

#display_nameString

Output only. The display name of the loss pattern. Corresponds to the JSON property displayName

Returns:

  • (String)


23453
23454
23455
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23453

def display_name
  @display_name
end

#examplesString

Output only. A markdown of loss pattern examples. Corresponds to the JSON property examples

Returns:

  • (String)


23458
23459
23460
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23458

def examples
  @examples
end

#idString

Output only. The unique identifier for the loss pattern. Corresponds to the JSON property id

Returns:

  • (String)


23463
23464
23465
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23463

def id
  @id
end

Output only. A list of links to conversations or bot instructions. Corresponds to the JSON property links



23468
23469
23470
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23468

def links
  @links
end

#percentageFloat

Output only. The percentage of conversations that match this loss pattern. Corresponds to the JSON property percentage

Returns:

  • (Float)


23473
23474
23475
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23473

def percentage
  @percentage
end

#suggested_fixesString

Output only. A markdown description of the suggested fixes. Corresponds to the JSON property suggestedFixes

Returns:

  • (String)


23478
23479
23480
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23478

def suggested_fixes
  @suggested_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23485
23486
23487
23488
23489
23490
23491
23492
23493
23494
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23485

def update!(**args)
  @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @links = args[:links] if args.key?(:links)
  @percentage = args[:percentage] if args.key?(:percentage)
  @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes)
end