Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLink
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLink
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A link to a conversation or bot instruction.
Instance Attribute Summary collapse
-
#bot_instruction_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLinkBotInstructionLink
A link to a bot instruction.
-
#conversation_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLinkConversationLink
A link to a conversation.
-
#end_byte_index ⇒ Fixnum
The end byte index of the highlighted text (exclusive).
-
#highlighted_text ⇒ String
The text that is highlighted.
-
#location_type ⇒ String
The location type.
-
#start_byte_index ⇒ Fixnum
The start byte index of the highlighted text (inclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainLossPatternLink
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainLossPatternLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainLossPatternLink
Returns a new instance of GoogleCloudContactcenterinsightsV1mainLossPatternLink.
23531 23532 23533 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bot_instruction_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLinkBotInstructionLink
A link to a bot instruction.
Corresponds to the JSON property botInstructionLink
23504 23505 23506 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23504 def bot_instruction_link @bot_instruction_link end |
#conversation_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLinkConversationLink
A link to a conversation.
Corresponds to the JSON property conversationLink
23509 23510 23511 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23509 def conversation_link @conversation_link end |
#end_byte_index ⇒ Fixnum
The end byte index of the highlighted text (exclusive).
Corresponds to the JSON property endByteIndex
23514 23515 23516 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23514 def end_byte_index @end_byte_index end |
#highlighted_text ⇒ String
The text that is highlighted. (populated for debugging purposes)
Corresponds to the JSON property highlightedText
23519 23520 23521 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23519 def highlighted_text @highlighted_text end |
#location_type ⇒ String
The location type.
Corresponds to the JSON property locationType
23524 23525 23526 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23524 def location_type @location_type end |
#start_byte_index ⇒ Fixnum
The start byte index of the highlighted text (inclusive).
Corresponds to the JSON property startByteIndex
23529 23530 23531 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23529 def start_byte_index @start_byte_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23536 23537 23538 23539 23540 23541 23542 23543 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23536 def update!(**args) @bot_instruction_link = args[:bot_instruction_link] if args.key?(:bot_instruction_link) @conversation_link = args[:conversation_link] if args.key?(:conversation_link) @end_byte_index = args[:end_byte_index] if args.key?(:end_byte_index) @highlighted_text = args[:highlighted_text] if args.key?(:highlighted_text) @location_type = args[:location_type] if args.key?(:location_type) @start_byte_index = args[:start_byte_index] if args.key?(:start_byte_index) end |