Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Deprecated: MetricValue is no longer used for diagnostics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainMetricValue

Returns a new instance of GoogleCloudContactcenterinsightsV1mainMetricValue.



23640
23641
23642
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationsArray<String>

Output only. The list of conversation names that contributed to this metric ( hits). Format: projects/project/locations/location/conversations/ conversation` Corresponds to the JSON propertyconversations`

Returns:

  • (Array<String>)


23605
23606
23607
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23605

def conversations
  @conversations
end

#display_nameString

Output only. The user-visible name of the metric (e.g., "Containment Rate"). Corresponds to the JSON property displayName

Returns:

  • (String)


23610
23611
23612
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23610

def display_name
  @display_name
end

#hit_countFixnum

Output only. The number of positive matches (hits) for this metric. Corresponds to the JSON property hitCount

Returns:

  • (Fixnum)


23615
23616
23617
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23615

def hit_count
  @hit_count
end

#metric_typeString

Output only. Deprecated: The type of the metric. Metrics for Outcome Based Insights derived from QueryMetrics. Corresponds to the JSON property metricType

Returns:

  • (String)


23621
23622
23623
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23621

def metric_type
  @metric_type
end

#source_idString

Output only. The resource name of the underlying Insights primitive (e.g., Tag or QaQuestion) used to calculate this metric. Corresponds to the JSON property sourceId

Returns:

  • (String)


23627
23628
23629
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23627

def source_id
  @source_id
end

#total_countFixnum

Output only. The total number of items evaluated for this metric. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


23632
23633
23634
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23632

def total_count
  @total_count
end

#valueFloat

Output only. The calculated value of the metric (usually a ratio or rate 0.0 - 1.0). Corresponds to the JSON property value

Returns:

  • (Float)


23638
23639
23640
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23638

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23645
23646
23647
23648
23649
23650
23651
23652
23653
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23645

def update!(**args)
  @conversations = args[:conversations] if args.key?(:conversations)
  @display_name = args[:display_name] if args.key?(:display_name)
  @hit_count = args[:hit_count] if args.key?(:hit_count)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @source_id = args[:source_id] if args.key?(:source_id)
  @total_count = args[:total_count] if args.key?(:total_count)
  @value = args[:value] if args.key?(:value)
end