Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResult.



24059
24060
24061
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


24003
24004
24005
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24003

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


24008
24009
24010
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24008

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24013
24014
24015
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24013

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


24019
24020
24021
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24019

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


24025
24026
24027
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24025

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


24031
24032
24033
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24031

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



24036
24037
24038
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24036

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


24041
24042
24043
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24041

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



24046
24047
24048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24046

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


24052
24053
24054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24052

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



24057
24058
24059
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24057

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24064
24065
24066
24067
24068
24069
24070
24071
24072
24073
24074
24075
24076
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24064

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end