Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSlice
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSlice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A slice contains a total and (if the request specified a time granularity) a time series of metric values. Each slice contains a unique combination of the cardinality of dimensions from the request. For example, if the request specifies a single ISSUE dimension and it has a cardinality of 2 (i.e. the data used to compute the metrics has 2 issues in total), the response will have 2 slices: * Slice 1 -> dimensions=[Issue 1] * Slice 2 -> dimensions=[ Issue 2]
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimension>
A unique combination of dimensions that this slice represents.
-
#time_series ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceTimeSeries
A time series of metric values.
-
#total ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
A data point contains the metric values mapped to an interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSlice
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSlice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSlice
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSlice.
16933 16934 16935 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16933 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimension>
A unique combination of dimensions that this slice represents.
Corresponds to the JSON property dimensions
16921 16922 16923 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16921 def dimensions @dimensions end |
#time_series ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceTimeSeries
A time series of metric values.
Corresponds to the JSON property timeSeries
16926 16927 16928 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16926 def time_series @time_series end |
#total ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
A data point contains the metric values mapped to an interval.
Corresponds to the JSON property total
16931 16932 16933 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16931 def total @total end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16938 16939 16940 16941 16942 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16938 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @time_series = args[:time_series] if args.key?(:time_series) @total = args[:total] if args.key?(:total) end |