Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An annotation that was generated during the customer and agent interaction.
Instance Attribute Summary collapse
-
#annotation_id ⇒ String
The unique identifier of the annotation.
-
#answer_feedback ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
-
#article_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData
Agent Assist Article Suggestion data.
-
#ces_end_session_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesEndSessionAnnotation
The CES end session annotation.
-
#ces_turn_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation
The CES diagnostic information.
-
#conversation_summarization_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
Conversation summarization suggestion data.
-
#create_time ⇒ String
The time at which this annotation was created.
-
#dialogflow_interaction ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowInteractionData
Dialogflow interaction data.
-
#end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#faq_answer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFaqAnswerData
Agent Assist frequently-asked-question answer data.
-
#smart_compose_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
-
#smart_reply ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartReplyData
Agent Assist Smart Reply data.
-
#start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#user_input ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotationUserInput
Explicit input used for generating the answer Corresponds to the JSON property
userInput.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation.
22267 22268 22269 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_id ⇒ String
The unique identifier of the annotation. Format: projects/project/locations/
location/conversationDatasets/dataset/conversationDataItems/data_item/
conversationAnnotations/annotation
Corresponds to the JSON property annotationId
22200 22201 22202 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22200 def annotation_id @annotation_id end |
#answer_feedback ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
Corresponds to the JSON property answerFeedback
22205 22206 22207 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22205 def answer_feedback @answer_feedback end |
#article_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData
Agent Assist Article Suggestion data.
Corresponds to the JSON property articleSuggestion
22210 22211 22212 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22210 def article_suggestion @article_suggestion end |
#ces_end_session_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesEndSessionAnnotation
The CES end session annotation.
Corresponds to the JSON property cesEndSessionAnnotation
22215 22216 22217 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22215 def ces_end_session_annotation @ces_end_session_annotation end |
#ces_turn_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation
The CES diagnostic information.
Corresponds to the JSON property cesTurnAnnotation
22220 22221 22222 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22220 def ces_turn_annotation @ces_turn_annotation end |
#conversation_summarization_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
Conversation summarization suggestion data.
Corresponds to the JSON property conversationSummarizationSuggestion
22225 22226 22227 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22225 def conversation_summarization_suggestion @conversation_summarization_suggestion end |
#create_time ⇒ String
The time at which this annotation was created.
Corresponds to the JSON property createTime
22230 22231 22232 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22230 def create_time @create_time end |
#dialogflow_interaction ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowInteractionData
Dialogflow interaction data.
Corresponds to the JSON property dialogflowInteraction
22235 22236 22237 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22235 def dialogflow_interaction @dialogflow_interaction end |
#end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property endBoundary
22240 22241 22242 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22240 def end_boundary @end_boundary end |
#faq_answer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFaqAnswerData
Agent Assist frequently-asked-question answer data.
Corresponds to the JSON property faqAnswer
22245 22246 22247 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22245 def faq_answer @faq_answer end |
#smart_compose_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
Corresponds to the JSON property smartComposeSuggestion
22250 22251 22252 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22250 def smart_compose_suggestion @smart_compose_suggestion end |
#smart_reply ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartReplyData
Agent Assist Smart Reply data.
Corresponds to the JSON property smartReply
22255 22256 22257 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22255 def smart_reply @smart_reply end |
#start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property startBoundary
22260 22261 22262 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22260 def start_boundary @start_boundary end |
#user_input ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotationUserInput
Explicit input used for generating the answer
Corresponds to the JSON property userInput
22265 22266 22267 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22265 def user_input @user_input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22272 22273 22274 22275 22276 22277 22278 22279 22280 22281 22282 22283 22284 22285 22286 22287 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22272 def update!(**args) @annotation_id = args[:annotation_id] if args.key?(:annotation_id) @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback) @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion) @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation) @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation) @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion) @create_time = args[:create_time] if args.key?(:create_time) @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction) @end_boundary = args[:end_boundary] if args.key?(:end_boundary) @faq_answer = args[:faq_answer] if args.key?(:faq_answer) @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion) @smart_reply = args[:smart_reply] if args.key?(:smart_reply) @start_boundary = args[:start_boundary] if args.key?(:start_boundary) @user_input = args[:user_input] if args.key?(:user_input) end |