Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for SampleConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats

Returns a new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats.



25063
25064
25065
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_sample_countFixnum

Output only. The number of objects which were unable to be sampled due to errors. The errors are populated in the partial_errors field. Corresponds to the JSON property failedSampleCount

Returns:

  • (Fixnum)


25055
25056
25057
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25055

def failed_sample_count
  @failed_sample_count
end

#successful_sample_countFixnum

Output only. The number of new conversations added during this sample operation. Corresponds to the JSON property successfulSampleCount

Returns:

  • (Fixnum)


25061
25062
25063
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25061

def successful_sample_count
  @successful_sample_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25068
25069
25070
25071
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25068

def update!(**args)
  @failed_sample_count = args[:failed_sample_count] if args.key?(:failed_sample_count)
  @successful_sample_count = args[:successful_sample_count] if args.key?(:successful_sample_count)
end