Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartReplyData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartReplyData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Agent Assist Smart Reply data.
Instance Attribute Summary collapse
-
#confidence_score ⇒ Float
The system's confidence score that this reply is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain).
-
#metadata ⇒ Hash<String,String>
Map that contains metadata about the Smart Reply and the document from which it originates.
-
#query_record ⇒ String
The name of the answer record.
-
#reply ⇒ String
The content of the reply.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSmartReplyData
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainSmartReplyData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSmartReplyData
Returns a new instance of GoogleCloudContactcenterinsightsV1mainSmartReplyData.
22655 22656 22657 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_score ⇒ Float
The system's confidence score that this reply is a good match for this
conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely
certain).
Corresponds to the JSON property confidenceScore
22636 22637 22638 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22636 def confidence_score @confidence_score end |
#metadata ⇒ Hash<String,String>
Map that contains metadata about the Smart Reply and the document from which
it originates.
Corresponds to the JSON property metadata
22642 22643 22644 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22642 def @metadata end |
#query_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property queryRecord
22648 22649 22650 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22648 def query_record @query_record end |
#reply ⇒ String
The content of the reply.
Corresponds to the JSON property reply
22653 22654 22655 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22653 def reply @reply end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22660 22661 22662 22663 22664 22665 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22660 def update!(**args) @confidence_score = args[:confidence_score] if args.key?(:confidence_score) @metadata = args[:metadata] if args.key?(:metadata) @query_record = args[:query_record] if args.key?(:query_record) @reply = args[:reply] if args.key?(:reply) end |