Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Statistics for TestCorrelationConfig operation.
Instance Attribute Summary collapse
-
#conversation_correlation_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError>
A list of errors that occurred during correlation, one for each conversation that failed.
-
#correlated_conversations_count ⇒ Fixnum
The number of conversations correlated.
-
#failed_conversations_count ⇒ Fixnum
The number of conversations that failed correlation.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the operation output to be incomplete.
-
#sampled_conversations_count ⇒ Fixnum
The number of conversations sampled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStats
Returns a new instance of GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStats.
21632 21633 21634 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_correlation_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError>
A list of errors that occurred during correlation, one for each conversation
that failed.
Corresponds to the JSON property conversationCorrelationErrors
21609 21610 21611 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21609 def conversation_correlation_errors @conversation_correlation_errors end |
#correlated_conversations_count ⇒ Fixnum
The number of conversations correlated.
Corresponds to the JSON property correlatedConversationsCount
21614 21615 21616 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21614 def @correlated_conversations_count end |
#failed_conversations_count ⇒ Fixnum
The number of conversations that failed correlation.
Corresponds to the JSON property failedConversationsCount
21619 21620 21621 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21619 def failed_conversations_count @failed_conversations_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during test correlation config operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
21625 21626 21627 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21625 def partial_errors @partial_errors end |
#sampled_conversations_count ⇒ Fixnum
The number of conversations sampled.
Corresponds to the JSON property sampledConversationsCount
21630 21631 21632 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21630 def sampled_conversations_count @sampled_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21637 21638 21639 21640 21641 21642 21643 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21637 def update!(**args) @conversation_correlation_errors = args[:conversation_correlation_errors] if args.key?(:conversation_correlation_errors) @correlated_conversations_count = args[:correlated_conversations_count] if args.key?(:correlated_conversations_count) @failed_conversations_count = args[:failed_conversations_count] if args.key?(:failed_conversations_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @sampled_conversations_count = args[:sampled_conversations_count] if args.key?(:sampled_conversations_count) end |