Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigResponseDetailedCorrelationResults

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Wrapper for detailed, step-by-step results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigResponseDetailedCorrelationResults

Returns a new instance of GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigResponseDetailedCorrelationResults.



25522
25523
25524
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraint_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResult>

A list of constraint evaluation results for each pair of conversations. Corresponds to the JSON property constraintResults



25515
25516
25517
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25515

def constraint_results
  @constraint_results
end

#join_key_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationResult>

A list of join key correlation results for each conversation tested. Corresponds to the JSON property joinKeyResults



25520
25521
25522
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25520

def join_key_results
  @join_key_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25527
25528
25529
25530
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25527

def update!(**args)
  @constraint_results = args[:constraint_results] if args.key?(:constraint_results)
  @join_key_results = args[:join_key_results] if args.key?(:join_key_results)
end