Class: Google::Apis::ContactcenterinsightsV1::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleLongrunningListOperationsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
18201 18202 18203 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
18186 18187 18188 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18186 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
18191 18192 18193 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18191 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
18199 18200 18201 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18199 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18206 18207 18208 18209 18210 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18206 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |