Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponsePart
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponsePart
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A datatype containing media that is part of a FunctionResponse message. A
FunctionResponsePart consists of data which has an associated datatype. A
FunctionResponsePart can only contain one of the accepted types in
FunctionResponsePart.data. A FunctionResponsePart must have a fixed IANA
MIME type identifying the type and subtype of the media if the inline_data
field is filled with raw bytes.
Instance Attribute Summary collapse
-
#file_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponseFileData
URI based data for function response.
-
#inline_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponseBlob
Raw media bytes for function response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionResponsePart
constructor
A new instance of GoogleCloudAiplatformV1FunctionResponsePart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionResponsePart
Returns a new instance of GoogleCloudAiplatformV1FunctionResponsePart.
363 364 365 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponseFileData
URI based data for function response.
Corresponds to the JSON property fileData
355 356 357 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 355 def file_data @file_data end |
#inline_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1FunctionResponseBlob
Raw media bytes for function response. Text should not be sent as raw bytes,
use the 'text' field.
Corresponds to the JSON property inlineData
361 362 363 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 361 def inline_data @inline_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
368 369 370 371 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 368 def update!(**args) @file_data = args[:file_data] if args.key?(:file_data) @inline_data = args[:inline_data] if args.key?(:inline_data) end |