Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainChunk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A chunk of content within a message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainChunk

Returns a new instance of GoogleCloudCesV1mainChunk.



136
137
138
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_transferGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainAgentTransfer

Represents an event indicating the transfer of a conversation to a different agent. Corresponds to the JSON property agentTransfer



87
88
89
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 87

def agent_transfer
  @agent_transfer
end

#blobGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainBlob

Represents a blob input or output in the conversation. Corresponds to the JSON property blob



92
93
94
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 92

def blob
  @blob
end

#default_variablesHash<String,Object>

A struct represents default variables at the start of the conversation, keyed by variable names. Corresponds to the JSON property defaultVariables

Returns:

  • (Hash<String,Object>)


98
99
100
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 98

def default_variables
  @default_variables
end

#imageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainImage

Represents an image input or output in the conversation. Corresponds to the JSON property image



103
104
105
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 103

def image
  @image
end

#payloadHash<String,Object>

Optional. Custom payload data. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


108
109
110
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 108

def payload
  @payload
end

#textString

Optional. Text data. Corresponds to the JSON property text

Returns:

  • (String)


113
114
115
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 113

def text
  @text
end

#tool_callGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall

Request for the client or the agent to execute the specified tool. Corresponds to the JSON property toolCall



118
119
120
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 118

def tool_call
  @tool_call
end

#tool_responseGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolResponse

The execution result of a specific tool from the client or the agent. Corresponds to the JSON property toolResponse



123
124
125
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 123

def tool_response
  @tool_response
end

#transcriptString

Optional. Transcript associated with the audio. Corresponds to the JSON property transcript

Returns:

  • (String)


128
129
130
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 128

def transcript
  @transcript
end

#updated_variablesHash<String,Object>

A struct represents variables that were updated in the conversation, keyed by variable names. Corresponds to the JSON property updatedVariables

Returns:

  • (Hash<String,Object>)


134
135
136
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 134

def updated_variables
  @updated_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 141

def update!(**args)
  @agent_transfer = args[:agent_transfer] if args.key?(:agent_transfer)
  @blob = args[:blob] if args.key?(:blob)
  @default_variables = args[:default_variables] if args.key?(:default_variables)
  @image = args[:image] if args.key?(:image)
  @payload = args[:payload] if args.key?(:payload)
  @text = args[:text] if args.key?(:text)
  @tool_call = args[:tool_call] if args.key?(:tool_call)
  @tool_response = args[:tool_response] if args.key?(:tool_response)
  @transcript = args[:transcript] if args.key?(:transcript)
  @updated_variables = args[:updated_variables] if args.key?(:updated_variables)
end