Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainChunk
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainChunk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A chunk of content within a message.
Instance Attribute Summary collapse
-
#agent_transfer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainAgentTransfer
Represents an event indicating the transfer of a conversation to a different agent.
-
#blob ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainBlob
Represents a blob input or output in the conversation.
-
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed by variable names.
-
#image ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainImage
Represents an image input or output in the conversation.
-
#payload ⇒ Hash<String,Object>
Optional.
-
#text ⇒ String
Optional.
-
#tool_call ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall
Request for the client or the agent to execute the specified tool.
-
#tool_response ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolResponse
The execution result of a specific tool from the client or the agent.
-
#transcript ⇒ String
Optional.
-
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by variable names.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCesV1mainChunk
constructor
A new instance of GoogleCloudCesV1mainChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCesV1mainChunk
Returns a new instance of GoogleCloudCesV1mainChunk.
136 137 138 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 136 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_transfer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainAgentTransfer
Represents an event indicating the transfer of a conversation to a different
agent.
Corresponds to the JSON property agentTransfer
87 88 89 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 87 def agent_transfer @agent_transfer end |
#blob ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainBlob
Represents a blob input or output in the conversation.
Corresponds to the JSON property blob
92 93 94 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 92 def blob @blob end |
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed
by variable names.
Corresponds to the JSON property defaultVariables
98 99 100 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 98 def default_variables @default_variables end |
#image ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainImage
Represents an image input or output in the conversation.
Corresponds to the JSON property image
103 104 105 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 103 def image @image end |
#payload ⇒ Hash<String,Object>
Optional. Custom payload data.
Corresponds to the JSON property payload
108 109 110 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 108 def payload @payload end |
#text ⇒ String
Optional. Text data.
Corresponds to the JSON property text
113 114 115 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 113 def text @text end |
#tool_call ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall
Request for the client or the agent to execute the specified tool.
Corresponds to the JSON property toolCall
118 119 120 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 118 def tool_call @tool_call end |
#tool_response ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolResponse
The execution result of a specific tool from the client or the agent.
Corresponds to the JSON property toolResponse
123 124 125 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 123 def tool_response @tool_response end |
#transcript ⇒ String
Optional. Transcript associated with the audio.
Corresponds to the JSON property transcript
128 129 130 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 128 def transcript @transcript end |
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by
variable names.
Corresponds to the JSON property updatedVariables
134 135 136 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 134 def updated_variables @updated_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 141 def update!(**args) @agent_transfer = args[:agent_transfer] if args.key?(:agent_transfer) @blob = args[:blob] if args.key?(:blob) @default_variables = args[:default_variables] if args.key?(:default_variables) @image = args[:image] if args.key?(:image) @payload = args[:payload] if args.key?(:payload) @text = args[:text] if args.key?(:text) @tool_call = args[:tool_call] if args.key?(:tool_call) @tool_response = args[:tool_response] if args.key?(:tool_response) @transcript = args[:transcript] if args.key?(:transcript) @updated_variables = args[:updated_variables] if args.key?(:updated_variables) end |