Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainEndSession
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainEndSession
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent.
Instance Attribute Summary collapse
-
#metadata ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCesV1mainEndSession
constructor
A new instance of GoogleCloudCesV1mainEndSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCesV1mainEndSession
Returns a new instance of GoogleCloudCesV1mainEndSession.
168 169 170 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ Hash<String,Object>
Optional. Provides additional information about the end session signal, such
as the reason for ending the session.
Corresponds to the JSON property metadata
166 167 168 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 166 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
173 174 175 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 173 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) end |