Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A message within a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainMessage

Returns a new instance of GoogleCloudCesV1mainMessage.



225
226
227
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunksArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainChunk>

Optional. Content of the message as a series of chunks. Corresponds to the JSON property chunks



212
213
214
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 212

def chunks
  @chunks
end

#event_timeString

Optional. Timestamp when the message was sent or received. Should not be used if the message is part of an example. Corresponds to the JSON property eventTime

Returns:

  • (String)


218
219
220
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 218

def event_time
  @event_time
end

#roleString

Optional. The role within the conversation, e.g., user, agent. Corresponds to the JSON property role

Returns:

  • (String)


223
224
225
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 223

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



230
231
232
233
234
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 230

def update!(**args)
  @chunks = args[:chunks] if args.key?(:chunks)
  @event_time = args[:event_time] if args.key?(:event_time)
  @role = args[:role] if args.key?(:role)
end