Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A span is a unit of work or a single operation during the request processing.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Object>
Output only.
-
#child_spans ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan>
Output only.
-
#duration ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCesV1mainSpan
constructor
A new instance of GoogleCloudCesV1mainSpan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCesV1mainSpan
Returns a new instance of GoogleCloudCesV1mainSpan.
271 272 273 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Object>
Output only. Key-value attributes associated with the span.
Corresponds to the JSON property attributes
244 245 246 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 244 def attributes @attributes end |
#child_spans ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan>
Output only. The child spans that are nested under this span.
Corresponds to the JSON property childSpans
249 250 251 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 249 def child_spans @child_spans end |
#duration ⇒ String
Output only. The duration of the span.
Corresponds to the JSON property duration
254 255 256 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 254 def duration @duration end |
#end_time ⇒ String
Output only. The end time of the span.
Corresponds to the JSON property endTime
259 260 261 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 259 def end_time @end_time end |
#name ⇒ String
Output only. The name of the span.
Corresponds to the JSON property name
264 265 266 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 264 def name @name end |
#start_time ⇒ String
Output only. The start time of the span.
Corresponds to the JSON property startTime
269 270 271 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 269 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
276 277 278 279 280 281 282 283 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 276 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @child_spans = args[:child_spans] if args.key?(:child_spans) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |