Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request for the client or the agent to execute the specified tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainToolCall

Returns a new instance of GoogleCloudCesV1mainToolCall.



874
875
876
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The input parameters and values for the tool in JSON object format. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


850
851
852
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 850

def args
  @args
end

#display_nameString

Output only. Display name of the tool. Corresponds to the JSON property displayName

Returns:

  • (String)


855
856
857
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 855

def display_name
  @display_name
end

#idString

Optional. The unique identifier of the tool call. If populated, the client should return the execution result with the matching ID in ToolResponse. Corresponds to the JSON property id

Returns:

  • (String)


861
862
863
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 861

def id
  @id
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool` Corresponds to the JSON propertytool`

Returns:

  • (String)


867
868
869
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 867

def tool
  @tool
end

#toolset_toolGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



872
873
874
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 872

def toolset_tool
  @toolset_tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



879
880
881
882
883
884
885
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 879

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
end