Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolCall
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Request for the client or the agent to execute the specified tool.
Instance Attribute Summary collapse
-
#args ⇒ Hash<String,Object>
Optional.
-
#display_name ⇒ String
Output only.
-
#id ⇒ String
Optional.
-
#tool ⇒ String
Optional.
-
#toolset_tool ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool
A tool that is created from a toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCesV1mainToolCall
constructor
A new instance of GoogleCloudCesV1mainToolCall.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCesV1mainToolCall
Returns a new instance of GoogleCloudCesV1mainToolCall.
317 318 319 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Hash<String,Object>
Optional. The input parameters and values for the tool in JSON object format.
Corresponds to the JSON property args
293 294 295 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 293 def args @args end |
#display_name ⇒ String
Output only. Display name of the tool.
Corresponds to the JSON property displayName
298 299 300 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 298 def display_name @display_name end |
#id ⇒ String
Optional. The unique identifier of the tool call. If populated, the client
should return the execution result with the matching ID in ToolResponse.
Corresponds to the JSON property id
304 305 306 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 304 def id @id end |
#tool ⇒ String
Optional. The name of the tool to execute. Format: projects/project/
locations/location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
310 311 312 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 310 def tool @tool end |
#toolset_tool ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
315 316 317 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 315 def toolset_tool @toolset_tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
322 323 324 325 326 327 328 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 322 def update!(**args) @args = args[:args] if args.key?(:args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) end |