Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The execution result of a specific tool from the client or the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainToolResponse

Returns a new instance of GoogleCloudCesV1mainToolResponse.



364
365
366
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. Display name of the tool. Corresponds to the JSON property displayName

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 338

def display_name
  @display_name
end

#idString

Optional. The matching ID of the tool call the response is for. Corresponds to the JSON property id

Returns:

  • (String)


343
344
345
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 343

def id
  @id
end

#responseHash<String,Object>

Required. The tool execution result in JSON object format. Use "output" key to specify tool response and "error" key to specify error details (if any). If " output" and "error" keys are not specified, then whole "response" is treated as tool execution result. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


351
352
353
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 351

def response
  @response
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool` Corresponds to the JSON propertytool`

Returns:

  • (String)


357
358
359
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 357

def tool
  @tool
end

#toolset_toolGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



362
363
364
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 362

def toolset_tool
  @toolset_tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



369
370
371
372
373
374
375
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 369

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @response = args[:response] if args.key?(:response)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
end