Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The execution result of a specific tool from the client or the agent.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#id ⇒ String
Optional.
-
#response ⇒ Hash<String,Object>
Required.
-
#tool ⇒ String
Optional.
-
#toolset_tool ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool
A tool that is created from a toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCesV1mainToolResponse
constructor
A new instance of GoogleCloudCesV1mainToolResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCesV1mainToolResponse
Returns a new instance of GoogleCloudCesV1mainToolResponse.
364 365 366 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Display name of the tool.
Corresponds to the JSON property displayName
338 339 340 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 338 def display_name @display_name end |
#id ⇒ String
Optional. The matching ID of the tool call the response is for.
Corresponds to the JSON property id
343 344 345 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 343 def id @id end |
#response ⇒ Hash<String,Object>
Required. The tool execution result in JSON object format. Use "output" key to
specify tool response and "error" key to specify error details (if any). If "
output" and "error" keys are not specified, then whole "response" is treated
as tool execution result.
Corresponds to the JSON property response
351 352 353 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 351 def response @response end |
#tool ⇒ String
Optional. The name of the tool to execute. Format: projects/project/
locations/location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
357 358 359 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 357 def tool @tool end |
#toolset_tool ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
362 363 364 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 362 def toolset_tool @toolset_tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
369 370 371 372 373 374 375 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 369 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @response = args[:response] if args.key?(:response) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) end |