Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A tool that is created from a toolset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudCesV1mainToolsetTool

Returns a new instance of GoogleCloudCesV1mainToolsetTool.



393
394
395
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_idString

Optional. The tool ID to filter the tools to retrieve the schema for. Corresponds to the JSON property toolId

Returns:

  • (String)


385
386
387
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 385

def tool_id
  @tool_id
end

#toolsetString

Required. The resource name of the Toolset from which this tool is derived. Format: projects/project/locations/location/apps/app/toolsets/toolset` Corresponds to the JSON propertytoolset`

Returns:

  • (String)


391
392
393
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 391

def toolset
  @toolset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



398
399
400
401
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 398

def update!(**args)
  @tool_id = args[:tool_id] if args.key?(:tool_id)
  @toolset = args[:toolset] if args.key?(:toolset)
end