Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainToolsetTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A tool that is created from a toolset.
Instance Attribute Summary collapse
-
#tool_id ⇒ String
Optional.
-
#toolset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudCesV1mainToolsetTool
constructor
A new instance of GoogleCloudCesV1mainToolsetTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudCesV1mainToolsetTool
Returns a new instance of GoogleCloudCesV1mainToolsetTool.
393 394 395 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tool_id ⇒ String
Optional. The tool ID to filter the tools to retrieve the schema for.
Corresponds to the JSON property toolId
385 386 387 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 385 def tool_id @tool_id end |
#toolset ⇒ String
Required. The resource name of the Toolset from which this tool is derived.
Format: projects/project/locations/location/apps/app/toolsets/toolset`
Corresponds to the JSON propertytoolset`
391 392 393 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 391 def toolset @toolset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
398 399 400 401 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 398 def update!(**args) @tool_id = args[:tool_id] if args.key?(:tool_id) @toolset = args[:toolset] if args.key?(:toolset) end |