Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Call-specific metadata created during analysis.
Instance Attribute Summary collapse
-
#annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CallAnnotation>
A list of call annotations that apply to this call.
-
#entities ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Entity>
All the entities in the call.
-
#intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Intent>
All the matched intents in the call.
-
#issue_model_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelResult
Issue Modeling result on a conversation.
-
#phrase_matchers ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchData>
All the matched phrase matchers in the call.
-
#qa_scorecard_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResult>
Results of scoring QaScorecards.
-
#sentiments ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationLevelSentiment>
Overall conversation-level sentiment for each channel of the call.
-
#silence ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationLevelSilence
Conversation-level silence data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata.
518 519 520 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CallAnnotation>
A list of call annotations that apply to this call.
Corresponds to the JSON property annotations
481 482 483 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 481 def annotations @annotations end |
#entities ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Entity>
All the entities in the call.
Corresponds to the JSON property entities
486 487 488 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 486 def entities @entities end |
#intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Intent>
All the matched intents in the call.
Corresponds to the JSON property intents
491 492 493 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 491 def intents @intents end |
#issue_model_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelResult
Issue Modeling result on a conversation.
Corresponds to the JSON property issueModelResult
496 497 498 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 496 def issue_model_result @issue_model_result end |
#phrase_matchers ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchData>
All the matched phrase matchers in the call.
Corresponds to the JSON property phraseMatchers
501 502 503 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 501 def phrase_matchers @phrase_matchers end |
#qa_scorecard_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResult>
Results of scoring QaScorecards.
Corresponds to the JSON property qaScorecardResults
506 507 508 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 506 def qa_scorecard_results @qa_scorecard_results end |
#sentiments ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationLevelSentiment>
Overall conversation-level sentiment for each channel of the call.
Corresponds to the JSON property sentiments
511 512 513 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 511 def sentiments @sentiments end |
#silence ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationLevelSilence
Conversation-level silence data.
Corresponds to the JSON property silence
516 517 518 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 516 def silence @silence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
523 524 525 526 527 528 529 530 531 532 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 523 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @entities = args[:entities] if args.key?(:entities) @intents = args[:intents] if args.key?(:intents) @issue_model_result = args[:issue_model_result] if args.key?(:issue_model_result) @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers) @qa_scorecard_results = args[:qa_scorecard_results] if args.key?(:qa_scorecard_results) @sentiments = args[:sentiments] if args.key?(:sentiments) @silence = args[:silence] if args.key?(:silence) end |