Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnalysisRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnalysisRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CCAI Insights project wide analysis rule. This rule will be applied to all conversations that match the filter defined in the rule. For a conversation matches the filter, the annotators specified in the rule will be run. If a conversation matches multiple rules, a union of all the annotators will be run. One project can have multiple analysis rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
If true, apply this rule to conversations.
-
#analysis_percentage ⇒ Float
Percentage of conversations that we should apply this analysis setting automatically, between [0, 1].
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#conversation_filter ⇒ String
Filter for the conversations that should apply this analysis rule.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display Name of the analysis rule.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnalysisRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1AnalysisRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnalysisRule
Returns a new instance of GoogleCloudContactcenterinsightsV1AnalysisRule.
591 592 593 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
If true, apply this rule to conversations. Otherwise, this rule is inactive
and saved as a draft.
Corresponds to the JSON property active
547 548 549 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 547 def active @active end |
#analysis_percentage ⇒ Float
Percentage of conversations that we should apply this analysis setting
automatically, between [0, 1]. For example, 0.1 means 10%. Conversations are
sampled in a determenestic way. The original runtime_percentage & upload
percentage will be replaced by defining filters on the conversation.
Corresponds to the JSON property analysisPercentage
556 557 558 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 556 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
561 562 563 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 561 def annotator_selector @annotator_selector end |
#conversation_filter ⇒ String
Filter for the conversations that should apply this analysis rule. An empty
filter means this analysis rule applies to all conversations. Refer to https://
cloud.google.com/contact-center/insights/docs/filtering for details.
Corresponds to the JSON property conversationFilter
568 569 570 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 568 def conversation_filter @conversation_filter end |
#create_time ⇒ String
Output only. The time at which this analysis rule was created.
Corresponds to the JSON property createTime
573 574 575 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 573 def create_time @create_time end |
#display_name ⇒ String
Display Name of the analysis rule.
Corresponds to the JSON property displayName
578 579 580 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 578 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of the analysis rule. Format: projects/project/
locations/location/analysisRules/analysis_rule
Corresponds to the JSON property name
584 585 586 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 584 def name @name end |
#update_time ⇒ String
Output only. The most recent time at which this analysis rule was updated.
Corresponds to the JSON property updateTime
589 590 591 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 589 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 596 def update!(**args) @active = args[:active] if args.key?(:active) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |