Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A point in a conversation that marks the start or the end of an annotation.
Instance Attribute Summary collapse
-
#transcript_index ⇒ Fixnum
The index in the sequence of transcribed pieces of the conversation where the boundary is located.
-
#word_index ⇒ Fixnum
The word index of this boundary with respect to the first word in the transcript piece.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnnotationBoundary
constructor
A new instance of GoogleCloudContactcenterinsightsV1AnnotationBoundary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnnotationBoundary
Returns a new instance of GoogleCloudContactcenterinsightsV1AnnotationBoundary.
624 625 626 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#transcript_index ⇒ Fixnum
The index in the sequence of transcribed pieces of the conversation where the
boundary is located. This index starts at zero.
Corresponds to the JSON property transcriptIndex
616 617 618 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 616 def transcript_index @transcript_index end |
#word_index ⇒ Fixnum
The word index of this boundary with respect to the first word in the
transcript piece. This index starts at zero.
Corresponds to the JSON property wordIndex
622 623 624 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 622 def word_index @word_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
629 630 631 632 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 629 def update!(**args) @transcript_index = args[:transcript_index] if args.key?(:transcript_index) @word_index = args[:word_index] if args.key?(:word_index) end |