Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Selector of all available annotators and phrase matchers to run.
Instance Attribute Summary collapse
-
#issue_models ⇒ Array<String>
The issue model to run.
-
#phrase_matchers ⇒ Array<String>
The list of phrase matchers to run.
-
#qa_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelectorQaConfig
Configuration for the QA feature.
-
#run_auto_labeling_annotator ⇒ Boolean
(also: #run_auto_labeling_annotator?)
Optional.
-
#run_entity_annotator ⇒ Boolean
(also: #run_entity_annotator?)
Whether to run the entity annotator.
-
#run_intent_annotator ⇒ Boolean
(also: #run_intent_annotator?)
Whether to run the intent annotator.
-
#run_interruption_annotator ⇒ Boolean
(also: #run_interruption_annotator?)
Whether to run the interruption annotator.
-
#run_issue_model_annotator ⇒ Boolean
(also: #run_issue_model_annotator?)
Whether to run the issue model annotator.
-
#run_phrase_matcher_annotator ⇒ Boolean
(also: #run_phrase_matcher_annotator?)
Whether to run the active phrase matcher annotator(s).
-
#run_qa_annotator ⇒ Boolean
(also: #run_qa_annotator?)
Whether to run the QA annotator.
-
#run_sentiment_annotator ⇒ Boolean
(also: #run_sentiment_annotator?)
Whether to run the sentiment annotator.
-
#run_silence_annotator ⇒ Boolean
(also: #run_silence_annotator?)
Whether to run the silence annotator.
-
#run_summarization_annotator ⇒ Boolean
(also: #run_summarization_annotator?)
Whether to run the summarization annotator.
-
#summarization_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelectorSummarizationConfig
Configuration for summarization.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnnotatorSelector
constructor
A new instance of GoogleCloudContactcenterinsightsV1AnnotatorSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnnotatorSelector
Returns a new instance of GoogleCloudContactcenterinsightsV1AnnotatorSelector.
730 731 732 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issue_models ⇒ Array<String>
The issue model to run. If not provided, the most recently deployed topic
model will be used. The provided issue model will only be used for inference
if the issue model is deployed and if run_issue_model_annotator is set to true.
If more than one issue model is provided, only the first provided issue model
will be used for inference.
Corresponds to the JSON property issueModels
646 647 648 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 646 def issue_models @issue_models end |
#phrase_matchers ⇒ Array<String>
The list of phrase matchers to run. If not provided, all active phrase
matchers will be used. If inactive phrase matchers are provided, they will not
be used. Phrase matchers will be run only if run_phrase_matcher_annotator is
set to true. Format: projects/project/locations/location/phraseMatchers/
phrase_matcher
Corresponds to the JSON property phraseMatchers
655 656 657 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 655 def phrase_matchers @phrase_matchers end |
#qa_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelectorQaConfig
Configuration for the QA feature.
Corresponds to the JSON property qaConfig
660 661 662 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 660 def qa_config @qa_config end |
#run_auto_labeling_annotator ⇒ Boolean Also known as: run_auto_labeling_annotator?
Optional. Whether to run the auto-labeling annotator. If true, the auto-
labeling annotator will be run. This is a non-billable operation designed for
fixing or backfilling custom labels.
Corresponds to the JSON property runAutoLabelingAnnotator
667 668 669 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 667 def run_auto_labeling_annotator @run_auto_labeling_annotator end |
#run_entity_annotator ⇒ Boolean Also known as: run_entity_annotator?
Whether to run the entity annotator.
Corresponds to the JSON property runEntityAnnotator
673 674 675 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 673 def run_entity_annotator @run_entity_annotator end |
#run_intent_annotator ⇒ Boolean Also known as: run_intent_annotator?
Whether to run the intent annotator.
Corresponds to the JSON property runIntentAnnotator
679 680 681 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 679 def run_intent_annotator @run_intent_annotator end |
#run_interruption_annotator ⇒ Boolean Also known as: run_interruption_annotator?
Whether to run the interruption annotator.
Corresponds to the JSON property runInterruptionAnnotator
685 686 687 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 685 def run_interruption_annotator @run_interruption_annotator end |
#run_issue_model_annotator ⇒ Boolean Also known as: run_issue_model_annotator?
Whether to run the issue model annotator. A model should have already been
deployed for this to take effect.
Corresponds to the JSON property runIssueModelAnnotator
692 693 694 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 692 def run_issue_model_annotator @run_issue_model_annotator end |
#run_phrase_matcher_annotator ⇒ Boolean Also known as: run_phrase_matcher_annotator?
Whether to run the active phrase matcher annotator(s).
Corresponds to the JSON property runPhraseMatcherAnnotator
698 699 700 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 698 def run_phrase_matcher_annotator @run_phrase_matcher_annotator end |
#run_qa_annotator ⇒ Boolean Also known as: run_qa_annotator?
Whether to run the QA annotator.
Corresponds to the JSON property runQaAnnotator
704 705 706 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 704 def run_qa_annotator @run_qa_annotator end |
#run_sentiment_annotator ⇒ Boolean Also known as: run_sentiment_annotator?
Whether to run the sentiment annotator.
Corresponds to the JSON property runSentimentAnnotator
710 711 712 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 710 def run_sentiment_annotator @run_sentiment_annotator end |
#run_silence_annotator ⇒ Boolean Also known as: run_silence_annotator?
Whether to run the silence annotator.
Corresponds to the JSON property runSilenceAnnotator
716 717 718 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 716 def run_silence_annotator @run_silence_annotator end |
#run_summarization_annotator ⇒ Boolean Also known as: run_summarization_annotator?
Whether to run the summarization annotator.
Corresponds to the JSON property runSummarizationAnnotator
722 723 724 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 722 def run_summarization_annotator @run_summarization_annotator end |
#summarization_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelectorSummarizationConfig
Configuration for summarization.
Corresponds to the JSON property summarizationConfig
728 729 730 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 728 def summarization_config @summarization_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 735 def update!(**args) @issue_models = args[:issue_models] if args.key?(:issue_models) @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers) @qa_config = args[:qa_config] if args.key?(:qa_config) @run_auto_labeling_annotator = args[:run_auto_labeling_annotator] if args.key?(:run_auto_labeling_annotator) @run_entity_annotator = args[:run_entity_annotator] if args.key?(:run_entity_annotator) @run_intent_annotator = args[:run_intent_annotator] if args.key?(:run_intent_annotator) @run_interruption_annotator = args[:run_interruption_annotator] if args.key?(:run_interruption_annotator) @run_issue_model_annotator = args[:run_issue_model_annotator] if args.key?(:run_issue_model_annotator) @run_phrase_matcher_annotator = args[:run_phrase_matcher_annotator] if args.key?(:run_phrase_matcher_annotator) @run_qa_annotator = args[:run_qa_annotator] if args.key?(:run_qa_annotator) @run_sentiment_annotator = args[:run_sentiment_annotator] if args.key?(:run_sentiment_annotator) @run_silence_annotator = args[:run_silence_annotator] if args.key?(:run_silence_annotator) @run_summarization_annotator = args[:run_summarization_annotator] if args.key?(:run_summarization_annotator) @summarization_config = args[:summarization_config] if args.key?(:summarization_config) end |