Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnswerFeedback
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnswerFeedback
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The feedback that the customer has about a certain answer in the conversation.
Instance Attribute Summary collapse
-
#clicked ⇒ Boolean
(also: #clicked?)
Indicates whether an answer or item was clicked by the human agent.
-
#correctness_level ⇒ String
The correctness level of an answer.
-
#displayed ⇒ Boolean
(also: #displayed?)
Indicates whether an answer or item was displayed to the human agent in the agent desktop UI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnswerFeedback
constructor
A new instance of GoogleCloudContactcenterinsightsV1AnswerFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AnswerFeedback
Returns a new instance of GoogleCloudContactcenterinsightsV1AnswerFeedback.
1403 1404 1405 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clicked ⇒ Boolean Also known as: clicked?
Indicates whether an answer or item was clicked by the human agent.
Corresponds to the JSON property clicked
1388 1389 1390 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1388 def clicked @clicked end |
#correctness_level ⇒ String
The correctness level of an answer.
Corresponds to the JSON property correctnessLevel
1394 1395 1396 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1394 def correctness_level @correctness_level end |
#displayed ⇒ Boolean Also known as: displayed?
Indicates whether an answer or item was displayed to the human agent in the
agent desktop UI.
Corresponds to the JSON property displayed
1400 1401 1402 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1400 def displayed @displayed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1408 1409 1410 1411 1412 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1408 def update!(**args) @clicked = args[:clicked] if args.key?(:clicked) @correctness_level = args[:correctness_level] if args.key?(:correctness_level) @displayed = args[:displayed] if args.key?(:displayed) end |