Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AssessmentRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AssessmentRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CCAI Insights project wide assessment rule. This assessment rule will be applied to all conversations from the previous sampling cycle that match the sample rule defined in the assessment rule. One project can have multiple assessment rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
If true, apply this rule to conversations.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display Name of the assessment rule.
-
#name ⇒ String
Identifier.
-
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
-
#schedule_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo
Message for schedule info.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AssessmentRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1AssessmentRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AssessmentRule
Returns a new instance of GoogleCloudContactcenterinsightsV1AssessmentRule.
1570 1571 1572 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
If true, apply this rule to conversations. Otherwise, this rule is inactive.
Corresponds to the JSON property active
1536 1537 1538 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1536 def active @active end |
#create_time ⇒ String
Output only. The time at which this assessment rule was created.
Corresponds to the JSON property createTime
1542 1543 1544 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1542 def create_time @create_time end |
#display_name ⇒ String
Display Name of the assessment rule.
Corresponds to the JSON property displayName
1547 1548 1549 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1547 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of the assessment rule. Format: projects/
project/locations/location/assessmentRules/assessment_rule
Corresponds to the JSON property name
1553 1554 1555 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1553 def name @name end |
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
Corresponds to the JSON property sampleRule
1558 1559 1560 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1558 def sample_rule @sample_rule end |
#schedule_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo
Message for schedule info.
Corresponds to the JSON property scheduleInfo
1563 1564 1565 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1563 def schedule_info @schedule_info end |
#update_time ⇒ String
Output only. The most recent time at which this assessment rule was updated.
Corresponds to the JSON property updateTime
1568 1569 1570 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1568 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1575 1576 1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1575 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @sample_rule = args[:sample_rule] if args.key?(:sample_rule) @schedule_info = args[:schedule_info] if args.key?(:schedule_info) @update_time = args[:update_time] if args.key?(:update_time) end |