Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AssessmentRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AssessmentRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CCAI Insights project wide assessment rule. This assessment rule will be applied to all conversations from the previous sampling cycle that match the sample rule defined in the assessment rule. One project can have multiple assessment rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
If true, apply this rule to conversations.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display Name of the assessment rule.
-
#name ⇒ String
Identifier.
-
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
-
#schedule_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo
Message for schedule info.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AssessmentRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1AssessmentRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AssessmentRule
Returns a new instance of GoogleCloudContactcenterinsightsV1AssessmentRule.
1013 1014 1015 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
If true, apply this rule to conversations. Otherwise, this rule is inactive.
Corresponds to the JSON property active
979 980 981 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 979 def active @active end |
#create_time ⇒ String
Output only. The time at which this assessment rule was created.
Corresponds to the JSON property createTime
985 986 987 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 985 def create_time @create_time end |
#display_name ⇒ String
Display Name of the assessment rule.
Corresponds to the JSON property displayName
990 991 992 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 990 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of the assessment rule. Format: projects/
project/locations/location/assessmentRules/assessment_rule
Corresponds to the JSON property name
996 997 998 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 996 def name @name end |
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
Corresponds to the JSON property sampleRule
1001 1002 1003 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1001 def sample_rule @sample_rule end |
#schedule_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo
Message for schedule info.
Corresponds to the JSON property scheduleInfo
1006 1007 1008 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1006 def schedule_info @schedule_info end |
#update_time ⇒ String
Output only. The most recent time at which this assessment rule was updated.
Corresponds to the JSON property updateTime
1011 1012 1013 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1011 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1018 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @sample_rule = args[:sample_rule] if args.key?(:sample_rule) @schedule_info = args[:schedule_info] if args.key?(:schedule_info) @update_time = args[:update_time] if args.key?(:update_time) end |