Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AuthorizedView

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An AuthorizedView represents a view of accessible Insights resources (for example, Conversation and Scorecard). Who have read access to the AuthorizedView resource will have access to these Insight resources as well.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AuthorizedView

Returns a new instance of GoogleCloudContactcenterinsightsV1AuthorizedView.



1174
1175
1176
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_filterString

A filter to reduce conversation results to a specific subset. The AuthorizedView's assigned permission (read/write) could be applied to the subset of conversations. If conversation_filter is empty, there is no restriction on the conversations that the AuthorizedView can access. Having * authorizedViews.get* access to the AuthorizedView means having the same read/ write access to the Conversations (as well as metadata/annotations linked to the conversation) that this AuthorizedView has. Corresponds to the JSON property conversationFilter

Returns:

  • (String)


1150
1151
1152
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1150

def conversation_filter
  @conversation_filter
end

#create_timeString

Output only. The time at which the authorized view was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1155
1156
1157
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1155

def create_time
  @create_time
end

#display_nameString

Display Name. Limit 64 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1160
1161
1162
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1160

def display_name
  @display_name
end

#nameString

Identifier. The resource name of the AuthorizedView. Format: projects/project /locations/location/authorizedViewSets/authorized_view_set/authorizedViews/ authorized_view Corresponds to the JSON property name

Returns:

  • (String)


1167
1168
1169
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1167

def name
  @name
end

#update_timeString

Output only. The most recent time at which the authorized view was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1172
1173
1174
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1172

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1179
1180
1181
1182
1183
1184
1185
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1179

def update!(**args)
  @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end