Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AuthorizedView
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AuthorizedView
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An AuthorizedView represents a view of accessible Insights resources (for example, Conversation and Scorecard). Who have read access to the AuthorizedView resource will have access to these Insight resources as well.
Instance Attribute Summary collapse
-
#conversation_filter ⇒ String
A filter to reduce conversation results to a specific subset.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display Name.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AuthorizedView
constructor
A new instance of GoogleCloudContactcenterinsightsV1AuthorizedView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AuthorizedView
Returns a new instance of GoogleCloudContactcenterinsightsV1AuthorizedView.
680 681 682 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_filter ⇒ String
A filter to reduce conversation results to a specific subset. The
AuthorizedView's assigned permission (read/write) could be applied to the
subset of conversations. If conversation_filter is empty, there is no
restriction on the conversations that the AuthorizedView can access. Having *
authorizedViews.get* access to the AuthorizedView means having the same read/
write access to the Conversations (as well as metadata/annotations linked to
the conversation) that this AuthorizedView has.
Corresponds to the JSON property conversationFilter
656 657 658 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 656 def conversation_filter @conversation_filter end |
#create_time ⇒ String
Output only. The time at which the authorized view was created.
Corresponds to the JSON property createTime
661 662 663 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 661 def create_time @create_time end |
#display_name ⇒ String
Display Name. Limit 64 characters.
Corresponds to the JSON property displayName
666 667 668 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 666 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of the AuthorizedView. Format: projects/project
/locations/location/authorizedViewSets/authorized_view_set/authorizedViews/
authorized_view
Corresponds to the JSON property name
673 674 675 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 673 def name @name end |
#update_time ⇒ String
Output only. The most recent time at which the authorized view was updated.
Corresponds to the JSON property updateTime
678 679 680 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 678 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
685 686 687 688 689 690 691 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 685 def update!(**args) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |