Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Rule for auto-labeling conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRule

Returns a new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRule.



1731
1732
1733
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1731

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Whether the rule is active. Corresponds to the JSON property active

Returns:

  • (Boolean)


1684
1685
1686
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1684

def active
  @active
end

#conditionsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition>

Conditions to apply for auto-labeling the label_key. Representing sequential block of if .. else if .. else statements. The value of the first matching condition will be used. Corresponds to the JSON property conditions



1692
1693
1694
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1692

def conditions
  @conditions
end

#create_timeString

Output only. The time at which this rule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1697
1698
1699
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1697

def create_time
  @create_time
end

#descriptionString

The description of the rule. Corresponds to the JSON property description

Returns:

  • (String)


1702
1703
1704
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1702

def description
  @description
end

#display_nameString

The user-provided display name of the rule. Corresponds to the JSON property displayName

Returns:

  • (String)


1707
1708
1709
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1707

def display_name
  @display_name
end

#label_keyString

The label key. This is also the auto_labeling_rule in the resource name. Only settable if label_key_type is LABEL_KEY_TYPE_CUSTOM. Corresponds to the JSON property labelKey

Returns:

  • (String)


1713
1714
1715
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1713

def label_key
  @label_key
end

#label_key_typeString

The type of the label key. Corresponds to the JSON property labelKeyType

Returns:

  • (String)


1718
1719
1720
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1718

def label_key_type
  @label_key_type
end

#nameString

Identifier. The resource name of the auto-labeling rule. Format: projects/ project/locations/location/autoLabelingRules/auto_labeling_rule Corresponds to the JSON property name

Returns:

  • (String)


1724
1725
1726
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1724

def name
  @name
end

#update_timeString

Output only. The most recent time at which the rule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1729
1730
1731
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1729

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1736

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @label_key = args[:label_key] if args.key?(:label_key)
  @label_key_type = args[:label_key_type] if args.key?(:label_key_type)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end