Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Rule for auto-labeling conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRule

Returns a new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRule.



786
787
788
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Whether the rule is active. Corresponds to the JSON property active

Returns:

  • (Boolean)


739
740
741
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 739

def active
  @active
end

#conditionsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition>

Conditions to apply for auto-labeling the label_key. Representing sequential block of if .. else if .. else statements. The value of the first matching condition will be used. Corresponds to the JSON property conditions



747
748
749
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 747

def conditions
  @conditions
end

#create_timeString

Output only. The time at which this rule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


752
753
754
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 752

def create_time
  @create_time
end

#descriptionString

The description of the rule. Corresponds to the JSON property description

Returns:

  • (String)


757
758
759
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 757

def description
  @description
end

#display_nameString

The user-provided display name of the rule. Corresponds to the JSON property displayName

Returns:

  • (String)


762
763
764
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 762

def display_name
  @display_name
end

#label_keyString

The label key. This is also the auto_labeling_rule in the resource name. Only settable if label_key_type is LABEL_KEY_TYPE_CUSTOM. Corresponds to the JSON property labelKey

Returns:

  • (String)


768
769
770
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 768

def label_key
  @label_key
end

#label_key_typeString

The type of the label key. Corresponds to the JSON property labelKeyType

Returns:

  • (String)


773
774
775
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 773

def label_key_type
  @label_key_type
end

#nameString

Identifier. The resource name of the auto-labeling rule. Format: projects/ project/locations/location/autoLabelingRules/auto_labeling_rule Corresponds to the JSON property name

Returns:

  • (String)


779
780
781
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 779

def name
  @name
end

#update_timeString

Output only. The most recent time at which the rule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


784
785
786
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 784

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



791
792
793
794
795
796
797
798
799
800
801
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 791

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @label_key = args[:label_key] if args.key?(:label_key)
  @label_key_type = args[:label_key_type] if args.key?(:label_key_type)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end