Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Condition for auto-labeling conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition

Returns a new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition.



1314
1315
1316
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

A optional CEL expression to be evaluated as a boolean value. Once evaluated as true, then we will proceed with the value evaluation. An empty condition will be auto evaluated as true. Corresponds to the JSON property condition

Returns:

  • (String)


1307
1308
1309
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1307

def condition
  @condition
end

#valueString

CEL expression to be evaluated as the value. Corresponds to the JSON property value

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1312

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1319
1320
1321
1322
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1319

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @value = args[:value] if args.key?(:value)
end