Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Condition for auto-labeling conversations.
Instance Attribute Summary collapse
-
#condition ⇒ String
A optional CEL expression to be evaluated as a boolean value.
-
#value ⇒ String
CEL expression to be evaluated as the value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
constructor
A new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
Returns a new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition.
1765 1766 1767 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
A optional CEL expression to be evaluated as a boolean value. Once evaluated
as true, then we will proceed with the value evaluation. An empty condition
will be auto evaluated as true.
Corresponds to the JSON property condition
1758 1759 1760 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1758 def condition @condition end |
#value ⇒ String
CEL expression to be evaluated as the value.
Corresponds to the JSON property value
1763 1764 1765 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1763 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1770 1771 1772 1773 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1770 def update!(**args) @condition = args[:condition] if args.key?(:condition) @value = args[:value] if args.key?(:value) end |