Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Condition for auto-labeling conversations.
Instance Attribute Summary collapse
-
#condition ⇒ String
A optional CEL expression to be evaluated as a boolean value.
-
#value ⇒ String
CEL expression to be evaluated as the value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
constructor
A new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
Returns a new instance of GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition.
1208 1209 1210 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
A optional CEL expression to be evaluated as a boolean value. Once evaluated
as true, then we will proceed with the value evaluation. An empty condition
will be auto evaluated as true.
Corresponds to the JSON property condition
1201 1202 1203 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1201 def condition @condition end |
#value ⇒ String
CEL expression to be evaluated as the value.
Corresponds to the JSON property value
1206 1207 1208 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1206 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1213 1214 1215 1216 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1213 def update!(**args) @condition = args[:condition] if args.key?(:condition) @value = args[:value] if args.key?(:value) end |