Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversations in bulk.
Instance Attribute Summary collapse
-
#analysis_percentage ⇒ Float
Required.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#filter ⇒ String
Required.
-
#parent ⇒ String
Required.
-
#relabel ⇒ Boolean
(also: #relabel?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest.
1872 1873 1874 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_percentage ⇒ Float
Required. Percentage of selected conversation to analyze, between [0, 100].
Corresponds to the JSON property analysisPercentage
1848 1849 1850 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1848 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
1853 1854 1855 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1853 def annotator_selector @annotator_selector end |
#filter ⇒ String
Required. Filter used to select the subset of conversations to analyze.
Corresponds to the JSON property filter
1858 1859 1860 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1858 def filter @filter end |
#parent ⇒ String
Required. The parent resource to create analyses in.
Corresponds to the JSON property parent
1863 1864 1865 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1863 def parent @parent end |
#relabel ⇒ Boolean Also known as: relabel?
Optional. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
1869 1870 1871 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1869 def relabel @relabel end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1877 1878 1879 1880 1881 1882 1883 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1877 def update!(**args) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @filter = args[:filter] if args.key?(:filter) @parent = args[:parent] if args.key?(:parent) @relabel = args[:relabel] if args.key?(:relabel) end |