Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk delete conversations operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during bulk delete conversations operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsMetadata.
1485 1486 1487 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
1467 1468 1469 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1467 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
1472 1473 1474 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1472 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during bulk delete conversations operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
1478 1479 1480 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1478 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
Corresponds to the JSON property request
1483 1484 1485 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1483 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1490 1491 1492 1493 1494 1495 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1490 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |