Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest.



1015
1016
1017
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


995
996
997
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 995

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


1001
1002
1003
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1001

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


1007
1008
1009
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1007

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1013

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1020
1021
1022
1023
1024
1025
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1020

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end