Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest.



916
917
918
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


896
897
898
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 896

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


902
903
904
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 902

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


908
909
910
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 908

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


914
915
916
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 914

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



921
922
923
924
925
926
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 921

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end