Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for the BulkDownloadFeedbackLabel endpoint.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata.
1543 1544 1545 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
1520 1521 1522 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1520 def create_time @create_time end |
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
Corresponds to the JSON property downloadStats
1525 1526 1527 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1525 def download_stats @download_stats end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
1530 1531 1532 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1530 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
1536 1537 1538 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1536 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Corresponds to the JSON property request
1541 1542 1543 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1541 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1548 1549 1550 1551 1552 1553 1554 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1548 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @download_stats = args[:download_stats] if args.key?(:download_stats) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |