Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for the BulkDownloadFeedbackLabel endpoint.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadata.
1040 1041 1042 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
1017 1018 1019 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1017 def create_time @create_time end |
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
Corresponds to the JSON property downloadStats
1022 1023 1024 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1022 def download_stats @download_stats end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
1027 1028 1029 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1027 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
1033 1034 1035 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1033 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Corresponds to the JSON property request
1038 1039 1040 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1038 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1045 1046 1047 1048 1049 1050 1051 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1045 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @download_stats = args[:download_stats] if args.key?(:download_stats) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |