Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Statistics for BulkDownloadFeedbackLabels operation.
Instance Attribute Summary collapse
-
#file_names ⇒ Array<String>
Output only.
-
#processed_object_count ⇒ Fixnum
The number of objects processed during the download operation.
-
#successful_download_count ⇒ Fixnum
The number of new feedback labels downloaded during this operation.
-
#total_files_written ⇒ Fixnum
Total number of files written to the provided Cloud Storage bucket.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats.
1582 1583 1584 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_names ⇒ Array<String>
Output only. Full name of the files written to Cloud storage.
Corresponds to the JSON property fileNames
1564 1565 1566 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1564 def file_names @file_names end |
#processed_object_count ⇒ Fixnum
The number of objects processed during the download operation.
Corresponds to the JSON property processedObjectCount
1569 1570 1571 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1569 def processed_object_count @processed_object_count end |
#successful_download_count ⇒ Fixnum
The number of new feedback labels downloaded during this operation. Different
from "processed" because some labels might not be downloaded because an error.
Corresponds to the JSON property successfulDownloadCount
1575 1576 1577 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1575 def successful_download_count @successful_download_count end |
#total_files_written ⇒ Fixnum
Total number of files written to the provided Cloud Storage bucket.
Corresponds to the JSON property totalFilesWritten
1580 1581 1582 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1580 def total_files_written @total_files_written end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1587 1588 1589 1590 1591 1592 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1587 def update!(**args) @file_names = args[:file_names] if args.key?(:file_names) @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count) @successful_download_count = args[:successful_download_count] if args.key?(:successful_download_count) @total_files_written = args[:total_files_written] if args.key?(:total_files_written) end |