Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for BulkDownloadFeedbackLabels operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsMetadataDownloadStats.



1079
1080
1081
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_namesArray<String>

Output only. Full name of the files written to Cloud storage. Corresponds to the JSON property fileNames

Returns:

  • (Array<String>)


1061
1062
1063
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1061

def file_names
  @file_names
end

#processed_object_countFixnum

The number of objects processed during the download operation. Corresponds to the JSON property processedObjectCount

Returns:

  • (Fixnum)


1066
1067
1068
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1066

def processed_object_count
  @processed_object_count
end

#successful_download_countFixnum

The number of new feedback labels downloaded during this operation. Different from "processed" because some labels might not be downloaded because an error. Corresponds to the JSON property successfulDownloadCount

Returns:

  • (Fixnum)


1072
1073
1074
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1072

def successful_download_count
  @successful_download_count
end

#total_files_writtenFixnum

Total number of files written to the provided Cloud Storage bucket. Corresponds to the JSON property totalFilesWritten

Returns:

  • (Fixnum)


1077
1078
1079
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1077

def total_files_written
  @total_files_written
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1084
1085
1086
1087
1088
1089
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1084

def update!(**args)
  @file_names = args[:file_names] if args.key?(:file_names)
  @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count)
  @successful_download_count = args[:successful_download_count] if args.key?(:successful_download_count)
  @total_files_written = args[:total_files_written] if args.key?(:total_files_written)
end