Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Google Cloud Storage Object details to write the feedback labels to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination.



2262
2263
2264
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_whitespaceBoolean Also known as: add_whitespace?

Optional. Add whitespace to the JSON file. Makes easier to read, but increases file size. Only applicable for JSON format. Corresponds to the JSON property addWhitespace

Returns:

  • (Boolean)


2232
2233
2234
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2232

def add_whitespace
  @add_whitespace
end

#always_print_empty_fieldsBoolean Also known as: always_print_empty_fields?

Optional. Always print fields with no presence. This is useful for printing fields that are not set, like implicit 0 value or empty lists/maps. Only applicable for JSON format. Corresponds to the JSON property alwaysPrintEmptyFields

Returns:

  • (Boolean)


2240
2241
2242
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2240

def always_print_empty_fields
  @always_print_empty_fields
end

#formatString

Required. File format in which the labels will be exported. Corresponds to the JSON property format

Returns:

  • (String)


2246
2247
2248
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2246

def format
  @format
end

#object_uriString

Required. The Google Cloud Storage URI to write the feedback labels to. The file name will be used as a prefix for the files written to the bucket if the output needs to be split across multiple files, otherwise it will be used as is. The file extension will be appended to the file name based on the format selected. E.g. gs://bucket_name/object_uri_prefix Corresponds to the JSON property objectUri

Returns:

  • (String)


2255
2256
2257
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2255

def object_uri
  @object_uri
end

#records_per_file_countFixnum

Optional. The number of records per file. Applicable for either format. Corresponds to the JSON property recordsPerFileCount

Returns:

  • (Fixnum)


2260
2261
2262
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2260

def records_per_file_count
  @records_per_file_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2267
2268
2269
2270
2271
2272
2273
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2267

def update!(**args)
  @add_whitespace = args[:add_whitespace] if args.key?(:add_whitespace)
  @always_print_empty_fields = args[:always_print_empty_fields] if args.key?(:always_print_empty_fields)
  @format = args[:format] if args.key?(:format)
  @object_uri = args[:object_uri] if args.key?(:object_uri)
  @records_per_file_count = args[:records_per_file_count] if args.key?(:records_per_file_count)
end