Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Google Cloud Storage Object details to write the feedback labels to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination.



1705
1706
1707
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_whitespaceBoolean Also known as: add_whitespace?

Optional. Add whitespace to the JSON file. Makes easier to read, but increases file size. Only applicable for JSON format. Corresponds to the JSON property addWhitespace

Returns:

  • (Boolean)


1675
1676
1677
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1675

def add_whitespace
  @add_whitespace
end

#always_print_empty_fieldsBoolean Also known as: always_print_empty_fields?

Optional. Always print fields with no presence. This is useful for printing fields that are not set, like implicit 0 value or empty lists/maps. Only applicable for JSON format. Corresponds to the JSON property alwaysPrintEmptyFields

Returns:

  • (Boolean)


1683
1684
1685
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1683

def always_print_empty_fields
  @always_print_empty_fields
end

#formatString

Required. File format in which the labels will be exported. Corresponds to the JSON property format

Returns:

  • (String)


1689
1690
1691
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1689

def format
  @format
end

#object_uriString

Required. The Google Cloud Storage URI to write the feedback labels to. The file name will be used as a prefix for the files written to the bucket if the output needs to be split across multiple files, otherwise it will be used as is. The file extension will be appended to the file name based on the format selected. E.g. gs://bucket_name/object_uri_prefix Corresponds to the JSON property objectUri

Returns:

  • (String)


1698
1699
1700
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1698

def object_uri
  @object_uri
end

#records_per_file_countFixnum

Optional. The number of records per file. Applicable for either format. Corresponds to the JSON property recordsPerFileCount

Returns:

  • (Fixnum)


1703
1704
1705
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1703

def records_per_file_count
  @records_per_file_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1710
1711
1712
1713
1714
1715
1716
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1710

def update!(**args)
  @add_whitespace = args[:add_whitespace] if args.key?(:add_whitespace)
  @always_print_empty_fields = args[:always_print_empty_fields] if args.key?(:always_print_empty_fields)
  @format = args[:format] if args.key?(:format)
  @object_uri = args[:object_uri] if args.key?(:object_uri)
  @records_per_file_count = args[:records_per_file_count] if args.key?(:records_per_file_count)
end