Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Google Cloud Storage Object details to write the feedback labels to.
Instance Attribute Summary collapse
-
#add_whitespace ⇒ Boolean
(also: #add_whitespace?)
Optional.
-
#always_print_empty_fields ⇒ Boolean
(also: #always_print_empty_fields?)
Optional.
-
#format ⇒ String
Required.
-
#object_uri ⇒ String
Required.
-
#records_per_file_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination.
1301 1302 1303 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_whitespace ⇒ Boolean Also known as: add_whitespace?
Optional. Add whitespace to the JSON file. Makes easier to read, but increases
file size. Only applicable for JSON format.
Corresponds to the JSON property addWhitespace
1271 1272 1273 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1271 def add_whitespace @add_whitespace end |
#always_print_empty_fields ⇒ Boolean Also known as: always_print_empty_fields?
Optional. Always print fields with no presence. This is useful for printing
fields that are not set, like implicit 0 value or empty lists/maps. Only
applicable for JSON format.
Corresponds to the JSON property alwaysPrintEmptyFields
1279 1280 1281 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1279 def always_print_empty_fields @always_print_empty_fields end |
#format ⇒ String
Required. File format in which the labels will be exported.
Corresponds to the JSON property format
1285 1286 1287 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1285 def format @format end |
#object_uri ⇒ String
Required. The Google Cloud Storage URI to write the feedback labels to. The
file name will be used as a prefix for the files written to the bucket if the
output needs to be split across multiple files, otherwise it will be used as
is. The file extension will be appended to the file name based on the format
selected. E.g. gs://bucket_name/object_uri_prefix
Corresponds to the JSON property objectUri
1294 1295 1296 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1294 def object_uri @object_uri end |
#records_per_file_count ⇒ Fixnum
Optional. The number of records per file. Applicable for either format.
Corresponds to the JSON property recordsPerFileCount
1299 1300 1301 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1299 def records_per_file_count @records_per_file_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1306 1307 1308 1309 1310 1311 1312 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1306 def update!(**args) @add_whitespace = args[:add_whitespace] if args.key?(:add_whitespace) @always_print_empty_fields = args[:always_print_empty_fields] if args.key?(:always_print_empty_fields) @format = args[:format] if args.key?(:format) @object_uri = args[:object_uri] if args.key?(:object_uri) @records_per_file_count = args[:records_per_file_count] if args.key?(:records_per_file_count) end |