Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Google Sheets document details to write the feedback labels to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination.



1333
1334
1335
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sheet_titleString

Optional. The title of the new sheet to write the feedback labels to. Corresponds to the JSON property sheetTitle

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1322

def sheet_title
  @sheet_title
end

#spreadsheet_uriString

Required. The Google Sheets document to write the feedback labels to. Retrieved from Google Sheets URI. E.g. https://docs.google.com/spreadsheets/d/ 1234567890 The spreadsheet must be shared with the Insights P4SA. The spreadsheet ID written to will be returned as file_names in the BulkDownloadFeedbackLabelsMetadata. Corresponds to the JSON property spreadsheetUri

Returns:

  • (String)


1331
1332
1333
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1331

def spreadsheet_uri
  @spreadsheet_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1338
1339
1340
1341
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1338

def update!(**args)
  @sheet_title = args[:sheet_title] if args.key?(:sheet_title)
  @spreadsheet_uri = args[:spreadsheet_uri] if args.key?(:spreadsheet_uri)
end