Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Google Sheets document details to write the feedback labels to.
Instance Attribute Summary collapse
-
#sheet_title ⇒ String
Optional.
-
#spreadsheet_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination.
1234 1235 1236 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sheet_title ⇒ String
Optional. The title of the new sheet to write the feedback labels to.
Corresponds to the JSON property sheetTitle
1223 1224 1225 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1223 def sheet_title @sheet_title end |
#spreadsheet_uri ⇒ String
Required. The Google Sheets document to write the feedback labels to.
Retrieved from Google Sheets URI. E.g. https://docs.google.com/spreadsheets/d/
1234567890 The spreadsheet must be shared with the Insights P4SA. The
spreadsheet ID written to will be returned as file_names in the
BulkDownloadFeedbackLabelsMetadata.
Corresponds to the JSON property spreadsheetUri
1232 1233 1234 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1232 def spreadsheet_uri @spreadsheet_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1239 1240 1241 1242 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1239 def update!(**args) @sheet_title = args[:sheet_title] if args.key?(:sheet_title) @spreadsheet_uri = args[:spreadsheet_uri] if args.key?(:spreadsheet_uri) end |