Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request for bulk uploading feedback labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest.



2340
2341
2342
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestGcsSource

Google Cloud Storage Object details to get the feedback label file from. Corresponds to the JSON property gcsSource



2325
2326
2327
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2325

def gcs_source
  @gcs_source
end

#sheets_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource

Google Sheets document details to get the feedback label file from. Corresponds to the JSON property sheetsSource



2330
2331
2332
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2330

def sheets_source
  @sheets_source
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, upload will not happen and the labels will be validated. If not set, then default behavior will be to upload the labels after validation is complete. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2337
2338
2339
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2337

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2345
2346
2347
2348
2349
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2345

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @sheets_source = args[:sheets_source] if args.key?(:sheets_source)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end