Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request for bulk uploading feedback labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest.



1783
1784
1785
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestGcsSource

Google Cloud Storage Object details to get the feedback label file from. Corresponds to the JSON property gcsSource



1768
1769
1770
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1768

def gcs_source
  @gcs_source
end

#sheets_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource

Google Sheets document details to get the feedback label file from. Corresponds to the JSON property sheetsSource



1773
1774
1775
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1773

def sheets_source
  @sheets_source
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, upload will not happen and the labels will be validated. If not set, then default behavior will be to upload the labels after validation is complete. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1780
1781
1782
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1780

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1788
1789
1790
1791
1792
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1788

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @sheets_source = args[:sheets_source] if args.key?(:sheets_source)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end