Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request for bulk uploading feedback labels.
Instance Attribute Summary collapse
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestGcsSource
Google Cloud Storage Object details to get the feedback label file from.
-
#sheets_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource
Google Sheets document details to get the feedback label file from.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest.
1379 1380 1381 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestGcsSource
Google Cloud Storage Object details to get the feedback label file from.
Corresponds to the JSON property gcsSource
1364 1365 1366 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1364 def gcs_source @gcs_source end |
#sheets_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource
Google Sheets document details to get the feedback label file from.
Corresponds to the JSON property sheetsSource
1369 1370 1371 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1369 def sheets_source @sheets_source end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, upload will not happen and the labels will be validated. If
not set, then default behavior will be to upload the labels after validation
is complete.
Corresponds to the JSON property validateOnly
1376 1377 1378 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1376 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1384 1385 1386 1387 1388 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1384 def update!(**args) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @sheets_source = args[:sheets_source] if args.key?(:sheets_source) @validate_only = args[:validate_only] if args.key?(:validate_only) end |