Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request for calculating conversation statistics.
Instance Attribute Summary collapse
-
#filter ⇒ String
A filter to reduce results to a specific subset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1CalculateStatsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1CalculateStatsRequest.
1871 1872 1873 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
A filter to reduce results to a specific subset. This field is useful for
getting statistics about conversations with specific properties.
Corresponds to the JSON property filter
1869 1870 1871 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1869 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1876 1877 1878 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1876 def update!(**args) @filter = args[:filter] if args.key?(:filter) end |