Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response for calculating conversation statistics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponse.



1528
1529
1530
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_durationString

The average duration of all conversations. The average is calculated using only conversations that have a time duration. Corresponds to the JSON property averageDuration

Returns:

  • (String)


1485
1486
1487
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1485

def average_duration
  @average_duration
end

#average_turn_countFixnum

The average number of turns per conversation. Corresponds to the JSON property averageTurnCount

Returns:

  • (Fixnum)


1490
1491
1492
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1490

def average_turn_count
  @average_turn_count
end

#conversation_countFixnum

The total number of conversations. Corresponds to the JSON property conversationCount

Returns:

  • (Fixnum)


1495
1496
1497
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1495

def conversation_count
  @conversation_count
end

#conversation_count_time_seriesGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries

A time series representing conversations over time. Corresponds to the JSON property conversationCountTimeSeries



1500
1501
1502
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1500

def conversation_count_time_series
  @conversation_count_time_series
end

#custom_highlighter_matchesHash<String,Fixnum>

A map associating each custom highlighter resource name with its respective number of matches in the set of conversations. Corresponds to the JSON property customHighlighterMatches

Returns:

  • (Hash<String,Fixnum>)


1506
1507
1508
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1506

def custom_highlighter_matches
  @custom_highlighter_matches
end

#issue_matchesHash<String,Fixnum>

A map associating each issue resource name with its respective number of matches in the set of conversations. Key has the format: projects//locations// issueModels//issues/ Deprecated, use issue_matches_stats field instead. Corresponds to the JSON property issueMatches

Returns:

  • (Hash<String,Fixnum>)


1513
1514
1515
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1513

def issue_matches
  @issue_matches
end

#issue_matches_statsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats>

A map associating each issue resource name with its respective number of matches in the set of conversations. Key has the format: projects//locations// issueModels//issues/ Corresponds to the JSON property issueMatchesStats



1520
1521
1522
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1520

def issue_matches_stats
  @issue_matches_stats
end

#smart_highlighter_matchesHash<String,Fixnum>

A map associating each smart highlighter display name with its respective number of matches in the set of conversations. Corresponds to the JSON property smartHighlighterMatches

Returns:

  • (Hash<String,Fixnum>)


1526
1527
1528
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1526

def smart_highlighter_matches
  @smart_highlighter_matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1533

def update!(**args)
  @average_duration = args[:average_duration] if args.key?(:average_duration)
  @average_turn_count = args[:average_turn_count] if args.key?(:average_turn_count)
  @conversation_count = args[:conversation_count] if args.key?(:conversation_count)
  @conversation_count_time_series = args[:conversation_count_time_series] if args.key?(:conversation_count_time_series)
  @custom_highlighter_matches = args[:custom_highlighter_matches] if args.key?(:custom_highlighter_matches)
  @issue_matches = args[:issue_matches] if args.key?(:issue_matches)
  @issue_matches_stats = args[:issue_matches_stats] if args.key?(:issue_matches_stats)
  @smart_highlighter_matches = args[:smart_highlighter_matches] if args.key?(:smart_highlighter_matches)
end