Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A time series representing conversations over time.
Instance Attribute Summary collapse
-
#interval_duration ⇒ String
The duration of each interval.
-
#points ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval>
An ordered list of intervals from earliest to latest, where each interval represents the number of conversations that transpired during the time window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
constructor
A new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
Returns a new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries.
2070 2071 2072 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval_duration ⇒ String
The duration of each interval.
Corresponds to the JSON property intervalDuration
2062 2063 2064 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2062 def interval_duration @interval_duration end |
#points ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval>
An ordered list of intervals from earliest to latest, where each interval
represents the number of conversations that transpired during the time window.
Corresponds to the JSON property points
2068 2069 2070 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2068 def points @points end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2075 2076 2077 2078 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2075 def update!(**args) @interval_duration = args[:interval_duration] if args.key?(:interval_duration) @points = args[:points] if args.key?(:points) end |