Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A time series representing conversations over time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries

Returns a new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries.



2521
2522
2523
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interval_durationString

The duration of each interval. Corresponds to the JSON property intervalDuration

Returns:

  • (String)


2513
2514
2515
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2513

def interval_duration
  @interval_duration
end

#pointsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval>

An ordered list of intervals from earliest to latest, where each interval represents the number of conversations that transpired during the time window. Corresponds to the JSON property points



2519
2520
2521
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2519

def points
  @points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2526
2527
2528
2529
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2526

def update!(**args)
  @interval_duration = args[:interval_duration] if args.key?(:interval_duration)
  @points = args[:points] if args.key?(:points)
end