Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A time series representing conversations over time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries

Returns a new instance of GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries.



1560
1561
1562
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interval_durationString

The duration of each interval. Corresponds to the JSON property intervalDuration

Returns:

  • (String)


1552
1553
1554
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1552

def interval_duration
  @interval_duration
end

#pointsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval>

An ordered list of intervals from earliest to latest, where each interval represents the number of conversations that transpired during the time window. Corresponds to the JSON property points



1558
1559
1560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1558

def points
  @points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1565
1566
1567
1568
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1565

def update!(**args)
  @interval_duration = args[:interval_duration] if args.key?(:interval_duration)
  @points = args[:points] if args.key?(:points)
end