Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CallAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A piece of metadata that applies to a window of a call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CallAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1CallAnnotation.



2170
2171
2172
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationEndBoundary



2113
2114
2115
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2113

def annotation_end_boundary
  @annotation_end_boundary
end

#annotation_start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationStartBoundary



2118
2119
2120
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2118

def annotation_start_boundary
  @annotation_start_boundary
end

#channel_tagFixnum

The channel of the audio where the annotation occurs. For single-channel audio, this field is not populated. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


2124
2125
2126
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2124

def channel_tag
  @channel_tag
end

#entity_mention_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1EntityMentionData

The data for an entity mention annotation. This represents a mention of an Entity in the conversation. Corresponds to the JSON property entityMentionData



2130
2131
2132
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2130

def entity_mention_data
  @entity_mention_data
end

#hold_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1HoldData

The data for a hold annotation. Corresponds to the JSON property holdData



2135
2136
2137
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2135

def hold_data
  @hold_data
end

#intent_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IntentMatchData

The data for an intent match. Represents an intent match for a text segment in the conversation. A text segment can be part of a sentence, a complete sentence, or an utterance with multiple sentences. Corresponds to the JSON property intentMatchData



2142
2143
2144
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2142

def intent_match_data
  @intent_match_data
end

#interruption_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1InterruptionData

The data for an interruption annotation. Corresponds to the JSON property interruptionData



2147
2148
2149
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2147

def interruption_data
  @interruption_data
end

#issue_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueMatchData

The data for an issue match annotation. Corresponds to the JSON property issueMatchData



2152
2153
2154
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2152

def issue_match_data
  @issue_match_data
end

#phrase_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchData

The data for a matched phrase matcher. Represents information identifying a phrase matcher for a given match. Corresponds to the JSON property phraseMatchData



2158
2159
2160
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2158

def phrase_match_data
  @phrase_match_data
end

#sentiment_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentimentData



2163
2164
2165
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2163

def sentiment_data
  @sentiment_data
end

#silence_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SilenceData

The data for a silence annotation. Corresponds to the JSON property silenceData



2168
2169
2170
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2168

def silence_data
  @silence_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2175

def update!(**args)
  @annotation_end_boundary = args[:annotation_end_boundary] if args.key?(:annotation_end_boundary)
  @annotation_start_boundary = args[:annotation_start_boundary] if args.key?(:annotation_start_boundary)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @entity_mention_data = args[:entity_mention_data] if args.key?(:entity_mention_data)
  @hold_data = args[:hold_data] if args.key?(:hold_data)
  @intent_match_data = args[:intent_match_data] if args.key?(:intent_match_data)
  @interruption_data = args[:interruption_data] if args.key?(:interruption_data)
  @issue_match_data = args[:issue_match_data] if args.key?(:issue_match_data)
  @phrase_match_data = args[:phrase_match_data] if args.key?(:phrase_match_data)
  @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data)
  @silence_data = args[:silence_data] if args.key?(:silence_data)
end