Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CallAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CallAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A piece of metadata that applies to a window of a call.
Instance Attribute Summary collapse
-
#annotation_end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#annotation_start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#channel_tag ⇒ Fixnum
The channel of the audio where the annotation occurs.
-
#entity_mention_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1EntityMentionData
The data for an entity mention annotation.
-
#hold_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1HoldData
The data for a hold annotation.
-
#intent_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IntentMatchData
The data for an intent match.
-
#interruption_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1InterruptionData
The data for an interruption annotation.
-
#issue_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueMatchData
The data for an issue match annotation.
-
#phrase_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchData
The data for a matched phrase matcher.
-
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
-
#silence_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SilenceData
The data for a silence annotation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CallAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1CallAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CallAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1CallAnnotation.
2064 2065 2066 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property annotationEndBoundary
2007 2008 2009 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2007 def annotation_end_boundary @annotation_end_boundary end |
#annotation_start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property annotationStartBoundary
2012 2013 2014 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2012 def annotation_start_boundary @annotation_start_boundary end |
#channel_tag ⇒ Fixnum
The channel of the audio where the annotation occurs. For single-channel audio,
this field is not populated.
Corresponds to the JSON property channelTag
2018 2019 2020 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2018 def channel_tag @channel_tag end |
#entity_mention_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1EntityMentionData
The data for an entity mention annotation. This represents a mention of an
Entity in the conversation.
Corresponds to the JSON property entityMentionData
2024 2025 2026 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2024 def entity_mention_data @entity_mention_data end |
#hold_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1HoldData
The data for a hold annotation.
Corresponds to the JSON property holdData
2029 2030 2031 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2029 def hold_data @hold_data end |
#intent_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IntentMatchData
The data for an intent match. Represents an intent match for a text segment in
the conversation. A text segment can be part of a sentence, a complete
sentence, or an utterance with multiple sentences.
Corresponds to the JSON property intentMatchData
2036 2037 2038 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2036 def intent_match_data @intent_match_data end |
#interruption_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1InterruptionData
The data for an interruption annotation.
Corresponds to the JSON property interruptionData
2041 2042 2043 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2041 def interruption_data @interruption_data end |
#issue_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueMatchData
The data for an issue match annotation.
Corresponds to the JSON property issueMatchData
2046 2047 2048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2046 def issue_match_data @issue_match_data end |
#phrase_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchData
The data for a matched phrase matcher. Represents information identifying a
phrase matcher for a given match.
Corresponds to the JSON property phraseMatchData
2052 2053 2054 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2052 def phrase_match_data @phrase_match_data end |
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentimentData
2057 2058 2059 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2057 def sentiment_data @sentiment_data end |
#silence_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SilenceData
The data for a silence annotation.
Corresponds to the JSON property silenceData
2062 2063 2064 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2062 def silence_data @silence_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2069 def update!(**args) @annotation_end_boundary = args[:annotation_end_boundary] if args.key?(:annotation_end_boundary) @annotation_start_boundary = args[:annotation_start_boundary] if args.key?(:annotation_start_boundary) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @entity_mention_data = args[:entity_mention_data] if args.key?(:entity_mention_data) @hold_data = args[:hold_data] if args.key?(:hold_data) @intent_match_data = args[:intent_match_data] if args.key?(:intent_match_data) @interruption_data = args[:interruption_data] if args.key?(:interruption_data) @issue_match_data = args[:issue_match_data] if args.key?(:issue_match_data) @phrase_match_data = args[:phrase_match_data] if args.key?(:phrase_match_data) @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data) @silence_data = args[:silence_data] if args.key?(:silence_data) end |