Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CES diagnostic information.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
-
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CesTurnAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1CesTurnAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CesTurnAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1CesTurnAnnotation.
2120 2121 2122 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
Corresponds to the JSON property messages
2113 2114 2115 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2113 def @messages end |
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
2118 2119 2120 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2118 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2125 2126 2127 2128 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2125 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |