Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Configurable dashboard's widget that displays data as a chart.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartAction
The action to be taken when the chart is clicked.
-
#chart_type ⇒ String
Output only.
-
#chart_visualization_type ⇒ String
Chart visualization type.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource
The request data for visualizing the dataset in the chart.
-
#date_range_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DateRangeConfig
Date range configuration for dashboard charts.
-
#description ⇒ String
Chart description Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the chart.
-
#filter ⇒ String
Filter applied to all charts in the container.
-
#height ⇒ Fixnum
The height of the chart in grid units.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
-
#width ⇒ Fixnum
The width of the chart in grid units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Chart
constructor
A new instance of GoogleCloudContactcenterinsightsV1Chart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Chart
Returns a new instance of GoogleCloudContactcenterinsightsV1Chart.
2339 2340 2341 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartAction
The action to be taken when the chart is clicked.
Corresponds to the JSON property action
2276 2277 2278 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2276 def action @action end |
#chart_type ⇒ String
Output only. Chart type.
Corresponds to the JSON property chartType
2281 2282 2283 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2281 def chart_type @chart_type end |
#chart_visualization_type ⇒ String
Chart visualization type.
Corresponds to the JSON property chartVisualizationType
2286 2287 2288 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2286 def chart_visualization_type @chart_visualization_type end |
#create_time ⇒ String
Output only. Chart create time.
Corresponds to the JSON property createTime
2291 2292 2293 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2291 def create_time @create_time end |
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource
The request data for visualizing the dataset in the chart.
Corresponds to the JSON property dataSource
2296 2297 2298 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2296 def data_source @data_source end |
#date_range_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DateRangeConfig
Date range configuration for dashboard charts.
Corresponds to the JSON property dateRangeConfig
2301 2302 2303 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2301 def date_range_config @date_range_config end |
#description ⇒ String
Chart description
Corresponds to the JSON property description
2306 2307 2308 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2306 def description @description end |
#display_name ⇒ String
User provided display name of the chart.
Corresponds to the JSON property displayName
2311 2312 2313 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2311 def display_name @display_name end |
#filter ⇒ String
Filter applied to all charts in the container. Should support scope later.
Corresponds to the JSON property filter
2316 2317 2318 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2316 def filter @filter end |
#height ⇒ Fixnum
The height of the chart in grid units.
Corresponds to the JSON property height
2321 2322 2323 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2321 def height @height end |
#name ⇒ String
Identifier. Chart resource name. Format: projects/project/locations/
location/dashboards/dashboard/charts/chart
Corresponds to the JSON property name
2327 2328 2329 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2327 def name @name end |
#update_time ⇒ String
Output only. Chart last update time.
Corresponds to the JSON property updateTime
2332 2333 2334 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2332 def update_time @update_time end |
#width ⇒ Fixnum
The width of the chart in grid units.
Corresponds to the JSON property width
2337 2338 2339 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2337 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2344 def update!(**args) @action = args[:action] if args.key?(:action) @chart_type = args[:chart_type] if args.key?(:chart_type) @chart_visualization_type = args[:chart_visualization_type] if args.key?(:chart_visualization_type) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @date_range_config = args[:date_range_config] if args.key?(:date_range_config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @filter = args[:filter] if args.key?(:filter) @height = args[:height] if args.key?(:height) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @width = args[:width] if args.key?(:width) end |