Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configurable dashboard's widget that displays data as a chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Chart

Returns a new instance of GoogleCloudContactcenterinsightsV1Chart.



2758
2759
2760
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartAction

The action to be taken when the chart is clicked. Corresponds to the JSON property action



2695
2696
2697
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2695

def action
  @action
end

#chart_typeString

Output only. Chart type. Corresponds to the JSON property chartType

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2700

def chart_type
  @chart_type
end

#chart_visualization_typeString

Chart visualization type. Corresponds to the JSON property chartVisualizationType

Returns:

  • (String)


2705
2706
2707
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2705

def chart_visualization_type
  @chart_visualization_type
end

#create_timeString

Output only. Chart create time. Corresponds to the JSON property createTime

Returns:

  • (String)


2710
2711
2712
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2710

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource

The request data for visualizing the dataset in the chart. Corresponds to the JSON property dataSource



2715
2716
2717
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2715

def data_source
  @data_source
end

#date_range_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DateRangeConfig

Date range configuration for dashboard charts. Corresponds to the JSON property dateRangeConfig



2720
2721
2722
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2720

def date_range_config
  @date_range_config
end

#descriptionString

Chart description Corresponds to the JSON property description

Returns:

  • (String)


2725
2726
2727
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2725

def description
  @description
end

#display_nameString

User provided display name of the chart. Corresponds to the JSON property displayName

Returns:

  • (String)


2730
2731
2732
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2730

def display_name
  @display_name
end

#filterString

Filter applied to all charts in the container. Should support scope later. Corresponds to the JSON property filter

Returns:

  • (String)


2735
2736
2737
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2735

def filter
  @filter
end

#heightFixnum

The height of the chart in grid units. Corresponds to the JSON property height

Returns:

  • (Fixnum)


2740
2741
2742
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2740

def height
  @height
end

#nameString

Identifier. Chart resource name. Format: projects/project/locations/ location/dashboards/dashboard/charts/chart Corresponds to the JSON property name

Returns:

  • (String)


2746
2747
2748
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2746

def name
  @name
end

#update_timeString

Output only. Chart last update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2751

def update_time
  @update_time
end

#widthFixnum

The width of the chart in grid units. Corresponds to the JSON property width

Returns:

  • (Fixnum)


2756
2757
2758
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2756

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2763
2764
2765
2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2763

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @chart_type = args[:chart_type] if args.key?(:chart_type)
  @chart_visualization_type = args[:chart_visualization_type] if args.key?(:chart_visualization_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @date_range_config = args[:date_range_config] if args.key?(:date_range_config)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @filter = args[:filter] if args.key?(:filter)
  @height = args[:height] if args.key?(:height)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @width = args[:width] if args.key?(:width)
end