Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configurable dashboard's widget that displays data as a chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Chart

Returns a new instance of GoogleCloudContactcenterinsightsV1Chart.



2201
2202
2203
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartAction

The action to be taken when the chart is clicked. Corresponds to the JSON property action



2138
2139
2140
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2138

def action
  @action
end

#chart_typeString

Output only. Chart type. Corresponds to the JSON property chartType

Returns:

  • (String)


2143
2144
2145
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2143

def chart_type
  @chart_type
end

#chart_visualization_typeString

Chart visualization type. Corresponds to the JSON property chartVisualizationType

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2148

def chart_visualization_type
  @chart_visualization_type
end

#create_timeString

Output only. Chart create time. Corresponds to the JSON property createTime

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2153

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource

The request data for visualizing the dataset in the chart. Corresponds to the JSON property dataSource



2158
2159
2160
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2158

def data_source
  @data_source
end

#date_range_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DateRangeConfig

Date range configuration for dashboard charts. Corresponds to the JSON property dateRangeConfig



2163
2164
2165
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2163

def date_range_config
  @date_range_config
end

#descriptionString

Chart description Corresponds to the JSON property description

Returns:

  • (String)


2168
2169
2170
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2168

def description
  @description
end

#display_nameString

User provided display name of the chart. Corresponds to the JSON property displayName

Returns:

  • (String)


2173
2174
2175
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2173

def display_name
  @display_name
end

#filterString

Filter applied to all charts in the container. Should support scope later. Corresponds to the JSON property filter

Returns:

  • (String)


2178
2179
2180
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2178

def filter
  @filter
end

#heightFixnum

The height of the chart in grid units. Corresponds to the JSON property height

Returns:

  • (Fixnum)


2183
2184
2185
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2183

def height
  @height
end

#nameString

Identifier. Chart resource name. Format: projects/project/locations/ location/dashboards/dashboard/charts/chart Corresponds to the JSON property name

Returns:

  • (String)


2189
2190
2191
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2189

def name
  @name
end

#update_timeString

Output only. Chart last update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2194

def update_time
  @update_time
end

#widthFixnum

The width of the chart in grid units. Corresponds to the JSON property width

Returns:

  • (Fixnum)


2199
2200
2201
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2199

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2206

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @chart_type = args[:chart_type] if args.key?(:chart_type)
  @chart_visualization_type = args[:chart_visualization_type] if args.key?(:chart_visualization_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @date_range_config = args[:date_range_config] if args.key?(:date_range_config)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @filter = args[:filter] if args.key?(:filter)
  @height = args[:height] if args.key?(:height)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @width = args[:width] if args.key?(:width)
end