Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Configurable dashboard's widget that displays data as a chart.
Instance Attribute Summary collapse
-
#chart_type ⇒ String
Output only.
-
#chart_visualization_type ⇒ String
Chart visualization type.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource
The request data for visualizing the dataset in the chart.
-
#date_range_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DateRangeConfig
Date range configuration for dashboard charts.
-
#description ⇒ String
Chart description Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the chart.
-
#filter ⇒ String
Filter applied to all charts in the container.
-
#height ⇒ Fixnum
The height of the chart in grid units.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
-
#width ⇒ Fixnum
The width of the chart in grid units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Chart
constructor
A new instance of GoogleCloudContactcenterinsightsV1Chart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Chart
Returns a new instance of GoogleCloudContactcenterinsightsV1Chart.
1745 1746 1747 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_type ⇒ String
Output only. Chart type.
Corresponds to the JSON property chartType
1687 1688 1689 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1687 def chart_type @chart_type end |
#chart_visualization_type ⇒ String
Chart visualization type.
Corresponds to the JSON property chartVisualizationType
1692 1693 1694 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1692 def chart_visualization_type @chart_visualization_type end |
#create_time ⇒ String
Output only. Chart create time.
Corresponds to the JSON property createTime
1697 1698 1699 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1697 def create_time @create_time end |
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartDataSource
The request data for visualizing the dataset in the chart.
Corresponds to the JSON property dataSource
1702 1703 1704 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1702 def data_source @data_source end |
#date_range_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DateRangeConfig
Date range configuration for dashboard charts.
Corresponds to the JSON property dateRangeConfig
1707 1708 1709 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1707 def date_range_config @date_range_config end |
#description ⇒ String
Chart description
Corresponds to the JSON property description
1712 1713 1714 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1712 def description @description end |
#display_name ⇒ String
User provided display name of the chart.
Corresponds to the JSON property displayName
1717 1718 1719 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1717 def display_name @display_name end |
#filter ⇒ String
Filter applied to all charts in the container. Should support scope later.
Corresponds to the JSON property filter
1722 1723 1724 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1722 def filter @filter end |
#height ⇒ Fixnum
The height of the chart in grid units.
Corresponds to the JSON property height
1727 1728 1729 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1727 def height @height end |
#name ⇒ String
Identifier. Chart resource name. Format: projects/project/locations/
location/dashboards/dashboard/charts/chart
Corresponds to the JSON property name
1733 1734 1735 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1733 def name @name end |
#update_time ⇒ String
Output only. Chart last update time.
Corresponds to the JSON property updateTime
1738 1739 1740 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1738 def update_time @update_time end |
#width ⇒ Fixnum
The width of the chart in grid units.
Corresponds to the JSON property width
1743 1744 1745 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1743 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1750 def update!(**args) @chart_type = args[:chart_type] if args.key?(:chart_type) @chart_visualization_type = args[:chart_visualization_type] if args.key?(:chart_visualization_type) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @date_range_config = args[:date_range_config] if args.key?(:date_range_config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @filter = args[:filter] if args.key?(:filter) @height = args[:height] if args.key?(:height) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @width = args[:width] if args.key?(:width) end |