Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ChartAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The action to be taken when the chart is clicked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ChartAction

Returns a new instance of GoogleCloudContactcenterinsightsV1ChartAction.



2232
2233
2234
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#redirect_actionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedirectAction

The redirect action to be taken when the chart is clicked. Corresponds to the JSON property redirectAction



2230
2231
2232
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2230

def redirect_action
  @redirect_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2237
2238
2239
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2237

def update!(**args)
  @redirect_action = args[:redirect_action] if args.key?(:redirect_action)
end