Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConstraintEvaluationResultRuleConstraintResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConstraintEvaluationResultRuleConstraintResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The result of a single constraint rule on the pair of conversations.
Instance Attribute Summary collapse
-
#constraint_met ⇒ Boolean
(also: #constraint_met?)
Whether the constraint expression evaluated to true for (A, B) or (B, A).
-
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#rule_id ⇒ String
The rule ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConstraintEvaluationResultRuleConstraintResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConstraintEvaluationResultRuleConstraintResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConstraintEvaluationResultRuleConstraintResult
Returns a new instance of GoogleCloudContactcenterinsightsV1ConstraintEvaluationResultRuleConstraintResult.
2880 2881 2882 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_met ⇒ Boolean Also known as: constraint_met?
Whether the constraint expression evaluated to true for (A, B) or (B, A).
Corresponds to the JSON property constraintMet
2862 2863 2864 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2862 def constraint_met @constraint_met end |
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2873 2874 2875 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2873 def error @error end |
#rule_id ⇒ String
The rule ID.
Corresponds to the JSON property ruleId
2878 2879 2880 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2878 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2885 2886 2887 2888 2889 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2885 def update!(**args) @constraint_met = args[:constraint_met] if args.key?(:constraint_met) @error = args[:error] if args.key?(:error) @rule_id = args[:rule_id] if args.key?(:rule_id) end |