Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Conversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Conversation

Returns a new instance of GoogleCloudContactcenterinsightsV1Conversation.



2531
2532
2533
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


2410
2411
2412
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2410

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



2415
2416
2417
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2415

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



2420
2421
2422
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2420

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2425
2426
2427
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2425

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



2430
2431
2432
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2430

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



2437
2438
2439
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2437

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


2442
2443
2444
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2442

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


2448
2449
2450
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2448

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2454
2455
2456
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2454

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


2459
2460
2461
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2459

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Analysis

The analysis resource. Corresponds to the JSON property latestAnalysis



2464
2465
2466
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2464

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



2469
2470
2471
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2469

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2474

def medium
  @medium
end

#metadata_jsonString

Optional. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2481

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2487

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


2492
2493
2494
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2492

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



2497
2498
2499
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2497

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



2503
2504
2505
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2503

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


2508
2509
2510
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2508

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



2513
2514
2515
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2513

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


2519
2520
2521
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2519

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


2524
2525
2526
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2524

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2529
2530
2531
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2529

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2536

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end