Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Conversation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Conversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation resource.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
An opaque, user-specified string representing the human agent who handled the conversation.
-
#call_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCallMetadata
Call-specific metadata.
-
#correlation_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
Info for correlating across conversations.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource
The conversation source, which is a combination of transcript and audio.
-
#dialogflow_intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowIntent>
Output only.
-
#duration ⇒ String
Output only.
-
#expire_time ⇒ String
The time at which this conversation should expire.
-
#labels ⇒ Hash<String,String>
A map for the user to specify any custom fields.
-
#language_code ⇒ String
A user-specified language code for the conversation.
-
#latest_analysis ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Analysis
The analysis resource.
-
#latest_summary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
-
#medium ⇒ String
Immutable.
-
#metadata_json ⇒ String
Input only.
-
#name ⇒ String
Immutable.
-
#obfuscated_user_id ⇒ String
Obfuscated user ID which the customer sent to us.
-
#quality_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
Conversation metadata related to quality management.
-
#runtime_annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation>
Output only.
-
#start_time ⇒ String
The time at which the conversation started.
-
#transcript ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscript
A message representing the transcript of a conversation.
-
#ttl ⇒ String
Input only.
-
#turn_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Conversation
constructor
A new instance of GoogleCloudContactcenterinsightsV1Conversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Conversation
Returns a new instance of GoogleCloudContactcenterinsightsV1Conversation.
2525 2526 2527 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
An opaque, user-specified string representing the human agent who handled the
conversation.
Corresponds to the JSON property agentId
2404 2405 2406 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2404 def agent_id @agent_id end |
#call_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCallMetadata
Call-specific metadata.
Corresponds to the JSON property callMetadata
2409 2410 2411 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2409 def @call_metadata end |
#correlation_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
Info for correlating across conversations.
Corresponds to the JSON property correlationInfo
2414 2415 2416 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2414 def correlation_info @correlation_info end |
#create_time ⇒ String
Output only. The time at which the conversation was created.
Corresponds to the JSON property createTime
2419 2420 2421 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2419 def create_time @create_time end |
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource
The conversation source, which is a combination of transcript and audio.
Corresponds to the JSON property dataSource
2424 2425 2426 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2424 def data_source @data_source end |
#dialogflow_intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowIntent>
Output only. All the matched Dialogflow intents in the call. The key
corresponds to a Dialogflow intent, format: projects/project/agent/agent/
intents/intent
Corresponds to the JSON property dialogflowIntents
2431 2432 2433 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2431 def dialogflow_intents @dialogflow_intents end |
#duration ⇒ String
Output only. The duration of the conversation.
Corresponds to the JSON property duration
2436 2437 2438 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2436 def duration @duration end |
#expire_time ⇒ String
The time at which this conversation should expire. After this time, the
conversation data and any associated analyses will be deleted.
Corresponds to the JSON property expireTime
2442 2443 2444 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2442 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
A map for the user to specify any custom fields. A maximum of 100 labels per
conversation is allowed, with a maximum of 256 characters per entry.
Corresponds to the JSON property labels
2448 2449 2450 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2448 def labels @labels end |
#language_code ⇒ String
A user-specified language code for the conversation.
Corresponds to the JSON property languageCode
2453 2454 2455 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2453 def language_code @language_code end |
#latest_analysis ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Analysis
The analysis resource.
Corresponds to the JSON property latestAnalysis
2458 2459 2460 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2458 def latest_analysis @latest_analysis end |
#latest_summary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
Corresponds to the JSON property latestSummary
2463 2464 2465 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2463 def latest_summary @latest_summary end |
#medium ⇒ String
Immutable. The conversation medium.
Corresponds to the JSON property medium
2468 2469 2470 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2468 def medium @medium end |
#metadata_json ⇒ String
Input only. JSON metadata encoded as a string. This field is primarily used by
Insights integrations with various telephony systems and must be in one of
Insight's supported formats.
Corresponds to the JSON property metadataJson
2475 2476 2477 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2475 def @metadata_json end |
#name ⇒ String
Immutable. The resource name of the conversation. Format: projects/project/
locations/location/conversations/conversation
Corresponds to the JSON property name
2481 2482 2483 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2481 def name @name end |
#obfuscated_user_id ⇒ String
Obfuscated user ID which the customer sent to us.
Corresponds to the JSON property obfuscatedUserId
2486 2487 2488 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2486 def @obfuscated_user_id end |
#quality_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
Conversation metadata related to quality management.
Corresponds to the JSON property qualityMetadata
2491 2492 2493 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2491 def @quality_metadata end |
#runtime_annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation>
Output only. The annotations that were generated during the customer and agent
interaction.
Corresponds to the JSON property runtimeAnnotations
2497 2498 2499 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2497 def runtime_annotations @runtime_annotations end |
#start_time ⇒ String
The time at which the conversation started.
Corresponds to the JSON property startTime
2502 2503 2504 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2502 def start_time @start_time end |
#transcript ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscript
A message representing the transcript of a conversation.
Corresponds to the JSON property transcript
2507 2508 2509 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2507 def transcript @transcript end |
#ttl ⇒ String
Input only. The TTL for this resource. If specified, then this TTL will be
used to calculate the expire time.
Corresponds to the JSON property ttl
2513 2514 2515 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2513 def ttl @ttl end |
#turn_count ⇒ Fixnum
Output only. The number of turns in the conversation.
Corresponds to the JSON property turnCount
2518 2519 2520 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2518 def turn_count @turn_count end |
#update_time ⇒ String
Output only. The most recent time at which the conversation was updated.
Corresponds to the JSON property updateTime
2523 2524 2525 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2523 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2530 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @call_metadata = args[:call_metadata] if args.key?(:call_metadata) @correlation_info = args[:correlation_info] if args.key?(:correlation_info) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents) @duration = args[:duration] if args.key?(:duration) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @language_code = args[:language_code] if args.key?(:language_code) @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis) @latest_summary = args[:latest_summary] if args.key?(:latest_summary) @medium = args[:medium] if args.key?(:medium) @metadata_json = args[:metadata_json] if args.key?(:metadata_json) @name = args[:name] if args.key?(:name) @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id) @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata) @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations) @start_time = args[:start_time] if args.key?(:start_time) @transcript = args[:transcript] if args.key?(:transcript) @ttl = args[:ttl] if args.key?(:ttl) @turn_count = args[:turn_count] if args.key?(:turn_count) @update_time = args[:update_time] if args.key?(:update_time) end |