Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation source, which is a combination of transcript and audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataSource

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationDataSource.



2839
2840
2841
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialogflow_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowSource

A Dialogflow source of conversation data. Corresponds to the JSON property dialogflowSource



2819
2820
2821
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2819

def dialogflow_source
  @dialogflow_source
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource

A Cloud Storage source of conversation data. Corresponds to the JSON property gcsSource



2824
2825
2826
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2824

def gcs_source
  @gcs_source
end

#metadata_uriString

Cloud Storage URI that points to a file that contains the conversation metadata. Corresponds to the JSON property metadataUri

Returns:

  • (String)


2830
2831
2832
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2830

def 
  @metadata_uri
end

#turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>

Cloud Storage URIs that points to files that contain the conversation audio for each turn. Assume the order of the URIs is the same as the order of the transcript turns. Corresponds to the JSON property turnLevelAudios



2837
2838
2839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2837

def turn_level_audios
  @turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2844
2845
2846
2847
2848
2849
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2844

def update!(**args)
  @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri)
  @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios)
end