Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation source, which is a combination of transcript and audio.
Instance Attribute Summary collapse
-
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowSource
A Dialogflow source of conversation data.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource
A Cloud Storage source of conversation data.
-
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation metadata.
-
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio for each turn.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataSource
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationDataSource.
3284 3285 3286 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowSource
A Dialogflow source of conversation data.
Corresponds to the JSON property dialogflowSource
3264 3265 3266 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3264 def dialogflow_source @dialogflow_source end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource
A Cloud Storage source of conversation data.
Corresponds to the JSON property gcsSource
3269 3270 3271 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3269 def gcs_source @gcs_source end |
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation
metadata.
Corresponds to the JSON property metadataUri
3275 3276 3277 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3275 def @metadata_uri end |
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio
for each turn. Assume the order of the URIs is the same as the order of the
transcript turns.
Corresponds to the JSON property turnLevelAudios
3282 3283 3284 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3282 def turn_level_audios @turn_level_audios end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3289 3290 3291 3292 3293 3294 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3289 def update!(**args) @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri) @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios) end |