Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation source, which is a combination of transcript and audio.
Instance Attribute Summary collapse
-
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowSource
A Dialogflow source of conversation data.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource
A Cloud Storage source of conversation data.
-
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationDataSource
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationDataSource.
2244 2245 2246 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowSource
A Dialogflow source of conversation data.
Corresponds to the JSON property dialogflowSource
2231 2232 2233 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2231 def dialogflow_source @dialogflow_source end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource
A Cloud Storage source of conversation data.
Corresponds to the JSON property gcsSource
2236 2237 2238 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2236 def gcs_source @gcs_source end |
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation
metadata.
Corresponds to the JSON property metadataUri
2242 2243 2244 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2242 def @metadata_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2249 2250 2251 2252 2253 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2249 def update!(**args) @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri) end |