Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation metadata related to quality management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationQualityMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationQualityMetadata.



2890
2891
2892
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_infoArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo>

Information about agents involved in the call. Corresponds to the JSON property agentInfo



2868
2869
2870
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2868

def agent_info
  @agent_info
end

#customer_satisfaction_ratingFixnum

An arbitrary integer value indicating the customer's satisfaction rating. Corresponds to the JSON property customerSatisfactionRating

Returns:

  • (Fixnum)


2873
2874
2875
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2873

def customer_satisfaction_rating
  @customer_satisfaction_rating
end

#feedback_labelsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FeedbackLabel>

Input only. The feedback labels associated with the conversation. Corresponds to the JSON property feedbackLabels



2878
2879
2880
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2878

def feedback_labels
  @feedback_labels
end

An arbitrary string value specifying the menu path the customer took. Corresponds to the JSON property menuPath

Returns:

  • (String)


2883
2884
2885
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2883

def menu_path
  @menu_path
end

#wait_durationString

The amount of time the customer waited to connect with an agent. Corresponds to the JSON property waitDuration

Returns:

  • (String)


2888
2889
2890
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2888

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2895
2896
2897
2898
2899
2900
2901
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2895

def update!(**args)
  @agent_info = args[:agent_info] if args.key?(:agent_info)
  @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating)
  @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels)
  @menu_path = args[:menu_path] if args.key?(:menu_path)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end