Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation metadata related to quality management.
Instance Attribute Summary collapse
-
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
-
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
-
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FeedbackLabel>
Input only.
-
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
-
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationQualityMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationQualityMetadata.
1943 1944 1945 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
Corresponds to the JSON property agentInfo
1921 1922 1923 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1921 def agent_info @agent_info end |
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
Corresponds to the JSON property customerSatisfactionRating
1926 1927 1928 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1926 def @customer_satisfaction_rating end |
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FeedbackLabel>
Input only. The feedback labels associated with the conversation.
Corresponds to the JSON property feedbackLabels
1931 1932 1933 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1931 def feedback_labels @feedback_labels end |
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
Corresponds to the JSON property menuPath
1936 1937 1938 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1936 def @menu_path end |
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Corresponds to the JSON property waitDuration
1941 1942 1943 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1941 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 1948 def update!(**args) @agent_info = args[:agent_info] if args.key?(:agent_info) @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @menu_path = args[:menu_path] if args.key?(:menu_path) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |