Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation summarization suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.



3047
3048
3049
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property answerRecord

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3011

def answer_record
  @answer_record
end

#confidenceFloat

The confidence score of the summarization. Corresponds to the JSON property confidence

Returns:

  • (Float)


3016
3017
3018
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3016

def confidence
  @confidence
end

#conversation_modelString

The name of the model that generates this summary. Format: projects/project/ locations/location/conversationModels/conversation_model Corresponds to the JSON property conversationModel

Returns:

  • (String)


3022
3023
3024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3022

def conversation_model
  @conversation_model
end

#generator_idString

Agent Assist generator ID. Corresponds to the JSON property generatorId

Returns:

  • (String)


3027
3028
3029
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3027

def generator_id
  @generator_id
end

#metadataHash<String,String>

A map that contains metadata about the summarization and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


3033
3034
3035
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3033

def 
  @metadata
end

#textString

The summarization content that is concatenated into one string. Corresponds to the JSON property text

Returns:

  • (String)


3038
3039
3040
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3038

def text
  @text
end

#text_sectionsHash<String,String>

The summarization content that is divided into sections. The key is the section's name and the value is the section's content. There is no specific format for the key or value. Corresponds to the JSON property textSections

Returns:

  • (Hash<String,String>)


3045
3046
3047
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3045

def text_sections
  @text_sections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3052
3053
3054
3055
3056
3057
3058
3059
3060
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3052

def update!(**args)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @confidence = args[:confidence] if args.key?(:confidence)
  @conversation_model = args[:conversation_model] if args.key?(:conversation_model)
  @generator_id = args[:generator_id] if args.key?(:generator_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @text = args[:text] if args.key?(:text)
  @text_sections = args[:text_sections] if args.key?(:text_sections)
end