Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation summarization suggestion data.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
The name of the answer record.
-
#confidence ⇒ Float
The confidence score of the summarization.
-
#conversation_model ⇒ String
The name of the model that generates this summary.
-
#generator_id ⇒ String
Agent Assist generator ID.
-
#metadata ⇒ Hash<String,String>
A map that contains metadata about the summarization and the document from which it originates.
-
#text ⇒ String
The summarization content that is concatenated into one string.
-
#text_sections ⇒ Hash<String,String>
The summarization content that is divided into sections.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.
3035 3036 3037 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property answerRecord
2999 3000 3001 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2999 def answer_record @answer_record end |
#confidence ⇒ Float
The confidence score of the summarization.
Corresponds to the JSON property confidence
3004 3005 3006 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3004 def confidence @confidence end |
#conversation_model ⇒ String
The name of the model that generates this summary. Format: projects/project/
locations/location/conversationModels/conversation_model
Corresponds to the JSON property conversationModel
3010 3011 3012 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3010 def conversation_model @conversation_model end |
#generator_id ⇒ String
Agent Assist generator ID.
Corresponds to the JSON property generatorId
3015 3016 3017 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3015 def generator_id @generator_id end |
#metadata ⇒ Hash<String,String>
A map that contains metadata about the summarization and the document from
which it originates.
Corresponds to the JSON property metadata
3021 3022 3023 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3021 def @metadata end |
#text ⇒ String
The summarization content that is concatenated into one string.
Corresponds to the JSON property text
3026 3027 3028 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3026 def text @text end |
#text_sections ⇒ Hash<String,String>
The summarization content that is divided into sections. The key is the
section's name and the value is the section's content. There is no specific
format for the key or value.
Corresponds to the JSON property textSections
3033 3034 3035 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3033 def text_sections @text_sections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3040 3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3040 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @confidence = args[:confidence] if args.key?(:confidence) @conversation_model = args[:conversation_model] if args.key?(:conversation_model) @generator_id = args[:generator_id] if args.key?(:generator_id) @metadata = args[:metadata] if args.key?(:metadata) @text = args[:text] if args.key?(:text) @text_sections = args[:text_sections] if args.key?(:text_sections) end |