Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation summarization suggestion data.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
The name of the answer record.
-
#confidence ⇒ Float
The confidence score of the summarization.
-
#conversation_model ⇒ String
The name of the model that generates this summary.
-
#generator_id ⇒ String
Agent Assist generator ID.
-
#metadata ⇒ Hash<String,String>
A map that contains metadata about the summarization and the document from which it originates.
-
#text ⇒ String
The summarization content that is concatenated into one string.
-
#text_sections ⇒ Hash<String,String>
The summarization content that is divided into sections.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData.
2545 2546 2547 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property answerRecord
2509 2510 2511 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2509 def answer_record @answer_record end |
#confidence ⇒ Float
The confidence score of the summarization.
Corresponds to the JSON property confidence
2514 2515 2516 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2514 def confidence @confidence end |
#conversation_model ⇒ String
The name of the model that generates this summary. Format: projects/project/
locations/location/conversationModels/conversation_model
Corresponds to the JSON property conversationModel
2520 2521 2522 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2520 def conversation_model @conversation_model end |
#generator_id ⇒ String
Agent Assist generator ID.
Corresponds to the JSON property generatorId
2525 2526 2527 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2525 def generator_id @generator_id end |
#metadata ⇒ Hash<String,String>
A map that contains metadata about the summarization and the document from
which it originates.
Corresponds to the JSON property metadata
2531 2532 2533 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2531 def @metadata end |
#text ⇒ String
The summarization content that is concatenated into one string.
Corresponds to the JSON property text
2536 2537 2538 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2536 def text @text end |
#text_sections ⇒ Hash<String,String>
The summarization content that is divided into sections. The key is the
section's name and the value is the section's content. There is no specific
format for the key or value.
Corresponds to the JSON property textSections
2543 2544 2545 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2543 def text_sections @text_sections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2550 2551 2552 2553 2554 2555 2556 2557 2558 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2550 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @confidence = args[:confidence] if args.key?(:confidence) @conversation_model = args[:conversation_model] if args.key?(:conversation_model) @generator_id = args[:generator_id] if args.key?(:generator_id) @metadata = args[:metadata] if args.key?(:metadata) @text = args[:text] if args.key?(:text) @text_sections = args[:text_sections] if args.key?(:text_sections) end |