Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A segment of a full transcript.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment

Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment.



3247
3248
3249
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_tagFixnum

For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel. For audioChannelCount = N, its output values can range from '1' to 'N'. A channel tag of 0 indicates that the audio is mono. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


3198
3199
3200
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3198

def channel_tag
  @channel_tag
end

#confidenceFloat

A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A default value of 0.0 indicates that the value is unset. Corresponds to the JSON property confidence

Returns:

  • (Float)


3204
3205
3206
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3204

def confidence
  @confidence
end

#dialogflow_segment_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Metadata from Dialogflow relating to the current transcript segment. Corresponds to the JSON property dialogflowSegmentMetadata



3209
3210
3211
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3209

def 
  @dialogflow_segment_metadata
end

#language_codeString

The language code of this segment as a BCP-47 language tag. Example: "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


3215
3216
3217
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3215

def language_code
  @language_code
end

#message_timeString

The time that the message occurred, if provided. Corresponds to the JSON property messageTime

Returns:

  • (String)


3220
3221
3222
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3220

def message_time
  @message_time
end

#segment_participantGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationParticipant

The call participant speaking for a given utterance. Corresponds to the JSON property segmentParticipant



3225
3226
3227
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3225

def segment_participant
  @segment_participant
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



3230
3231
3232
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3230

def sentiment
  @sentiment
end

#textString

The text of this segment. Corresponds to the JSON property text

Returns:

  • (String)


3235
3236
3237
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3235

def text
  @text
end

#turn_level_audioGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio

A wrapper for holding the audio for any given turn. Corresponds to the JSON property turnLevelAudio



3240
3241
3242
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3240

def turn_level_audio
  @turn_level_audio
end

#wordsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo>

A list of the word-specific information for each word in the segment. Corresponds to the JSON property words



3245
3246
3247
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3245

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3252

def update!(**args)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @confidence = args[:confidence] if args.key?(:confidence)
  @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata)
  @language_code = args[:language_code] if args.key?(:language_code)
  @message_time = args[:message_time] if args.key?(:message_time)
  @segment_participant = args[:segment_participant] if args.key?(:segment_participant)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @text = args[:text] if args.key?(:text)
  @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio)
  @words = args[:words] if args.key?(:words)
end