Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A segment of a full transcript.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel.
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment.
-
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
-
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag.
-
#message_time ⇒ String
The time that the message occurred, if provided.
-
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationParticipant
The call participant speaking for a given utterance.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
-
#text ⇒ String
The text of this segment.
-
#turn_level_audio ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
-
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment
constructor
A new instance of GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment
Returns a new instance of GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment.
3141 3142 3143 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number
corresponding to the audio from that channel. For audioChannelCount = N, its
output values can range from '1' to 'N'. A channel tag of 0 indicates that the
audio is mono.
Corresponds to the JSON property channelTag
3092 3093 3094 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3092 def channel_tag @channel_tag end |
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
3098 3099 3100 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3098 def confidence @confidence end |
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
Corresponds to the JSON property dialogflowSegmentMetadata
3103 3104 3105 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3103 def @dialogflow_segment_metadata end |
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag. Example: "en-US".
Corresponds to the JSON property languageCode
3109 3110 3111 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3109 def language_code @language_code end |
#message_time ⇒ String
The time that the message occurred, if provided.
Corresponds to the JSON property messageTime
3114 3115 3116 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3114 def @message_time end |
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationParticipant
The call participant speaking for a given utterance.
Corresponds to the JSON property segmentParticipant
3119 3120 3121 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3119 def segment_participant @segment_participant end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
3124 3125 3126 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3124 def sentiment @sentiment end |
#text ⇒ String
The text of this segment.
Corresponds to the JSON property text
3129 3130 3131 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3129 def text @text end |
#turn_level_audio ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
Corresponds to the JSON property turnLevelAudio
3134 3135 3136 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3134 def turn_level_audio @turn_level_audio end |
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Corresponds to the JSON property words
3139 3140 3141 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3139 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3146 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @confidence = args[:confidence] if args.key?(:confidence) @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata) @language_code = args[:language_code] if args.key?(:language_code) @message_time = args[:message_time] if args.key?(:message_time) @segment_participant = args[:segment_participant] if args.key?(:segment_participant) @sentiment = args[:sentiment] if args.key?(:sentiment) @text = args[:text] if args.key?(:text) @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio) @words = args[:words] if args.key?(:words) end |