Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A configuration that defines how to correlate conversations for a given a given project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1CorrelationConfig.



3235
3236
3237
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the correlation config was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3217
3218
3219
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3217

def create_time
  @create_time
end

#full_conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationTypeConfig

A list of correlation rules for a given correlation type. Corresponds to the JSON property fullConversationConfig



3222
3223
3224
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3222

def full_conversation_config
  @full_conversation_config
end

#nameString

Immutable. Identifier. The resource name of the correlation config. Format: projects/project/locations/location/correlationConfig Corresponds to the JSON property name

Returns:

  • (String)


3228
3229
3230
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3228

def name
  @name
end

#update_timeString

Output only. The time at which the correlation config was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3233
3234
3235
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3233

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3240
3241
3242
3243
3244
3245
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3240

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @full_conversation_config = args[:full_conversation_config] if args.key?(:full_conversation_config)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end