Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A configuration that defines how to correlate conversations for a given a given project.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#full_conversation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationTypeConfig
A list of correlation rules for a given correlation type.
-
#name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationConfig
constructor
A new instance of GoogleCloudContactcenterinsightsV1CorrelationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationConfig
Returns a new instance of GoogleCloudContactcenterinsightsV1CorrelationConfig.
2739 2740 2741 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the correlation config was created.
Corresponds to the JSON property createTime
2721 2722 2723 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2721 def create_time @create_time end |
#full_conversation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationTypeConfig
A list of correlation rules for a given correlation type.
Corresponds to the JSON property fullConversationConfig
2726 2727 2728 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2726 def full_conversation_config @full_conversation_config end |
#name ⇒ String
Immutable. Identifier. The resource name of the correlation config. Format:
projects/project/locations/location/correlationConfig
Corresponds to the JSON property name
2732 2733 2734 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2732 def name @name end |
#update_time ⇒ String
Output only. The time at which the correlation config was last updated.
Corresponds to the JSON property updateTime
2737 2738 2739 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2737 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2744 2745 2746 2747 2748 2749 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2744 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @full_conversation_config = args[:full_conversation_config] if args.key?(:full_conversation_config) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |