Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A correlation rule that defines how to join conversations for a given correlation type.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Optional.
-
#constraint_expression ⇒ String
Optional.
-
#join_key_expression ⇒ String
Optional.
-
#rule_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1CorrelationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationRule
Returns a new instance of GoogleCloudContactcenterinsightsV1CorrelationRule.
3845 3846 3847 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Optional. Whether the config is active to be evaluated.
Corresponds to the JSON property active
3819 3820 3821 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3819 def active @active end |
#constraint_expression ⇒ String
Optional. A cel expression (go/cel) to be evaluated as a boolean value. Two
variables conversation_a and conversation_b will be available for evaluation.
This expression should evaluate to true if conversation_a and conversation_b
should be joined. This is used as an extra constraint on top of the
join_key_expression to further refine the group of conversations that are
joined together and will be evaluated in both directions. for two
conversations c1 and c2 and the result will be OR'd. We will evaluate: f(c1,
c2) OR f(c2, c1)
Corresponds to the JSON property constraintExpression
3832 3833 3834 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3832 def constraint_expression @constraint_expression end |
#join_key_expression ⇒ String
Optional. A cel expression (go/cel) to be evaluated as a string value. This
string value will be used as the join key for the correlation.
Corresponds to the JSON property joinKeyExpression
3838 3839 3840 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3838 def join_key_expression @join_key_expression end |
#rule_id ⇒ String
Required. The unique identifier of the rule.
Corresponds to the JSON property ruleId
3843 3844 3845 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3843 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3850 3851 3852 3853 3854 3855 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3850 def update!(**args) @active = args[:active] if args.key?(:active) @constraint_expression = args[:constraint_expression] if args.key?(:constraint_expression) @join_key_expression = args[:join_key_expression] if args.key?(:join_key_expression) @rule_id = args[:rule_id] if args.key?(:rule_id) end |