Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A correlation rule that defines how to join conversations for a given correlation type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1CorrelationRule

Returns a new instance of GoogleCloudContactcenterinsightsV1CorrelationRule.



2786
2787
2788
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Optional. Whether the config is active to be evaluated. Corresponds to the JSON property active

Returns:

  • (Boolean)


2760
2761
2762
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2760

def active
  @active
end

#constraint_expressionString

Optional. A cel expression (go/cel) to be evaluated as a boolean value. Two variables conversation_a and conversation_b will be available for evaluation. This expression should evaluate to true if conversation_a and conversation_b should be joined. This is used as an extra constraint on top of the join_key_expression to further refine the group of conversations that are joined together and will be evaluated in both directions. for two conversations c1 and c2 and the result will be OR'd. We will evaluate: f(c1, c2) OR f(c2, c1) Corresponds to the JSON property constraintExpression

Returns:

  • (String)


2773
2774
2775
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2773

def constraint_expression
  @constraint_expression
end

#join_key_expressionString

Optional. A cel expression (go/cel) to be evaluated as a string value. This string value will be used as the join key for the correlation. Corresponds to the JSON property joinKeyExpression

Returns:

  • (String)


2779
2780
2781
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2779

def join_key_expression
  @join_key_expression
end

#rule_idString

Required. The unique identifier of the rule. Corresponds to the JSON property ruleId

Returns:

  • (String)


2784
2785
2786
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2784

def rule_id
  @rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2791
2792
2793
2794
2795
2796
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2791

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @constraint_expression = args[:constraint_expression] if args.key?(:constraint_expression)
  @join_key_expression = args[:join_key_expression] if args.key?(:join_key_expression)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
end