Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset

Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.



3581
3582
3583
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


3548
3549
3550
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3548

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


3553
3554
3555
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3553

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


3558
3559
3560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3558

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3564

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3569

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


3574
3575
3576
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3574

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


3579
3580
3581
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3579

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3586
3587
3588
3589
3590
3591
3592
3593
3594
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3586

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end