Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.
4132 4133 4134 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
4099 4100 4101 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4099 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
4104 4105 4106 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4104 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
4109 4110 4111 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4109 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
4115 4116 4117 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4115 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
4120 4121 4122 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4120 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
4125 4126 4127 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4125 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
4130 4131 4132 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4130 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4137 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |