Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.
3575 3576 3577 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
3542 3543 3544 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3542 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
3547 3548 3549 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3547 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
3552 3553 3554 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3552 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
3558 3559 3560 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3558 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
3563 3564 3565 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3563 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
3568 3569 3570 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3568 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
3573 3574 3575 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3573 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3580 3581 3582 3583 3584 3585 3586 3587 3588 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3580 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |