Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset

Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.



3079
3080
3081
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


3046
3047
3048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3046

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


3051
3052
3053
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3051

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


3056
3057
3058
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3056

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


3062
3063
3064
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3062

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


3067
3068
3069
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3067

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


3072
3073
3074
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3072

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


3077
3078
3079
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3077

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3084
3085
3086
3087
3088
3089
3090
3091
3092
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3084

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end