Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset

Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.



2441
2442
2443
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


2408
2409
2410
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2408

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


2413
2414
2415
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2413

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


2418
2419
2420
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2418

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2424

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


2429
2430
2431
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2429

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


2434
2435
2436
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2434

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2439
2440
2441
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2439

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2446
2447
2448
2449
2450
2451
2452
2453
2454
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2446

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end