Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1Dataset.
2441 2442 2443 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
2408 2409 2410 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2408 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
2413 2414 2415 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2413 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
2418 2419 2420 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2418 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
2424 2425 2426 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2424 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
2429 2430 2431 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2429 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
2434 2435 2436 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2434 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
2439 2440 2441 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2439 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2446 2447 2448 2449 2450 2451 2452 2453 2454 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2446 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |