Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for a DiagnoseConversations operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#diagnostic_report ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
A diagnostic report containing loss patterns and problematic slice stats.
-
#end_time ⇒ String
Output only.
-
#full_report ⇒ Boolean
(also: #full_report?)
Output only.
-
#latest_step ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
A step in the agent's reasoning process (Trajectory Step).
-
#metric_type ⇒ String
Output only.
-
#partial_trajectories ⇒ Array<String>
Output only.
-
#partial_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep>
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
The request to analyze conversation data using agentic workflows.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata.
4436 4437 4438 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
4387 4388 4389 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4387 def create_time @create_time end |
#diagnostic_report ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
A diagnostic report containing loss patterns and problematic slice stats.
Corresponds to the JSON property diagnosticReport
4392 4393 4394 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4392 def diagnostic_report @diagnostic_report end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
4397 4398 4399 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4397 def end_time @end_time end |
#full_report ⇒ Boolean Also known as: full_report?
Output only. If true, the agent generated a full diagnostic report for all sub-
agents.
Corresponds to the JSON property fullReport
4403 4404 4405 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4403 def full_report @full_report end |
#latest_step ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
A step in the agent's reasoning process (Trajectory Step).
Corresponds to the JSON property latestStep
4409 4410 4411 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4409 def latest_step @latest_step end |
#metric_type ⇒ String
Output only. The type of metric being diagnosed.
Corresponds to the JSON property metricType
4414 4415 4416 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4414 def metric_type @metric_type end |
#partial_trajectories ⇒ Array<String>
Output only. Deprecated: Use partial_trajectory_steps instead. Output only.
The intermediate trajectory updates (partial trajectory).
Corresponds to the JSON property partialTrajectories
4420 4421 4422 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4420 def partial_trajectories @partial_trajectories end |
#partial_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep>
Output only. The intermediate trajectory updates. This can be used for live
progress tracking of the agent's thoughts and actions as it works through the
analysis.
Corresponds to the JSON property partialTrajectorySteps
4427 4428 4429 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4427 def partial_trajectory_steps @partial_trajectory_steps end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
The request to analyze conversation data using agentic workflows. This RPC
triggers a complex analysis process that may involve several steps of
reasoning and tool execution.
Corresponds to the JSON property request
4434 4435 4436 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4434 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4441 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report) @end_time = args[:end_time] if args.key?(:end_time) @full_report = args[:full_report] if args.key?(:full_report) @latest_step = args[:latest_step] if args.key?(:latest_step) @metric_type = args[:metric_type] if args.key?(:metric_type) @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories) @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps) @request = args[:request] if args.key?(:request) end |