Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for a DiagnoseConversations operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#diagnostic_report ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
A diagnostic report containing aggregate metrics and intent breakdowns.
-
#end_time ⇒ String
Output only.
-
#full_report ⇒ Boolean
(also: #full_report?)
Output only.
-
#latest_step ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
A step in the agent's reasoning process (Trajectory Step).
-
#metric_type ⇒ String
Output only.
-
#partial_trajectories ⇒ Array<String>
Output only.
-
#partial_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep>
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
The request to analyze conversation data using agentic workflows.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsMetadata.
3873 3874 3875 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3824 3825 3826 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3824 def create_time @create_time end |
#diagnostic_report ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
A diagnostic report containing aggregate metrics and intent breakdowns.
Corresponds to the JSON property diagnosticReport
3829 3830 3831 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3829 def diagnostic_report @diagnostic_report end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3834 3835 3836 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3834 def end_time @end_time end |
#full_report ⇒ Boolean Also known as: full_report?
Output only. If true, the agent generated a full diagnostic report for all sub-
agents.
Corresponds to the JSON property fullReport
3840 3841 3842 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3840 def full_report @full_report end |
#latest_step ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
A step in the agent's reasoning process (Trajectory Step).
Corresponds to the JSON property latestStep
3846 3847 3848 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3846 def latest_step @latest_step end |
#metric_type ⇒ String
Output only. The type of metric being diagnosed.
Corresponds to the JSON property metricType
3851 3852 3853 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3851 def metric_type @metric_type end |
#partial_trajectories ⇒ Array<String>
Output only. Deprecated: Use partial_trajectory_steps instead. The
intermediate trajectory updates (partial trajectory).
Corresponds to the JSON property partialTrajectories
3857 3858 3859 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3857 def partial_trajectories @partial_trajectories end |
#partial_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep>
Output only. The intermediate trajectory updates. This can be used for live
progress tracking of the agent's thoughts and actions as it works through the
analysis.
Corresponds to the JSON property partialTrajectorySteps
3864 3865 3866 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3864 def partial_trajectory_steps @partial_trajectory_steps end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
The request to analyze conversation data using agentic workflows. This RPC
triggers a complex analysis process that may involve several steps of
reasoning and tool execution.
Corresponds to the JSON property request
3871 3872 3873 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3871 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3878 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report) @end_time = args[:end_time] if args.key?(:end_time) @full_report = args[:full_report] if args.key?(:full_report) @latest_step = args[:latest_step] if args.key?(:latest_step) @metric_type = args[:metric_type] if args.key?(:metric_type) @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories) @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps) @request = args[:request] if args.key?(:request) end |