Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#filter ⇒ String
Optional.
-
#full_report ⇒ Boolean
(also: #full_report?)
Optional.
-
#instructions ⇒ String
Optional.
-
#max_steps ⇒ Fixnum
Optional.
-
#metric_type ⇒ String
Optional.
-
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1OutputConfig
Configuration for where to export or return the analysis findings.
-
#parent ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#task_query ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest.
4523 4524 4525 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. Deprecated: If true, the request will be validated and a simulation
of the analysis will be performed without actually executing the task. This
field is unused. Use validate_only instead.
Corresponds to the JSON property dryRun
4459 4460 4461 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4459 def dry_run @dry_run end |
#filter ⇒ String
Optional. AIP-160 compliant filter for selecting target conversations.
Corresponds to the JSON property filter
4465 4466 4467 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4465 def filter @filter end |
#full_report ⇒ Boolean Also known as: full_report?
Optional. Deprecated: If true, the agent will generate a full diagnostic
report for all sub-agents. Subagent reporting configuration is unused. The
final diagnostic details are already persisted inside the Diagnostic resource
instead.
Corresponds to the JSON property fullReport
4473 4474 4475 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4473 def full_report @full_report end |
#instructions ⇒ String
Optional. Specific instructions for the agent.
Corresponds to the JSON property instructions
4479 4480 4481 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4479 def instructions @instructions end |
#max_steps ⇒ Fixnum
Optional. The maximum number of steps the agent can take during the execution
of the task. Defaults to 10.
Corresponds to the JSON property maxSteps
4485 4486 4487 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4485 def max_steps @max_steps end |
#metric_type ⇒ String
Optional. The type of metric being diagnosed.
Corresponds to the JSON property metricType
4490 4491 4492 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4490 def metric_type @metric_type end |
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1OutputConfig
Configuration for where to export or return the analysis findings.
Corresponds to the JSON property outputConfig
4495 4496 4497 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4495 def output_config @output_config end |
#parent ⇒ String
Required. The parent resource where the analysis will be performed.
Corresponds to the JSON property parent
4500 4501 4502 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4500 def parent @parent end |
#request_id ⇒ String
Optional. Required. A unique ID that identifies the request. If the service
receives two DiagnoseConversationsRequests with the same request_id, then
the second request will be ignored; instead, the response of the first request
will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9),
underscores (_), and hyphens (-). The maximum length is 40 characters.
Corresponds to the JSON property requestId
4509 4510 4511 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4509 def request_id @request_id end |
#task_query ⇒ String
Optional. A natural language description of the analysis goal or question.
Corresponds to the JSON property taskQuery
4514 4515 4516 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4514 def task_query @task_query end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If true, the request will only be validated (permissions, filter
syntax, etc.) without actually triggering the analysis.
Corresponds to the JSON property validateOnly
4520 4521 4522 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4520 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4528 4529 4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4528 def update!(**args) @dry_run = args[:dry_run] if args.key?(:dry_run) @filter = args[:filter] if args.key?(:filter) @full_report = args[:full_report] if args.key?(:full_report) @instructions = args[:instructions] if args.key?(:instructions) @max_steps = args[:max_steps] if args.key?(:max_steps) @metric_type = args[:metric_type] if args.key?(:metric_type) @output_config = args[:output_config] if args.key?(:output_config) @parent = args[:parent] if args.key?(:parent) @request_id = args[:request_id] if args.key?(:request_id) @task_query = args[:task_query] if args.key?(:task_query) @validate_only = args[:validate_only] if args.key?(:validate_only) end |