Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsRequest.



3963
3964
3965
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dry_runBoolean Also known as: dry_run?

Optional. If true, the request will be validated and a simulation of the analysis will be performed without actually executing the task. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


3901
3902
3903
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3901

def dry_run
  @dry_run
end

#filterString

Optional. AIP-160 compliant filter for selecting target conversations. Corresponds to the JSON property filter

Returns:

  • (String)


3907
3908
3909
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3907

def filter
  @filter
end

#full_reportBoolean Also known as: full_report?

Optional. If true, the agent will generate a full diagnostic report for all sub-agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


3913
3914
3915
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3913

def full_report
  @full_report
end

#instructionsString

Optional. Specific instructions for the agent. Corresponds to the JSON property instructions

Returns:

  • (String)


3919
3920
3921
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3919

def instructions
  @instructions
end

#max_stepsFixnum

Optional. The maximum number of steps the agent can take during the execution of the task. Defaults to 10. Corresponds to the JSON property maxSteps

Returns:

  • (Fixnum)


3925
3926
3927
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3925

def max_steps
  @max_steps
end

#metric_typeString

Optional. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


3930
3931
3932
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3930

def metric_type
  @metric_type
end

#output_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1OutputConfig

Configuration for where to export or return the analysis findings. Corresponds to the JSON property outputConfig



3935
3936
3937
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3935

def output_config
  @output_config
end

#parentString

Required. The parent resource where the analysis will be performed. Corresponds to the JSON property parent

Returns:

  • (String)


3940
3941
3942
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3940

def parent
  @parent
end

#request_idString

Optional. Required. A unique ID that identifies the request. If the service receives two DiagnoseConversationsRequests with the same request_id, then the second request will be ignored; instead, the response of the first request will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


3949
3950
3951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3949

def request_id
  @request_id
end

#task_queryString

Optional. A natural language description of the analysis goal or question. Corresponds to the JSON property taskQuery

Returns:

  • (String)


3954
3955
3956
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3954

def task_query
  @task_query
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If true, the request will only be validated (permissions, filter syntax, etc.) without actually triggering the analysis. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3960
3961
3962
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3960

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3968

def update!(**args)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @filter = args[:filter] if args.key?(:filter)
  @full_report = args[:full_report] if args.key?(:full_report)
  @instructions = args[:instructions] if args.key?(:instructions)
  @max_steps = args[:max_steps] if args.key?(:max_steps)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @output_config = args[:output_config] if args.key?(:output_config)
  @parent = args[:parent] if args.key?(:parent)
  @request_id = args[:request_id] if args.key?(:request_id)
  @task_query = args[:task_query] if args.key?(:task_query)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end