Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response from a DiagnoseConversations request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsResponse.



4574
4575
4576
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

Output only. Deprecated: Output only. The final, high-level answer or diagnostic summary returned by the Sherlock worker is deprecated. The persistent analysis summary is stored inside the Diagnostic resource instead. Corresponds to the JSON property answer

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4552

def answer
  @answer
end

#export_uriString

Output only. Deprecated: Output only. If an external destination was requested, the URI of the exported data is deprecated. The persistent diagnostic details are stored inside the Diagnostic resource instead. Corresponds to the JSON property exportUri

Returns:

  • (String)


4559
4560
4561
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4559

def export_uri
  @export_uri
end

#full_trajectoriesArray<String>

Output only. Deprecated: Use full_trajectory_steps instead. Output only. The complete sequence of thoughts and actions (full trajectory). Corresponds to the JSON property fullTrajectories

Returns:

  • (Array<String>)


4565
4566
4567
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4565

def full_trajectories
  @full_trajectories
end

#full_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep>

Output only. Deprecated: Output only. The complete sequence of thoughts and actions taken by the agent is deprecated under LRO response completions. Use the persistent details inside the Diagnostic resource instead. Corresponds to the JSON property fullTrajectorySteps



4572
4573
4574
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4572

def full_trajectory_steps
  @full_trajectory_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4579
4580
4581
4582
4583
4584
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4579

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @export_uri = args[:export_uri] if args.key?(:export_uri)
  @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories)
  @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps)
end