Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnoseConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response from a DiagnoseConversations request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnoseConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnoseConversationsResponse.



4010
4011
4012
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

Output only. The final, high-level answer or diagnostic summary returned by the Sherlock worker. Corresponds to the JSON property answer

Returns:

  • (String)


3991
3992
3993
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3991

def answer
  @answer
end

#export_uriString

Output only. If an external destination was requested, the URI of the exported data. Corresponds to the JSON property exportUri

Returns:

  • (String)


3997
3998
3999
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3997

def export_uri
  @export_uri
end

#full_trajectoriesArray<String>

Output only. Deprecated: Use full_trajectory_steps instead. The complete sequence of thoughts and actions (full trajectory). Corresponds to the JSON property fullTrajectories

Returns:

  • (Array<String>)


4003
4004
4005
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4003

def full_trajectories
  @full_trajectories
end

#full_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep>

Output only. The complete sequence of thoughts and actions taken by the agent. Corresponds to the JSON property fullTrajectorySteps



4008
4009
4010
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4008

def full_trajectory_steps
  @full_trajectory_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4015
4016
4017
4018
4019
4020
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4015

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @export_uri = args[:export_uri] if args.key?(:export_uri)
  @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories)
  @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps)
end