Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Diagnostic

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The diagnostic resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Diagnostic

Returns a new instance of GoogleCloudContactcenterinsightsV1Diagnostic.



4617
4618
4619
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_summaryString

Output only. The complete sequence of thoughts and actions taken by the agent. Corresponds to the JSON property analysisSummary

Returns:

  • (String)


4594
4595
4596
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4594

def analysis_summary
  @analysis_summary
end

#conversation_filterString

Output only. The filter used to select the conversations that were included in the diagnostic. Corresponds to the JSON property conversationFilter

Returns:

  • (String)


4600
4601
4602
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4600

def conversation_filter
  @conversation_filter
end

#create_timeString

Output only. The time at which the diagnostic was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4605

def create_time
  @create_time
end

#nameString

Immutable. Identifier. The resource name of the diagnostic. Corresponds to the JSON property name

Returns:

  • (String)


4610
4611
4612
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4610

def name
  @name
end

#reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport

A diagnostic report containing aggregate metrics and intent breakdowns. Corresponds to the JSON property report



4615
4616
4617
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4615

def report
  @report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4622
4623
4624
4625
4626
4627
4628
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4622

def update!(**args)
  @analysis_summary = args[:analysis_summary] if args.key?(:analysis_summary)
  @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @report = args[:report] if args.key?(:report)
end