Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Diagnostic
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Diagnostic
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The diagnostic resource.
Instance Attribute Summary collapse
-
#analysis_summary ⇒ String
Output only.
-
#conversation_filter ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#report ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
A diagnostic report containing aggregate metrics and intent breakdowns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Diagnostic
constructor
A new instance of GoogleCloudContactcenterinsightsV1Diagnostic.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Diagnostic
Returns a new instance of GoogleCloudContactcenterinsightsV1Diagnostic.
4053 4054 4055 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_summary ⇒ String
Output only. The complete sequence of thoughts and actions taken by the agent.
Corresponds to the JSON property analysisSummary
4030 4031 4032 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4030 def analysis_summary @analysis_summary end |
#conversation_filter ⇒ String
Output only. The filter used to select the conversations that were included in
the diagnostic.
Corresponds to the JSON property conversationFilter
4036 4037 4038 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4036 def conversation_filter @conversation_filter end |
#create_time ⇒ String
Output only. The time at which the diagnostic was created.
Corresponds to the JSON property createTime
4041 4042 4043 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4041 def create_time @create_time end |
#name ⇒ String
Immutable. Identifier. The resource name of the diagnostic.
Corresponds to the JSON property name
4046 4047 4048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4046 def name @name end |
#report ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
A diagnostic report containing aggregate metrics and intent breakdowns.
Corresponds to the JSON property report
4051 4052 4053 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4051 def report @report end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4058 4059 4060 4061 4062 4063 4064 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4058 def update!(**args) @analysis_summary = args[:analysis_summary] if args.key?(:analysis_summary) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @report = args[:report] if args.key?(:report) end |