Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A diagnostic report containing loss patterns and problematic slice stats.
Instance Attribute Summary collapse
-
#conversation_slices ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportConversationSlice>
Output only.
-
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportIntentStats>
Output only.
-
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern>
Output only.
-
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricValue>
Output only.
-
#report ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnosticReport
constructor
A new instance of GoogleCloudContactcenterinsightsV1DiagnosticReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnosticReport
Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnosticReport.
4731 4732 4733 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_slices ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportConversationSlice>
Output only. A map of conversation slices used in the report.
Corresponds to the JSON property conversationSlices
4708 4709 4710 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4708 def conversation_slices @conversation_slices end |
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportIntentStats>
Output only. Deprecated: Intent breakdowns are no longer used.
Corresponds to the JSON property intentStats
4713 4714 4715 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4713 def intent_stats @intent_stats end |
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern>
Output only. A list of loss patterns identified for the entire project/dataset.
Corresponds to the JSON property lossPatterns
4718 4719 4720 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4718 def loss_patterns @loss_patterns end |
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricValue>
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metrics
4724 4725 4726 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4724 def metrics @metrics end |
#report ⇒ String
Output only. The final report in markdown format.
Corresponds to the JSON property report
4729 4730 4731 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4729 def report @report end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4736 def update!(**args) @conversation_slices = args[:conversation_slices] if args.key?(:conversation_slices) @intent_stats = args[:intent_stats] if args.key?(:intent_stats) @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns) @metrics = args[:metrics] if args.key?(:metrics) @report = args[:report] if args.key?(:report) end |