Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A diagnostic report containing aggregate metrics and intent breakdowns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnosticReport

Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnosticReport.



4661
4662
4663
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_slicesHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportConversationSlice>

Output only. A map of conversation slices used in the report. Corresponds to the JSON property conversationSlices



4638
4639
4640
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4638

def conversation_slices
  @conversation_slices
end

#intent_statsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportIntentStats>

Output only. Deprecated: Intent breakdowns are no longer used. Corresponds to the JSON property intentStats



4643
4644
4645
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4643

def intent_stats
  @intent_stats
end

#loss_patternsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern>

Output only. A list of loss patterns identified for the entire project/dataset. Corresponds to the JSON property lossPatterns



4648
4649
4650
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4648

def loss_patterns
  @loss_patterns
end

#metricsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricValue>

Output only. Deprecated: The type of the metric. Metrics for Outcome Based Insights derived from QueryMetrics. Corresponds to the JSON property metrics



4654
4655
4656
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4654

def metrics
  @metrics
end

#reportString

Output only. The final report in markdown format. Corresponds to the JSON property report

Returns:

  • (String)


4659
4660
4661
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4659

def report
  @report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4666
4667
4668
4669
4670
4671
4672
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4666

def update!(**args)
  @conversation_slices = args[:conversation_slices] if args.key?(:conversation_slices)
  @intent_stats = args[:intent_stats] if args.key?(:intent_stats)
  @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns)
  @metrics = args[:metrics] if args.key?(:metrics)
  @report = args[:report] if args.key?(:report)
end