Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A diagnostic report containing aggregate metrics and intent breakdowns.
Instance Attribute Summary collapse
-
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportIntentStats>
Output only.
-
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern>
Output only.
-
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricValue>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnosticReport
constructor
A new instance of GoogleCloudContactcenterinsightsV1DiagnosticReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1DiagnosticReport
Returns a new instance of GoogleCloudContactcenterinsightsV1DiagnosticReport.
4087 4088 4089 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DiagnosticReportIntentStats>
Output only. A breakdown of metrics grouped by intent.
Corresponds to the JSON property intentStats
4074 4075 4076 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4074 def intent_stats @intent_stats end |
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern>
Output only. A list of loss patterns identified for the entire project/dataset.
Corresponds to the JSON property lossPatterns
4079 4080 4081 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4079 def loss_patterns @loss_patterns end |
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricValue>
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metrics
4085 4086 4087 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4085 def metrics @metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4092 4093 4094 4095 4096 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4092 def update!(**args) @intent_stats = args[:intent_stats] if args.key?(:intent_stats) @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns) @metrics = args[:metrics] if args.key?(:metrics) end |