Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dimension

Returns a new instance of GoogleCloudContactcenterinsightsV1Dimension.



4075
4076
4077
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata

Metadata about the agent dimension. Corresponds to the JSON property agentDimensionMetadata



4017
4018
4019
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4017

def 
  @agent_dimension_metadata
end

#client_sentiment_category_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata

Metadata about the client sentiment category dimension. Corresponds to the JSON property clientSentimentCategoryDimensionMetadata



4022
4023
4024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4022

def 
  @client_sentiment_category_dimension_metadata
end

#conversation_profile_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata

Metadata about the conversation profile dimension. Corresponds to the JSON property conversationProfileDimensionMetadata



4027
4028
4029
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4027

def 
  @conversation_profile_dimension_metadata
end

#conversational_agents_playbook_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata

Metadata about the Conversational Agents playbook dimension. Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata



4032
4033
4034
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4032

def 
  @conversational_agents_playbook_dimension_metadata
end

#conversational_agents_tool_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata

Metadata about the Conversational Agents tool dimension. Corresponds to the JSON property conversationalAgentsToolDimensionMetadata



4037
4038
4039
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4037

def 
  @conversational_agents_tool_dimension_metadata
end

#dimension_keyString

The key of the dimension. Corresponds to the JSON property dimensionKey

Returns:

  • (String)


4042
4043
4044
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4042

def dimension_key
  @dimension_key
end

#issue_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata

Metadata about the issue dimension. Corresponds to the JSON property issueDimensionMetadata



4047
4048
4049
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4047

def 
  @issue_dimension_metadata
end

#label_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata

Metadata about conversation labels. Corresponds to the JSON property labelDimensionMetadata



4052
4053
4054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4052

def 
  @label_dimension_metadata
end

#medium_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata

Metadata about the conversation medium dimension. Corresponds to the JSON property mediumDimensionMetadata



4057
4058
4059
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4057

def 
  @medium_dimension_metadata
end

#qa_question_answer_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata

Metadata about the QA question-answer dimension. This is useful for showing the answer distribution for questions for a given scorecard. Corresponds to the JSON property qaQuestionAnswerDimensionMetadata



4063
4064
4065
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4063

def 
  @qa_question_answer_dimension_metadata
end

#qa_question_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata

Metadata about the QA question dimension. Corresponds to the JSON property qaQuestionDimensionMetadata



4068
4069
4070
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4068

def 
  @qa_question_dimension_metadata
end

#qa_scorecard_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata

Metadata about the QA scorecard dimension. Corresponds to the JSON property qaScorecardDimensionMetadata



4073
4074
4075
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4073

def 
  @qa_scorecard_dimension_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4080

def update!(**args)
  @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata)
  @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata)
  @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata)
  @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata)
  @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata)
  @dimension_key = args[:dimension_key] if args.key?(:dimension_key)
  @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata)
  @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata)
  @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata)
  @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata)
  @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata)
  @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata)
end