Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dimension

Returns a new instance of GoogleCloudContactcenterinsightsV1Dimension.



3963
3964
3965
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata

Metadata about the agent dimension. Corresponds to the JSON property agentDimensionMetadata



3905
3906
3907
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3905

def 
  @agent_dimension_metadata
end

#client_sentiment_category_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata

Metadata about the client sentiment category dimension. Corresponds to the JSON property clientSentimentCategoryDimensionMetadata



3910
3911
3912
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3910

def 
  @client_sentiment_category_dimension_metadata
end

#conversation_profile_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata

Metadata about the conversation profile dimension. Corresponds to the JSON property conversationProfileDimensionMetadata



3915
3916
3917
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3915

def 
  @conversation_profile_dimension_metadata
end

#conversational_agents_playbook_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata

Metadata about the Conversational Agents playbook dimension. Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata



3920
3921
3922
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3920

def 
  @conversational_agents_playbook_dimension_metadata
end

#conversational_agents_tool_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata

Metadata about the Conversational Agents tool dimension. Corresponds to the JSON property conversationalAgentsToolDimensionMetadata



3925
3926
3927
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3925

def 
  @conversational_agents_tool_dimension_metadata
end

#dimension_keyString

The key of the dimension. Corresponds to the JSON property dimensionKey

Returns:

  • (String)


3930
3931
3932
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3930

def dimension_key
  @dimension_key
end

#issue_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata

Metadata about the issue dimension. Corresponds to the JSON property issueDimensionMetadata



3935
3936
3937
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3935

def 
  @issue_dimension_metadata
end

#label_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata

Metadata about conversation labels. Corresponds to the JSON property labelDimensionMetadata



3940
3941
3942
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3940

def 
  @label_dimension_metadata
end

#medium_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata

Metadata about the conversation medium dimension. Corresponds to the JSON property mediumDimensionMetadata



3945
3946
3947
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3945

def 
  @medium_dimension_metadata
end

#qa_question_answer_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata

Metadata about the QA question-answer dimension. This is useful for showing the answer distribution for questions for a given scorecard. Corresponds to the JSON property qaQuestionAnswerDimensionMetadata



3951
3952
3953
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3951

def 
  @qa_question_answer_dimension_metadata
end

#qa_question_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata

Metadata about the QA question dimension. Corresponds to the JSON property qaQuestionDimensionMetadata



3956
3957
3958
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3956

def 
  @qa_question_dimension_metadata
end

#qa_scorecard_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata

Metadata about the QA scorecard dimension. Corresponds to the JSON property qaScorecardDimensionMetadata



3961
3962
3963
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3961

def 
  @qa_scorecard_dimension_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3968

def update!(**args)
  @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata)
  @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata)
  @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata)
  @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata)
  @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata)
  @dimension_key = args[:dimension_key] if args.key?(:dimension_key)
  @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata)
  @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata)
  @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata)
  @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata)
  @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata)
  @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata)
end