Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dimension

Returns a new instance of GoogleCloudContactcenterinsightsV1Dimension.



4878
4879
4880
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata

Metadata about the agent dimension. Corresponds to the JSON property agentDimensionMetadata



4820
4821
4822
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4820

def 
  @agent_dimension_metadata
end

#client_sentiment_category_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata

Metadata about the client sentiment category dimension. Corresponds to the JSON property clientSentimentCategoryDimensionMetadata



4825
4826
4827
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4825

def 
  @client_sentiment_category_dimension_metadata
end

#conversation_profile_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata

Metadata about the conversation profile dimension. Corresponds to the JSON property conversationProfileDimensionMetadata



4830
4831
4832
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4830

def 
  @conversation_profile_dimension_metadata
end

#conversational_agents_playbook_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata

Metadata about the Conversational Agents playbook dimension. Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata



4835
4836
4837
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4835

def 
  @conversational_agents_playbook_dimension_metadata
end

#conversational_agents_tool_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata

Metadata about the Conversational Agents tool dimension. Corresponds to the JSON property conversationalAgentsToolDimensionMetadata



4840
4841
4842
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4840

def 
  @conversational_agents_tool_dimension_metadata
end

#dimension_keyString

The key of the dimension. Corresponds to the JSON property dimensionKey

Returns:

  • (String)


4845
4846
4847
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4845

def dimension_key
  @dimension_key
end

#issue_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata

Metadata about the issue dimension. Corresponds to the JSON property issueDimensionMetadata



4850
4851
4852
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4850

def 
  @issue_dimension_metadata
end

#label_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata

Metadata about conversation labels. Corresponds to the JSON property labelDimensionMetadata



4855
4856
4857
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4855

def 
  @label_dimension_metadata
end

#medium_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata

Metadata about the conversation medium dimension. Corresponds to the JSON property mediumDimensionMetadata



4860
4861
4862
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4860

def 
  @medium_dimension_metadata
end

#qa_question_answer_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata

Metadata about the QA question-answer dimension. This is useful for showing the answer distribution for questions for a given scorecard. Corresponds to the JSON property qaQuestionAnswerDimensionMetadata



4866
4867
4868
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4866

def 
  @qa_question_answer_dimension_metadata
end

#qa_question_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata

Metadata about the QA question dimension. Corresponds to the JSON property qaQuestionDimensionMetadata



4871
4872
4873
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4871

def 
  @qa_question_dimension_metadata
end

#qa_scorecard_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata

Metadata about the QA scorecard dimension. Corresponds to the JSON property qaScorecardDimensionMetadata



4876
4877
4878
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4876

def 
  @qa_scorecard_dimension_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4883

def update!(**args)
  @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata)
  @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata)
  @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata)
  @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata)
  @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata)
  @dimension_key = args[:dimension_key] if args.key?(:dimension_key)
  @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata)
  @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata)
  @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata)
  @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata)
  @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata)
  @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata)
end