Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.
Instance Attribute Summary collapse
-
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata
Metadata about the agent dimension.
-
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
-
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
-
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
-
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
-
#dimension_key ⇒ String
The key of the dimension.
-
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata
Metadata about the issue dimension.
-
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata
Metadata about conversation labels.
-
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
-
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension.
-
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
-
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dimension
constructor
A new instance of GoogleCloudContactcenterinsightsV1Dimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dimension
Returns a new instance of GoogleCloudContactcenterinsightsV1Dimension.
4283 4284 4285 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata
Metadata about the agent dimension.
Corresponds to the JSON property agentDimensionMetadata
4225 4226 4227 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4225 def @agent_dimension_metadata end |
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
Corresponds to the JSON property clientSentimentCategoryDimensionMetadata
4230 4231 4232 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4230 def @client_sentiment_category_dimension_metadata end |
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
Corresponds to the JSON property conversationProfileDimensionMetadata
4235 4236 4237 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4235 def @conversation_profile_dimension_metadata end |
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata
4240 4241 4242 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4240 def @conversational_agents_playbook_dimension_metadata end |
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
Corresponds to the JSON property conversationalAgentsToolDimensionMetadata
4245 4246 4247 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4245 def @conversational_agents_tool_dimension_metadata end |
#dimension_key ⇒ String
The key of the dimension.
Corresponds to the JSON property dimensionKey
4250 4251 4252 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4250 def dimension_key @dimension_key end |
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata
Metadata about the issue dimension.
Corresponds to the JSON property issueDimensionMetadata
4255 4256 4257 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4255 def @issue_dimension_metadata end |
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata
Metadata about conversation labels.
Corresponds to the JSON property labelDimensionMetadata
4260 4261 4262 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4260 def @label_dimension_metadata end |
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
Corresponds to the JSON property mediumDimensionMetadata
4265 4266 4267 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4265 def @medium_dimension_metadata end |
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension. This is useful for showing
the answer distribution for questions for a given scorecard.
Corresponds to the JSON property qaQuestionAnswerDimensionMetadata
4271 4272 4273 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4271 def @qa_question_answer_dimension_metadata end |
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
Corresponds to the JSON property qaQuestionDimensionMetadata
4276 4277 4278 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4276 def @qa_question_dimension_metadata end |
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Corresponds to the JSON property qaScorecardDimensionMetadata
4281 4282 4283 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4281 def @qa_scorecard_dimension_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4288 4289 4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4288 def update!(**args) @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata) @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata) @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata) @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata) @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata) @dimension_key = args[:dimension_key] if args.key?(:dimension_key) @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata) @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata) @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata) @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata) @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata) @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata) end |