Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Dimension

Returns a new instance of GoogleCloudContactcenterinsightsV1Dimension.



2773
2774
2775
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata

Metadata about the agent dimension. Corresponds to the JSON property agentDimensionMetadata



2715
2716
2717
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2715

def 
  @agent_dimension_metadata
end

#client_sentiment_category_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata

Metadata about the client sentiment category dimension. Corresponds to the JSON property clientSentimentCategoryDimensionMetadata



2720
2721
2722
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2720

def 
  @client_sentiment_category_dimension_metadata
end

#conversation_profile_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata

Metadata about the conversation profile dimension. Corresponds to the JSON property conversationProfileDimensionMetadata



2725
2726
2727
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2725

def 
  @conversation_profile_dimension_metadata
end

#conversational_agents_playbook_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata

Metadata about the Conversational Agents playbook dimension. Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata



2730
2731
2732
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2730

def 
  @conversational_agents_playbook_dimension_metadata
end

#conversational_agents_tool_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata

Metadata about the Conversational Agents tool dimension. Corresponds to the JSON property conversationalAgentsToolDimensionMetadata



2735
2736
2737
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2735

def 
  @conversational_agents_tool_dimension_metadata
end

#dimension_keyString

The key of the dimension. Corresponds to the JSON property dimensionKey

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2740

def dimension_key
  @dimension_key
end

#issue_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata

Metadata about the issue dimension. Corresponds to the JSON property issueDimensionMetadata



2745
2746
2747
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2745

def 
  @issue_dimension_metadata
end

#label_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata

Metadata about conversation labels. Corresponds to the JSON property labelDimensionMetadata



2750
2751
2752
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2750

def 
  @label_dimension_metadata
end

#medium_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata

Metadata about the conversation medium dimension. Corresponds to the JSON property mediumDimensionMetadata



2755
2756
2757
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2755

def 
  @medium_dimension_metadata
end

#qa_question_answer_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata

Metadata about the QA question-answer dimension. This is useful for showing the answer distribution for questions for a given scorecard. Corresponds to the JSON property qaQuestionAnswerDimensionMetadata



2761
2762
2763
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2761

def 
  @qa_question_answer_dimension_metadata
end

#qa_question_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata

Metadata about the QA question dimension. Corresponds to the JSON property qaQuestionDimensionMetadata



2766
2767
2768
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2766

def 
  @qa_question_dimension_metadata
end

#qa_scorecard_dimension_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata

Metadata about the QA scorecard dimension. Corresponds to the JSON property qaScorecardDimensionMetadata



2771
2772
2773
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2771

def 
  @qa_scorecard_dimension_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 2778

def update!(**args)
  @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata)
  @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata)
  @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata)
  @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata)
  @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata)
  @dimension_key = args[:dimension_key] if args.key?(:dimension_key)
  @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata)
  @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata)
  @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata)
  @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata)
  @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata)
  @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata)
end