Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Entity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The data for an entity annotation. Represents a phrase in the conversation that is a known entity, such as a person, an organization, or location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Entity

Returns a new instance of GoogleCloudContactcenterinsightsV1Entity.



4477
4478
4479
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The representative name for the entity. Corresponds to the JSON property displayName

Returns:

  • (String)


4449
4450
4451
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4449

def display_name
  @display_name
end

#metadataHash<String,String>

Metadata associated with the entity. For most entity types, the metadata is a Wikipedia URL (wikipedia_url) and Knowledge Graph MID (mid), if they are available. For the metadata associated with other entity types, see the Type table below. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


4457
4458
4459
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4457

def 
  @metadata
end

#salienceFloat

The salience score associated with the entity in the [0, 1.0] range. The salience score for an entity provides information about the importance or centrality of that entity to the entire document text. Scores closer to 0 are less salient, while scores closer to 1.0 are highly salient. Corresponds to the JSON property salience

Returns:

  • (Float)


4465
4466
4467
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4465

def salience
  @salience
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



4470
4471
4472
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4470

def sentiment
  @sentiment
end

#typeString

The entity type. Corresponds to the JSON property type

Returns:

  • (String)


4475
4476
4477
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4475

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4482
4483
4484
4485
4486
4487
4488
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4482

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metadata = args[:metadata] if args.key?(:metadata)
  @salience = args[:salience] if args.key?(:salience)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @type = args[:type] if args.key?(:type)
end