Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Entity
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Entity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The data for an entity annotation. Represents a phrase in the conversation that is a known entity, such as a person, an organization, or location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The representative name for the entity.
-
#metadata ⇒ Hash<String,String>
Metadata associated with the entity.
-
#salience ⇒ Float
The salience score associated with the entity in the [0, 1.0] range.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
-
#type ⇒ String
The entity type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Entity
constructor
A new instance of GoogleCloudContactcenterinsightsV1Entity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Entity
Returns a new instance of GoogleCloudContactcenterinsightsV1Entity.
3175 3176 3177 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The representative name for the entity.
Corresponds to the JSON property displayName
3147 3148 3149 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3147 def display_name @display_name end |
#metadata ⇒ Hash<String,String>
Metadata associated with the entity. For most entity types, the metadata is a
Wikipedia URL (wikipedia_url) and Knowledge Graph MID (mid), if they are
available. For the metadata associated with other entity types, see the Type
table below.
Corresponds to the JSON property metadata
3155 3156 3157 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3155 def @metadata end |
#salience ⇒ Float
The salience score associated with the entity in the [0, 1.0] range. The
salience score for an entity provides information about the importance or
centrality of that entity to the entire document text. Scores closer to 0 are
less salient, while scores closer to 1.0 are highly salient.
Corresponds to the JSON property salience
3163 3164 3165 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3163 def salience @salience end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
3168 3169 3170 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3168 def sentiment @sentiment end |
#type ⇒ String
The entity type.
Corresponds to the JSON property type
3173 3174 3175 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3173 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3180 3181 3182 3183 3184 3185 3186 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3180 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @salience = args[:salience] if args.key?(:salience) @sentiment = args[:sentiment] if args.key?(:sentiment) @type = args[:type] if args.key?(:type) end |