Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for an export insights operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1ExportInsightsDataMetadata.



5452
5453
5454
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_export_countFixnum

The number of conversations that were exported successfully. Corresponds to the JSON property completedExportCount

Returns:

  • (Fixnum)


5424
5425
5426
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5424

def completed_export_count
  @completed_export_count
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5429
5430
5431
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5429

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


5434
5435
5436
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5434

def end_time
  @end_time
end

#failed_export_countFixnum

The number of conversations that failed to be exported. Corresponds to the JSON property failedExportCount

Returns:

  • (Fixnum)


5439
5440
5441
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5439

def failed_export_count
  @failed_export_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Partial errors during export operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



5445
5446
5447
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5445

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

The request to export insights. Corresponds to the JSON property request



5450
5451
5452
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5450

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5457
5458
5459
5460
5461
5462
5463
5464
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5457

def update!(**args)
  @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
end