Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to export insights.
Instance Attribute Summary collapse
-
#big_query_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination
A BigQuery Table Reference.
-
#export_schema_version ⇒ String
Optional.
-
#filter ⇒ String
A filter to reduce results to a specific subset.
-
#kms_key ⇒ String
A fully qualified KMS key name for BigQuery tables protected by CMEK.
-
#parent ⇒ String
Required.
-
#write_disposition ⇒ String
Options for what to do if the destination table already exists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest.
5504 5505 5506 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination
A BigQuery Table Reference.
Corresponds to the JSON property bigQueryDestination
5474 5475 5476 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5474 def big_query_destination @big_query_destination end |
#export_schema_version ⇒ String
Optional. Version of the export schema.
Corresponds to the JSON property exportSchemaVersion
5479 5480 5481 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5479 def export_schema_version @export_schema_version end |
#filter ⇒ String
A filter to reduce results to a specific subset. Useful for exporting
conversations with specific properties.
Corresponds to the JSON property filter
5485 5486 5487 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5485 def filter @filter end |
#kms_key ⇒ String
A fully qualified KMS key name for BigQuery tables protected by CMEK. Format:
projects/project/locations/location/keyRings/keyring/cryptoKeys/key/
cryptoKeyVersions/version
Corresponds to the JSON property kmsKey
5492 5493 5494 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5492 def kms_key @kms_key end |
#parent ⇒ String
Required. The parent resource to export data from.
Corresponds to the JSON property parent
5497 5498 5499 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5497 def parent @parent end |
#write_disposition ⇒ String
Options for what to do if the destination table already exists.
Corresponds to the JSON property writeDisposition
5502 5503 5504 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5502 def write_disposition @write_disposition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5509 5510 5511 5512 5513 5514 5515 5516 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5509 def update!(**args) @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination) @export_schema_version = args[:export_schema_version] if args.key?(:export_schema_version) @filter = args[:filter] if args.key?(:filter) @kms_key = args[:kms_key] if args.key?(:kms_key) @parent = args[:parent] if args.key?(:parent) @write_disposition = args[:write_disposition] if args.key?(:write_disposition) end |