Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to export insights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest.



4839
4840
4841
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_destinationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination

A BigQuery Table Reference. Corresponds to the JSON property bigQueryDestination



4809
4810
4811
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4809

def big_query_destination
  @big_query_destination
end

#export_schema_versionString

Optional. Version of the export schema. Corresponds to the JSON property exportSchemaVersion

Returns:

  • (String)


4814
4815
4816
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4814

def export_schema_version
  @export_schema_version
end

#filterString

A filter to reduce results to a specific subset. Useful for exporting conversations with specific properties. Corresponds to the JSON property filter

Returns:

  • (String)


4820
4821
4822
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4820

def filter
  @filter
end

#kms_keyString

A fully qualified KMS key name for BigQuery tables protected by CMEK. Format: projects/project/locations/location/keyRings/keyring/cryptoKeys/key/ cryptoKeyVersions/version Corresponds to the JSON property kmsKey

Returns:

  • (String)


4827
4828
4829
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4827

def kms_key
  @kms_key
end

#parentString

Required. The parent resource to export data from. Corresponds to the JSON property parent

Returns:

  • (String)


4832
4833
4834
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4832

def parent
  @parent
end

#write_dispositionString

Options for what to do if the destination table already exists. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


4837
4838
4839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4837

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4844

def update!(**args)
  @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination)
  @export_schema_version = args[:export_schema_version] if args.key?(:export_schema_version)
  @filter = args[:filter] if args.key?(:filter)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @parent = args[:parent] if args.key?(:parent)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end