Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist frequently-asked-question answer data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1FaqAnswerData

Returns a new instance of GoogleCloudContactcenterinsightsV1FaqAnswerData.



4208
4209
4210
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

The piece of text from the source knowledge base document. Corresponds to the JSON property answer

Returns:

  • (String)


4176
4177
4178
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4176

def answer
  @answer
end

#confidence_scoreFloat

The system's confidence score that this answer is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


4183
4184
4185
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4183

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the FAQ answer and the document that it originates from. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


4189
4190
4191
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4189

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


4195
4196
4197
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4195

def query_record
  @query_record
end

#questionString

The corresponding FAQ question. Corresponds to the JSON property question

Returns:

  • (String)


4200
4201
4202
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4200

def question
  @question
end

#sourceString

The knowledge document that this answer was extracted from. Format: projects/ project/knowledgeBases/knowledge_base/documents/document. Corresponds to the JSON property source

Returns:

  • (String)


4206
4207
4208
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4206

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4213
4214
4215
4216
4217
4218
4219
4220
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4213

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @question = args[:question] if args.key?(:question)
  @source = args[:source] if args.key?(:source)
end