Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1GcsSource.



4925
4926
4927
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


4917
4918
4919
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4917

def audio_uri
  @audio_uri
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


4923
4924
4925
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4923

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4930
4931
4932
4933
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4930

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end