Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The message in the conversation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#message_id ⇒ String
The message id of the message.
-
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
-
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage.
4912 4913 4914 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. For user messages, this is the time at which the system received
the message. For system messages, this is the time at which the system
generated the message.
Corresponds to the JSON property createTime
4895 4896 4897 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4895 def create_time @create_time end |
#message_id ⇒ String
The message id of the message.
Corresponds to the JSON property messageId
4900 4901 4902 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4900 def @message_id end |
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
Corresponds to the JSON property systemMessageWrapper
4905 4906 4907 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4905 def @system_message_wrapper end |
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Corresponds to the JSON property userMessage
4910 4911 4912 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4910 def @user_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4917 4918 4919 4920 4921 4922 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4917 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @message_id = args[:message_id] if args.key?(:message_id) @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper) @user_message = args[:user_message] if args.key?(:user_message) end |