Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The message in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessage.



5821
5822
5823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. For user messages, this is the time at which the system received the message. For system messages, this is the time at which the system generated the message. Corresponds to the JSON property createTime

Returns:

  • (String)


5804
5805
5806
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5804

def create_time
  @create_time
end

#message_idString

The message id of the message. Corresponds to the JSON property messageId

Returns:

  • (String)


5809
5810
5811
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5809

def message_id
  @message_id
end

#system_message_wrapperGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessages

A wrapper for system messages per turn. Corresponds to the JSON property systemMessageWrapper



5814
5815
5816
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5814

def system_message_wrapper
  @system_message_wrapper
end

#user_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageUserMessage

The user message. Corresponds to the JSON property userMessage



5819
5820
5821
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5819

def user_message
  @user_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5826
5827
5828
5829
5830
5831
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5826

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @message_id = args[:message_id] if args.key?(:message_id)
  @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper)
  @user_message = args[:user_message] if args.key?(:user_message)
end