Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessage.



4956
4957
4958
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_specHash<String,Object>

Chart spec from LLM Corresponds to the JSON property chartSpec

Returns:

  • (Hash<String,Object>)


4934
4935
4936
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4934

def chart_spec
  @chart_spec
end

#generated_sql_queryString

Raw SQL from LLM, before templatization Corresponds to the JSON property generatedSqlQuery

Returns:

  • (String)


4939
4940
4941
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4939

def generated_sql_query
  @generated_sql_query
end

#text_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightConversationTranscriptMessageSystemMessageTextOutput

A text output message from the system. Corresponds to the JSON property textMessage



4944
4945
4946
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4944

def text_message
  @text_message
end

#user_provided_chart_specHash<String,Object>

Optional. User provided chart spec Corresponds to the JSON property userProvidedChartSpec

Returns:

  • (Hash<String,Object>)


4949
4950
4951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4949

def user_provided_chart_spec
  @user_provided_chart_spec
end

#user_provided_sql_queryString

Optional. User provided SQL query Corresponds to the JSON property userProvidedSqlQuery

Returns:

  • (String)


4954
4955
4956
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4954

def user_provided_sql_query
  @user_provided_sql_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4961
4962
4963
4964
4965
4966
4967
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4961

def update!(**args)
  @chart_spec = args[:chart_spec] if args.key?(:chart_spec)
  @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query)
  @text_message = args[:text_message] if args.key?(:text_message)
  @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec)
  @user_provided_sql_query = args[:user_provided_sql_query] if args.key?(:user_provided_sql_query)
end