Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Request that use natural language query to generate the chart.
Instance Attribute Summary collapse
-
#chart_checkpoint ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartCheckpoint
The current chart checkpoint state.
-
#chart_conversations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation>
Output only.
-
#chart_spec ⇒ Hash<String,Object>
Chart spec for the chart.
-
#request ⇒ Hash<String,Object>
Corresponds to the JSON property
request. -
#sql_comparison_key ⇒ String
Optional.
-
#sql_query ⇒ String
SQL query used to generate the chart.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsights
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsights.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsights
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsights.
6047 6048 6049 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_checkpoint ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartCheckpoint
The current chart checkpoint state.
Corresponds to the JSON property chartCheckpoint
6019 6020 6021 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6019 def chart_checkpoint @chart_checkpoint end |
#chart_conversations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation>
Output only. The chart conversations used to generate the chart.
Corresponds to the JSON property chartConversations
6024 6025 6026 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6024 def chart_conversations @chart_conversations end |
#chart_spec ⇒ Hash<String,Object>
Chart spec for the chart.
Corresponds to the JSON property chartSpec
6029 6030 6031 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6029 def chart_spec @chart_spec end |
#request ⇒ Hash<String,Object>
Corresponds to the JSON property request
6034 6035 6036 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6034 def request @request end |
#sql_comparison_key ⇒ String
Optional. For charts with comparison, this key will determine the metric that
will be compared between the current and another dataset.
Corresponds to the JSON property sqlComparisonKey
6040 6041 6042 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6040 def sql_comparison_key @sql_comparison_key end |
#sql_query ⇒ String
SQL query used to generate the chart.
Corresponds to the JSON property sqlQuery
6045 6046 6047 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6045 def sql_query @sql_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6052 6053 6054 6055 6056 6057 6058 6059 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6052 def update!(**args) @chart_checkpoint = args[:chart_checkpoint] if args.key?(:chart_checkpoint) @chart_conversations = args[:chart_conversations] if args.key?(:chart_conversations) @chart_spec = args[:chart_spec] if args.key?(:chart_spec) @request = args[:request] if args.key?(:request) @sql_comparison_key = args[:sql_comparison_key] if args.key?(:sql_comparison_key) @sql_query = args[:sql_query] if args.key?(:sql_query) end |