Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Request that use natural language query to generate the chart.
Instance Attribute Summary collapse
-
#chart_checkpoint ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartCheckpoint
The current chart checkpoint state.
-
#chart_conversations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation>
Output only.
-
#chart_spec ⇒ Hash<String,Object>
Chart spec for the chart.
-
#request ⇒ Hash<String,Object>
Corresponds to the JSON property
request. -
#sql_comparison_key ⇒ String
Optional.
-
#sql_query ⇒ String
SQL query used to generate the chart.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsights
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsights.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsights
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsights.
5382 5383 5384 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_checkpoint ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartCheckpoint
The current chart checkpoint state.
Corresponds to the JSON property chartCheckpoint
5354 5355 5356 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5354 def chart_checkpoint @chart_checkpoint end |
#chart_conversations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation>
Output only. The chart conversations used to generate the chart.
Corresponds to the JSON property chartConversations
5359 5360 5361 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5359 def chart_conversations @chart_conversations end |
#chart_spec ⇒ Hash<String,Object>
Chart spec for the chart.
Corresponds to the JSON property chartSpec
5364 5365 5366 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5364 def chart_spec @chart_spec end |
#request ⇒ Hash<String,Object>
Corresponds to the JSON property request
5369 5370 5371 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5369 def request @request end |
#sql_comparison_key ⇒ String
Optional. For charts with comparison, this key will determine the metric that
will be compared between the current and another dataset.
Corresponds to the JSON property sqlComparisonKey
5375 5376 5377 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5375 def sql_comparison_key @sql_comparison_key end |
#sql_query ⇒ String
SQL query used to generate the chart.
Corresponds to the JSON property sqlQuery
5380 5381 5382 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5380 def sql_query @sql_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5387 5388 5389 5390 5391 5392 5393 5394 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5387 def update!(**args) @chart_checkpoint = args[:chart_checkpoint] if args.key?(:chart_checkpoint) @chart_conversations = args[:chart_conversations] if args.key?(:chart_conversations) @chart_spec = args[:chart_spec] if args.key?(:chart_spec) @request = args[:request] if args.key?(:request) @sql_comparison_key = args[:sql_comparison_key] if args.key?(:sql_comparison_key) @sql_query = args[:sql_query] if args.key?(:sql_query) end |