Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsights

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request that use natural language query to generate the chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsights

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsights.



4560
4561
4562
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_checkpointGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartCheckpoint

The current chart checkpoint state. Corresponds to the JSON property chartCheckpoint



4532
4533
4534
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4532

def chart_checkpoint
  @chart_checkpoint
end

#chart_conversationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation>

Output only. The chart conversations used to generate the chart. Corresponds to the JSON property chartConversations



4537
4538
4539
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4537

def chart_conversations
  @chart_conversations
end

#chart_specHash<String,Object>

Chart spec for the chart. Corresponds to the JSON property chartSpec

Returns:

  • (Hash<String,Object>)


4542
4543
4544
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4542

def chart_spec
  @chart_spec
end

#requestHash<String,Object>

Corresponds to the JSON property request

Returns:

  • (Hash<String,Object>)


4547
4548
4549
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4547

def request
  @request
end

#sql_comparison_keyString

Optional. For charts with comparison, this key will determine the metric that will be compared between the current and another dataset. Corresponds to the JSON property sqlComparisonKey

Returns:

  • (String)


4553
4554
4555
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4553

def sql_comparison_key
  @sql_comparison_key
end

#sql_queryString

SQL query used to generate the chart. Corresponds to the JSON property sqlQuery

Returns:

  • (String)


4558
4559
4560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4558

def sql_query
  @sql_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4565
4566
4567
4568
4569
4570
4571
4572
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4565

def update!(**args)
  @chart_checkpoint = args[:chart_checkpoint] if args.key?(:chart_checkpoint)
  @chart_conversations = args[:chart_conversations] if args.key?(:chart_conversations)
  @chart_spec = args[:chart_spec] if args.key?(:chart_spec)
  @request = args[:request] if args.key?(:request)
  @sql_comparison_key = args[:sql_comparison_key] if args.key?(:sql_comparison_key)
  @sql_query = args[:sql_query] if args.key?(:sql_query)
end