Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation used to generate the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
The create time of the conversation.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
The update time of the conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation.
6041 6042 6043 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
6024 6025 6026 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6024 def conversation_id @conversation_id end |
#create_time ⇒ String
The create time of the conversation.
Corresponds to the JSON property createTime
6029 6030 6031 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6029 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
6034 6035 6036 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6034 def @messages end |
#update_time ⇒ String
The update time of the conversation.
Corresponds to the JSON property updateTime
6039 6040 6041 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6039 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6046 6047 6048 6049 6050 6051 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6046 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |