Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation used to generate the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
The create time of the conversation.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
The update time of the conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation.
4624 4625 4626 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
4607 4608 4609 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4607 def conversation_id @conversation_id end |
#create_time ⇒ String
The create time of the conversation.
Corresponds to the JSON property createTime
4612 4613 4614 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4612 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
4617 4618 4619 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4617 def @messages end |
#update_time ⇒ String
The update time of the conversation.
Corresponds to the JSON property updateTime
4622 4623 4624 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4622 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4629 4630 4631 4632 4633 4634 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4629 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |