Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The message in the conversation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
For user messages, this is the time at which the system received the message.
-
#message_id ⇒ String
The message id of the message.
-
#system_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
A message from the system in response to the user.
-
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
The user message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage.
5279 5280 5281 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
For user messages, this is the time at which the system received the message.
For system messages, this is the time at which the system generated the
message.
Corresponds to the JSON property createTime
5260 5261 5262 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5260 def create_time @create_time end |
#message_id ⇒ String
The message id of the message.
Corresponds to the JSON property messageId
5265 5266 5267 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5265 def @message_id end |
#system_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
A message from the system in response to the user. This message can also be a
message from the user as historical context for multiturn conversations with
the system.
Corresponds to the JSON property systemMessage
5272 5273 5274 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5272 def @system_message end |
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
The user message.
Corresponds to the JSON property userMessage
5277 5278 5279 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5277 def @user_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5284 5285 5286 5287 5288 5289 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5284 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @message_id = args[:message_id] if args.key?(:message_id) @system_message = args[:system_message] if args.key?(:system_message) @user_message = args[:user_message] if args.key?(:user_message) end |