Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The message in the conversation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
For user messages, this is the time at which the system received the message.
-
#message_id ⇒ String
The message id of the message.
-
#system_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
A message from the system in response to the user.
-
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
The user message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage.
5167 5168 5169 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
For user messages, this is the time at which the system received the message.
For system messages, this is the time at which the system generated the
message.
Corresponds to the JSON property createTime
5148 5149 5150 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5148 def create_time @create_time end |
#message_id ⇒ String
The message id of the message.
Corresponds to the JSON property messageId
5153 5154 5155 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5153 def @message_id end |
#system_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
A message from the system in response to the user. This message can also be a
message from the user as historical context for multiturn conversations with
the system.
Corresponds to the JSON property systemMessage
5160 5161 5162 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5160 def @system_message end |
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
The user message.
Corresponds to the JSON property userMessage
5165 5166 5167 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5165 def @user_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5172 5173 5174 5175 5176 5177 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5172 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @message_id = args[:message_id] if args.key?(:message_id) @system_message = args[:system_message] if args.key?(:system_message) @user_message = args[:user_message] if args.key?(:user_message) end |