Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The message in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage.



6152
6153
6154
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

For user messages, this is the time at which the system received the message. For system messages, this is the time at which the system generated the message. Corresponds to the JSON property createTime

Returns:

  • (String)


6133
6134
6135
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6133

def create_time
  @create_time
end

#message_idString

The message id of the message. Corresponds to the JSON property messageId

Returns:

  • (String)


6138
6139
6140
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6138

def message_id
  @message_id
end

#system_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage

A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system. Corresponds to the JSON property systemMessage



6145
6146
6147
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6145

def system_message
  @system_message
end

#user_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage

The user message. Corresponds to the JSON property userMessage



6150
6151
6152
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6150

def user_message
  @user_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6157
6158
6159
6160
6161
6162
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6157

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @message_id = args[:message_id] if args.key?(:message_id)
  @system_message = args[:system_message] if args.key?(:system_message)
  @user_message = args[:user_message] if args.key?(:user_message)
end