Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The message in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage.



5487
5488
5489
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

For user messages, this is the time at which the system received the message. For system messages, this is the time at which the system generated the message. Corresponds to the JSON property createTime

Returns:

  • (String)


5468
5469
5470
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5468

def create_time
  @create_time
end

#message_idString

The message id of the message. Corresponds to the JSON property messageId

Returns:

  • (String)


5473
5474
5475
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5473

def message_id
  @message_id
end

#system_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage

A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system. Corresponds to the JSON property systemMessage



5480
5481
5482
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5480

def system_message
  @system_message
end

#user_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage

The user message. Corresponds to the JSON property userMessage



5485
5486
5487
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5485

def user_message
  @user_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5492
5493
5494
5495
5496
5497
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5492

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @message_id = args[:message_id] if args.key?(:message_id)
  @system_message = args[:system_message] if args.key?(:system_message)
  @user_message = args[:user_message] if args.key?(:user_message)
end