Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.
Instance Attribute Summary collapse
-
#chart_spec ⇒ Hash<String,Object>
Chart spec from LLM Corresponds to the JSON property
chartSpec. -
#generated_sql_query ⇒ String
Raw SQL from LLM, before templatization Corresponds to the JSON property
generatedSqlQuery. -
#text_output ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessageTextOutput
A text output message from the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage.
6186 6187 6188 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_spec ⇒ Hash<String,Object>
Chart spec from LLM
Corresponds to the JSON property chartSpec
6174 6175 6176 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6174 def chart_spec @chart_spec end |
#generated_sql_query ⇒ String
Raw SQL from LLM, before templatization
Corresponds to the JSON property generatedSqlQuery
6179 6180 6181 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6179 def generated_sql_query @generated_sql_query end |
#text_output ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessageTextOutput
A text output message from the system.
Corresponds to the JSON property textOutput
6184 6185 6186 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6184 def text_output @text_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6191 6192 6193 6194 6195 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6191 def update!(**args) @chart_spec = args[:chart_spec] if args.key?(:chart_spec) @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query) @text_output = args[:text_output] if args.key?(:text_output) end |