Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.
Instance Attribute Summary collapse
-
#chart_spec ⇒ Hash<String,Object>
Chart spec from LLM Corresponds to the JSON property
chartSpec. -
#generated_sql_query ⇒ String
Raw SQL from LLM, before templatization Corresponds to the JSON property
generatedSqlQuery. -
#text_output ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessageTextOutput
A text output message from the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage.
4699 4700 4701 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_spec ⇒ Hash<String,Object>
Chart spec from LLM
Corresponds to the JSON property chartSpec
4687 4688 4689 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4687 def chart_spec @chart_spec end |
#generated_sql_query ⇒ String
Raw SQL from LLM, before templatization
Corresponds to the JSON property generatedSqlQuery
4692 4693 4694 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4692 def generated_sql_query @generated_sql_query end |
#text_output ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessageTextOutput
A text output message from the system.
Corresponds to the JSON property textOutput
4697 4698 4699 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4697 def text_output @text_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4704 4705 4706 4707 4708 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4704 def update!(**args) @chart_spec = args[:chart_spec] if args.key?(:chart_spec) @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query) @text_output = args[:text_output] if args.key?(:text_output) end |