Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request for generative insights.
Instance Attribute Summary collapse
-
#chart ⇒ String
The full name of the chart resource this request corresponds to.
-
#comparison_filter ⇒ String
Optional.
-
#filter ⇒ String
Filter for the data that can be specified in addition to the natural language query.
-
#natural_language_query ⇒ String
The natural language query specified by the user.
-
#revision_id ⇒ String
Optional.
-
#session_id ⇒ String
Optional.
-
#sql_comparison_key ⇒ String
Optional.
-
#sql_query ⇒ String
Optional.
-
#user_provided_chart_spec ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest.
5340 5341 5342 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart ⇒ String
The full name of the chart resource this request corresponds to. Format:
projects/project/locations/location/dashboards/dashboard/charts/chart
Corresponds to the JSON property chart
5284 5285 5286 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5284 def chart @chart end |
#comparison_filter ⇒ String
Optional. Filter for the data that can be specified in addition to the natural
language query. This filter is specifically used for charts where
comparisons are possible. For example, "compare to last month" or "compare to
previous quarter".
Corresponds to the JSON property comparisonFilter
5292 5293 5294 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5292 def comparison_filter @comparison_filter end |
#filter ⇒ String
Filter for the data that can be specified in addition to the natural language
query. Users are encouraged to use this field to populate time-windows.
Corresponds to the JSON property filter
5298 5299 5300 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5298 def filter @filter end |
#natural_language_query ⇒ String
The natural language query specified by the user. If this field is specified,
sql_query will be ignored.
Corresponds to the JSON property naturalLanguageQuery
5304 5305 5306 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5304 def natural_language_query @natural_language_query end |
#revision_id ⇒ String
Optional. The revision id that maps to the state of the chart state revision.
When specified, the backend will reload the chart with the sql and visual spec
from that revision.
Corresponds to the JSON property revisionId
5311 5312 5313 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5311 def revision_id @revision_id end |
#session_id ⇒ String
Optional. The session id of the conversation. If the session id is not
specified, backend will generate a random session id. If the session id is
specified, will associate user-provided user_query with the provided session
id.
Corresponds to the JSON property sessionId
5319 5320 5321 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5319 def session_id @session_id end |
#sql_comparison_key ⇒ String
Optional. For charts with comparison, this key will determine the metric that
will be compared between the current and another dataset.
Corresponds to the JSON property sqlComparisonKey
5325 5326 5327 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5325 def sql_comparison_key @sql_comparison_key end |
#sql_query ⇒ String
Optional. The SQL query specified by the user. This query must be in BigQuery
SQL dialect. The filter field will also be ignored, as it is assumed that
any filtering is already included in the SQL query.
Corresponds to the JSON property sqlQuery
5332 5333 5334 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5332 def sql_query @sql_query end |
#user_provided_chart_spec ⇒ Hash<String,Object>
Optional. The user provided chart spec for the chart. This will be used to
override the visual spec generated by the LLM.
Corresponds to the JSON property userProvidedChartSpec
5338 5339 5340 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5338 def user_provided_chart_spec @user_provided_chart_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5345 def update!(**args) @chart = args[:chart] if args.key?(:chart) @comparison_filter = args[:comparison_filter] if args.key?(:comparison_filter) @filter = args[:filter] if args.key?(:filter) @natural_language_query = args[:natural_language_query] if args.key?(:natural_language_query) @revision_id = args[:revision_id] if args.key?(:revision_id) @session_id = args[:session_id] if args.key?(:session_id) @sql_comparison_key = args[:sql_comparison_key] if args.key?(:sql_comparison_key) @sql_query = args[:sql_query] if args.key?(:sql_query) @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec) end |