Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request for generative insights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest.



4838
4839
4840
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chartString

The full name of the chart resource this request corresponds to. Format: projects/project/locations/location/dashboards/dashboard/charts/chart Corresponds to the JSON property chart

Returns:

  • (String)


4782
4783
4784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4782

def chart
  @chart
end

#comparison_filterString

Optional. Filter for the data that can be specified in addition to the natural language query. This filter is specifically used for charts where comparisons are possible. For example, "compare to last month" or "compare to previous quarter". Corresponds to the JSON property comparisonFilter

Returns:

  • (String)


4790
4791
4792
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4790

def comparison_filter
  @comparison_filter
end

#filterString

Filter for the data that can be specified in addition to the natural language query. Users are encouraged to use this field to populate time-windows. Corresponds to the JSON property filter

Returns:

  • (String)


4796
4797
4798
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4796

def filter
  @filter
end

#natural_language_queryString

The natural language query specified by the user. If this field is specified, sql_query will be ignored. Corresponds to the JSON property naturalLanguageQuery

Returns:

  • (String)


4802
4803
4804
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4802

def natural_language_query
  @natural_language_query
end

#revision_idString

Optional. The revision id that maps to the state of the chart state revision. When specified, the backend will reload the chart with the sql and visual spec from that revision. Corresponds to the JSON property revisionId

Returns:

  • (String)


4809
4810
4811
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4809

def revision_id
  @revision_id
end

#session_idString

Optional. The session id of the conversation. If the session id is not specified, backend will generate a random session id. If the session id is specified, will associate user-provided user_query with the provided session id. Corresponds to the JSON property sessionId

Returns:

  • (String)


4817
4818
4819
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4817

def session_id
  @session_id
end

#sql_comparison_keyString

Optional. For charts with comparison, this key will determine the metric that will be compared between the current and another dataset. Corresponds to the JSON property sqlComparisonKey

Returns:

  • (String)


4823
4824
4825
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4823

def sql_comparison_key
  @sql_comparison_key
end

#sql_queryString

Optional. The SQL query specified by the user. This query must be in BigQuery SQL dialect. The filter field will also be ignored, as it is assumed that any filtering is already included in the SQL query. Corresponds to the JSON property sqlQuery

Returns:

  • (String)


4830
4831
4832
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4830

def sql_query
  @sql_query
end

#user_provided_chart_specHash<String,Object>

Optional. The user provided chart spec for the chart. This will be used to override the visual spec generated by the LLM. Corresponds to the JSON property userProvidedChartSpec

Returns:

  • (Hash<String,Object>)


4836
4837
4838
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4836

def user_provided_chart_spec
  @user_provided_chart_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4843

def update!(**args)
  @chart = args[:chart] if args.key?(:chart)
  @comparison_filter = args[:comparison_filter] if args.key?(:comparison_filter)
  @filter = args[:filter] if args.key?(:filter)
  @natural_language_query = args[:natural_language_query] if args.key?(:natural_language_query)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @session_id = args[:session_id] if args.key?(:session_id)
  @sql_comparison_key = args[:sql_comparison_key] if args.key?(:sql_comparison_key)
  @sql_query = args[:sql_query] if args.key?(:sql_query)
  @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec)
end