Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ImportIssueModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ImportIssueModelRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Request to import an issue model.
Instance Attribute Summary collapse
-
#create_new_model ⇒ Boolean
(also: #create_new_model?)
Optional.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ImportIssueModelRequestGcsSource
Google Cloud Storage Object URI to get the issue model file from.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ImportIssueModelRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1ImportIssueModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ImportIssueModelRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1ImportIssueModelRequest.
5522 5523 5524 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_new_model ⇒ Boolean Also known as: create_new_model?
Optional. If set to true, will create an issue model from the imported file
with randomly generated IDs for the issue model and corresponding issues.
Otherwise, replaces an existing model with the same ID as the file.
Corresponds to the JSON property createNewModel
5509 5510 5511 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5509 def create_new_model @create_new_model end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ImportIssueModelRequestGcsSource
Google Cloud Storage Object URI to get the issue model file from.
Corresponds to the JSON property gcsSource
5515 5516 5517 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5515 def gcs_source @gcs_source end |
#parent ⇒ String
Required. The parent resource of the issue model.
Corresponds to the JSON property parent
5520 5521 5522 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5520 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5527 5528 5529 5530 5531 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5527 def update!(**args) @create_new_model = args[:create_new_model] if args.key?(:create_new_model) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @parent = args[:parent] if args.key?(:parent) end |