Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ImportIssueModelRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to import an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ImportIssueModelRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1ImportIssueModelRequest.



5836
5837
5838
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_new_modelBoolean Also known as: create_new_model?

Optional. If set to true, will create an issue model from the imported file with randomly generated IDs for the issue model and corresponding issues. Otherwise, replaces an existing model with the same ID as the file. Corresponds to the JSON property createNewModel

Returns:

  • (Boolean)


5823
5824
5825
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5823

def create_new_model
  @create_new_model
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ImportIssueModelRequestGcsSource

Google Cloud Storage Object URI to get the issue model file from. Corresponds to the JSON property gcsSource



5829
5830
5831
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5829

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource of the issue model. Corresponds to the JSON property parent

Returns:

  • (String)


5834
5835
5836
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5834

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5841
5842
5843
5844
5845
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5841

def update!(**args)
  @create_new_model = args[:create_new_model] if args.key?(:create_new_model)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
end