Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to ingest conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IngestConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1IngestConversationsRequest.



5708
5709
5710
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestConversationConfig

Configuration that applies to all conversations. Corresponds to the JSON property conversationConfig



5664
5665
5666
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5664

def conversation_config
  @conversation_config
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource

Configuration for Cloud Storage bucket sources. Corresponds to the JSON property gcsSource



5669
5670
5671
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5669

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource for new conversations. Corresponds to the JSON property parent

Returns:

  • (String)


5674
5675
5676
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5674

def parent
  @parent
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



5685
5686
5687
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5685

def redaction_config
  @redaction_config
end

#sample_sizeFixnum

Optional. If set, this fields indicates the number of objects to ingest from the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless they are first deleted, conversations produced through sampling won't be ingested by subsequent ingest requests. Corresponds to the JSON property sampleSize

Returns:

  • (Fixnum)


5693
5694
5695
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5693

def sample_size
  @sample_size
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



5701
5702
5703
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5701

def speech_config
  @speech_config
end

#transcript_object_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestTranscriptObjectConfig

Configuration for processing transcript objects. Corresponds to the JSON property transcriptObjectConfig



5706
5707
5708
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5706

def transcript_object_config
  @transcript_object_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5713
5714
5715
5716
5717
5718
5719
5720
5721
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5713

def update!(**args)
  @conversation_config = args[:conversation_config] if args.key?(:conversation_config)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @sample_size = args[:sample_size] if args.key?(:sample_size)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config)
end