Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to ingest conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IngestConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1IngestConversationsRequest.



6623
6624
6625
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestConversationConfig

Configuration that applies to all conversations. Corresponds to the JSON property conversationConfig



6579
6580
6581
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6579

def conversation_config
  @conversation_config
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource

Configuration for Cloud Storage bucket sources. Corresponds to the JSON property gcsSource



6584
6585
6586
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6584

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource for new conversations. Corresponds to the JSON property parent

Returns:

  • (String)


6589
6590
6591
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6589

def parent
  @parent
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



6600
6601
6602
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6600

def redaction_config
  @redaction_config
end

#sample_sizeFixnum

Optional. If set, this fields indicates the number of objects to ingest from the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless they are first deleted, conversations produced through sampling won't be ingested by subsequent ingest requests. Corresponds to the JSON property sampleSize

Returns:

  • (Fixnum)


6608
6609
6610
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6608

def sample_size
  @sample_size
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



6616
6617
6618
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6616

def speech_config
  @speech_config
end

#transcript_object_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestTranscriptObjectConfig

Configuration for processing transcript objects. Corresponds to the JSON property transcriptObjectConfig



6621
6622
6623
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6621

def transcript_object_config
  @transcript_object_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6628
6629
6630
6631
6632
6633
6634
6635
6636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6628

def update!(**args)
  @conversation_config = args[:conversation_config] if args.key?(:conversation_config)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @sample_size = args[:sample_size] if args.key?(:sample_size)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config)
end