Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configuration for Cloud Storage bucket sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource.



4015
4016
4017
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bucket_uriString

Optional. The Cloud Storage path to the conversation audio file. Note that: [1] Audio files will be transcribed if not already. [2] Audio files and transcript files must be in separate buckets / folders. [3] A source file and its corresponding audio file must share the same name to be properly ingested, E.g. gs://bucket/transcript/conversation1.json and gs://bucket/audio/ conversation1.mp3. Corresponds to the JSON property audioBucketUri

Returns:

  • (String)


3974
3975
3976
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3974

def audio_bucket_uri
  @audio_bucket_uri
end

#bucket_object_typeString

Optional. Specifies the type of the objects in bucket_uri. Avoid passing this. This is inferred from the transcript_bucket_uri, audio_bucket_uri. Corresponds to the JSON property bucketObjectType

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3980

def bucket_object_type
  @bucket_object_type
end

#bucket_uriString

Optional. The Cloud Storage bucket containing source objects. Avoid passing this. Pass this through one of transcript_bucket_uri or audio_bucket_uri. Corresponds to the JSON property bucketUri

Returns:

  • (String)


3986
3987
3988
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3986

def bucket_uri
  @bucket_uri
end

#custom_metadata_keysArray<String>

Optional. Custom keys to extract as conversation labels from metadata files in metadata_bucket_uri. Keys not included in this field will be ignored. Note that there is a limit of 100 labels per conversation. Corresponds to the JSON property customMetadataKeys

Returns:

  • (Array<String>)


3993
3994
3995
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 3993

def 
  @custom_metadata_keys
end

#metadata_bucket_uriString

Optional. The Cloud Storage path to the conversation metadata. Note that: [1] Metadata files are expected to be in JSON format. [2] Metadata and source files (transcripts or audio) must be in separate buckets / folders. [3] A source file and its corresponding metadata file must share the same name to be properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/ metadata/conversation1.json. Corresponds to the JSON property metadataBucketUri

Returns:

  • (String)


4003
4004
4005
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4003

def 
  @metadata_bucket_uri
end

#transcript_bucket_uriString

Optional. The Cloud Storage path to the conversation transcripts. Note that: [ 1] Transcript files are expected to be in JSON format. [2] Transcript, audio, metadata files must be in separate buckets / folders. [3] A source file and its corresponding metadata file must share the same name to be properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/metadata/ conversation1.json. Corresponds to the JSON property transcriptBucketUri

Returns:

  • (String)


4013
4014
4015
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4013

def transcript_bucket_uri
  @transcript_bucket_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4020
4021
4022
4023
4024
4025
4026
4027
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 4020

def update!(**args)
  @audio_bucket_uri = args[:audio_bucket_uri] if args.key?(:audio_bucket_uri)
  @bucket_object_type = args[:bucket_object_type] if args.key?(:bucket_object_type)
  @bucket_uri = args[:bucket_uri] if args.key?(:bucket_uri)
  @custom_metadata_keys = args[:custom_metadata_keys] if args.key?(:custom_metadata_keys)
  @metadata_bucket_uri = args[:metadata_bucket_uri] if args.key?(:metadata_bucket_uri)
  @transcript_bucket_uri = args[:transcript_bucket_uri] if args.key?(:transcript_bucket_uri)
end