Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Issue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Issue

Returns a new instance of GoogleCloudContactcenterinsightsV1Issue.



7012
7013
7014
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6983
6984
6985
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6983

def create_time
  @create_time
end

#display_descriptionString

Representative description of the issue. Corresponds to the JSON property displayDescription

Returns:

  • (String)


6988
6989
6990
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6988

def display_description
  @display_description
end

#display_nameString

The representative name for the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


6993
6994
6995
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6993

def display_name
  @display_name
end

#nameString

Immutable. The resource name of the issue. Format: projects/project/ locations/location/issueModels/issue_model/issues/issue Corresponds to the JSON property name

Returns:

  • (String)


6999
7000
7001
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6999

def name
  @name
end

#sample_utterancesArray<String>

Output only. Resource names of the sample representative utterances that match to this issue. Corresponds to the JSON property sampleUtterances

Returns:

  • (Array<String>)


7005
7006
7007
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7005

def sample_utterances
  @sample_utterances
end

#update_timeString

Output only. The most recent time that this issue was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7010
7011
7012
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7010

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7017
7018
7019
7020
7021
7022
7023
7024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7017

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_description = args[:display_description] if args.key?(:display_description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances)
  @update_time = args[:update_time] if args.key?(:update_time)
end