Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue model resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The representative name for the issue model.
-
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
-
#issue_count ⇒ Fixnum
Output only.
-
#language_code ⇒ String
Language of the model.
-
#model_type ⇒ String
Type of the model.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats
Aggregated statistics about an issue model.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModel
constructor
A new instance of GoogleCloudContactcenterinsightsV1IssueModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModel
Returns a new instance of GoogleCloudContactcenterinsightsV1IssueModel.
7134 7135 7136 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue model was created.
Corresponds to the JSON property createTime
7086 7087 7088 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7086 def create_time @create_time end |
#display_name ⇒ String
The representative name for the issue model.
Corresponds to the JSON property displayName
7091 7092 7093 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7091 def display_name @display_name end |
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
Corresponds to the JSON property inputDataConfig
7096 7097 7098 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7096 def input_data_config @input_data_config end |
#issue_count ⇒ Fixnum
Output only. Number of issues in this issue model.
Corresponds to the JSON property issueCount
7101 7102 7103 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7101 def issue_count @issue_count end |
#language_code ⇒ String
Language of the model.
Corresponds to the JSON property languageCode
7106 7107 7108 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7106 def language_code @language_code end |
#model_type ⇒ String
Type of the model.
Corresponds to the JSON property modelType
7111 7112 7113 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7111 def model_type @model_type end |
#name ⇒ String
Immutable. The resource name of the issue model. Format: projects/project/
locations/location/issueModels/issue_model
Corresponds to the JSON property name
7117 7118 7119 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7117 def name @name end |
#state ⇒ String
Output only. State of the model.
Corresponds to the JSON property state
7122 7123 7124 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7122 def state @state end |
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats
Aggregated statistics about an issue model.
Corresponds to the JSON property trainingStats
7127 7128 7129 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7127 def training_stats @training_stats end |
#update_time ⇒ String
Output only. The most recent time at which the issue model was updated.
Corresponds to the JSON property updateTime
7132 7133 7134 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7132 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7139 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @input_data_config = args[:input_data_config] if args.key?(:input_data_config) @issue_count = args[:issue_count] if args.key?(:issue_count) @language_code = args[:language_code] if args.key?(:language_code) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @training_stats = args[:training_stats] if args.key?(:training_stats) @update_time = args[:update_time] if args.key?(:update_time) end |