Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue model resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModel

Returns a new instance of GoogleCloudContactcenterinsightsV1IssueModel.



7064
7065
7066
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue model was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7016
7017
7018
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7016

def create_time
  @create_time
end

#display_nameString

The representative name for the issue model. Corresponds to the JSON property displayName

Returns:

  • (String)


7021
7022
7023
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7021

def display_name
  @display_name
end

#input_data_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig

Configs for the input data used to create the issue model. Corresponds to the JSON property inputDataConfig



7026
7027
7028
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7026

def input_data_config
  @input_data_config
end

#issue_countFixnum

Output only. Number of issues in this issue model. Corresponds to the JSON property issueCount

Returns:

  • (Fixnum)


7031
7032
7033
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7031

def issue_count
  @issue_count
end

#language_codeString

Language of the model. Corresponds to the JSON property languageCode

Returns:

  • (String)


7036
7037
7038
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7036

def language_code
  @language_code
end

#model_typeString

Type of the model. Corresponds to the JSON property modelType

Returns:

  • (String)


7041
7042
7043
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7041

def model_type
  @model_type
end

#nameString

Immutable. The resource name of the issue model. Format: projects/project/ locations/location/issueModels/issue_model Corresponds to the JSON property name

Returns:

  • (String)


7047
7048
7049
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7047

def name
  @name
end

#stateString

Output only. State of the model. Corresponds to the JSON property state

Returns:

  • (String)


7052
7053
7054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7052

def state
  @state
end

#training_statsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats

Aggregated statistics about an issue model. Corresponds to the JSON property trainingStats



7057
7058
7059
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7057

def training_stats
  @training_stats
end

#update_timeString

Output only. The most recent time at which the issue model was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7062
7063
7064
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7062

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7069
7070
7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7069

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @input_data_config = args[:input_data_config] if args.key?(:input_data_config)
  @issue_count = args[:issue_count] if args.key?(:issue_count)
  @language_code = args[:language_code] if args.key?(:language_code)
  @model_type = args[:model_type] if args.key?(:model_type)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @training_stats = args[:training_stats] if args.key?(:training_stats)
  @update_time = args[:update_time] if args.key?(:update_time)
end