Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Aggregated statistics about an issue model.
Instance Attribute Summary collapse
-
#analyzed_conversations_count ⇒ Fixnum
Number of conversations the issue model has analyzed at this point in time.
-
#issue_stats ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats>
Statistics on each issue.
-
#unclassified_conversations_count ⇒ Fixnum
Number of analyzed conversations for which no issue was applicable at this point in time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModelLabelStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1IssueModelLabelStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1IssueModelLabelStats
Returns a new instance of GoogleCloudContactcenterinsightsV1IssueModelLabelStats.
7138 7139 7140 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analyzed_conversations_count ⇒ Fixnum
Number of conversations the issue model has analyzed at this point in time.
Corresponds to the JSON property analyzedConversationsCount
7125 7126 7127 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7125 def analyzed_conversations_count @analyzed_conversations_count end |
#issue_stats ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats>
Statistics on each issue. Key is the issue's resource name.
Corresponds to the JSON property issueStats
7130 7131 7132 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7130 def issue_stats @issue_stats end |
#unclassified_conversations_count ⇒ Fixnum
Number of analyzed conversations for which no issue was applicable at this
point in time.
Corresponds to the JSON property unclassifiedConversationsCount
7136 7137 7138 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7136 def unclassified_conversations_count @unclassified_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7143 7144 7145 7146 7147 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7143 def update!(**args) @analyzed_conversations_count = args[:analyzed_conversations_count] if args.key?(:analyzed_conversations_count) @issue_stats = args[:issue_stats] if args.key?(:issue_stats) @unclassified_conversations_count = args[:unclassified_conversations_count] if args.key?(:unclassified_conversations_count) end |