Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ListChartsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response of listing charts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ListChartsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1ListChartsResponse.



6015
6016
6017
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chartsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Chart>

The charts under the parent. Corresponds to the JSON property charts



6006
6007
6008
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6006

def charts
  @charts
end

#next_page_tokenString

The value returned by the last ListChartsResponse. This value indicates that this is a continuation of a prior ListCharts call and that the system should return the next page of data. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6013
6014
6015
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6013

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6020
6021
6022
6023
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6020

def update!(**args)
  @charts = args[:charts] if args.key?(:charts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end