Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ListConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response of listing conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ListConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1ListConversationsResponse.



6544
6545
6546
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Conversation>

The conversations that match the request. Corresponds to the JSON property conversations



6535
6536
6537
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6535

def conversations
  @conversations
end

#next_page_tokenString

A token which can be sent as page_token to retrieve the next page. If this field is set, it means there is another page available. If it is not set, it means no other pages are available. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6542
6543
6544
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6542

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6549
6550
6551
6552
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6549

def update!(**args)
  @conversations = args[:conversations] if args.key?(:conversations)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end