Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ListConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response of listing conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ListConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1ListConversationsResponse.



6864
6865
6866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Conversation>

The conversations that match the request. Corresponds to the JSON property conversations



6855
6856
6857
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6855

def conversations
  @conversations
end

#next_page_tokenString

A token which can be sent as page_token to retrieve the next page. If this field is set, it means there is another page available. If it is not set, it means no other pages are available. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6862
6863
6864
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6862

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6869
6870
6871
6872
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6869

def update!(**args)
  @conversations = args[:conversations] if args.key?(:conversations)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end