Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A loss pattern of a virtual agent and suggested fixes.
Instance Attribute Summary collapse
-
#conversation_ids ⇒ Array<String>
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#examples ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#links ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPatternLink>
Output only.
-
#percentage ⇒ Float
Output only.
-
#suggested_fixes ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1LossPattern
constructor
A new instance of GoogleCloudContactcenterinsightsV1LossPattern.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1LossPattern
Returns a new instance of GoogleCloudContactcenterinsightsV1LossPattern.
7908 7909 7910 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_ids ⇒ Array<String>
Output only. A list of conversation IDs that match this loss pattern.
Corresponds to the JSON property conversationIds
7871 7872 7873 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7871 def conversation_ids @conversation_ids end |
#description ⇒ String
Output only. A markdown description of the loss pattern.
Corresponds to the JSON property description
7876 7877 7878 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7876 def description @description end |
#display_name ⇒ String
Output only. The display name of the loss pattern.
Corresponds to the JSON property displayName
7881 7882 7883 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7881 def display_name @display_name end |
#examples ⇒ String
Output only. A markdown of loss pattern examples.
Corresponds to the JSON property examples
7886 7887 7888 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7886 def examples @examples end |
#id ⇒ String
Output only. The unique identifier for the loss pattern.
Corresponds to the JSON property id
7891 7892 7893 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7891 def id @id end |
#links ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPatternLink>
Output only. A list of links to conversations or bot instructions.
Corresponds to the JSON property links
7896 7897 7898 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7896 def links @links end |
#percentage ⇒ Float
Output only. The percentage of conversations that match this loss pattern.
Corresponds to the JSON property percentage
7901 7902 7903 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7901 def percentage @percentage end |
#suggested_fixes ⇒ String
Output only. A markdown description of the suggested fixes.
Corresponds to the JSON property suggestedFixes
7906 7907 7908 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7906 def suggested_fixes @suggested_fixes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7913 def update!(**args) @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @examples = args[:examples] if args.key?(:examples) @id = args[:id] if args.key?(:id) @links = args[:links] if args.key?(:links) @percentage = args[:percentage] if args.key?(:percentage) @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes) end |