Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A loss pattern of a virtual agent and suggested fixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1LossPattern

Returns a new instance of GoogleCloudContactcenterinsightsV1LossPattern.



7838
7839
7840
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idsArray<String>

Output only. A list of conversation IDs that match this loss pattern. Corresponds to the JSON property conversationIds

Returns:

  • (Array<String>)


7801
7802
7803
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7801

def conversation_ids
  @conversation_ids
end

#descriptionString

Output only. A markdown description of the loss pattern. Corresponds to the JSON property description

Returns:

  • (String)


7806
7807
7808
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7806

def description
  @description
end

#display_nameString

Output only. The display name of the loss pattern. Corresponds to the JSON property displayName

Returns:

  • (String)


7811
7812
7813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7811

def display_name
  @display_name
end

#examplesString

Output only. A markdown of loss pattern examples. Corresponds to the JSON property examples

Returns:

  • (String)


7816
7817
7818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7816

def examples
  @examples
end

#idString

Output only. The unique identifier for the loss pattern. Corresponds to the JSON property id

Returns:

  • (String)


7821
7822
7823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7821

def id
  @id
end

Output only. A list of links to conversations or bot instructions. Corresponds to the JSON property links



7826
7827
7828
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7826

def links
  @links
end

#percentageFloat

Output only. The percentage of conversations that match this loss pattern. Corresponds to the JSON property percentage

Returns:

  • (Float)


7831
7832
7833
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7831

def percentage
  @percentage
end

#suggested_fixesString

Output only. A markdown description of the suggested fixes. Corresponds to the JSON property suggestedFixes

Returns:

  • (String)


7836
7837
7838
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7836

def suggested_fixes
  @suggested_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7843

def update!(**args)
  @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @links = args[:links] if args.key?(:links)
  @percentage = args[:percentage] if args.key?(:percentage)
  @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes)
end