Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1LossPattern

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A loss pattern of a virtual agent and suggested fixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1LossPattern

Returns a new instance of GoogleCloudContactcenterinsightsV1LossPattern.



7238
7239
7240
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idsArray<String>

Output only. A list of conversation IDs that match this loss pattern. Corresponds to the JSON property conversationIds

Returns:

  • (Array<String>)


7206
7207
7208
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7206

def conversation_ids
  @conversation_ids
end

#descriptionString

Output only. A markdown description of the loss pattern. Corresponds to the JSON property description

Returns:

  • (String)


7211
7212
7213
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7211

def description
  @description
end

#display_nameString

Output only. The display name of the loss pattern. Corresponds to the JSON property displayName

Returns:

  • (String)


7216
7217
7218
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7216

def display_name
  @display_name
end

#examplesString

Output only. A markdown of loss pattern examples. Corresponds to the JSON property examples

Returns:

  • (String)


7221
7222
7223
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7221

def examples
  @examples
end

#idString

Output only. The unique identifier for the loss pattern. Corresponds to the JSON property id

Returns:

  • (String)


7226
7227
7228
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7226

def id
  @id
end

#percentageFloat

Output only. The percentage of conversations that match this loss pattern. Corresponds to the JSON property percentage

Returns:

  • (Float)


7231
7232
7233
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7231

def percentage
  @percentage
end

#suggested_fixesString

Output only. A markdown description of the suggested fixes. Corresponds to the JSON property suggestedFixes

Returns:

  • (String)


7236
7237
7238
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7236

def suggested_fixes
  @suggested_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7243
7244
7245
7246
7247
7248
7249
7250
7251
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7243

def update!(**args)
  @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @percentage = args[:percentage] if args.key?(:percentage)
  @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes)
end