Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricDefinition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A definition for a metric to be calculated during analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1MetricDefinition

Returns a new instance of GoogleCloudContactcenterinsightsV1MetricDefinition.



7969
7970
7971
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The user-visible name of the metric (e.g., "Containment Rate"). Corresponds to the JSON property displayName

Returns:

  • (String)


7961
7962
7963
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7961

def display_name
  @display_name
end

#source_idString

Output only. The resource name of the underlying Insights primitive (e.g., Tag or QaQuestion) used to calculate this metric. Corresponds to the JSON property sourceId

Returns:

  • (String)


7967
7968
7969
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7967

def source_id
  @source_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7974
7975
7976
7977
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7974

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @source_id = args[:source_id] if args.key?(:source_id)
end