Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricDefinition
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1MetricDefinition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A definition for a metric to be calculated during analysis.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#source_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1MetricDefinition
constructor
A new instance of GoogleCloudContactcenterinsightsV1MetricDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1MetricDefinition
Returns a new instance of GoogleCloudContactcenterinsightsV1MetricDefinition.
7269 7270 7271 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The user-visible name of the metric (e.g., "Containment Rate").
Corresponds to the JSON property displayName
7261 7262 7263 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7261 def display_name @display_name end |
#source_id ⇒ String
Output only. The resource name of the underlying Insights primitive (e.g., Tag
or QaQuestion) used to calculate this metric.
Corresponds to the JSON property sourceId
7267 7268 7269 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7267 def source_id @source_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7274 7275 7276 7277 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7274 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @source_id = args[:source_id] if args.key?(:source_id) end |