Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The data for a phrase match rule.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig
Configuration information of a phrase match rule.
-
#negated ⇒ Boolean
(also: #negated?)
Specifies whether the phrase must be missing from the transcript segment or present in the transcript segment.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatchRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1PhraseMatchRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatchRule
Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatchRule.
8307 8308 8309 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig
Configuration information of a phrase match rule.
Corresponds to the JSON property config
8293 8294 8295 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8293 def config @config end |
#negated ⇒ Boolean Also known as: negated?
Specifies whether the phrase must be missing from the transcript segment or
present in the transcript segment.
Corresponds to the JSON property negated
8299 8300 8301 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8299 def negated @negated end |
#query ⇒ String
Required. The phrase to be matched.
Corresponds to the JSON property query
8305 8306 8307 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8305 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8312 8313 8314 8315 8316 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8312 def update!(**args) @config = args[:config] if args.key?(:config) @negated = args[:negated] if args.key?(:negated) @query = args[:query] if args.key?(:query) end |