Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The data for a phrase match rule.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig
Configuration information of a phrase match rule.
-
#negated ⇒ Boolean
(also: #negated?)
Specifies whether the phrase must be missing from the transcript segment or present in the transcript segment.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatchRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1PhraseMatchRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatchRule
Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatchRule.
7607 7608 7609 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig
Configuration information of a phrase match rule.
Corresponds to the JSON property config
7593 7594 7595 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7593 def config @config end |
#negated ⇒ Boolean Also known as: negated?
Specifies whether the phrase must be missing from the transcript segment or
present in the transcript segment.
Corresponds to the JSON property negated
7599 7600 7601 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7599 def negated @negated end |
#query ⇒ String
Required. The phrase to be matched.
Corresponds to the JSON property query
7605 7606 7607 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7605 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7612 7613 7614 7615 7616 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7612 def update!(**args) @config = args[:config] if args.key?(:config) @negated = args[:negated] if args.key?(:negated) @query = args[:query] if args.key?(:query) end |