Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The phrase matcher resource.
Instance Attribute Summary collapse
-
#activation_update_time ⇒ String
Output only.
-
#active ⇒ Boolean
(also: #active?)
Applies the phrase matcher only when it is active.
-
#display_name ⇒ String
The human-readable name of the phrase matcher.
-
#name ⇒ String
The resource name of the phrase matcher.
-
#phrase_match_rule_groups ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>
A list of phase match rule groups that are included in this matcher.
-
#revision_create_time ⇒ String
Output only.
-
#revision_id ⇒ String
Output only.
-
#role_match ⇒ String
The role whose utterances the phrase matcher should be matched against.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
-
#version_tag ⇒ String
The customized version tag to use for the phrase matcher.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher
constructor
A new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher
Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.
7737 7738 7739 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_update_time ⇒ String
Output only. The most recent time at which the activation status was updated.
Corresponds to the JSON property activationUpdateTime
7676 7677 7678 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7676 def activation_update_time @activation_update_time end |
#active ⇒ Boolean Also known as: active?
Applies the phrase matcher only when it is active.
Corresponds to the JSON property active
7681 7682 7683 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7681 def active @active end |
#display_name ⇒ String
The human-readable name of the phrase matcher.
Corresponds to the JSON property displayName
7687 7688 7689 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7687 def display_name @display_name end |
#name ⇒ String
The resource name of the phrase matcher. Format: projects/project/locations/
location/phraseMatchers/phrase_matcher
Corresponds to the JSON property name
7693 7694 7695 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7693 def name @name end |
#phrase_match_rule_groups ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>
A list of phase match rule groups that are included in this matcher.
Corresponds to the JSON property phraseMatchRuleGroups
7698 7699 7700 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7698 def phrase_match_rule_groups @phrase_match_rule_groups end |
#revision_create_time ⇒ String
Output only. The timestamp of when the revision was created. It is also the
create time when a new matcher is added.
Corresponds to the JSON property revisionCreateTime
7704 7705 7706 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7704 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Output only. Immutable. The revision ID of the phrase matcher. A new revision
is committed whenever the matcher is changed, except when it is activated or
deactivated. A server generated random ID will be used. Example: locations/
global/phraseMatchers/my-first-matcher@1234567
Corresponds to the JSON property revisionId
7712 7713 7714 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7712 def revision_id @revision_id end |
#role_match ⇒ String
The role whose utterances the phrase matcher should be matched against. If the
role is ROLE_UNSPECIFIED it will be matched against any utterances in the
transcript.
Corresponds to the JSON property roleMatch
7719 7720 7721 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7719 def role_match @role_match end |
#type ⇒ String
Required. The type of this phrase matcher.
Corresponds to the JSON property type
7724 7725 7726 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7724 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the phrase matcher was updated.
Corresponds to the JSON property updateTime
7729 7730 7731 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7729 def update_time @update_time end |
#version_tag ⇒ String
The customized version tag to use for the phrase matcher. If not specified, it
will default to revision_id.
Corresponds to the JSON property versionTag
7735 7736 7737 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7735 def version_tag @version_tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7742 def update!(**args) @activation_update_time = args[:activation_update_time] if args.key?(:activation_update_time) @active = args[:active] if args.key?(:active) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @phrase_match_rule_groups = args[:phrase_match_rule_groups] if args.key?(:phrase_match_rule_groups) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @role_match = args[:role_match] if args.key?(:role_match) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @version_tag = args[:version_tag] if args.key?(:version_tag) end |