Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The phrase matcher resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher

Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.



6642
6643
6644
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_update_timeString

Output only. The most recent time at which the activation status was updated. Corresponds to the JSON property activationUpdateTime

Returns:

  • (String)


6581
6582
6583
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6581

def activation_update_time
  @activation_update_time
end

#activeBoolean Also known as: active?

Applies the phrase matcher only when it is active. Corresponds to the JSON property active

Returns:

  • (Boolean)


6586
6587
6588
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6586

def active
  @active
end

#display_nameString

The human-readable name of the phrase matcher. Corresponds to the JSON property displayName

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6592

def display_name
  @display_name
end

#nameString

The resource name of the phrase matcher. Format: projects/project/locations/ location/phraseMatchers/phrase_matcher Corresponds to the JSON property name

Returns:

  • (String)


6598
6599
6600
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6598

def name
  @name
end

#phrase_match_rule_groupsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>

A list of phase match rule groups that are included in this matcher. Corresponds to the JSON property phraseMatchRuleGroups



6603
6604
6605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6603

def phrase_match_rule_groups
  @phrase_match_rule_groups
end

#revision_create_timeString

Output only. The timestamp of when the revision was created. It is also the create time when a new matcher is added. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


6609
6610
6611
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6609

def revision_create_time
  @revision_create_time
end

#revision_idString

Output only. Immutable. The revision ID of the phrase matcher. A new revision is committed whenever the matcher is changed, except when it is activated or deactivated. A server generated random ID will be used. Example: locations/ global/phraseMatchers/my-first-matcher@1234567 Corresponds to the JSON property revisionId

Returns:

  • (String)


6617
6618
6619
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6617

def revision_id
  @revision_id
end

#role_matchString

The role whose utterances the phrase matcher should be matched against. If the role is ROLE_UNSPECIFIED it will be matched against any utterances in the transcript. Corresponds to the JSON property roleMatch

Returns:

  • (String)


6624
6625
6626
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6624

def role_match
  @role_match
end

#typeString

Required. The type of this phrase matcher. Corresponds to the JSON property type

Returns:

  • (String)


6629
6630
6631
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6629

def type
  @type
end

#update_timeString

Output only. The most recent time at which the phrase matcher was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6634
6635
6636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6634

def update_time
  @update_time
end

#version_tagString

The customized version tag to use for the phrase matcher. If not specified, it will default to revision_id. Corresponds to the JSON property versionTag

Returns:

  • (String)


6640
6641
6642
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6640

def version_tag
  @version_tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6647
6648
6649
6650
6651
6652
6653
6654
6655
6656
6657
6658
6659
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6647

def update!(**args)
  @activation_update_time = args[:activation_update_time] if args.key?(:activation_update_time)
  @active = args[:active] if args.key?(:active)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @phrase_match_rule_groups = args[:phrase_match_rule_groups] if args.key?(:phrase_match_rule_groups)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @role_match = args[:role_match] if args.key?(:role_match)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_tag = args[:version_tag] if args.key?(:version_tag)
end