Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The phrase matcher resource.
Instance Attribute Summary collapse
-
#activation_update_time ⇒ String
Output only.
-
#active ⇒ Boolean
(also: #active?)
Applies the phrase matcher only when it is active.
-
#display_name ⇒ String
The human-readable name of the phrase matcher.
-
#name ⇒ String
The resource name of the phrase matcher.
-
#phrase_match_rule_groups ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>
A list of phase match rule groups that are included in this matcher.
-
#revision_create_time ⇒ String
Output only.
-
#revision_id ⇒ String
Output only.
-
#role_match ⇒ String
The role whose utterances the phrase matcher should be matched against.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
-
#version_tag ⇒ String
The customized version tag to use for the phrase matcher.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher
constructor
A new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PhraseMatcher
Returns a new instance of GoogleCloudContactcenterinsightsV1PhraseMatcher.
5267 5268 5269 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_update_time ⇒ String
Output only. The most recent time at which the activation status was updated.
Corresponds to the JSON property activationUpdateTime
5206 5207 5208 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5206 def activation_update_time @activation_update_time end |
#active ⇒ Boolean Also known as: active?
Applies the phrase matcher only when it is active.
Corresponds to the JSON property active
5211 5212 5213 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5211 def active @active end |
#display_name ⇒ String
The human-readable name of the phrase matcher.
Corresponds to the JSON property displayName
5217 5218 5219 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5217 def display_name @display_name end |
#name ⇒ String
The resource name of the phrase matcher. Format: projects/project/locations/
location/phraseMatchers/phrase_matcher
Corresponds to the JSON property name
5223 5224 5225 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5223 def name @name end |
#phrase_match_rule_groups ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup>
A list of phase match rule groups that are included in this matcher.
Corresponds to the JSON property phraseMatchRuleGroups
5228 5229 5230 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5228 def phrase_match_rule_groups @phrase_match_rule_groups end |
#revision_create_time ⇒ String
Output only. The timestamp of when the revision was created. It is also the
create time when a new matcher is added.
Corresponds to the JSON property revisionCreateTime
5234 5235 5236 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5234 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Output only. Immutable. The revision ID of the phrase matcher. A new revision
is committed whenever the matcher is changed, except when it is activated or
deactivated. A server generated random ID will be used. Example: locations/
global/phraseMatchers/my-first-matcher@1234567
Corresponds to the JSON property revisionId
5242 5243 5244 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5242 def revision_id @revision_id end |
#role_match ⇒ String
The role whose utterances the phrase matcher should be matched against. If the
role is ROLE_UNSPECIFIED it will be matched against any utterances in the
transcript.
Corresponds to the JSON property roleMatch
5249 5250 5251 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5249 def role_match @role_match end |
#type ⇒ String
Required. The type of this phrase matcher.
Corresponds to the JSON property type
5254 5255 5256 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5254 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the phrase matcher was updated.
Corresponds to the JSON property updateTime
5259 5260 5261 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5259 def update_time @update_time end |
#version_tag ⇒ String
The customized version tag to use for the phrase matcher. If not specified, it
will default to revision_id.
Corresponds to the JSON property versionTag
5265 5266 5267 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5265 def version_tag @version_tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5272 def update!(**args) @activation_update_time = args[:activation_update_time] if args.key?(:activation_update_time) @active = args[:active] if args.key?(:active) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @phrase_match_rule_groups = args[:phrase_match_rule_groups] if args.key?(:phrase_match_rule_groups) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @role_match = args[:role_match] if args.key?(:role_match) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @version_tag = args[:version_tag] if args.key?(:version_tag) end |