Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1PublishAssessmentRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The message to publish an assessment. Draft and appealed assessments can be published. Publishing simply changes the state of the assessment to published, allowing the console and authorized views to filter on the state.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1PublishAssessmentRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1PublishAssessmentRequest.



5293
5294
5295
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5293

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5298
5299
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5298

def update!(**args)
end