Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An answer to a QaQuestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswer

Returns a new instance of GoogleCloudContactcenterinsightsV1QaAnswer.



8511
8512
8513
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource>

Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources. Corresponds to the JSON property answerSources



8481
8482
8483
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8481

def answer_sources
  @answer_sources
end

#answer_valueGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property answerValue



8487
8488
8489
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8487

def answer_value
  @answer_value
end

#conversationString

The conversation the answer applies to. Corresponds to the JSON property conversation

Returns:

  • (String)


8492
8493
8494
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8492

def conversation
  @conversation
end

#qa_questionString

The QaQuestion answered by this answer. Corresponds to the JSON property qaQuestion

Returns:

  • (String)


8497
8498
8499
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8497

def qa_question
  @qa_question
end

#question_bodyString

Question text. E.g., "Did the agent greet the customer?" Corresponds to the JSON property questionBody

Returns:

  • (String)


8502
8503
8504
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8502

def question_body
  @question_body
end

#tagsArray<String>

User-defined list of arbitrary tags. Matches the value from QaScorecard. ScorecardQuestion.tags. Used for grouping/organization and for weighting the score of each answer. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


8509
8510
8511
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8509

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8516
8517
8518
8519
8520
8521
8522
8523
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8516

def update!(**args)
  @answer_sources = args[:answer_sources] if args.key?(:answer_sources)
  @answer_value = args[:answer_value] if args.key?(:answer_value)
  @conversation = args[:conversation] if args.key?(:conversation)
  @qa_question = args[:qa_question] if args.key?(:qa_question)
  @question_body = args[:question_body] if args.key?(:question_body)
  @tags = args[:tags] if args.key?(:tags)
end