Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An answer to a QaQuestion.
Instance Attribute Summary collapse
-
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources.
-
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#conversation ⇒ String
The conversation the answer applies to.
-
#qa_question ⇒ String
The QaQuestion answered by this answer.
-
#question_body ⇒ String
Question text.
-
#tags ⇒ Array<String>
User-defined list of arbitrary tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswer
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswer
Returns a new instance of GoogleCloudContactcenterinsightsV1QaAnswer.
5341 5342 5343 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific
source type, e.g., all system-generated answer sources, or all manual edit
answer sources.
Corresponds to the JSON property answerSources
5311 5312 5313 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5311 def answer_sources @answer_sources end |
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property answerValue
5317 5318 5319 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5317 def answer_value @answer_value end |
#conversation ⇒ String
The conversation the answer applies to.
Corresponds to the JSON property conversation
5322 5323 5324 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5322 def conversation @conversation end |
#qa_question ⇒ String
The QaQuestion answered by this answer.
Corresponds to the JSON property qaQuestion
5327 5328 5329 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5327 def qa_question @qa_question end |
#question_body ⇒ String
Question text. E.g., "Did the agent greet the customer?"
Corresponds to the JSON property questionBody
5332 5333 5334 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5332 def question_body @question_body end |
#tags ⇒ Array<String>
User-defined list of arbitrary tags. Matches the value from QaScorecard.
ScorecardQuestion.tags. Used for grouping/organization and for weighting the
score of each answer.
Corresponds to the JSON property tags
5339 5340 5341 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5339 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5346 5347 5348 5349 5350 5351 5352 5353 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5346 def update!(**args) @answer_sources = args[:answer_sources] if args.key?(:answer_sources) @answer_value = args[:answer_value] if args.key?(:answer_value) @conversation = args[:conversation] if args.key?(:conversation) @qa_question = args[:qa_question] if args.key?(:qa_question) @question_body = args[:question_body] if args.key?(:question_body) @tags = args[:tags] if args.key?(:tags) end |