Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A question may have multiple answers from varying sources, one of which becomes the "main" answer above. AnswerSource represents each individual answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource

Returns a new instance of GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource.



5373
5374
5375
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_valueGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property answerValue



5366
5367
5368
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5366

def answer_value
  @answer_value
end

#source_typeString

What created the answer. Corresponds to the JSON property sourceType

Returns:

  • (String)


5371
5372
5373
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5371

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5378
5379
5380
5381
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5378

def update!(**args)
  @answer_value = args[:answer_value] if args.key?(:answer_value)
  @source_type = args[:source_type] if args.key?(:source_type)
end