Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue

Returns a new instance of GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue.



8611
8612
8613
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


8562
8563
8564
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8562

def bool_value
  @bool_value
end

#keyString

A short string used as an identifier. Matches the value used in QaQuestion. AnswerChoice.key. Corresponds to the JSON property key

Returns:

  • (String)


8569
8570
8571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8569

def key
  @key
end

#na_valueBoolean Also known as: na_value?

A value of "Not Applicable (N/A)". Should only ever be true. Corresponds to the JSON property naValue

Returns:

  • (Boolean)


8574
8575
8576
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8574

def na_value
  @na_value
end

#normalized_scoreFloat

Output only. Normalized score of the questions. Calculated as score / potential_score. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


8581
8582
8583
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8581

def normalized_score
  @normalized_score
end

#num_valueFloat

Numerical value. Corresponds to the JSON property numValue

Returns:

  • (Float)


8586
8587
8588
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8586

def num_value
  @num_value
end

#potential_scoreFloat

Output only. The maximum potential score of the question. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


8591
8592
8593
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8591

def potential_score
  @potential_score
end

#scoreFloat

Output only. Numerical score of the answer. Corresponds to the JSON property score

Returns:

  • (Float)


8596
8597
8598
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8596

def score
  @score
end

#skip_valueBoolean Also known as: skip_value?

Output only. A value of "Skip". If provided, this field may only be set to true. If a question receives this answer, it will be excluded from any score calculations. This would mean that the question was not evaluated. Corresponds to the JSON property skipValue

Returns:

  • (Boolean)


8603
8604
8605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8603

def skip_value
  @skip_value
end

#str_valueString

String value. Corresponds to the JSON property strValue

Returns:

  • (String)


8609
8610
8611
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8609

def str_value
  @str_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8616

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @key = args[:key] if args.key?(:key)
  @na_value = args[:na_value] if args.key?(:na_value)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @num_value = args[:num_value] if args.key?(:num_value)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @score = args[:score] if args.key?(:score)
  @skip_value = args[:skip_value] if args.key?(:skip_value)
  @str_value = args[:str_value] if args.key?(:str_value)
end