Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#key ⇒ String
A short string used as an identifier.
-
#na_value ⇒ Boolean
(also: #na_value?)
A value of "Not Applicable (N/A)".
-
#normalized_score ⇒ Float
Output only.
-
#num_value ⇒ Float
Numerical value.
-
#potential_score ⇒ Float
Output only.
-
#score ⇒ Float
Output only.
-
#skip_value ⇒ Boolean
(also: #skip_value?)
Output only.
-
#str_value ⇒ String
String value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
Returns a new instance of GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue.
6816 6817 6818 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
6767 6768 6769 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6767 def bool_value @bool_value end |
#key ⇒ String
A short string used as an identifier. Matches the value used in QaQuestion.
AnswerChoice.key.
Corresponds to the JSON property key
6774 6775 6776 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6774 def key @key end |
#na_value ⇒ Boolean Also known as: na_value?
A value of "Not Applicable (N/A)". Should only ever be true.
Corresponds to the JSON property naValue
6779 6780 6781 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6779 def na_value @na_value end |
#normalized_score ⇒ Float
Output only. Normalized score of the questions. Calculated as score /
potential_score.
Corresponds to the JSON property normalizedScore
6786 6787 6788 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6786 def normalized_score @normalized_score end |
#num_value ⇒ Float
Numerical value.
Corresponds to the JSON property numValue
6791 6792 6793 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6791 def num_value @num_value end |
#potential_score ⇒ Float
Output only. The maximum potential score of the question.
Corresponds to the JSON property potentialScore
6796 6797 6798 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6796 def potential_score @potential_score end |
#score ⇒ Float
Output only. Numerical score of the answer.
Corresponds to the JSON property score
6801 6802 6803 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6801 def score @score end |
#skip_value ⇒ Boolean Also known as: skip_value?
Output only. A value of "Skip". If provided, this field may only be set to
true. If a question receives this answer, it will be excluded from any score
calculations. This would mean that the question was not evaluated.
Corresponds to the JSON property skipValue
6808 6809 6810 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6808 def skip_value @skip_value end |
#str_value ⇒ String
String value.
Corresponds to the JSON property strValue
6814 6815 6816 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6814 def str_value @str_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6821 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @key = args[:key] if args.key?(:key) @na_value = args[:na_value] if args.key?(:na_value) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @num_value = args[:num_value] if args.key?(:num_value) @potential_score = args[:potential_score] if args.key?(:potential_score) @score = args[:score] if args.key?(:score) @skip_value = args[:skip_value] if args.key?(:skip_value) @str_value = args[:str_value] if args.key?(:str_value) end |