Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestion
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A single question to be scored by the Insights QA feature.
Instance Attribute Summary collapse
-
#abbreviation ⇒ String
Short, descriptive string, used in the UI where it's not practical to display the full question body.
-
#answer_choices ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice>
A list of valid answers to the question, which the LLM must choose from.
-
#answer_instructions ⇒ String
Instructions describing how to determine the answer.
-
#create_time ⇒ String
Output only.
-
#metrics ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionMetrics
A wrapper representing metrics calculated against a test-set on a LLM that was fine tuned for this question.
-
#name ⇒ String
Identifier.
-
#order ⇒ Fixnum
Defines the order of the question within its parent scorecard revision.
-
#predefined_question_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionPredefinedQuestionConfig
Configuration for a predefined question.
-
#qa_question_data_options ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
Options for configuring the data used to generate the QA question.
-
#question_body ⇒ String
Question text.
-
#question_type ⇒ String
The type of question.
-
#tags ⇒ Array<String>
Questions are tagged for categorization and scoring.
-
#tuning_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata
Metadata about the tuning operation for the question.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestion
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaQuestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestion
Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestion.
7448 7449 7450 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abbreviation ⇒ String
Short, descriptive string, used in the UI where it's not practical to display
the full question body. E.g., "Greeting".
Corresponds to the JSON property abbreviation
7370 7371 7372 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7370 def abbreviation @abbreviation end |
#answer_choices ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice>
A list of valid answers to the question, which the LLM must choose from.
Corresponds to the JSON property answerChoices
7375 7376 7377 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7375 def answer_choices @answer_choices end |
#answer_instructions ⇒ String
Instructions describing how to determine the answer.
Corresponds to the JSON property answerInstructions
7380 7381 7382 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7380 def answer_instructions @answer_instructions end |
#create_time ⇒ String
Output only. The time at which this question was created.
Corresponds to the JSON property createTime
7385 7386 7387 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7385 def create_time @create_time end |
#metrics ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionMetrics
A wrapper representing metrics calculated against a test-set on a LLM that was
fine tuned for this question.
Corresponds to the JSON property metrics
7391 7392 7393 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7391 def metrics @metrics end |
#name ⇒ String
Identifier. The resource name of the question. Format: projects/project/
locations/location/qaScorecards/qa_scorecard/revisions/revision/
qaQuestions/qa_question
Corresponds to the JSON property name
7398 7399 7400 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7398 def name @name end |
#order ⇒ Fixnum
Defines the order of the question within its parent scorecard revision.
Corresponds to the JSON property order
7403 7404 7405 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7403 def order @order end |
#predefined_question_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionPredefinedQuestionConfig
Configuration for a predefined question. This field will only be set if the
Question Type is predefined.
Corresponds to the JSON property predefinedQuestionConfig
7409 7410 7411 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7409 def predefined_question_config @predefined_question_config end |
#qa_question_data_options ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
Options for configuring the data used to generate the QA question.
Corresponds to the JSON property qaQuestionDataOptions
7414 7415 7416 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7414 def @qa_question_data_options end |
#question_body ⇒ String
Question text. E.g., "Did the agent greet the customer?"
Corresponds to the JSON property questionBody
7419 7420 7421 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7419 def question_body @question_body end |
#question_type ⇒ String
The type of question.
Corresponds to the JSON property questionType
7424 7425 7426 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7424 def question_type @question_type end |
#tags ⇒ Array<String>
Questions are tagged for categorization and scoring. Tags can either be: -
Default Tags: These are predefined categories. They are identified by their
string value (e.g., "BUSINESS", "COMPLIANCE", and "CUSTOMER"). - Custom Tags:
These are user-defined categories. They are identified by their full resource
name (e.g., projects/project/locations/location/qaQuestionTags/
qa_question_tag). Both default and custom tags are used to group questions
and to influence the scoring of each question.
Corresponds to the JSON property tags
7435 7436 7437 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7435 def @tags end |
#tuning_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata
Metadata about the tuning operation for the question. Will only be set if a
scorecard containing this question has been tuned.
Corresponds to the JSON property tuningMetadata
7441 7442 7443 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7441 def @tuning_metadata end |
#update_time ⇒ String
Output only. The most recent time at which the question was updated.
Corresponds to the JSON property updateTime
7446 7447 7448 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7446 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7453 def update!(**args) @abbreviation = args[:abbreviation] if args.key?(:abbreviation) @answer_choices = args[:answer_choices] if args.key?(:answer_choices) @answer_instructions = args[:answer_instructions] if args.key?(:answer_instructions) @create_time = args[:create_time] if args.key?(:create_time) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @order = args[:order] if args.key?(:order) @predefined_question_config = args[:predefined_question_config] if args.key?(:predefined_question_config) @qa_question_data_options = args[:qa_question_data_options] if args.key?(:qa_question_data_options) @question_body = args[:question_body] if args.key?(:question_body) @question_type = args[:question_type] if args.key?(:question_type) @tags = args[:tags] if args.key?(:tags) @tuning_metadata = args[:tuning_metadata] if args.key?(:tuning_metadata) @update_time = args[:update_time] if args.key?(:update_time) end |