Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A single question to be scored by the Insights QA feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestion

Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestion.



6920
6921
6922
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abbreviationString

Short, descriptive string, used in the UI where it's not practical to display the full question body. E.g., "Greeting". Corresponds to the JSON property abbreviation

Returns:

  • (String)


6842
6843
6844
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6842

def abbreviation
  @abbreviation
end

#answer_choicesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice>

A list of valid answers to the question, which the LLM must choose from. Corresponds to the JSON property answerChoices



6847
6848
6849
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6847

def answer_choices
  @answer_choices
end

#answer_instructionsString

Instructions describing how to determine the answer. Corresponds to the JSON property answerInstructions

Returns:

  • (String)


6852
6853
6854
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6852

def answer_instructions
  @answer_instructions
end

#create_timeString

Output only. The time at which this question was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6857
6858
6859
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6857

def create_time
  @create_time
end

#metricsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionMetrics

A wrapper representing metrics calculated against a test-set on a LLM that was fine tuned for this question. Corresponds to the JSON property metrics



6863
6864
6865
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6863

def metrics
  @metrics
end

#nameString

Identifier. The resource name of the question. Format: projects/project/ locations/location/qaScorecards/qa_scorecard/revisions/revision/ qaQuestions/qa_question Corresponds to the JSON property name

Returns:

  • (String)


6870
6871
6872
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6870

def name
  @name
end

#orderFixnum

Defines the order of the question within its parent scorecard revision. Corresponds to the JSON property order

Returns:

  • (Fixnum)


6875
6876
6877
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6875

def order
  @order
end

#predefined_question_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionPredefinedQuestionConfig

Configuration for a predefined question. This field will only be set if the Question Type is predefined. Corresponds to the JSON property predefinedQuestionConfig



6881
6882
6883
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6881

def predefined_question_config
  @predefined_question_config
end

#qa_question_data_optionsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions

Options for configuring the data used to generate the QA question. Corresponds to the JSON property qaQuestionDataOptions



6886
6887
6888
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6886

def qa_question_data_options
  @qa_question_data_options
end

#question_bodyString

Question text. E.g., "Did the agent greet the customer?" Corresponds to the JSON property questionBody

Returns:

  • (String)


6891
6892
6893
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6891

def question_body
  @question_body
end

#question_typeString

The type of question. Corresponds to the JSON property questionType

Returns:

  • (String)


6896
6897
6898
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6896

def question_type
  @question_type
end

#tagsArray<String>

Questions are tagged for categorization and scoring. Tags can either be: - Default Tags: These are predefined categories. They are identified by their string value (e.g., "BUSINESS", "COMPLIANCE", and "CUSTOMER"). - Custom Tags: These are user-defined categories. They are identified by their full resource name (e.g., projects/project/locations/location/qaQuestionTags/ qa_question_tag). Both default and custom tags are used to group questions and to influence the scoring of each question. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


6907
6908
6909
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6907

def tags
  @tags
end

#tuning_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata

Metadata about the tuning operation for the question. Will only be set if a scorecard containing this question has been tuned. Corresponds to the JSON property tuningMetadata



6913
6914
6915
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6913

def 
  @tuning_metadata
end

#update_timeString

Output only. The most recent time at which the question was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6918
6919
6920
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6918

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6925
6926
6927
6928
6929
6930
6931
6932
6933
6934
6935
6936
6937
6938
6939
6940
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6925

def update!(**args)
  @abbreviation = args[:abbreviation] if args.key?(:abbreviation)
  @answer_choices = args[:answer_choices] if args.key?(:answer_choices)
  @answer_instructions = args[:answer_instructions] if args.key?(:answer_instructions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @order = args[:order] if args.key?(:order)
  @predefined_question_config = args[:predefined_question_config] if args.key?(:predefined_question_config)
  @qa_question_data_options = args[:qa_question_data_options] if args.key?(:qa_question_data_options)
  @question_body = args[:question_body] if args.key?(:question_body)
  @question_type = args[:question_type] if args.key?(:question_type)
  @tags = args[:tags] if args.key?(:tags)
  @tuning_metadata = args[:tuning_metadata] if args.key?(:tuning_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end