Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message representing a possible answer to the question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice

Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.



7647
7648
7649
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


7615
7616
7617
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7615

def bool_value
  @bool_value
end

#keyString

A short string used as an identifier. Corresponds to the JSON property key

Returns:

  • (String)


7621
7622
7623
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7621

def key
  @key
end

#na_valueBoolean Also known as: na_value?

A value of "Not Applicable (N/A)". If provided, this field may only be set to true. If a question receives this answer, it will be excluded from any score calculations. Corresponds to the JSON property naValue

Returns:

  • (Boolean)


7628
7629
7630
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7628

def na_value
  @na_value
end

#num_valueFloat

Numerical value. Corresponds to the JSON property numValue

Returns:

  • (Float)


7634
7635
7636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7634

def num_value
  @num_value
end

#scoreFloat

Numerical score of the answer, used for generating the overall score of a QaScorecardResult. If the answer uses na_value, this field is unused. Corresponds to the JSON property score

Returns:

  • (Float)


7640
7641
7642
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7640

def score
  @score
end

#str_valueString

String value. Corresponds to the JSON property strValue

Returns:

  • (String)


7645
7646
7647
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7645

def str_value
  @str_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7652
7653
7654
7655
7656
7657
7658
7659
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7652

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @key = args[:key] if args.key?(:key)
  @na_value = args[:na_value] if args.key?(:na_value)
  @num_value = args[:num_value] if args.key?(:num_value)
  @score = args[:score] if args.key?(:score)
  @str_value = args[:str_value] if args.key?(:str_value)
end