Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message representing a possible answer to the question.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#key ⇒ String
A short string used as an identifier.
-
#na_value ⇒ Boolean
(also: #na_value?)
A value of "Not Applicable (N/A)".
-
#num_value ⇒ Float
Numerical value.
-
#score ⇒ Float
Numerical score of the answer, used for generating the overall score of a QaScorecardResult.
-
#str_value ⇒ String
String value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.
8077 8078 8079 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
8045 8046 8047 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8045 def bool_value @bool_value end |
#key ⇒ String
A short string used as an identifier.
Corresponds to the JSON property key
8051 8052 8053 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8051 def key @key end |
#na_value ⇒ Boolean Also known as: na_value?
A value of "Not Applicable (N/A)". If provided, this field may only be set to
true. If a question receives this answer, it will be excluded from any score
calculations.
Corresponds to the JSON property naValue
8058 8059 8060 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8058 def na_value @na_value end |
#num_value ⇒ Float
Numerical value.
Corresponds to the JSON property numValue
8064 8065 8066 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8064 def num_value @num_value end |
#score ⇒ Float
Numerical score of the answer, used for generating the overall score of a
QaScorecardResult. If the answer uses na_value, this field is unused.
Corresponds to the JSON property score
8070 8071 8072 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8070 def score @score end |
#str_value ⇒ String
String value.
Corresponds to the JSON property strValue
8075 8076 8077 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8075 def str_value @str_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8082 8083 8084 8085 8086 8087 8088 8089 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8082 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @key = args[:key] if args.key?(:key) @na_value = args[:na_value] if args.key?(:na_value) @num_value = args[:num_value] if args.key?(:num_value) @score = args[:score] if args.key?(:score) @str_value = args[:str_value] if args.key?(:str_value) end |