Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message representing a possible answer to the question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice

Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice.



5601
5602
5603
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


5569
5570
5571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5569

def bool_value
  @bool_value
end

#keyString

A short string used as an identifier. Corresponds to the JSON property key

Returns:

  • (String)


5575
5576
5577
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5575

def key
  @key
end

#na_valueBoolean Also known as: na_value?

A value of "Not Applicable (N/A)". If provided, this field may only be set to true. If a question receives this answer, it will be excluded from any score calculations. Corresponds to the JSON property naValue

Returns:

  • (Boolean)


5582
5583
5584
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5582

def na_value
  @na_value
end

#num_valueFloat

Numerical value. Corresponds to the JSON property numValue

Returns:

  • (Float)


5588
5589
5590
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5588

def num_value
  @num_value
end

#scoreFloat

Numerical score of the answer, used for generating the overall score of a QaScorecardResult. If the answer uses na_value, this field is unused. Corresponds to the JSON property score

Returns:

  • (Float)


5594
5595
5596
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5594

def score
  @score
end

#str_valueString

String value. Corresponds to the JSON property strValue

Returns:

  • (String)


5599
5600
5601
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5599

def str_value
  @str_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5606

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @key = args[:key] if args.key?(:key)
  @na_value = args[:na_value] if args.key?(:na_value)
  @num_value = args[:num_value] if args.key?(:num_value)
  @score = args[:score] if args.key?(:score)
  @str_value = args[:str_value] if args.key?(:str_value)
end