Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Options for configuring the data used to generate the QA question.
Instance Attribute Summary collapse
-
#conversation_data_options ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataOptions
Options for configuring what metadata is included in the conversation data used in QAI and Discovery Engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions.
7048 7049 7050 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_data_options ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataOptions
Options for configuring what metadata is included in the conversation data
used in QAI and Discovery Engine.
Corresponds to the JSON property conversationDataOptions
7046 7047 7048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7046 def @conversation_data_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7053 7054 7055 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7053 def update!(**args) @conversation_data_options = args[:conversation_data_options] if args.key?(:conversation_data_options) end |