Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata about the tuning operation for the question. Will only be set if a scorecard containing this question has been tuned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata.



5729
5730
5731
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_validation_warningsArray<String>

A list of any applicable data validation warnings about the question's feedback labels. Corresponds to the JSON property datasetValidationWarnings

Returns:

  • (Array<String>)


5716
5717
5718
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5716

def dataset_validation_warnings
  @dataset_validation_warnings
end

#total_valid_label_countFixnum

Total number of valid labels provided for the question at the time of tuining. Corresponds to the JSON property totalValidLabelCount

Returns:

  • (Fixnum)


5721
5722
5723
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5721

def total_valid_label_count
  @total_valid_label_count
end

#tuning_errorString

Error status of the tuning operation for the question. Will only be set if the tuning operation failed. Corresponds to the JSON property tuningError

Returns:

  • (String)


5727
5728
5729
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5727

def tuning_error
  @tuning_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5734
5735
5736
5737
5738
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5734

def update!(**args)
  @dataset_validation_warnings = args[:dataset_validation_warnings] if args.key?(:dataset_validation_warnings)
  @total_valid_label_count = args[:total_valid_label_count] if args.key?(:total_valid_label_count)
  @tuning_error = args[:tuning_error] if args.key?(:tuning_error)
end