Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A QaScorecard represents a collection of questions to be scored during analysis.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A text description explaining the intent of the scorecard.
-
#display_name ⇒ String
The user-specified display name of the scorecard.
-
#is_default ⇒ Boolean
(also: #is_default?)
Whether the scorecard is the default one for the project.
-
#name ⇒ String
Identifier.
-
#source ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecard
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaScorecard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecard
Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecard.
8980 8981 8982 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this scorecard was created.
Corresponds to the JSON property createTime
8945 8946 8947 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8945 def create_time @create_time end |
#description ⇒ String
A text description explaining the intent of the scorecard.
Corresponds to the JSON property description
8950 8951 8952 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8950 def description @description end |
#display_name ⇒ String
The user-specified display name of the scorecard.
Corresponds to the JSON property displayName
8955 8956 8957 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8955 def display_name @display_name end |
#is_default ⇒ Boolean Also known as: is_default?
Whether the scorecard is the default one for the project. A default scorecard
cannot be deleted and will always appear first in scorecard selector.
Corresponds to the JSON property isDefault
8961 8962 8963 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8961 def is_default @is_default end |
#name ⇒ String
Identifier. The scorecard name. Format: projects/project/locations/location
/qaScorecards/qa_scorecard
Corresponds to the JSON property name
8968 8969 8970 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8968 def name @name end |
#source ⇒ String
Output only. The source of the scorecard.
Corresponds to the JSON property source
8973 8974 8975 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8973 def source @source end |
#update_time ⇒ String
Output only. The most recent time at which the scorecard was updated.
Corresponds to the JSON property updateTime
8978 8979 8980 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8978 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8985 8986 8987 8988 8989 8990 8991 8992 8993 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8985 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @is_default = args[:is_default] if args.key?(:is_default) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |