Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A QaScorecard represents a collection of questions to be scored during analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecard

Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecard.



7185
7186
7187
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this scorecard was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7150
7151
7152
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7150

def create_time
  @create_time
end

#descriptionString

A text description explaining the intent of the scorecard. Corresponds to the JSON property description

Returns:

  • (String)


7155
7156
7157
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7155

def description
  @description
end

#display_nameString

The user-specified display name of the scorecard. Corresponds to the JSON property displayName

Returns:

  • (String)


7160
7161
7162
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7160

def display_name
  @display_name
end

#is_defaultBoolean Also known as: is_default?

Whether the scorecard is the default one for the project. A default scorecard cannot be deleted and will always appear first in scorecard selector. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


7166
7167
7168
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7166

def is_default
  @is_default
end

#nameString

Identifier. The scorecard name. Format: projects/project/locations/location /qaScorecards/qa_scorecard Corresponds to the JSON property name

Returns:

  • (String)


7173
7174
7175
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7173

def name
  @name
end

#sourceString

Output only. The source of the scorecard. Corresponds to the JSON property source

Returns:

  • (String)


7178
7179
7180
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7178

def source
  @source
end

#update_timeString

Output only. The most recent time at which the scorecard was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7183
7184
7185
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7183

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7190
7191
7192
7193
7194
7195
7196
7197
7198
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7190

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_default = args[:is_default] if args.key?(:is_default)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
end