Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A QaScorecard represents a collection of questions to be scored during analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecard

Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecard.



5784
5785
5786
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this scorecard was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5749
5750
5751
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5749

def create_time
  @create_time
end

#descriptionString

A text description explaining the intent of the scorecard. Corresponds to the JSON property description

Returns:

  • (String)


5754
5755
5756
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5754

def description
  @description
end

#display_nameString

The user-specified display name of the scorecard. Corresponds to the JSON property displayName

Returns:

  • (String)


5759
5760
5761
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5759

def display_name
  @display_name
end

#is_defaultBoolean Also known as: is_default?

Whether the scorecard is the default one for the project. A default scorecard cannot be deleted and will always appear first in scorecard selector. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


5765
5766
5767
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5765

def is_default
  @is_default
end

#nameString

Identifier. The scorecard name. Format: projects/project/locations/location /qaScorecards/qa_scorecard Corresponds to the JSON property name

Returns:

  • (String)


5772
5773
5774
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5772

def name
  @name
end

#sourceString

Output only. The source of the scorecard. Corresponds to the JSON property source

Returns:

  • (String)


5777
5778
5779
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5777

def source
  @source
end

#update_timeString

Output only. The most recent time at which the scorecard was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5782
5783
5784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5782

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5789
5790
5791
5792
5793
5794
5795
5796
5797
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5789

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_default = args[:is_default] if args.key?(:is_default)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
end