Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecardResult.



7793
7794
7795
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


7737
7738
7739
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7737

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


7742
7743
7744
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7742

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7747
7748
7749
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7747

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


7753
7754
7755
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7753

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


7759
7760
7761
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7759

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


7765
7766
7767
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7765

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



7770
7771
7772
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7770

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


7775
7776
7777
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7775

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



7780
7781
7782
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7780

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


7786
7787
7788
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7786

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



7791
7792
7793
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7791

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7798

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end