Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecardResult.



7265
7266
7267
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


7209
7210
7211
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7209

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


7214
7215
7216
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7214

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7219
7220
7221
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7219

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


7225
7226
7227
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7225

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


7231
7232
7233
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7231

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


7237
7238
7239
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7237

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



7242
7243
7244
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7242

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


7247
7248
7249
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7247

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



7252
7253
7254
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7252

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


7258
7259
7260
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7258

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



7263
7264
7265
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7263

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7270

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end