Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
ID of the agent that handled the conversation.
-
#conversation ⇒ String
The conversation scored by this result.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_answers ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer>
Set of QaAnswers represented in the result.
-
#qa_scorecard_revision ⇒ String
The QaScorecardRevision scored by this result.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result, incorporating any manual edits if they exist.
-
#score_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource>
List of all individual score sets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaScorecardResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardResult
Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecardResult.
5864 5865 5866 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
ID of the agent that handled the conversation.
Corresponds to the JSON property agentId
5808 5809 5810 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5808 def agent_id @agent_id end |
#conversation ⇒ String
The conversation scored by this result.
Corresponds to the JSON property conversation
5813 5814 5815 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5813 def conversation @conversation end |
#create_time ⇒ String
Output only. The timestamp that the revision was created.
Corresponds to the JSON property createTime
5818 5819 5820 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5818 def create_time @create_time end |
#name ⇒ String
Identifier. The name of the scorecard result. Format: projects/project/
locations/location/qaScorecardResults/qa_scorecard_result
Corresponds to the JSON property name
5824 5825 5826 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5824 def name @name end |
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score. Any
manual edits are included if they exist.
Corresponds to the JSON property normalizedScore
5830 5831 5832 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5830 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
5836 5837 5838 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5836 def potential_score @potential_score end |
#qa_answers ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaAnswer>
Set of QaAnswers represented in the result.
Corresponds to the JSON property qaAnswers
5841 5842 5843 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5841 def qa_answers @qa_answers end |
#qa_scorecard_revision ⇒ String
The QaScorecardRevision scored by this result.
Corresponds to the JSON property qaScorecardRevision
5846 5847 5848 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5846 def qa_scorecard_revision @qa_scorecard_revision end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
5851 5852 5853 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5851 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result, incorporating any manual edits if
they exist.
Corresponds to the JSON property score
5857 5858 5859 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5857 def score @score end |
#score_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource>
List of all individual score sets.
Corresponds to the JSON property scoreSources
5862 5863 5864 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5862 def score_sources @score_sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5869 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @conversation = args[:conversation] if args.key?(:conversation) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_answers = args[:qa_answers] if args.key?(:qa_answers) @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @score_sources = args[:score_sources] if args.key?(:score_sources) end |