Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.
Instance Attribute Summary collapse
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result.
-
#source_type ⇒ String
What created the score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource
Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource.
5953 5954 5955 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
Corresponds to the JSON property normalizedScore
5930 5931 5932 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5930 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
5936 5937 5938 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5936 def potential_score @potential_score end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
5941 5942 5943 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5941 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result.
Corresponds to the JSON property score
5946 5947 5948 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5946 def score @score end |
#source_type ⇒ String
What created the score.
Corresponds to the JSON property sourceType
5951 5952 5953 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5951 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5958 5959 5960 5961 5962 5963 5964 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 5958 def update!(**args) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @source_type = args[:source_type] if args.key?(:source_type) end |