Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardRevision
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecardRevision
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A revision of a QaScorecard. Modifying published scorecard fields would invalidate existing scorecard results — the questions may have changed, or the score weighting will make existing scores impossible to understand. So changes must create a new revision, rather than modifying the existing resource.
Instance Attribute Summary collapse
-
#alternate_ids ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#snapshot ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard
A QaScorecard represents a collection of questions to be scored during analysis.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardRevision
constructor
A new instance of GoogleCloudContactcenterinsightsV1QaScorecardRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QaScorecardRevision
Returns a new instance of GoogleCloudContactcenterinsightsV1QaScorecardRevision.
9199 9200 9201 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_ids ⇒ Array<String>
Output only. Alternative IDs for this revision of the scorecard, e.g., latest
.
Corresponds to the JSON property alternateIds
9174 9175 9176 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9174 def alternate_ids @alternate_ids end |
#create_time ⇒ String
Output only. The timestamp that the revision was created.
Corresponds to the JSON property createTime
9179 9180 9181 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9179 def create_time @create_time end |
#name ⇒ String
Identifier. The name of the scorecard revision. Format: projects/project/
locations/location/qaScorecards/qa_scorecard/revisions/revision
Corresponds to the JSON property name
9185 9186 9187 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9185 def name @name end |
#snapshot ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QaScorecard
A QaScorecard represents a collection of questions to be scored during
analysis.
Corresponds to the JSON property snapshot
9191 9192 9193 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9191 def snapshot @snapshot end |
#state ⇒ String
Output only. State of the scorecard revision, indicating whether it's ready to
be used in analysis.
Corresponds to the JSON property state
9197 9198 9199 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9197 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9204 9205 9206 9207 9208 9209 9210 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9204 def update!(**args) @alternate_ids = args[:alternate_ids] if args.key?(:alternate_ids) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @snapshot = args[:snapshot] if args.key?(:snapshot) @state = args[:state] if args.key?(:state) end |