Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request for querying metrics.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension>
The dimensions that determine the grouping key for the query.
-
#filter ⇒ String
Required.
-
#measure_mask ⇒ String
Measures to return.
-
#time_granularity ⇒ String
The time granularity of each data point in the time series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1QueryMetricsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsRequest.
8224 8225 8226 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension>
The dimensions that determine the grouping key for the query. Defaults to no
dimension if this field is unspecified. If a dimension is specified, its key
must also be specified. Each dimension's key must be unique. If a time
granularity is also specified, metric values in the dimension will be bucketed
by this granularity. Up to one dimension is supported for now.
Corresponds to the JSON property dimensions
8200 8201 8202 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8200 def dimensions @dimensions end |
#filter ⇒ String
Required. Filter to select a subset of conversations to compute the metrics.
Must specify a window of the conversation create time to compute the metrics.
The returned metrics will be from the range [DATE(starting create time), DATE(
ending create time)).
Corresponds to the JSON property filter
8208 8209 8210 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8208 def filter @filter end |
#measure_mask ⇒ String
Measures to return. Defaults to all measures if this field is unspecified. A
valid mask should traverse from the measure field from the response. For
example, a path from a measure mask to get the conversation count is "
conversation_measure.count".
Corresponds to the JSON property measureMask
8216 8217 8218 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8216 def measure_mask @measure_mask end |
#time_granularity ⇒ String
The time granularity of each data point in the time series. Defaults to NONE
if this field is unspecified.
Corresponds to the JSON property timeGranularity
8222 8223 8224 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8222 def time_granularity @time_granularity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8229 8230 8231 8232 8233 8234 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8229 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @filter = args[:filter] if args.key?(:filter) @measure_mask = args[:measure_mask] if args.key?(:measure_mask) @time_granularity = args[:time_granularity] if args.key?(:time_granularity) end |