Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request for querying metrics.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension>
The dimensions that determine the grouping key for the query.
-
#filter ⇒ String
Required.
-
#measure_mask ⇒ String
Measures to return.
-
#time_granularity ⇒ String
The time granularity of each data point in the time series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1QueryMetricsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsRequest.
8046 8047 8048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension>
The dimensions that determine the grouping key for the query. Defaults to no
dimension if this field is unspecified. If a dimension is specified, its key
must also be specified. Each dimension's key must be unique. If a time
granularity is also specified, metric values in the dimension will be bucketed
by this granularity. Up to one dimension is supported for now.
Corresponds to the JSON property dimensions
8022 8023 8024 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8022 def dimensions @dimensions end |
#filter ⇒ String
Required. Filter to select a subset of conversations to compute the metrics.
Must specify a window of the conversation create time to compute the metrics.
The returned metrics will be from the range [DATE(starting create time), DATE(
ending create time)).
Corresponds to the JSON property filter
8030 8031 8032 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8030 def filter @filter end |
#measure_mask ⇒ String
Measures to return. Defaults to all measures if this field is unspecified. A
valid mask should traverse from the measure field from the response. For
example, a path from a measure mask to get the conversation count is "
conversation_measure.count".
Corresponds to the JSON property measureMask
8038 8039 8040 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8038 def measure_mask @measure_mask end |
#time_granularity ⇒ String
The time granularity of each data point in the time series. Defaults to NONE
if this field is unspecified.
Corresponds to the JSON property timeGranularity
8044 8045 8046 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8044 def time_granularity @time_granularity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8051 8052 8053 8054 8055 8056 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8051 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @filter = args[:filter] if args.key?(:filter) @measure_mask = args[:measure_mask] if args.key?(:measure_mask) @time_granularity = args[:time_granularity] if args.key?(:time_granularity) end |