Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request for querying metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsRequest.



6098
6099
6100
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Dimension>

The dimensions that determine the grouping key for the query. Defaults to no dimension if this field is unspecified. If a dimension is specified, its key must also be specified. Each dimension's key must be unique. If a time granularity is also specified, metric values in the dimension will be bucketed by this granularity. Up to one dimension is supported for now. Corresponds to the JSON property dimensions



6074
6075
6076
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6074

def dimensions
  @dimensions
end

#filterString

Required. Filter to select a subset of conversations to compute the metrics. Must specify a window of the conversation create time to compute the metrics. The returned metrics will be from the range [DATE(starting create time), DATE( ending create time)). Corresponds to the JSON property filter

Returns:

  • (String)


6082
6083
6084
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6082

def filter
  @filter
end

#measure_maskString

Measures to return. Defaults to all measures if this field is unspecified. A valid mask should traverse from the measure field from the response. For example, a path from a measure mask to get the conversation count is " conversation_measure.count". Corresponds to the JSON property measureMask

Returns:

  • (String)


6090
6091
6092
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6090

def measure_mask
  @measure_mask
end

#time_granularityString

The time granularity of each data point in the time series. Defaults to NONE if this field is unspecified. Corresponds to the JSON property timeGranularity

Returns:

  • (String)


6096
6097
6098
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6096

def time_granularity
  @time_granularity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6103
6104
6105
6106
6107
6108
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6103

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @filter = args[:filter] if args.key?(:filter)
  @measure_mask = args[:measure_mask] if args.key?(:measure_mask)
  @time_granularity = args[:time_granularity] if args.key?(:time_granularity)
end