Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A data point contains the metric values mapped to an interval.
Instance Attribute Summary collapse
-
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
-
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint
constructor
A new instance of GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint
Returns a new instance of GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPoint.
6210 6211 6212 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
Corresponds to the JSON property conversationMeasure
6200 6201 6202 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6200 def conversation_measure @conversation_measure end |
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
6208 6209 6210 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6208 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6215 6216 6217 6218 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6215 def update!(**args) @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure) @interval = args[:interval] if args.key?(:interval) end |