Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request for summarizing performance according to different metrics for conversations over a specified time window.
Instance Attribute Summary collapse
-
#agent_performance_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequestAgentSource
The entity whose performance is being queried is a single agent.
-
#comparison_query_interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryInterval
A time window for querying conversations.
-
#filter ⇒ String
Optional.
-
#query_interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryInterval
A time window for querying conversations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest.
8723 8724 8725 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8723 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_performance_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequestAgentSource
The entity whose performance is being queried is a single agent.
Corresponds to the JSON property agentPerformanceSource
8703 8704 8705 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8703 def agent_performance_source @agent_performance_source end |
#comparison_query_interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryInterval
A time window for querying conversations.
Corresponds to the JSON property comparisonQueryInterval
8708 8709 8710 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8708 def comparison_query_interval @comparison_query_interval end |
#filter ⇒ String
Optional. Filter to select a subset of conversations to compute the
performance overview. Supports the same filters as the filter field in
QueryMetricsRequest. The source and query interval/comparison query interval
should not be included here.
Corresponds to the JSON property filter
8716 8717 8718 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8716 def filter @filter end |
#query_interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryInterval
A time window for querying conversations.
Corresponds to the JSON property queryInterval
8721 8722 8723 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8721 def query_interval @query_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8728 8729 8730 8731 8732 8733 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8728 def update!(**args) @agent_performance_source = args[:agent_performance_source] if args.key?(:agent_performance_source) @comparison_query_interval = args[:comparison_query_interval] if args.key?(:comparison_query_interval) @filter = args[:filter] if args.key?(:filter) @query_interval = args[:query_interval] if args.key?(:query_interval) end |