Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request for summarizing performance according to different metrics for conversations over a specified time window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest.



9290
9291
9292
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_performance_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequestAgentSource

The entity whose performance is being queried is a single agent. Corresponds to the JSON property agentPerformanceSource



9270
9271
9272
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9270

def agent_performance_source
  @agent_performance_source
end

#comparison_query_intervalGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryInterval

A time window for querying conversations. Corresponds to the JSON property comparisonQueryInterval



9275
9276
9277
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9275

def comparison_query_interval
  @comparison_query_interval
end

#filterString

Optional. Filter to select a subset of conversations to compute the performance overview. Supports the same filters as the filter field in QueryMetricsRequest. The source and query interval/comparison query interval should not be included here. Corresponds to the JSON property filter

Returns:

  • (String)


9283
9284
9285
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9283

def filter
  @filter
end

#query_intervalGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1QueryInterval

A time window for querying conversations. Corresponds to the JSON property queryInterval



9288
9289
9290
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9288

def query_interval
  @query_interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9295
9296
9297
9298
9299
9300
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9295

def update!(**args)
  @agent_performance_source = args[:agent_performance_source] if args.key?(:agent_performance_source)
  @comparison_query_interval = args[:comparison_query_interval] if args.key?(:comparison_query_interval)
  @filter = args[:filter] if args.key?(:filter)
  @query_interval = args[:query_interval] if args.key?(:query_interval)
end