Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedirectAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The redirect action to be taken when the chart is clicked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1RedirectAction

Returns a new instance of GoogleCloudContactcenterinsightsV1RedirectAction.



10088
10089
10090
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#query_paramsHash<String,String>

The query params to be added to the redirect path. Corresponds to the JSON property queryParams

Returns:

  • (Hash<String,String>)


10081
10082
10083
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10081

def query_params
  @query_params
end

#relative_pathString

The relative path to redirect to. Corresponds to the JSON property relativePath

Returns:

  • (String)


10086
10087
10088
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10086

def relative_path
  @relative_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10093
10094
10095
10096
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10093

def update!(**args)
  @query_params = args[:query_params] if args.key?(:query_params)
  @relative_path = args[:relative_path] if args.key?(:relative_path)
end