Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1RuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1RuntimeAnnotation.



8921
8922
8923
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


8854
8855
8856
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8854

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



8859
8860
8861
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8859

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



8864
8865
8866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8864

def article_suggestion
  @article_suggestion
end

#ces_end_session_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesEndSessionAnnotation

The CES end session annotation. Corresponds to the JSON property cesEndSessionAnnotation



8869
8870
8871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8869

def ces_end_session_annotation
  @ces_end_session_annotation
end

#ces_turn_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation

The CES diagnostic information. Corresponds to the JSON property cesTurnAnnotation



8874
8875
8876
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8874

def ces_turn_annotation
  @ces_turn_annotation
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



8879
8880
8881
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8879

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8884
8885
8886
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8884

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



8889
8890
8891
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8889

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



8894
8895
8896
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8894

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



8899
8900
8901
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8899

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



8904
8905
8906
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8904

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



8909
8910
8911
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8909

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



8914
8915
8916
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8914

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



8919
8920
8921
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8919

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8926
8927
8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
8938
8939
8940
8941
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8926

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation)
  @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end