Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An annotation that was generated during the customer and agent interaction.
Instance Attribute Summary collapse
-
#annotation_id ⇒ String
The unique identifier of the annotation.
-
#answer_feedback ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
-
#article_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ArticleSuggestionData
Agent Assist Article Suggestion data.
-
#ces_end_session_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesEndSessionAnnotation
The CES end session annotation.
-
#ces_turn_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation
The CES diagnostic information.
-
#conversation_summarization_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
-
#create_time ⇒ String
The time at which this annotation was created.
-
#dialogflow_interaction ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowInteractionData
Dialogflow interaction data.
-
#end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#faq_answer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData
Agent Assist frequently-asked-question answer data.
-
#smart_compose_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
-
#smart_reply ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartReplyData
Agent Assist Smart Reply data.
-
#start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#user_input ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput
Explicit input used for generating the answer Corresponds to the JSON property
userInput.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1RuntimeAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1RuntimeAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1RuntimeAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1RuntimeAnnotation.
10258 10259 10260 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_id ⇒ String
The unique identifier of the annotation. Format: projects/project/locations/
location/conversationDatasets/dataset/conversationDataItems/data_item/
conversationAnnotations/annotation
Corresponds to the JSON property annotationId
10191 10192 10193 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10191 def annotation_id @annotation_id end |
#answer_feedback ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
Corresponds to the JSON property answerFeedback
10196 10197 10198 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10196 def answer_feedback @answer_feedback end |
#article_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ArticleSuggestionData
Agent Assist Article Suggestion data.
Corresponds to the JSON property articleSuggestion
10201 10202 10203 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10201 def article_suggestion @article_suggestion end |
#ces_end_session_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesEndSessionAnnotation
The CES end session annotation.
Corresponds to the JSON property cesEndSessionAnnotation
10206 10207 10208 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10206 def ces_end_session_annotation @ces_end_session_annotation end |
#ces_turn_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CesTurnAnnotation
The CES diagnostic information.
Corresponds to the JSON property cesTurnAnnotation
10211 10212 10213 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10211 def ces_turn_annotation @ces_turn_annotation end |
#conversation_summarization_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
Corresponds to the JSON property conversationSummarizationSuggestion
10216 10217 10218 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10216 def conversation_summarization_suggestion @conversation_summarization_suggestion end |
#create_time ⇒ String
The time at which this annotation was created.
Corresponds to the JSON property createTime
10221 10222 10223 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10221 def create_time @create_time end |
#dialogflow_interaction ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1DialogflowInteractionData
Dialogflow interaction data.
Corresponds to the JSON property dialogflowInteraction
10226 10227 10228 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10226 def dialogflow_interaction @dialogflow_interaction end |
#end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property endBoundary
10231 10232 10233 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10231 def end_boundary @end_boundary end |
#faq_answer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1FaqAnswerData
Agent Assist frequently-asked-question answer data.
Corresponds to the JSON property faqAnswer
10236 10237 10238 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10236 def faq_answer @faq_answer end |
#smart_compose_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
Corresponds to the JSON property smartComposeSuggestion
10241 10242 10243 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10241 def smart_compose_suggestion @smart_compose_suggestion end |
#smart_reply ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SmartReplyData
Agent Assist Smart Reply data.
Corresponds to the JSON property smartReply
10246 10247 10248 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10246 def smart_reply @smart_reply end |
#start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property startBoundary
10251 10252 10253 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10251 def start_boundary @start_boundary end |
#user_input ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput
Explicit input used for generating the answer
Corresponds to the JSON property userInput
10256 10257 10258 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10256 def user_input @user_input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10263 10264 10265 10266 10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10263 def update!(**args) @annotation_id = args[:annotation_id] if args.key?(:annotation_id) @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback) @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion) @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation) @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation) @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion) @create_time = args[:create_time] if args.key?(:create_time) @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction) @end_boundary = args[:end_boundary] if args.key?(:end_boundary) @faq_answer = args[:faq_answer] if args.key?(:faq_answer) @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion) @smart_reply = args[:smart_reply] if args.key?(:smart_reply) @start_boundary = args[:start_boundary] if args.key?(:start_boundary) @user_input = args[:user_input] if args.key?(:user_input) end |