Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleConversationsMetadataSampleConversationsStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for SampleConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleConversationsMetadataSampleConversationsStats

Returns a new instance of GoogleCloudContactcenterinsightsV1SampleConversationsMetadataSampleConversationsStats.



9037
9038
9039
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_sample_countFixnum

Output only. The number of objects which were unable to be sampled due to errors. The errors are populated in the partial_errors field. Corresponds to the JSON property failedSampleCount

Returns:

  • (Fixnum)


9029
9030
9031
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9029

def failed_sample_count
  @failed_sample_count
end

#successful_sample_countFixnum

Output only. The number of new conversations added during this sample operation. Corresponds to the JSON property successfulSampleCount

Returns:

  • (Fixnum)


9035
9036
9037
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9035

def successful_sample_count
  @successful_sample_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9042
9043
9044
9045
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9042

def update!(**args)
  @failed_sample_count = args[:failed_sample_count] if args.key?(:failed_sample_count)
  @successful_sample_count = args[:successful_sample_count] if args.key?(:successful_sample_count)
end