Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message for sampling conversations.
Instance Attribute Summary collapse
-
#conversation_filter ⇒ String
To specify the filter for the conversions that should apply this sample rule.
-
#dimension ⇒ String
Optional.
-
#sample_percentage ⇒ Float
Percentage of conversations that we should sample based on the dimension between [0, 100].
-
#sample_row ⇒ Fixnum
Number of the conversations that we should sample based on the dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1SampleRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleRule
Returns a new instance of GoogleCloudContactcenterinsightsV1SampleRule.
9300 9301 9302 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_filter ⇒ String
To specify the filter for the conversions that should apply this sample rule.
An empty filter means this sample rule applies to all conversations.
Corresponds to the JSON property conversationFilter
9280 9281 9282 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9280 def conversation_filter @conversation_filter end |
#dimension ⇒ String
Optional. Group by dimension to sample the conversation. If no dimension is
provided, the sampling will be applied to the project level. Current supported
dimensions is 'quality_metadata.agent_info.agent_id'.
Corresponds to the JSON property dimension
9287 9288 9289 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9287 def dimension @dimension end |
#sample_percentage ⇒ Float
Percentage of conversations that we should sample based on the dimension
between [0, 100].
Corresponds to the JSON property samplePercentage
9293 9294 9295 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9293 def sample_percentage @sample_percentage end |
#sample_row ⇒ Fixnum
Number of the conversations that we should sample based on the dimension.
Corresponds to the JSON property sampleRow
9298 9299 9300 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9298 def sample_row @sample_row end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9305 9306 9307 9308 9309 9310 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9305 def update!(**args) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @dimension = args[:dimension] if args.key?(:dimension) @sample_percentage = args[:sample_percentage] if args.key?(:sample_percentage) @sample_row = args[:sample_row] if args.key?(:sample_row) end |