Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SampleRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message for sampling conversations.
Instance Attribute Summary collapse
-
#conversation_filter ⇒ String
To specify the filter for the conversions that should apply this sample rule.
-
#dimension ⇒ String
Optional.
-
#sample_percentage ⇒ Float
Percentage of conversations that we should sample based on the dimension between [0, 100].
-
#sample_row ⇒ Fixnum
Number of the conversations that we should sample based on the dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleRule
constructor
A new instance of GoogleCloudContactcenterinsightsV1SampleRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SampleRule
Returns a new instance of GoogleCloudContactcenterinsightsV1SampleRule.
10459 10460 10461 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_filter ⇒ String
To specify the filter for the conversions that should apply this sample rule.
An empty filter means this sample rule applies to all conversations.
Corresponds to the JSON property conversationFilter
10439 10440 10441 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10439 def conversation_filter @conversation_filter end |
#dimension ⇒ String
Optional. Group by dimension to sample the conversation. If no dimension is
provided, the sampling will be applied to the project level. Current supported
dimensions is 'quality_metadata.agent_info.agent_id'.
Corresponds to the JSON property dimension
10446 10447 10448 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10446 def dimension @dimension end |
#sample_percentage ⇒ Float
Percentage of conversations that we should sample based on the dimension
between [0, 100].
Corresponds to the JSON property samplePercentage
10452 10453 10454 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10452 def sample_percentage @sample_percentage end |
#sample_row ⇒ Fixnum
Number of the conversations that we should sample based on the dimension.
Corresponds to the JSON property sampleRow
10457 10458 10459 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10457 def sample_row @sample_row end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10464 10465 10466 10467 10468 10469 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10464 def update!(**args) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @dimension = args[:dimension] if args.key?(:dimension) @sample_percentage = args[:sample_percentage] if args.key?(:sample_percentage) @sample_row = args[:sample_row] if args.key?(:sample_row) end |