Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message for schedule info.
Instance Attribute Summary collapse
-
#end_time ⇒ String
End time of the schedule.
-
#schedule ⇒ String
The groc expression.
-
#start_time ⇒ String
Start time of the schedule.
-
#time_zone ⇒ String
The timezone to use for the groc expression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ScheduleInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1ScheduleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ScheduleInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1ScheduleInfo.
9165 9166 9167 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
End time of the schedule. If not specified, will keep scheduling new pipelines
for execution util the schedule is no longer active or deleted.
Corresponds to the JSON property endTime
9143 9144 9145 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9143 def end_time @end_time end |
#schedule ⇒ String
The groc expression. Format: every number [synchronized] Time units can be:
minutes, hours Synchronized is optional and indicates that the schedule should
be synchronized to the start of the interval: every 5 minutes synchronized
means 00:00, 00:05 ... Otherwise the start time is random within the interval.
Example: every 5 minutes could be 00:02, 00:07, 00:12, ...
Corresponds to the JSON property schedule
9152 9153 9154 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9152 def schedule @schedule end |
#start_time ⇒ String
Start time of the schedule. If not specified, will start as soon as the
schedule is created.
Corresponds to the JSON property startTime
9158 9159 9160 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9158 def start_time @start_time end |
#time_zone ⇒ String
The timezone to use for the groc expression. If not specified, defaults to UTC.
Corresponds to the JSON property timeZone
9163 9164 9165 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9163 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9170 9171 9172 9173 9174 9175 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9170 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @schedule = args[:schedule] if args.key?(:schedule) @start_time = args[:start_time] if args.key?(:start_time) @time_zone = args[:time_zone] if args.key?(:time_zone) end |