Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ScheduleInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for schedule info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1ScheduleInfo

Returns a new instance of GoogleCloudContactcenterinsightsV1ScheduleInfo.



10432
10433
10434
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

End time of the schedule. If not specified, will keep scheduling new pipelines for execution util the schedule is no longer active or deleted. Corresponds to the JSON property endTime

Returns:

  • (String)


10410
10411
10412
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10410

def end_time
  @end_time
end

#scheduleString

The groc expression. Format: every number [synchronized] Time units can be: minutes, hours Synchronized is optional and indicates that the schedule should be synchronized to the start of the interval: every 5 minutes synchronized means 00:00, 00:05 ... Otherwise the start time is random within the interval. Example: every 5 minutes could be 00:02, 00:07, 00:12, ... Corresponds to the JSON property schedule

Returns:

  • (String)


10419
10420
10421
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10419

def schedule
  @schedule
end

#start_timeString

Start time of the schedule. If not specified, will start as soon as the schedule is created. Corresponds to the JSON property startTime

Returns:

  • (String)


10425
10426
10427
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10425

def start_time
  @start_time
end

#time_zoneString

The timezone to use for the groc expression. If not specified, defaults to UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


10430
10431
10432
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10430

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10437
10438
10439
10440
10441
10442
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10437

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @schedule = args[:schedule] if args.key?(:schedule)
  @start_time = args[:start_time] if args.key?(:start_time)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end