Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CCAI Insights project wide settings. Use these settings to configure the
behavior of Insights. View these settings with getsettings and change the settings with updateSettings.
Instance Attribute Summary collapse
-
#analysis_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
Default configuration when creating Analyses in Insights.
-
#conversation_ttl ⇒ String
The default TTL for newly-created conversations.
-
#create_time ⇒ String
Output only.
-
#diagnostic_metric_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsDiagnosticMetricConfig
Configuration for diagnostic metrics.
-
#language_code ⇒ String
A language code to be applied to each transcript segment unless the segment already specifies a language code.
-
#name ⇒ String
Immutable.
-
#pubsub_notification_settings ⇒ Hash<String,String>
A map that maps a notification trigger to a Pub/Sub topic.
-
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#screen_recording_bucket_uri ⇒ String
Optional.
-
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig
Speech-to-Text configuration.
-
#time_zone ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings
constructor
A new instance of GoogleCloudContactcenterinsightsV1Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings
Returns a new instance of GoogleCloudContactcenterinsightsV1Settings.
9471 9472 9473 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
Default configuration when creating Analyses in Insights.
Corresponds to the JSON property analysisConfig
9379 9380 9381 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9379 def analysis_config @analysis_config end |
#conversation_ttl ⇒ String
The default TTL for newly-created conversations. If a conversation has a
specified expiration, that value will be used instead. Changing this value
will not change the expiration of existing conversations. Conversations with
no expire time persist until they are deleted.
Corresponds to the JSON property conversationTtl
9387 9388 9389 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9387 def conversation_ttl @conversation_ttl end |
#create_time ⇒ String
Output only. The time at which the settings was created.
Corresponds to the JSON property createTime
9392 9393 9394 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9392 def create_time @create_time end |
#diagnostic_metric_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsDiagnosticMetricConfig
Configuration for diagnostic metrics.
Corresponds to the JSON property diagnosticMetricConfig
9397 9398 9399 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9397 def diagnostic_metric_config @diagnostic_metric_config end |
#language_code ⇒ String
A language code to be applied to each transcript segment unless the segment
already specifies a language code. Language code defaults to "en-US" if it is
neither specified on the segment nor here.
Corresponds to the JSON property languageCode
9404 9405 9406 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9404 def language_code @language_code end |
#name ⇒ String
Immutable. The resource name of the settings resource. Format: projects/
project/locations/location/settings
Corresponds to the JSON property name
9410 9411 9412 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9410 def name @name end |
#pubsub_notification_settings ⇒ Hash<String,String>
A map that maps a notification trigger to a Pub/Sub topic. Each time a
specified trigger occurs, Insights will notify the corresponding Pub/Sub topic.
Keys are notification triggers. Supported keys are: * "all-triggers": Notify
each time any of the supported triggers occurs. * "create-analysis": Notify
each time an analysis is created. * "create-conversation": Notify each time a
conversation is created. * "export-insights-data": Notify each time an export
is complete. * "ingest-conversations": Notify each time an IngestConversations
LRO is complete. * "update-conversation": Notify each time a conversation is
updated via UpdateConversation. * "upload-conversation": Notify when an
UploadConversation LRO is complete. * "update-or-analyze-conversation": Notify
when an analysis for a conversation is completed or when the conversation is
updated. The message will contain the conversation with transcript, analysis
and other metadata. Values are Pub/Sub topics. The format of each Pub/Sub
topic is: projects/project/topics/topic
Corresponds to the JSON property pubsubNotificationSettings
9428 9429 9430 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9428 def pubsub_notification_settings @pubsub_notification_settings end |
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property redactionConfig
9439 9440 9441 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9439 def redaction_config @redaction_config end |
#screen_recording_bucket_uri ⇒ String
Optional. The path to a Cloud Storage bucket containing conversation screen
recordings. If provided, Insights will search in the bucket for a screen
recording file matching the conversation data source object name prefix. If
matches are found, these file URIs will be stored in the conversation screen
recordings field.
Corresponds to the JSON property screenRecordingBucketUri
9448 9449 9450 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9448 def screen_recording_bucket_uri @screen_recording_bucket_uri end |
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig
Speech-to-Text configuration. Speech-to-Text settings are applied to
conversations ingested from the UploadConversation and IngestConversations
endpoints, including conversation coming from CCAI Platform. They are not
applied to conversations ingested from the CreateConversation endpoint.
Corresponds to the JSON property speechConfig
9456 9457 9458 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9456 def speech_config @speech_config end |
#time_zone ⇒ String
Optional. The time zone applied to the project. This is a string
representation of the time zone, for example, "America/New_York". This field
follows the IANA TZ database format. See https://www.iana.org/time-zones for a
list of valid values. If no value is set the user time zone will be used.
Corresponds to the JSON property timeZone
9464 9465 9466 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9464 def time_zone @time_zone end |
#update_time ⇒ String
Output only. The time at which the settings were last updated.
Corresponds to the JSON property updateTime
9469 9470 9471 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9469 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9476 def update!(**args) @analysis_config = args[:analysis_config] if args.key?(:analysis_config) @conversation_ttl = args[:conversation_ttl] if args.key?(:conversation_ttl) @create_time = args[:create_time] if args.key?(:create_time) @diagnostic_metric_config = args[:diagnostic_metric_config] if args.key?(:diagnostic_metric_config) @language_code = args[:language_code] if args.key?(:language_code) @name = args[:name] if args.key?(:name) @pubsub_notification_settings = args[:pubsub_notification_settings] if args.key?(:pubsub_notification_settings) @redaction_config = args[:redaction_config] if args.key?(:redaction_config) @screen_recording_bucket_uri = args[:screen_recording_bucket_uri] if args.key?(:screen_recording_bucket_uri) @speech_config = args[:speech_config] if args.key?(:speech_config) @time_zone = args[:time_zone] if args.key?(:time_zone) @update_time = args[:update_time] if args.key?(:update_time) end |