Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The CCAI Insights project wide settings. Use these settings to configure the behavior of Insights. View these settings with getsettings and change the settings with updateSettings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings

Returns a new instance of GoogleCloudContactcenterinsightsV1Settings.



9340
9341
9342
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig

Default configuration when creating Analyses in Insights. Corresponds to the JSON property analysisConfig



9248
9249
9250
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9248

def analysis_config
  @analysis_config
end

#conversation_ttlString

The default TTL for newly-created conversations. If a conversation has a specified expiration, that value will be used instead. Changing this value will not change the expiration of existing conversations. Conversations with no expire time persist until they are deleted. Corresponds to the JSON property conversationTtl

Returns:

  • (String)


9256
9257
9258
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9256

def conversation_ttl
  @conversation_ttl
end

#create_timeString

Output only. The time at which the settings was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9261
9262
9263
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9261

def create_time
  @create_time
end

#diagnostic_metric_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsDiagnosticMetricConfig

Configuration for diagnostic metrics. Corresponds to the JSON property diagnosticMetricConfig



9266
9267
9268
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9266

def diagnostic_metric_config
  @diagnostic_metric_config
end

#language_codeString

A language code to be applied to each transcript segment unless the segment already specifies a language code. Language code defaults to "en-US" if it is neither specified on the segment nor here. Corresponds to the JSON property languageCode

Returns:

  • (String)


9273
9274
9275
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9273

def language_code
  @language_code
end

#nameString

Immutable. The resource name of the settings resource. Format: projects/ project/locations/location/settings Corresponds to the JSON property name

Returns:

  • (String)


9279
9280
9281
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9279

def name
  @name
end

#pubsub_notification_settingsHash<String,String>

A map that maps a notification trigger to a Pub/Sub topic. Each time a specified trigger occurs, Insights will notify the corresponding Pub/Sub topic. Keys are notification triggers. Supported keys are: * "all-triggers": Notify each time any of the supported triggers occurs. * "create-analysis": Notify each time an analysis is created. * "create-conversation": Notify each time a conversation is created. * "export-insights-data": Notify each time an export is complete. * "ingest-conversations": Notify each time an IngestConversations LRO is complete. * "update-conversation": Notify each time a conversation is updated via UpdateConversation. * "upload-conversation": Notify when an UploadConversation LRO is complete. * "update-or-analyze-conversation": Notify when an analysis for a conversation is completed or when the conversation is updated. The message will contain the conversation with transcript, analysis and other metadata. Values are Pub/Sub topics. The format of each Pub/Sub topic is: projects/project/topics/topic Corresponds to the JSON property pubsubNotificationSettings

Returns:

  • (Hash<String,String>)


9297
9298
9299
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9297

def pubsub_notification_settings
  @pubsub_notification_settings
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



9308
9309
9310
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9308

def redaction_config
  @redaction_config
end

#screen_recording_bucket_uriString

Optional. The path to a Cloud Storage bucket containing conversation screen recordings. If provided, Insights will search in the bucket for a screen recording file matching the conversation data source object name prefix. If matches are found, these file URIs will be stored in the conversation screen recordings field. Corresponds to the JSON property screenRecordingBucketUri

Returns:

  • (String)


9317
9318
9319
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9317

def screen_recording_bucket_uri
  @screen_recording_bucket_uri
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



9325
9326
9327
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9325

def speech_config
  @speech_config
end

#time_zoneString

Optional. The time zone applied to the project. This is a string representation of the time zone, for example, "America/New_York". This field follows the IANA TZ database format. See https://www.iana.org/time-zones for a list of valid values. If no value is set the user time zone will be used. Corresponds to the JSON property timeZone

Returns:

  • (String)


9333
9334
9335
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9333

def time_zone
  @time_zone
end

#update_timeString

Output only. The time at which the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


9338
9339
9340
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9338

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9345
9346
9347
9348
9349
9350
9351
9352
9353
9354
9355
9356
9357
9358
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9345

def update!(**args)
  @analysis_config = args[:analysis_config] if args.key?(:analysis_config)
  @conversation_ttl = args[:conversation_ttl] if args.key?(:conversation_ttl)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_metric_config = args[:diagnostic_metric_config] if args.key?(:diagnostic_metric_config)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @pubsub_notification_settings = args[:pubsub_notification_settings] if args.key?(:pubsub_notification_settings)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @screen_recording_bucket_uri = args[:screen_recording_bucket_uri] if args.key?(:screen_recording_bucket_uri)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
end