Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The CCAI Insights project wide settings. Use these settings to configure the behavior of Insights. View these settings with getsettings and change the settings with updateSettings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings

Returns a new instance of GoogleCloudContactcenterinsightsV1Settings.



10601
10602
10603
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig

Default configuration when creating Analyses in Insights. Corresponds to the JSON property analysisConfig



10509
10510
10511
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10509

def analysis_config
  @analysis_config
end

#conversation_ttlString

The default TTL for newly-created conversations. If a conversation has a specified expiration, that value will be used instead. Changing this value will not change the expiration of existing conversations. Conversations with no expire time persist until they are deleted. Corresponds to the JSON property conversationTtl

Returns:

  • (String)


10517
10518
10519
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10517

def conversation_ttl
  @conversation_ttl
end

#create_timeString

Output only. The time at which the settings was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10522
10523
10524
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10522

def create_time
  @create_time
end

#diagnostic_metric_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsDiagnosticMetricConfig

Configuration for diagnostic metrics. Corresponds to the JSON property diagnosticMetricConfig



10527
10528
10529
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10527

def diagnostic_metric_config
  @diagnostic_metric_config
end

#language_codeString

A language code to be applied to each transcript segment unless the segment already specifies a language code. Language code defaults to "en-US" if it is neither specified on the segment nor here. Corresponds to the JSON property languageCode

Returns:

  • (String)


10534
10535
10536
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10534

def language_code
  @language_code
end

#nameString

Immutable. The resource name of the settings resource. Format: projects/ project/locations/location/settings Corresponds to the JSON property name

Returns:

  • (String)


10540
10541
10542
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10540

def name
  @name
end

#pubsub_notification_settingsHash<String,String>

A map that maps a notification trigger to a Pub/Sub topic. Each time a specified trigger occurs, Insights will notify the corresponding Pub/Sub topic. Keys are notification triggers. Supported keys are: * "all-triggers": Notify each time any of the supported triggers occurs. * "create-analysis": Notify each time an analysis is created. * "create-conversation": Notify each time a conversation is created. * "export-insights-data": Notify each time an export is complete. * "ingest-conversations": Notify each time an IngestConversations LRO is complete. * "update-conversation": Notify each time a conversation is updated via UpdateConversation. * "upload-conversation": Notify when an UploadConversation LRO is complete. * "update-or-analyze-conversation": Notify when an analysis for a conversation is completed or when the conversation is updated. The message will contain the conversation with transcript, analysis and other metadata. Values are Pub/Sub topics. The format of each Pub/Sub topic is: projects/project/topics/topic Corresponds to the JSON property pubsubNotificationSettings

Returns:

  • (Hash<String,String>)


10558
10559
10560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10558

def pubsub_notification_settings
  @pubsub_notification_settings
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



10569
10570
10571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10569

def redaction_config
  @redaction_config
end

#screen_recording_bucket_uriString

Optional. The path to a Cloud Storage bucket containing conversation screen recordings. If provided, Insights will search in the bucket for a screen recording file matching the conversation data source object name prefix. If matches are found, these file URIs will be stored in the conversation screen recordings field. Corresponds to the JSON property screenRecordingBucketUri

Returns:

  • (String)


10578
10579
10580
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10578

def screen_recording_bucket_uri
  @screen_recording_bucket_uri
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



10586
10587
10588
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10586

def speech_config
  @speech_config
end

#time_zoneString

Optional. The time zone applied to the project. This is a string representation of the time zone, for example, "America/New_York". This field follows the IANA TZ database format. See https://www.iana.org/time-zones for a list of valid values. If no value is set the user time zone will be used. Corresponds to the JSON property timeZone

Returns:

  • (String)


10594
10595
10596
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10594

def time_zone
  @time_zone
end

#update_timeString

Output only. The time at which the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10599
10600
10601
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10599

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
10617
10618
10619
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10606

def update!(**args)
  @analysis_config = args[:analysis_config] if args.key?(:analysis_config)
  @conversation_ttl = args[:conversation_ttl] if args.key?(:conversation_ttl)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_metric_config = args[:diagnostic_metric_config] if args.key?(:diagnostic_metric_config)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @pubsub_notification_settings = args[:pubsub_notification_settings] if args.key?(:pubsub_notification_settings)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @screen_recording_bucket_uri = args[:screen_recording_bucket_uri] if args.key?(:screen_recording_bucket_uri)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
end