Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CCAI Insights project wide settings. Use these settings to configure the
behavior of Insights. View these settings with getsettings and change the settings with updateSettings.
Instance Attribute Summary collapse
-
#analysis_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
Default configuration when creating Analyses in Insights.
-
#conversation_ttl ⇒ String
The default TTL for newly-created conversations.
-
#create_time ⇒ String
Output only.
-
#language_code ⇒ String
A language code to be applied to each transcript segment unless the segment already specifies a language code.
-
#name ⇒ String
Immutable.
-
#pubsub_notification_settings ⇒ Hash<String,String>
A map that maps a notification trigger to a Pub/Sub topic.
-
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#screen_recording_bucket_uri ⇒ String
Optional.
-
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig
Speech-to-Text configuration.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings
constructor
A new instance of GoogleCloudContactcenterinsightsV1Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings
Returns a new instance of GoogleCloudContactcenterinsightsV1Settings.
8756 8757 8758 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
Default configuration when creating Analyses in Insights.
Corresponds to the JSON property analysisConfig
8677 8678 8679 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8677 def analysis_config @analysis_config end |
#conversation_ttl ⇒ String
The default TTL for newly-created conversations. If a conversation has a
specified expiration, that value will be used instead. Changing this value
will not change the expiration of existing conversations. Conversations with
no expire time persist until they are deleted.
Corresponds to the JSON property conversationTtl
8685 8686 8687 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8685 def conversation_ttl @conversation_ttl end |
#create_time ⇒ String
Output only. The time at which the settings was created.
Corresponds to the JSON property createTime
8690 8691 8692 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8690 def create_time @create_time end |
#language_code ⇒ String
A language code to be applied to each transcript segment unless the segment
already specifies a language code. Language code defaults to "en-US" if it is
neither specified on the segment nor here.
Corresponds to the JSON property languageCode
8697 8698 8699 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8697 def language_code @language_code end |
#name ⇒ String
Immutable. The resource name of the settings resource. Format: projects/
project/locations/location/settings
Corresponds to the JSON property name
8703 8704 8705 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8703 def name @name end |
#pubsub_notification_settings ⇒ Hash<String,String>
A map that maps a notification trigger to a Pub/Sub topic. Each time a
specified trigger occurs, Insights will notify the corresponding Pub/Sub topic.
Keys are notification triggers. Supported keys are: * "all-triggers": Notify
each time any of the supported triggers occurs. * "create-analysis": Notify
each time an analysis is created. * "create-conversation": Notify each time a
conversation is created. * "export-insights-data": Notify each time an export
is complete. * "ingest-conversations": Notify each time an IngestConversations
LRO is complete. * "update-conversation": Notify each time a conversation is
updated via UpdateConversation. * "upload-conversation": Notify when an
UploadConversation LRO is complete. * "update-or-analyze-conversation": Notify
when an analysis for a conversation is completed or when the conversation is
updated. The message will contain the conversation with transcript, analysis
and other metadata. Values are Pub/Sub topics. The format of each Pub/Sub
topic is: projects/project/topics/topic
Corresponds to the JSON property pubsubNotificationSettings
8721 8722 8723 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8721 def pubsub_notification_settings @pubsub_notification_settings end |
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property redactionConfig
8732 8733 8734 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8732 def redaction_config @redaction_config end |
#screen_recording_bucket_uri ⇒ String
Optional. The path to a Cloud Storage bucket containing conversation screen
recordings. If provided, Insights will search in the bucket for a screen
recording file matching the conversation data source object name prefix. If
matches are found, these file URIs will be stored in the conversation screen
recordings field.
Corresponds to the JSON property screenRecordingBucketUri
8741 8742 8743 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8741 def screen_recording_bucket_uri @screen_recording_bucket_uri end |
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig
Speech-to-Text configuration. Speech-to-Text settings are applied to
conversations ingested from the UploadConversation and IngestConversations
endpoints, including conversation coming from CCAI Platform. They are not
applied to conversations ingested from the CreateConversation endpoint.
Corresponds to the JSON property speechConfig
8749 8750 8751 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8749 def speech_config @speech_config end |
#update_time ⇒ String
Output only. The time at which the settings were last updated.
Corresponds to the JSON property updateTime
8754 8755 8756 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8754 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8761 def update!(**args) @analysis_config = args[:analysis_config] if args.key?(:analysis_config) @conversation_ttl = args[:conversation_ttl] if args.key?(:conversation_ttl) @create_time = args[:create_time] if args.key?(:create_time) @language_code = args[:language_code] if args.key?(:language_code) @name = args[:name] if args.key?(:name) @pubsub_notification_settings = args[:pubsub_notification_settings] if args.key?(:pubsub_notification_settings) @redaction_config = args[:redaction_config] if args.key?(:redaction_config) @screen_recording_bucket_uri = args[:screen_recording_bucket_uri] if args.key?(:screen_recording_bucket_uri) @speech_config = args[:speech_config] if args.key?(:speech_config) @update_time = args[:update_time] if args.key?(:update_time) end |