Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Settings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The CCAI Insights project wide settings. Use these settings to configure the behavior of Insights. View these settings with getsettings and change the settings with updateSettings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1Settings

Returns a new instance of GoogleCloudContactcenterinsightsV1Settings.



6946
6947
6948
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig

Default configuration when creating Analyses in Insights. Corresponds to the JSON property analysisConfig



6867
6868
6869
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6867

def analysis_config
  @analysis_config
end

#conversation_ttlString

The default TTL for newly-created conversations. If a conversation has a specified expiration, that value will be used instead. Changing this value will not change the expiration of existing conversations. Conversations with no expire time persist until they are deleted. Corresponds to the JSON property conversationTtl

Returns:

  • (String)


6875
6876
6877
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6875

def conversation_ttl
  @conversation_ttl
end

#create_timeString

Output only. The time at which the settings was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6880
6881
6882
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6880

def create_time
  @create_time
end

#language_codeString

A language code to be applied to each transcript segment unless the segment already specifies a language code. Language code defaults to "en-US" if it is neither specified on the segment nor here. Corresponds to the JSON property languageCode

Returns:

  • (String)


6887
6888
6889
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6887

def language_code
  @language_code
end

#nameString

Immutable. The resource name of the settings resource. Format: projects/ project/locations/location/settings Corresponds to the JSON property name

Returns:

  • (String)


6893
6894
6895
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6893

def name
  @name
end

#pubsub_notification_settingsHash<String,String>

A map that maps a notification trigger to a Pub/Sub topic. Each time a specified trigger occurs, Insights will notify the corresponding Pub/Sub topic. Keys are notification triggers. Supported keys are: * "all-triggers": Notify each time any of the supported triggers occurs. * "create-analysis": Notify each time an analysis is created. * "create-conversation": Notify each time a conversation is created. * "export-insights-data": Notify each time an export is complete. * "ingest-conversations": Notify each time an IngestConversations LRO is complete. * "update-conversation": Notify each time a conversation is updated via UpdateConversation. * "upload-conversation": Notify when an UploadConversation LRO is complete. * "update-or-analyze-conversation": Notify when an analysis for a conversation is completed or when the conversation is updated. The message will contain the conversation with transcript, analysis and other metadata. Values are Pub/Sub topics. The format of each Pub/Sub topic is: projects/project/topics/topic Corresponds to the JSON property pubsubNotificationSettings

Returns:

  • (Hash<String,String>)


6911
6912
6913
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6911

def pubsub_notification_settings
  @pubsub_notification_settings
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



6922
6923
6924
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6922

def redaction_config
  @redaction_config
end

#screen_recording_bucket_uriString

Optional. The path to a Cloud Storage bucket containing conversation screen recordings. If provided, Insights will search in the bucket for a screen recording file matching the conversation data source object name prefix. If matches are found, these file URIs will be stored in the conversation screen recordings field. Corresponds to the JSON property screenRecordingBucketUri

Returns:

  • (String)


6931
6932
6933
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6931

def screen_recording_bucket_uri
  @screen_recording_bucket_uri
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



6939
6940
6941
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6939

def speech_config
  @speech_config
end

#update_timeString

Output only. The time at which the settings were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6944
6945
6946
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6944

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
6962
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 6951

def update!(**args)
  @analysis_config = args[:analysis_config] if args.key?(:analysis_config)
  @conversation_ttl = args[:conversation_ttl] if args.key?(:conversation_ttl)
  @create_time = args[:create_time] if args.key?(:create_time)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @pubsub_notification_settings = args[:pubsub_notification_settings] if args.key?(:pubsub_notification_settings)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @screen_recording_bucket_uri = args[:screen_recording_bucket_uri] if args.key?(:screen_recording_bucket_uri)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end