Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A step in the agent's reasoning process (Trajectory Step).
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Output only.
-
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#state_deltas ⇒ Array<Hash<String,Object>>
Output only.
-
#step_id ⇒ String
Output only.
-
#text_input ⇒ Array<String>
Output only.
-
#thought ⇒ String
Output only.
-
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ToolCall>
Output only.
-
#tool_output ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SherlockStep
constructor
A new instance of GoogleCloudContactcenterinsightsV1SherlockStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SherlockStep
Returns a new instance of GoogleCloudContactcenterinsightsV1SherlockStep.
10791 10792 10793 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Output only. The ID of the agent that produced/received this content.
Corresponds to the JSON property agentId
10752 10753 10754 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10752 def agent_id @agent_id end |
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
10759 10760 10761 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10759 def content @content end |
#state_deltas ⇒ Array<Hash<String,Object>>
Output only. List of state changes caused by this specific turn.
Corresponds to the JSON property stateDeltas
10764 10765 10766 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10764 def state_deltas @state_deltas end |
#step_id ⇒ String
Output only. Unique ID for this specific turn.
Corresponds to the JSON property stepId
10769 10770 10771 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10769 def step_id @step_id end |
#text_input ⇒ Array<String>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property textInput
10774 10775 10776 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10774 def text_input @text_input end |
#thought ⇒ String
Output only. Deprecated: Use content instead.
Corresponds to the JSON property thought
10779 10780 10781 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10779 def thought @thought end |
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ToolCall>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolCalls
10784 10785 10786 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10784 def tool_calls @tool_calls end |
#tool_output ⇒ Hash<String,Object>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolOutput
10789 10790 10791 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10789 def tool_output @tool_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10796 10797 10798 10799 10800 10801 10802 10803 10804 10805 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10796 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @content = args[:content] if args.key?(:content) @state_deltas = args[:state_deltas] if args.key?(:state_deltas) @step_id = args[:step_id] if args.key?(:step_id) @text_input = args[:text_input] if args.key?(:text_input) @thought = args[:thought] if args.key?(:thought) @tool_calls = args[:tool_calls] if args.key?(:tool_calls) @tool_output = args[:tool_output] if args.key?(:tool_output) end |