Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SherlockStep
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A step in the agent's reasoning process (Trajectory Step).
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Output only.
-
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#state_deltas ⇒ Array<Hash<String,Object>>
Output only.
-
#step_id ⇒ String
Output only.
-
#text_input ⇒ Array<String>
Output only.
-
#thought ⇒ String
Output only.
-
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ToolCall>
Output only.
-
#tool_output ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SherlockStep
constructor
A new instance of GoogleCloudContactcenterinsightsV1SherlockStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SherlockStep
Returns a new instance of GoogleCloudContactcenterinsightsV1SherlockStep.
10721 10722 10723 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Output only. The ID of the agent that produced/received this content.
Corresponds to the JSON property agentId
10682 10683 10684 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10682 def agent_id @agent_id end |
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
10689 10690 10691 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10689 def content @content end |
#state_deltas ⇒ Array<Hash<String,Object>>
Output only. List of state changes caused by this specific turn.
Corresponds to the JSON property stateDeltas
10694 10695 10696 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10694 def state_deltas @state_deltas end |
#step_id ⇒ String
Output only. Unique ID for this specific turn.
Corresponds to the JSON property stepId
10699 10700 10701 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10699 def step_id @step_id end |
#text_input ⇒ Array<String>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property textInput
10704 10705 10706 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10704 def text_input @text_input end |
#thought ⇒ String
Output only. Deprecated: Use content instead.
Corresponds to the JSON property thought
10709 10710 10711 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10709 def thought @thought end |
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ToolCall>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolCalls
10714 10715 10716 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10714 def tool_calls @tool_calls end |
#tool_output ⇒ Hash<String,Object>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolOutput
10719 10720 10721 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10719 def tool_output @tool_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10726 10727 10728 10729 10730 10731 10732 10733 10734 10735 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10726 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @content = args[:content] if args.key?(:content) @state_deltas = args[:state_deltas] if args.key?(:state_deltas) @step_id = args[:step_id] if args.key?(:step_id) @text_input = args[:text_input] if args.key?(:text_input) @thought = args[:thought] if args.key?(:thought) @tool_calls = args[:tool_calls] if args.key?(:tool_calls) @tool_output = args[:tool_output] if args.key?(:tool_output) end |