Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SignedAudioUris
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SignedAudioUris
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Signed audio URIs for a conversation.
Instance Attribute Summary collapse
-
#signed_dialogflow_audio_uri ⇒ String
The signed URI for the audio from the Dialogflow conversation source.
-
#signed_gcs_audio_uri ⇒ String
The signed URI for the audio from the Cloud Storage conversation source.
-
#signed_gcs_audio_uris ⇒ Array<String>
Output only.
-
#signed_turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>
The signed URI for the audio corresponding to each turn in the conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SignedAudioUris
constructor
A new instance of GoogleCloudContactcenterinsightsV1SignedAudioUris.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SignedAudioUris
Returns a new instance of GoogleCloudContactcenterinsightsV1SignedAudioUris.
9611 9612 9613 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#signed_dialogflow_audio_uri ⇒ String
The signed URI for the audio from the Dialogflow conversation source.
Corresponds to the JSON property signedDialogflowAudioUri
9593 9594 9595 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9593 def signed_dialogflow_audio_uri @signed_dialogflow_audio_uri end |
#signed_gcs_audio_uri ⇒ String
The signed URI for the audio from the Cloud Storage conversation source.
Corresponds to the JSON property signedGcsAudioUri
9598 9599 9600 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9598 def signed_gcs_audio_uri @signed_gcs_audio_uri end |
#signed_gcs_audio_uris ⇒ Array<String>
Output only. The signed URIs for the audio from the Cloud Storage conversation
source when multiple audio files exist (e.g. multi-leg conversations).
Corresponds to the JSON property signedGcsAudioUris
9604 9605 9606 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9604 def signed_gcs_audio_uris @signed_gcs_audio_uris end |
#signed_turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>
The signed URI for the audio corresponding to each turn in the conversation.
Corresponds to the JSON property signedTurnLevelAudios
9609 9610 9611 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9609 def signed_turn_level_audios @signed_turn_level_audios end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9616 9617 9618 9619 9620 9621 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9616 def update!(**args) @signed_dialogflow_audio_uri = args[:signed_dialogflow_audio_uri] if args.key?(:signed_dialogflow_audio_uri) @signed_gcs_audio_uri = args[:signed_gcs_audio_uri] if args.key?(:signed_gcs_audio_uri) @signed_gcs_audio_uris = args[:signed_gcs_audio_uris] if args.key?(:signed_gcs_audio_uris) @signed_turn_level_audios = args[:signed_turn_level_audios] if args.key?(:signed_turn_level_audios) end |