Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SignedAudioUris

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Signed audio URIs for a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SignedAudioUris

Returns a new instance of GoogleCloudContactcenterinsightsV1SignedAudioUris.



9564
9565
9566
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signed_dialogflow_audio_uriString

The signed URI for the audio from the Dialogflow conversation source. Corresponds to the JSON property signedDialogflowAudioUri

Returns:

  • (String)


9552
9553
9554
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9552

def signed_dialogflow_audio_uri
  @signed_dialogflow_audio_uri
end

#signed_gcs_audio_uriString

The signed URI for the audio from the Cloud Storage conversation source. Corresponds to the JSON property signedGcsAudioUri

Returns:

  • (String)


9557
9558
9559
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9557

def signed_gcs_audio_uri
  @signed_gcs_audio_uri
end

#signed_turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>

The signed URI for the audio corresponding to each turn in the conversation. Corresponds to the JSON property signedTurnLevelAudios



9562
9563
9564
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9562

def signed_turn_level_audios
  @signed_turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9569
9570
9571
9572
9573
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9569

def update!(**args)
  @signed_dialogflow_audio_uri = args[:signed_dialogflow_audio_uri] if args.key?(:signed_dialogflow_audio_uri)
  @signed_gcs_audio_uri = args[:signed_gcs_audio_uri] if args.key?(:signed_gcs_audio_uri)
  @signed_turn_level_audios = args[:signed_turn_level_audios] if args.key?(:signed_turn_level_audios)
end