Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SignedAudioUris

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Signed audio URIs for a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SignedAudioUris

Returns a new instance of GoogleCloudContactcenterinsightsV1SignedAudioUris.



10757
10758
10759
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signed_dialogflow_audio_uriString

The signed URI for the audio from the Dialogflow conversation source. Corresponds to the JSON property signedDialogflowAudioUri

Returns:

  • (String)


10745
10746
10747
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10745

def signed_dialogflow_audio_uri
  @signed_dialogflow_audio_uri
end

#signed_gcs_audio_uriString

The signed URI for the audio from the Cloud Storage conversation source. Corresponds to the JSON property signedGcsAudioUri

Returns:

  • (String)


10750
10751
10752
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10750

def signed_gcs_audio_uri
  @signed_gcs_audio_uri
end

#signed_turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>

The signed URI for the audio corresponding to each turn in the conversation. Corresponds to the JSON property signedTurnLevelAudios



10755
10756
10757
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10755

def signed_turn_level_audios
  @signed_turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10762
10763
10764
10765
10766
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10762

def update!(**args)
  @signed_dialogflow_audio_uri = args[:signed_dialogflow_audio_uri] if args.key?(:signed_dialogflow_audio_uri)
  @signed_gcs_audio_uri = args[:signed_gcs_audio_uri] if args.key?(:signed_gcs_audio_uri)
  @signed_turn_level_audios = args[:signed_turn_level_audios] if args.key?(:signed_turn_level_audios)
end