Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SignedAudioUris

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Signed audio URIs for a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SignedAudioUris

Returns a new instance of GoogleCloudContactcenterinsightsV1SignedAudioUris.



7017
7018
7019
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signed_dialogflow_audio_uriString

The signed URI for the audio from the Dialogflow conversation source. Corresponds to the JSON property signedDialogflowAudioUri

Returns:

  • (String)


7005
7006
7007
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7005

def signed_dialogflow_audio_uri
  @signed_dialogflow_audio_uri
end

#signed_gcs_audio_uriString

The signed URI for the audio from the Cloud Storage conversation source. Corresponds to the JSON property signedGcsAudioUri

Returns:

  • (String)


7010
7011
7012
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7010

def signed_gcs_audio_uri
  @signed_gcs_audio_uri
end

#signed_turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio>

The signed URI for the audio corresponding to each turn in the conversation. Corresponds to the JSON property signedTurnLevelAudios



7015
7016
7017
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7015

def signed_turn_level_audios
  @signed_turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7022
7023
7024
7025
7026
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7022

def update!(**args)
  @signed_dialogflow_audio_uri = args[:signed_dialogflow_audio_uri] if args.key?(:signed_dialogflow_audio_uri)
  @signed_gcs_audio_uri = args[:signed_gcs_audio_uri] if args.key?(:signed_gcs_audio_uri)
  @signed_turn_level_audios = args[:signed_turn_level_audios] if args.key?(:signed_turn_level_audios)
end