Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1SpeechConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1SpeechConfig.



9554
9555
9556
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_word_time_offsetsBoolean Also known as: disable_word_time_offsets?

Whether to disable word time offsets. If true, the enable_word_time_offsets field in the recognition config will be set to false. Corresponds to the JSON property disableWordTimeOffsets

Returns:

  • (Boolean)


9545
9546
9547
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9545

def disable_word_time_offsets
  @disable_word_time_offsets
end

#speech_recognizerString

The fully-qualified Speech Recognizer resource name. Format: projects/ project_id/locations/location/recognizer/recognizer` Corresponds to the JSON propertyspeechRecognizer`

Returns:

  • (String)


9552
9553
9554
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9552

def speech_recognizer
  @speech_recognizer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9559
9560
9561
9562
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9559

def update!(**args)
  @disable_word_time_offsets = args[:disable_word_time_offsets] if args.key?(:disable_word_time_offsets)
  @speech_recognizer = args[:speech_recognizer] if args.key?(:speech_recognizer)
end