Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to test correlation config.
Instance Attribute Summary collapse
-
#conversations ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequestConversations
Wrapper for a list of conversations.
-
#correlation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig
A configuration that defines how to correlate conversations for a given a given project.
-
#filter ⇒ String
Optional.
-
#max_sample_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest.
9752 9753 9754 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversations ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequestConversations
Wrapper for a list of conversations.
Corresponds to the JSON property conversations
9728 9729 9730 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9728 def conversations @conversations end |
#correlation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig
A configuration that defines how to correlate conversations for a given a
given project.
Corresponds to the JSON property correlationConfig
9734 9735 9736 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9734 def correlation_config @correlation_config end |
#filter ⇒ String
Optional. Filter to select conversations to test correlation against.
Conversations matching this filter will be sampled based on start time. The
most recent max_sample_count conversations will be selected. If no
conversations match the filter, the request will fail with an
INVALID_ARGUMENT error.
Corresponds to the JSON property filter
9743 9744 9745 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9743 def filter @filter end |
#max_sample_count ⇒ Fixnum
Optional. The maximum number of conversations to sample when using the filter
. If not set, defaults to 1000. Values greater than 1000 are coerced to 1000.
This field is ignored if conversations is provided.
Corresponds to the JSON property maxSampleCount
9750 9751 9752 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9750 def max_sample_count @max_sample_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9757 9758 9759 9760 9761 9762 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9757 def update!(**args) @conversations = args[:conversations] if args.key?(:conversations) @correlation_config = args[:correlation_config] if args.key?(:correlation_config) @filter = args[:filter] if args.key?(:filter) @max_sample_count = args[:max_sample_count] if args.key?(:max_sample_count) end |