Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to test correlation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest.



9146
9147
9148
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequestConversations

Wrapper for a list of conversations. Corresponds to the JSON property conversations



9122
9123
9124
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9122

def conversations
  @conversations
end

#correlation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1CorrelationConfig

A configuration that defines how to correlate conversations for a given a given project. Corresponds to the JSON property correlationConfig



9128
9129
9130
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9128

def correlation_config
  @correlation_config
end

#filterString

Optional. Filter to select conversations to test correlation against. Conversations matching this filter will be sampled based on start time. The most recent max_sample_count conversations will be selected. If no conversations match the filter, the request will fail with an INVALID_ARGUMENT error. Corresponds to the JSON property filter

Returns:

  • (String)


9137
9138
9139
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9137

def filter
  @filter
end

#max_sample_countFixnum

Optional. The maximum number of conversations to sample when using the filter . If not set, defaults to 1000. Values greater than 1000 are coerced to 1000. This field is ignored if conversations is provided. Corresponds to the JSON property maxSampleCount

Returns:

  • (Fixnum)


9144
9145
9146
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9144

def max_sample_count
  @max_sample_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9151
9152
9153
9154
9155
9156
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9151

def update!(**args)
  @conversations = args[:conversations] if args.key?(:conversations)
  @correlation_config = args[:correlation_config] if args.key?(:correlation_config)
  @filter = args[:filter] if args.key?(:filter)
  @max_sample_count = args[:max_sample_count] if args.key?(:max_sample_count)
end