Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Wrapper for detailed, step-by-step results.
Instance Attribute Summary collapse
-
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
-
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
constructor
A new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults
Returns a new instance of GoogleCloudContactcenterinsightsV1TestCorrelationConfigResponseDetailedCorrelationResults.
9218 9219 9220 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
Corresponds to the JSON property constraintResults
9211 9212 9213 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9211 def constraint_results @constraint_results end |
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Corresponds to the JSON property joinKeyResults
9216 9217 9218 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9216 def join_key_results @join_key_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9223 9224 9225 9226 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9223 def update!(**args) @constraint_results = args[:constraint_results] if args.key?(:constraint_results) @join_key_results = args[:join_key_results] if args.key?(:join_key_results) end |