Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Request for TuneQaScorecardRevision endpoint.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest.
11204 11205 11206 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. Filter for selecting the feedback labels that needs to be used for
training. This filter can be used to limit the feedback labels used for tuning
to a feedback labels created or updated for a specific time-window etc.
Corresponds to the JSON property filter
11193 11194 11195 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11193 def filter @filter end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. Run in validate only mode, no fine tuning will actually run. Data
quality validations like training data distributions will run. Even when set
to false, the data quality validations will still run but once the validations
complete we will proceed with the fine tune, if applicable.
Corresponds to the JSON property validateOnly
11201 11202 11203 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11201 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11209 11210 11211 11212 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11209 def update!(**args) @filter = args[:filter] if args.key?(:filter) @validate_only = args[:validate_only] if args.key?(:validate_only) end |