Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request for TuneQaScorecardRevision endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest.



7175
7176
7177
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. Filter for selecting the feedback labels that needs to be used for training. This filter can be used to limit the feedback labels used for tuning to a feedback labels created or updated for a specific time-window etc. Corresponds to the JSON property filter

Returns:

  • (String)


7164
7165
7166
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7164

def filter
  @filter
end

#validate_onlyBoolean Also known as: validate_only?

Optional. Run in validate only mode, no fine tuning will actually run. Data quality validations like training data distributions will run. Even when set to false, the data quality validations will still run but once the validations complete we will proceed with the fine tune, if applicable. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


7172
7173
7174
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7172

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7180
7181
7182
7183
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7180

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end