Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for an UploadConversation operation.
Instance Attribute Summary collapse
-
#analysis_operation ⇒ String
Output only.
-
#applied_redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationRequest
Request to upload a conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1UploadConversationMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1UploadConversationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1UploadConversationMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1UploadConversationMetadata.
10038 10039 10040 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_operation ⇒ String
Output only. The operation name for a successfully created analysis operation,
if any.
Corresponds to the JSON property analysisOperation
10010 10011 10012 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10010 def analysis_operation @analysis_operation end |
#applied_redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property appliedRedactionConfig
10021 10022 10023 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10021 def applied_redaction_config @applied_redaction_config end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
10026 10027 10028 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10026 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
10031 10032 10033 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10031 def end_time @end_time end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationRequest
Request to upload a conversation.
Corresponds to the JSON property request
10036 10037 10038 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10036 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10043 10044 10045 10046 10047 10048 10049 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10043 def update!(**args) @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation) @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @request = args[:request] if args.key?(:request) end |