Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an UploadConversation operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1UploadConversationMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1UploadConversationMetadata.



11457
11458
11459
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_operationString

Output only. The operation name for a successfully created analysis operation, if any. Corresponds to the JSON property analysisOperation

Returns:

  • (String)


11429
11430
11431
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11429

def analysis_operation
  @analysis_operation
end

#applied_redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property appliedRedactionConfig



11440
11441
11442
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11440

def applied_redaction_config
  @applied_redaction_config
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11445
11446
11447
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11445

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


11450
11451
11452
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11450

def end_time
  @end_time
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationRequest

Request to upload a conversation. Corresponds to the JSON property request



11455
11456
11457
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11455

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11462
11463
11464
11465
11466
11467
11468
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11462

def update!(**args)
  @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation)
  @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @request = args[:request] if args.key?(:request)
end