Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1UploadConversationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to upload a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1UploadConversationRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1UploadConversationRequest.



10710
10711
10712
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1Conversation

The conversation resource. Corresponds to the JSON property conversation



10676
10677
10678
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10676

def conversation
  @conversation
end

#conversation_idString

Optional. A unique ID for the new conversation. This ID will become the final component of the conversation's resource name. If no ID is specified, a server- generated ID will be used. This value should be 4-64 characters and must match the regular expression ^[a-z0-9-]4,64$. Valid characters are a-z- Corresponds to the JSON property conversationId

Returns:

  • (String)


10684
10685
10686
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10684

def conversation_id
  @conversation_id
end

#parentString

Required. The parent resource of the conversation. Corresponds to the JSON property parent

Returns:

  • (String)


10689
10690
10691
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10689

def parent
  @parent
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



10700
10701
10702
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10700

def redaction_config
  @redaction_config
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



10708
10709
10710
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10708

def speech_config
  @speech_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10715
10716
10717
10718
10719
10720
10721
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10715

def update!(**args)
  @conversation = args[:conversation] if args.key?(:conversation)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @parent = args[:parent] if args.key?(:parent)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
end