Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1View

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The View resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1View

Returns a new instance of GoogleCloudContactcenterinsightsV1View.



11506
11507
11508
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this view was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11482
11483
11484
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11482

def create_time
  @create_time
end

#display_nameString

The human-readable display name of the view. Corresponds to the JSON property displayName

Returns:

  • (String)


11487
11488
11489
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11487

def display_name
  @display_name
end

#nameString

Immutable. The resource name of the view. Format: projects/project/locations/ location/views/view Corresponds to the JSON property name

Returns:

  • (String)


11493
11494
11495
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11493

def name
  @name
end

#update_timeString

Output only. The most recent time at which the view was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11498
11499
11500
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11498

def update_time
  @update_time
end

#valueString

A filter to reduce conversation results to a specific subset. Refer to https:// cloud.google.com/contact-center/insights/docs/filtering for details. Corresponds to the JSON property value

Returns:

  • (String)


11504
11505
11506
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11504

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11511
11512
11513
11514
11515
11516
11517
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11511

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value = args[:value] if args.key?(:value)
end