Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1View
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1View
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The View resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The human-readable display name of the view.
-
#name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#value ⇒ String
A filter to reduce conversation results to a specific subset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1View
constructor
A new instance of GoogleCloudContactcenterinsightsV1View.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1View
Returns a new instance of GoogleCloudContactcenterinsightsV1View.
9551 9552 9553 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this view was created.
Corresponds to the JSON property createTime
9527 9528 9529 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9527 def create_time @create_time end |
#display_name ⇒ String
The human-readable display name of the view.
Corresponds to the JSON property displayName
9532 9533 9534 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9532 def display_name @display_name end |
#name ⇒ String
Immutable. The resource name of the view. Format: projects/project/locations/
location/views/view
Corresponds to the JSON property name
9538 9539 9540 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9538 def name @name end |
#update_time ⇒ String
Output only. The most recent time at which the view was updated.
Corresponds to the JSON property updateTime
9543 9544 9545 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9543 def update_time @update_time end |
#value ⇒ String
A filter to reduce conversation results to a specific subset. Refer to https://
cloud.google.com/contact-center/insights/docs/filtering for details.
Corresponds to the JSON property value
9549 9550 9551 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9549 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9556 9557 9558 9559 9560 9561 9562 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9556 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @value = args[:value] if args.key?(:value) end |