Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The analysis resource.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnalysisResult
The result of an analysis.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#request_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Analysis
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Analysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Analysis
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Analysis.
10857 10858 10859 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnalysisResult
The result of an analysis.
Corresponds to the JSON property analysisResult
10833 10834 10835 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10833 def analysis_result @analysis_result end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
10838 10839 10840 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10838 def annotator_selector @annotator_selector end |
#create_time ⇒ String
Output only. The time at which the analysis was created, which occurs when the
long-running operation completes.
Corresponds to the JSON property createTime
10844 10845 10846 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10844 def create_time @create_time end |
#name ⇒ String
Immutable. The resource name of the analysis. Format: projects/project/
locations/location/conversations/conversation/analyses/analysis
Corresponds to the JSON property name
10850 10851 10852 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10850 def name @name end |
#request_time ⇒ String
Output only. The time at which the analysis was requested.
Corresponds to the JSON property requestTime
10855 10856 10857 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10855 def request_time @request_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10862 10863 10864 10865 10866 10867 10868 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10862 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) end |