Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The analysis resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Analysis

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Analysis.



7522
7523
7524
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnalysisResult

The result of an analysis. Corresponds to the JSON property analysisResult



7498
7499
7500
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7498

def analysis_result
  @analysis_result
end

#annotator_selectorGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector

Selector of all available annotators and phrase matchers to run. Corresponds to the JSON property annotatorSelector



7503
7504
7505
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7503

def annotator_selector
  @annotator_selector
end

#create_timeString

Output only. The time at which the analysis was created, which occurs when the long-running operation completes. Corresponds to the JSON property createTime

Returns:

  • (String)


7509
7510
7511
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7509

def create_time
  @create_time
end

#nameString

Immutable. The resource name of the analysis. Format: projects/project/ locations/location/conversations/conversation/analyses/analysis Corresponds to the JSON property name

Returns:

  • (String)


7515
7516
7517
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7515

def name
  @name
end

#request_timeString

Output only. The time at which the analysis was requested. Corresponds to the JSON property requestTime

Returns:

  • (String)


7520
7521
7522
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7520

def request_time
  @request_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7527
7528
7529
7530
7531
7532
7533
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7527

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
end