Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Call-specific metadata created during analysis.
Instance Attribute Summary collapse
-
#annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CallAnnotation>
A list of call annotations that apply to this call.
-
#entities ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Entity>
All the entities in the call.
-
#intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Intent>
All the matched intents in the call.
-
#issue_model_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelResult
Issue Modeling result on a conversation.
-
#phrase_matchers ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData>
All the matched phrase matchers in the call.
-
#qa_scorecard_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult>
Results of scoring QaScorecards.
-
#sentiments ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSentiment>
Overall conversation-level sentiment for each channel of the call.
-
#silence ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSilence
Conversation-level silence data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1AnalysisResultCallAnalysisMetadata.
7605 7606 7607 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CallAnnotation>
A list of call annotations that apply to this call.
Corresponds to the JSON property annotations
7568 7569 7570 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7568 def annotations @annotations end |
#entities ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Entity>
All the entities in the call.
Corresponds to the JSON property entities
7573 7574 7575 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7573 def entities @entities end |
#intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Intent>
All the matched intents in the call.
Corresponds to the JSON property intents
7578 7579 7580 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7578 def intents @intents end |
#issue_model_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueModelResult
Issue Modeling result on a conversation.
Corresponds to the JSON property issueModelResult
7583 7584 7585 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7583 def issue_model_result @issue_model_result end |
#phrase_matchers ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData>
All the matched phrase matchers in the call.
Corresponds to the JSON property phraseMatchers
7588 7589 7590 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7588 def phrase_matchers @phrase_matchers end |
#qa_scorecard_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult>
Results of scoring QaScorecards.
Corresponds to the JSON property qaScorecardResults
7593 7594 7595 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7593 def qa_scorecard_results @qa_scorecard_results end |
#sentiments ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSentiment>
Overall conversation-level sentiment for each channel of the call.
Corresponds to the JSON property sentiments
7598 7599 7600 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7598 def sentiments @sentiments end |
#silence ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationLevelSilence
Conversation-level silence data.
Corresponds to the JSON property silence
7603 7604 7605 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7603 def silence @silence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 7610 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @entities = args[:entities] if args.key?(:entities) @intents = args[:intents] if args.key?(:intents) @issue_model_result = args[:issue_model_result] if args.key?(:issue_model_result) @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers) @qa_scorecard_results = args[:qa_scorecard_results] if args.key?(:qa_scorecard_results) @sentiments = args[:sentiments] if args.key?(:sentiments) @silence = args[:silence] if args.key?(:silence) end |