Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Selector of all available annotators and phrase matchers to run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.



11079
11080
11081
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#issue_modelsArray<String>

The issue model to run. If not provided, the most recently deployed topic model will be used. The provided issue model will only be used for inference if the issue model is deployed and if run_issue_model_annotator is set to true. If more than one issue model is provided, only the first provided issue model will be used for inference. Corresponds to the JSON property issueModels

Returns:

  • (Array<String>)


10995
10996
10997
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10995

def issue_models
  @issue_models
end

#phrase_matchersArray<String>

The list of phrase matchers to run. If not provided, all active phrase matchers will be used. If inactive phrase matchers are provided, they will not be used. Phrase matchers will be run only if run_phrase_matcher_annotator is set to true. Format: projects/project/locations/location/phraseMatchers/ phrase_matcher Corresponds to the JSON property phraseMatchers

Returns:

  • (Array<String>)


11004
11005
11006
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11004

def phrase_matchers
  @phrase_matchers
end

#qa_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorQaConfig

Configuration for the QA feature. Corresponds to the JSON property qaConfig



11009
11010
11011
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11009

def qa_config
  @qa_config
end

#run_auto_labeling_annotatorBoolean Also known as: run_auto_labeling_annotator?

Optional. Whether to run the auto-labeling annotator. If true, the auto- labeling annotator will be run. This is a non-billable operation designed for fixing or backfilling custom labels. Corresponds to the JSON property runAutoLabelingAnnotator

Returns:

  • (Boolean)


11016
11017
11018
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11016

def run_auto_labeling_annotator
  @run_auto_labeling_annotator
end

#run_entity_annotatorBoolean Also known as: run_entity_annotator?

Whether to run the entity annotator. Corresponds to the JSON property runEntityAnnotator

Returns:

  • (Boolean)


11022
11023
11024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11022

def run_entity_annotator
  @run_entity_annotator
end

#run_intent_annotatorBoolean Also known as: run_intent_annotator?

Whether to run the intent annotator. Corresponds to the JSON property runIntentAnnotator

Returns:

  • (Boolean)


11028
11029
11030
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11028

def run_intent_annotator
  @run_intent_annotator
end

#run_interruption_annotatorBoolean Also known as: run_interruption_annotator?

Whether to run the interruption annotator. Corresponds to the JSON property runInterruptionAnnotator

Returns:

  • (Boolean)


11034
11035
11036
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11034

def run_interruption_annotator
  @run_interruption_annotator
end

#run_issue_model_annotatorBoolean Also known as: run_issue_model_annotator?

Whether to run the issue model annotator. A model should have already been deployed for this to take effect. Corresponds to the JSON property runIssueModelAnnotator

Returns:

  • (Boolean)


11041
11042
11043
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11041

def run_issue_model_annotator
  @run_issue_model_annotator
end

#run_phrase_matcher_annotatorBoolean Also known as: run_phrase_matcher_annotator?

Whether to run the active phrase matcher annotator(s). Corresponds to the JSON property runPhraseMatcherAnnotator

Returns:

  • (Boolean)


11047
11048
11049
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11047

def run_phrase_matcher_annotator
  @run_phrase_matcher_annotator
end

#run_qa_annotatorBoolean Also known as: run_qa_annotator?

Whether to run the QA annotator. Corresponds to the JSON property runQaAnnotator

Returns:

  • (Boolean)


11053
11054
11055
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11053

def run_qa_annotator
  @run_qa_annotator
end

#run_sentiment_annotatorBoolean Also known as: run_sentiment_annotator?

Whether to run the sentiment annotator. Corresponds to the JSON property runSentimentAnnotator

Returns:

  • (Boolean)


11059
11060
11061
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11059

def run_sentiment_annotator
  @run_sentiment_annotator
end

#run_silence_annotatorBoolean Also known as: run_silence_annotator?

Whether to run the silence annotator. Corresponds to the JSON property runSilenceAnnotator

Returns:

  • (Boolean)


11065
11066
11067
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11065

def run_silence_annotator
  @run_silence_annotator
end

#run_summarization_annotatorBoolean Also known as: run_summarization_annotator?

Whether to run the summarization annotator. Corresponds to the JSON property runSummarizationAnnotator

Returns:

  • (Boolean)


11071
11072
11073
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11071

def run_summarization_annotator
  @run_summarization_annotator
end

#summarization_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorSummarizationConfig

Configuration for summarization. Corresponds to the JSON property summarizationConfig



11077
11078
11079
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11077

def summarization_config
  @summarization_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11084
11085
11086
11087
11088
11089
11090
11091
11092
11093
11094
11095
11096
11097
11098
11099
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11084

def update!(**args)
  @issue_models = args[:issue_models] if args.key?(:issue_models)
  @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers)
  @qa_config = args[:qa_config] if args.key?(:qa_config)
  @run_auto_labeling_annotator = args[:run_auto_labeling_annotator] if args.key?(:run_auto_labeling_annotator)
  @run_entity_annotator = args[:run_entity_annotator] if args.key?(:run_entity_annotator)
  @run_intent_annotator = args[:run_intent_annotator] if args.key?(:run_intent_annotator)
  @run_interruption_annotator = args[:run_interruption_annotator] if args.key?(:run_interruption_annotator)
  @run_issue_model_annotator = args[:run_issue_model_annotator] if args.key?(:run_issue_model_annotator)
  @run_phrase_matcher_annotator = args[:run_phrase_matcher_annotator] if args.key?(:run_phrase_matcher_annotator)
  @run_qa_annotator = args[:run_qa_annotator] if args.key?(:run_qa_annotator)
  @run_sentiment_annotator = args[:run_sentiment_annotator] if args.key?(:run_sentiment_annotator)
  @run_silence_annotator = args[:run_silence_annotator] if args.key?(:run_silence_annotator)
  @run_summarization_annotator = args[:run_summarization_annotator] if args.key?(:run_summarization_annotator)
  @summarization_config = args[:summarization_config] if args.key?(:summarization_config)
end