Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Selector of all available annotators and phrase matchers to run.
Instance Attribute Summary collapse
-
#issue_models ⇒ Array<String>
The issue model to run.
-
#phrase_matchers ⇒ Array<String>
The list of phrase matchers to run.
-
#qa_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorQaConfig
Configuration for the QA feature.
-
#run_entity_annotator ⇒ Boolean
(also: #run_entity_annotator?)
Whether to run the entity annotator.
-
#run_intent_annotator ⇒ Boolean
(also: #run_intent_annotator?)
Whether to run the intent annotator.
-
#run_interruption_annotator ⇒ Boolean
(also: #run_interruption_annotator?)
Whether to run the interruption annotator.
-
#run_issue_model_annotator ⇒ Boolean
(also: #run_issue_model_annotator?)
Whether to run the issue model annotator.
-
#run_phrase_matcher_annotator ⇒ Boolean
(also: #run_phrase_matcher_annotator?)
Whether to run the active phrase matcher annotator(s).
-
#run_qa_annotator ⇒ Boolean
(also: #run_qa_annotator?)
Whether to run the QA annotator.
-
#run_sentiment_annotator ⇒ Boolean
(also: #run_sentiment_annotator?)
Whether to run the sentiment annotator.
-
#run_silence_annotator ⇒ Boolean
(also: #run_silence_annotator?)
Whether to run the silence annotator.
-
#run_summarization_annotator ⇒ Boolean
(also: #run_summarization_annotator?)
Whether to run the summarization annotator.
-
#summarization_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorSummarizationConfig
Configuration for summarization.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector.
9848 9849 9850 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issue_models ⇒ Array<String>
The issue model to run. If not provided, the most recently deployed topic
model will be used. The provided issue model will only be used for inference
if the issue model is deployed and if run_issue_model_annotator is set to true.
If more than one issue model is provided, only the first provided issue model
will be used for inference.
Corresponds to the JSON property issueModels
9772 9773 9774 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9772 def issue_models @issue_models end |
#phrase_matchers ⇒ Array<String>
The list of phrase matchers to run. If not provided, all active phrase
matchers will be used. If inactive phrase matchers are provided, they will not
be used. Phrase matchers will be run only if run_phrase_matcher_annotator is
set to true. Format: projects/project/locations/location/phraseMatchers/
phrase_matcher
Corresponds to the JSON property phraseMatchers
9781 9782 9783 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9781 def phrase_matchers @phrase_matchers end |
#qa_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorQaConfig
Configuration for the QA feature.
Corresponds to the JSON property qaConfig
9786 9787 9788 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9786 def qa_config @qa_config end |
#run_entity_annotator ⇒ Boolean Also known as: run_entity_annotator?
Whether to run the entity annotator.
Corresponds to the JSON property runEntityAnnotator
9791 9792 9793 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9791 def run_entity_annotator @run_entity_annotator end |
#run_intent_annotator ⇒ Boolean Also known as: run_intent_annotator?
Whether to run the intent annotator.
Corresponds to the JSON property runIntentAnnotator
9797 9798 9799 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9797 def run_intent_annotator @run_intent_annotator end |
#run_interruption_annotator ⇒ Boolean Also known as: run_interruption_annotator?
Whether to run the interruption annotator.
Corresponds to the JSON property runInterruptionAnnotator
9803 9804 9805 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9803 def run_interruption_annotator @run_interruption_annotator end |
#run_issue_model_annotator ⇒ Boolean Also known as: run_issue_model_annotator?
Whether to run the issue model annotator. A model should have already been
deployed for this to take effect.
Corresponds to the JSON property runIssueModelAnnotator
9810 9811 9812 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9810 def run_issue_model_annotator @run_issue_model_annotator end |
#run_phrase_matcher_annotator ⇒ Boolean Also known as: run_phrase_matcher_annotator?
Whether to run the active phrase matcher annotator(s).
Corresponds to the JSON property runPhraseMatcherAnnotator
9816 9817 9818 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9816 def run_phrase_matcher_annotator @run_phrase_matcher_annotator end |
#run_qa_annotator ⇒ Boolean Also known as: run_qa_annotator?
Whether to run the QA annotator.
Corresponds to the JSON property runQaAnnotator
9822 9823 9824 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9822 def run_qa_annotator @run_qa_annotator end |
#run_sentiment_annotator ⇒ Boolean Also known as: run_sentiment_annotator?
Whether to run the sentiment annotator.
Corresponds to the JSON property runSentimentAnnotator
9828 9829 9830 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9828 def run_sentiment_annotator @run_sentiment_annotator end |
#run_silence_annotator ⇒ Boolean Also known as: run_silence_annotator?
Whether to run the silence annotator.
Corresponds to the JSON property runSilenceAnnotator
9834 9835 9836 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9834 def run_silence_annotator @run_silence_annotator end |
#run_summarization_annotator ⇒ Boolean Also known as: run_summarization_annotator?
Whether to run the summarization annotator.
Corresponds to the JSON property runSummarizationAnnotator
9840 9841 9842 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9840 def run_summarization_annotator @run_summarization_annotator end |
#summarization_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelectorSummarizationConfig
Configuration for summarization.
Corresponds to the JSON property summarizationConfig
9846 9847 9848 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9846 def summarization_config @summarization_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 9864 9865 9866 9867 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9853 def update!(**args) @issue_models = args[:issue_models] if args.key?(:issue_models) @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers) @qa_config = args[:qa_config] if args.key?(:qa_config) @run_entity_annotator = args[:run_entity_annotator] if args.key?(:run_entity_annotator) @run_intent_annotator = args[:run_intent_annotator] if args.key?(:run_intent_annotator) @run_interruption_annotator = args[:run_interruption_annotator] if args.key?(:run_interruption_annotator) @run_issue_model_annotator = args[:run_issue_model_annotator] if args.key?(:run_issue_model_annotator) @run_phrase_matcher_annotator = args[:run_phrase_matcher_annotator] if args.key?(:run_phrase_matcher_annotator) @run_qa_annotator = args[:run_qa_annotator] if args.key?(:run_qa_annotator) @run_sentiment_annotator = args[:run_sentiment_annotator] if args.key?(:run_sentiment_annotator) @run_silence_annotator = args[:run_silence_annotator] if args.key?(:run_silence_annotator) @run_summarization_annotator = args[:run_summarization_annotator] if args.key?(:run_summarization_annotator) @summarization_config = args[:summarization_config] if args.key?(:summarization_config) end |