Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk analyze conversations operation.
Instance Attribute Summary collapse
-
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only.
-
#relabel ⇒ Boolean
(also: #relabel?)
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
-
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata.
11309 11310 11311 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
Corresponds to the JSON property completedAnalysesCount
11268 11269 11270 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11268 def completed_analyses_count @completed_analyses_count end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
11273 11274 11275 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11273 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
11278 11279 11280 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11278 def end_time @end_time end |
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
Corresponds to the JSON property failedAnalysesCount
11283 11284 11285 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11283 def failed_analyses_count @failed_analyses_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only. Partial errors during bulk analyze operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
11289 11290 11291 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11289 def partial_errors @partial_errors end |
#relabel ⇒ Boolean Also known as: relabel?
Output only. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
11295 11296 11297 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11295 def relabel @relabel end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
Corresponds to the JSON property request
11301 11302 11303 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11301 def request @request end |
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested. Computed by the number of conversations
returned by filter multiplied by analysis_percentage in the request.
Corresponds to the JSON property totalRequestedAnalysesCount
11307 11308 11309 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11307 def total_requested_analyses_count @total_requested_analyses_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11314 11315 11316 11317 11318 11319 11320 11321 11322 11323 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11314 def update!(**args) @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @relabel = args[:relabel] if args.key?(:relabel) @request = args[:request] if args.key?(:request) @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count) end |