Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for a bulk analyze conversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsMetadata.



10070
10071
10072
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_analyses_countFixnum

The number of requested analyses that have completed successfully so far. Corresponds to the JSON property completedAnalysesCount

Returns:

  • (Fixnum)


10036
10037
10038
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10036

def completed_analyses_count
  @completed_analyses_count
end

#create_timeString

The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10041
10042
10043
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10041

def create_time
  @create_time
end

#end_timeString

The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


10046
10047
10048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10046

def end_time
  @end_time
end

#failed_analyses_countFixnum

The number of requested analyses that have failed so far. Corresponds to the JSON property failedAnalysesCount

Returns:

  • (Fixnum)


10051
10052
10053
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10051

def failed_analyses_count
  @failed_analyses_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during bulk analyze operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



10057
10058
10059
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10057

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest

The request to analyze conversations in bulk. Corresponds to the JSON property request



10062
10063
10064
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10062

def request
  @request
end

#total_requested_analyses_countFixnum

Total number of analyses requested. Computed by the number of conversations returned by filter multiplied by analysis_percentage in the request. Corresponds to the JSON property totalRequestedAnalysesCount

Returns:

  • (Fixnum)


10068
10069
10070
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10068

def total_requested_analyses_count
  @total_requested_analyses_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10075
10076
10077
10078
10079
10080
10081
10082
10083
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10075

def update!(**args)
  @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
  @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count)
end