Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversations in bulk.
Instance Attribute Summary collapse
-
#analysis_percentage ⇒ Float
Required.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#filter ⇒ String
Required.
-
#parent ⇒ String
Required.
-
#relabel ⇒ Boolean
(also: #relabel?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkAnalyzeConversationsRequest.
11357 11358 11359 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_percentage ⇒ Float
Required. Percentage of selected conversation to analyze, between [0, 100].
Corresponds to the JSON property analysisPercentage
11333 11334 11335 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11333 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
11338 11339 11340 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11338 def annotator_selector @annotator_selector end |
#filter ⇒ String
Required. Filter used to select the subset of conversations to analyze.
Corresponds to the JSON property filter
11343 11344 11345 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11343 def filter @filter end |
#parent ⇒ String
Required. The parent resource to create analyses in.
Corresponds to the JSON property parent
11348 11349 11350 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11348 def parent @parent end |
#relabel ⇒ Boolean Also known as: relabel?
Optional. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
11354 11355 11356 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11354 def relabel @relabel end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11362 11363 11364 11365 11366 11367 11368 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11362 def update!(**args) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @filter = args[:filter] if args.key?(:filter) @parent = args[:parent] if args.key?(:parent) @relabel = args[:relabel] if args.key?(:relabel) end |