Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk delete conversations operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during bulk delete conversations operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsMetadata.
8061 8062 8063 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
8043 8044 8045 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8043 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
8048 8049 8050 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8048 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during bulk delete conversations operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
8054 8055 8056 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8054 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
Corresponds to the JSON property request
8059 8060 8061 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8059 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8066 8067 8068 8069 8070 8071 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8066 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |