Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to delete conversations in bulk.
Instance Attribute Summary collapse
-
#filter ⇒ String
Filter used to select the subset of conversations to delete.
-
#force ⇒ Boolean
(also: #force?)
If set to true, all of this conversation's analyses will also be deleted.
-
#max_delete_count ⇒ Fixnum
Maximum number of conversations to delete.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.
11031 11032 11033 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Filter used to select the subset of conversations to delete.
Corresponds to the JSON property filter
11011 11012 11013 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11011 def filter @filter end |
#force ⇒ Boolean Also known as: force?
If set to true, all of this conversation's analyses will also be deleted.
Otherwise, the request will only succeed if the conversation has no analyses.
Corresponds to the JSON property force
11017 11018 11019 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11017 def force @force end |
#max_delete_count ⇒ Fixnum
Maximum number of conversations to delete.
Corresponds to the JSON property maxDeleteCount
11023 11024 11025 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11023 def max_delete_count @max_delete_count end |
#parent ⇒ String
Required. The parent resource to delete conversations from. Format: projects/
project/locations/location
Corresponds to the JSON property parent
11029 11030 11031 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11029 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11036 11037 11038 11039 11040 11041 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11036 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count) @parent = args[:parent] if args.key?(:parent) end |