Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to delete conversations in bulk.
Instance Attribute Summary collapse
-
#filter ⇒ String
Filter used to select the subset of conversations to delete.
-
#force ⇒ Boolean
(also: #force?)
If set to true, all of this conversation's analyses will also be deleted.
-
#max_delete_count ⇒ Fixnum
Maximum number of conversations to delete.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.
10838 10839 10840 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Filter used to select the subset of conversations to delete.
Corresponds to the JSON property filter
10818 10819 10820 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10818 def filter @filter end |
#force ⇒ Boolean Also known as: force?
If set to true, all of this conversation's analyses will also be deleted.
Otherwise, the request will only succeed if the conversation has no analyses.
Corresponds to the JSON property force
10824 10825 10826 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10824 def force @force end |
#max_delete_count ⇒ Fixnum
Maximum number of conversations to delete.
Corresponds to the JSON property maxDeleteCount
10830 10831 10832 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10830 def max_delete_count @max_delete_count end |
#parent ⇒ String
Required. The parent resource to delete conversations from. Format: projects/
project/locations/location
Corresponds to the JSON property parent
10836 10837 10838 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10836 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10843 10844 10845 10846 10847 10848 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10843 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count) @parent = args[:parent] if args.key?(:parent) end |