Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteConversationsRequest.



8101
8102
8103
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


8081
8082
8083
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8081

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


8087
8088
8089
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8087

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


8093
8094
8095
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8093

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


8099
8100
8101
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8099

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8106
8107
8108
8109
8110
8111
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8106

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end