Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for the BulkDeleteFeedbackLabels endpoint.
Instance Attribute Summary collapse
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during deletion operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsRequest
Request for the BulkDeleteFeedbackLabels endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsMetadata.
8142 8143 8144 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during deletion operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
8135 8136 8137 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8135 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1BulkDeleteFeedbackLabelsRequest
Request for the BulkDeleteFeedbackLabels endpoint.
Corresponds to the JSON property request
8140 8141 8142 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8140 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8147 8148 8149 8150 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 8147 def update!(**args) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |