Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CallAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CallAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A piece of metadata that applies to a window of a call.
Instance Attribute Summary collapse
-
#annotation_end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#annotation_start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#channel_tag ⇒ Fixnum
The channel of the audio where the annotation occurs.
-
#entity_mention_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1EntityMentionData
The data for an entity mention annotation.
-
#hold_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1HoldData
The data for a hold annotation.
-
#intent_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IntentMatchData
The data for an intent match.
-
#interruption_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InterruptionData
The data for an interruption annotation.
-
#issue_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueMatchData
The data for an issue match annotation.
-
#phrase_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData
The data for a matched phrase matcher.
-
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
-
#silence_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SilenceData
The data for a silence annotation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CallAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1CallAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CallAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CallAnnotation.
12351 12352 12353 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property annotationEndBoundary
12294 12295 12296 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12294 def annotation_end_boundary @annotation_end_boundary end |
#annotation_start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property annotationStartBoundary
12299 12300 12301 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12299 def annotation_start_boundary @annotation_start_boundary end |
#channel_tag ⇒ Fixnum
The channel of the audio where the annotation occurs. For single-channel audio,
this field is not populated.
Corresponds to the JSON property channelTag
12305 12306 12307 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12305 def channel_tag @channel_tag end |
#entity_mention_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1EntityMentionData
The data for an entity mention annotation. This represents a mention of an
Entity in the conversation.
Corresponds to the JSON property entityMentionData
12311 12312 12313 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12311 def entity_mention_data @entity_mention_data end |
#hold_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1HoldData
The data for a hold annotation.
Corresponds to the JSON property holdData
12316 12317 12318 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12316 def hold_data @hold_data end |
#intent_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IntentMatchData
The data for an intent match. Represents an intent match for a text segment in
the conversation. A text segment can be part of a sentence, a complete
sentence, or an utterance with multiple sentences.
Corresponds to the JSON property intentMatchData
12323 12324 12325 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12323 def intent_match_data @intent_match_data end |
#interruption_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InterruptionData
The data for an interruption annotation.
Corresponds to the JSON property interruptionData
12328 12329 12330 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12328 def interruption_data @interruption_data end |
#issue_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueMatchData
The data for an issue match annotation.
Corresponds to the JSON property issueMatchData
12333 12334 12335 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12333 def issue_match_data @issue_match_data end |
#phrase_match_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData
The data for a matched phrase matcher. Represents information identifying a
phrase matcher for a given match.
Corresponds to the JSON property phraseMatchData
12339 12340 12341 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12339 def phrase_match_data @phrase_match_data end |
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentimentData
12344 12345 12346 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12344 def sentiment_data @sentiment_data end |
#silence_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SilenceData
The data for a silence annotation.
Corresponds to the JSON property silenceData
12349 12350 12351 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12349 def silence_data @silence_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12356 12357 12358 12359 12360 12361 12362 12363 12364 12365 12366 12367 12368 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12356 def update!(**args) @annotation_end_boundary = args[:annotation_end_boundary] if args.key?(:annotation_end_boundary) @annotation_start_boundary = args[:annotation_start_boundary] if args.key?(:annotation_start_boundary) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @entity_mention_data = args[:entity_mention_data] if args.key?(:entity_mention_data) @hold_data = args[:hold_data] if args.key?(:hold_data) @intent_match_data = args[:intent_match_data] if args.key?(:intent_match_data) @interruption_data = args[:interruption_data] if args.key?(:interruption_data) @issue_match_data = args[:issue_match_data] if args.key?(:issue_match_data) @phrase_match_data = args[:phrase_match_data] if args.key?(:phrase_match_data) @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data) @silence_data = args[:silence_data] if args.key?(:silence_data) end |