Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CallAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A piece of metadata that applies to a window of a call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CallAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CallAnnotation.



11619
11620
11621
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationEndBoundary



11562
11563
11564
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11562

def annotation_end_boundary
  @annotation_end_boundary
end

#annotation_start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationStartBoundary



11567
11568
11569
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11567

def annotation_start_boundary
  @annotation_start_boundary
end

#channel_tagFixnum

The channel of the audio where the annotation occurs. For single-channel audio, this field is not populated. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


11573
11574
11575
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11573

def channel_tag
  @channel_tag
end

#entity_mention_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1EntityMentionData

The data for an entity mention annotation. This represents a mention of an Entity in the conversation. Corresponds to the JSON property entityMentionData



11579
11580
11581
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11579

def entity_mention_data
  @entity_mention_data
end

#hold_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1HoldData

The data for a hold annotation. Corresponds to the JSON property holdData



11584
11585
11586
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11584

def hold_data
  @hold_data
end

#intent_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IntentMatchData

The data for an intent match. Represents an intent match for a text segment in the conversation. A text segment can be part of a sentence, a complete sentence, or an utterance with multiple sentences. Corresponds to the JSON property intentMatchData



11591
11592
11593
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11591

def intent_match_data
  @intent_match_data
end

#interruption_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1InterruptionData

The data for an interruption annotation. Corresponds to the JSON property interruptionData



11596
11597
11598
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11596

def interruption_data
  @interruption_data
end

#issue_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IssueMatchData

The data for an issue match annotation. Corresponds to the JSON property issueMatchData



11601
11602
11603
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11601

def issue_match_data
  @issue_match_data
end

#phrase_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1PhraseMatchData

The data for a matched phrase matcher. Represents information identifying a phrase matcher for a given match. Corresponds to the JSON property phraseMatchData



11607
11608
11609
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11607

def phrase_match_data
  @phrase_match_data
end

#sentiment_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentimentData



11612
11613
11614
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11612

def sentiment_data
  @sentiment_data
end

#silence_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SilenceData

The data for a silence annotation. Corresponds to the JSON property silenceData



11617
11618
11619
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11617

def silence_data
  @silence_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11624
11625
11626
11627
11628
11629
11630
11631
11632
11633
11634
11635
11636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11624

def update!(**args)
  @annotation_end_boundary = args[:annotation_end_boundary] if args.key?(:annotation_end_boundary)
  @annotation_start_boundary = args[:annotation_start_boundary] if args.key?(:annotation_start_boundary)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @entity_mention_data = args[:entity_mention_data] if args.key?(:entity_mention_data)
  @hold_data = args[:hold_data] if args.key?(:hold_data)
  @intent_match_data = args[:intent_match_data] if args.key?(:intent_match_data)
  @interruption_data = args[:interruption_data] if args.key?(:interruption_data)
  @issue_match_data = args[:issue_match_data] if args.key?(:issue_match_data)
  @phrase_match_data = args[:phrase_match_data] if args.key?(:phrase_match_data)
  @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data)
  @silence_data = args[:silence_data] if args.key?(:silence_data)
end