Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CES end session annotation.
Instance Attribute Summary collapse
-
#end_session ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainEndSession
Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation.
11651 11652 11653 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_session ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainEndSession
Indicates the session has terminated, due to either successful completion (e.g.
user says "Good bye!" ) or an agent escalation. The agent will not process
any further inputs after session is terminated and the client should half-
close and disconnect after receiving all remaining responses from the agent.
Corresponds to the JSON property endSession
11649 11650 11651 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11649 def end_session @end_session end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11656 11657 11658 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11656 def update!(**args) @end_session = args[:end_session] if args.key?(:end_session) end |