Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The CES diagnostic information.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
-
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation.
11675 11676 11677 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainMessage>
The messages in the turn.
Corresponds to the JSON property messages
11668 11669 11670 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11668 def @messages end |
#root_span ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainSpan
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
11673 11674 11675 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11673 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11680 11681 11682 11683 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11680 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |