Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Conversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Conversation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Conversation.



11260
11261
11262
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


11139
11140
11141
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11139

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



11144
11145
11146
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11144

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



11149
11150
11151
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11149

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11154
11155
11156
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11154

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



11159
11160
11161
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11159

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



11166
11167
11168
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11166

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


11171
11172
11173
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11171

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


11177
11178
11179
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11177

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11183
11184
11185
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11183

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


11188
11189
11190
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11188

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis

The analysis resource. Corresponds to the JSON property latestAnalysis



11193
11194
11195
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11193

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



11198
11199
11200
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11198

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


11203
11204
11205
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11203

def medium
  @medium
end

#metadata_jsonString

Optional. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


11210
11211
11212
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11210

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


11216
11217
11218
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11216

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


11221
11222
11223
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11221

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



11226
11227
11228
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11226

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



11232
11233
11234
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11232

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


11237
11238
11239
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11237

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



11242
11243
11244
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11242

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


11248
11249
11250
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11248

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


11253
11254
11255
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11253

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11258
11259
11260
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11258

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11265
11266
11267
11268
11269
11270
11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11265

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end