Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Conversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Conversation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Conversation.



12615
12616
12617
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


12494
12495
12496
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12494

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



12499
12500
12501
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12499

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



12504
12505
12506
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12504

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12509
12510
12511
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12509

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



12514
12515
12516
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12514

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



12521
12522
12523
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12521

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


12526
12527
12528
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12526

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


12532
12533
12534
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12532

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


12538
12539
12540
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12538

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


12543
12544
12545
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12543

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis

The analysis resource. Corresponds to the JSON property latestAnalysis



12548
12549
12550
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12548

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



12553
12554
12555
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12553

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


12558
12559
12560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12558

def medium
  @medium
end

#metadata_jsonString

Input only. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


12565
12566
12567
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12565

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


12571
12572
12573
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12571

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


12576
12577
12578
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12576

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



12581
12582
12583
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12581

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



12587
12588
12589
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12587

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


12592
12593
12594
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12592

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



12597
12598
12599
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12597

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


12603
12604
12605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12603

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


12608
12609
12610
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12608

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12613
12614
12615
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12613

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
12634
12635
12636
12637
12638
12639
12640
12641
12642
12643
12644
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12620

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end