Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Conversation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Conversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation resource.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
An opaque, user-specified string representing the human agent who handled the conversation.
-
#call_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata
Call-specific metadata.
-
#correlation_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo
Info for correlating across conversations.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource
The conversation source, which is a combination of transcript and audio.
-
#dialogflow_intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent>
Output only.
-
#duration ⇒ String
Output only.
-
#expire_time ⇒ String
The time at which this conversation should expire.
-
#labels ⇒ Hash<String,String>
A map for the user to specify any custom fields.
-
#language_code ⇒ String
A user-specified language code for the conversation.
-
#latest_analysis ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis
The analysis resource.
-
#latest_summary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
-
#medium ⇒ String
Immutable.
-
#metadata_json ⇒ String
Input only.
-
#name ⇒ String
Immutable.
-
#obfuscated_user_id ⇒ String
Obfuscated user ID which the customer sent to us.
-
#quality_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
Conversation metadata related to quality management.
-
#runtime_annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation>
Output only.
-
#start_time ⇒ String
The time at which the conversation started.
-
#transcript ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript
A message representing the transcript of a conversation.
-
#ttl ⇒ String
Input only.
-
#turn_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Conversation
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Conversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Conversation
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Conversation.
11883 11884 11885 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
An opaque, user-specified string representing the human agent who handled the
conversation.
Corresponds to the JSON property agentId
11762 11763 11764 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11762 def agent_id @agent_id end |
#call_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata
Call-specific metadata.
Corresponds to the JSON property callMetadata
11767 11768 11769 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11767 def @call_metadata end |
#correlation_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo
Info for correlating across conversations.
Corresponds to the JSON property correlationInfo
11772 11773 11774 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11772 def correlation_info @correlation_info end |
#create_time ⇒ String
Output only. The time at which the conversation was created.
Corresponds to the JSON property createTime
11777 11778 11779 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11777 def create_time @create_time end |
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource
The conversation source, which is a combination of transcript and audio.
Corresponds to the JSON property dataSource
11782 11783 11784 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11782 def data_source @data_source end |
#dialogflow_intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent>
Output only. All the matched Dialogflow intents in the call. The key
corresponds to a Dialogflow intent, format: projects/project/agent/agent/
intents/intent
Corresponds to the JSON property dialogflowIntents
11789 11790 11791 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11789 def dialogflow_intents @dialogflow_intents end |
#duration ⇒ String
Output only. The duration of the conversation.
Corresponds to the JSON property duration
11794 11795 11796 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11794 def duration @duration end |
#expire_time ⇒ String
The time at which this conversation should expire. After this time, the
conversation data and any associated analyses will be deleted.
Corresponds to the JSON property expireTime
11800 11801 11802 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11800 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
A map for the user to specify any custom fields. A maximum of 100 labels per
conversation is allowed, with a maximum of 256 characters per entry.
Corresponds to the JSON property labels
11806 11807 11808 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11806 def labels @labels end |
#language_code ⇒ String
A user-specified language code for the conversation.
Corresponds to the JSON property languageCode
11811 11812 11813 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11811 def language_code @language_code end |
#latest_analysis ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis
The analysis resource.
Corresponds to the JSON property latestAnalysis
11816 11817 11818 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11816 def latest_analysis @latest_analysis end |
#latest_summary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
Corresponds to the JSON property latestSummary
11821 11822 11823 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11821 def latest_summary @latest_summary end |
#medium ⇒ String
Immutable. The conversation medium.
Corresponds to the JSON property medium
11826 11827 11828 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11826 def medium @medium end |
#metadata_json ⇒ String
Input only. JSON metadata encoded as a string. This field is primarily used by
Insights integrations with various telephony systems and must be in one of
Insight's supported formats.
Corresponds to the JSON property metadataJson
11833 11834 11835 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11833 def @metadata_json end |
#name ⇒ String
Immutable. The resource name of the conversation. Format: projects/project/
locations/location/conversations/conversation
Corresponds to the JSON property name
11839 11840 11841 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11839 def name @name end |
#obfuscated_user_id ⇒ String
Obfuscated user ID which the customer sent to us.
Corresponds to the JSON property obfuscatedUserId
11844 11845 11846 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11844 def @obfuscated_user_id end |
#quality_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
Conversation metadata related to quality management.
Corresponds to the JSON property qualityMetadata
11849 11850 11851 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11849 def @quality_metadata end |
#runtime_annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation>
Output only. The annotations that were generated during the customer and agent
interaction.
Corresponds to the JSON property runtimeAnnotations
11855 11856 11857 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11855 def runtime_annotations @runtime_annotations end |
#start_time ⇒ String
The time at which the conversation started.
Corresponds to the JSON property startTime
11860 11861 11862 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11860 def start_time @start_time end |
#transcript ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript
A message representing the transcript of a conversation.
Corresponds to the JSON property transcript
11865 11866 11867 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11865 def transcript @transcript end |
#ttl ⇒ String
Input only. The TTL for this resource. If specified, then this TTL will be
used to calculate the expire time.
Corresponds to the JSON property ttl
11871 11872 11873 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11871 def ttl @ttl end |
#turn_count ⇒ Fixnum
Output only. The number of turns in the conversation.
Corresponds to the JSON property turnCount
11876 11877 11878 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11876 def turn_count @turn_count end |
#update_time ⇒ String
Output only. The most recent time at which the conversation was updated.
Corresponds to the JSON property updateTime
11881 11882 11883 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11881 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11888 11889 11890 11891 11892 11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11888 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @call_metadata = args[:call_metadata] if args.key?(:call_metadata) @correlation_info = args[:correlation_info] if args.key?(:correlation_info) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents) @duration = args[:duration] if args.key?(:duration) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @language_code = args[:language_code] if args.key?(:language_code) @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis) @latest_summary = args[:latest_summary] if args.key?(:latest_summary) @medium = args[:medium] if args.key?(:medium) @metadata_json = args[:metadata_json] if args.key?(:metadata_json) @name = args[:name] if args.key?(:name) @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id) @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata) @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations) @start_time = args[:start_time] if args.key?(:start_time) @transcript = args[:transcript] if args.key?(:transcript) @ttl = args[:ttl] if args.key?(:ttl) @turn_count = args[:turn_count] if args.key?(:turn_count) @update_time = args[:update_time] if args.key?(:update_time) end |