Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Conversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Conversation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Conversation.



10588
10589
10590
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


10467
10468
10469
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10467

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



10472
10473
10474
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10472

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



10477
10478
10479
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10477

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10482
10483
10484
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10482

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



10487
10488
10489
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10487

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



10494
10495
10496
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10494

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


10499
10500
10501
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10499

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


10505
10506
10507
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10505

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


10511
10512
10513
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10511

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


10516
10517
10518
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10516

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Analysis

The analysis resource. Corresponds to the JSON property latestAnalysis



10521
10522
10523
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10521

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



10526
10527
10528
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10526

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


10531
10532
10533
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10531

def medium
  @medium
end

#metadata_jsonString

Input only. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


10538
10539
10540
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10538

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


10544
10545
10546
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10544

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


10549
10550
10551
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10549

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



10554
10555
10556
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10554

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



10560
10561
10562
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10560

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


10565
10566
10567
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10565

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



10570
10571
10572
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10570

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


10576
10577
10578
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10576

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


10581
10582
10583
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10581

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10586
10587
10588
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10586

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
10617
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10593

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end