Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Info for correlating across conversations.
Instance Attribute Summary collapse
-
#correlation_types ⇒ Array<String>
Output only.
-
#full_conversation_correlation_id ⇒ String
Output only.
-
#merged_full_conversation_correlation_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationInfo.
10668 10669 10670 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#correlation_types ⇒ Array<String>
Output only. The correlation types of this conversation. A single conversation
can have multiple correlation types. For example a conversation that only has
a single segment is both a SEGMENT and a FULL_CONVERSATION.
Corresponds to the JSON property correlationTypes
10654 10655 10656 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10654 def correlation_types @correlation_types end |
#full_conversation_correlation_id ⇒ String
Output only. The full conversation correlation id this conversation is a
segment of.
Corresponds to the JSON property fullConversationCorrelationId
10660 10661 10662 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10660 def full_conversation_correlation_id @full_conversation_correlation_id end |
#merged_full_conversation_correlation_id ⇒ String
Output only. The full conversation correlation id this conversation is a
merged conversation of.
Corresponds to the JSON property mergedFullConversationCorrelationId
10666 10667 10668 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10666 def merged_full_conversation_correlation_id @merged_full_conversation_correlation_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10673 10674 10675 10676 10677 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10673 def update!(**args) @correlation_types = args[:correlation_types] if args.key?(:correlation_types) @full_conversation_correlation_id = args[:full_conversation_correlation_id] if args.key?(:full_conversation_correlation_id) @merged_full_conversation_correlation_id = args[:merged_full_conversation_correlation_id] if args.key?(:merged_full_conversation_correlation_id) end |