Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResultRuleCorrelationResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResultRuleCorrelationResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The result of a single correlation rule.
Instance Attribute Summary collapse
-
#correlation_id ⇒ String
The correlation ID generated by the join key expression.
-
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#rule_id ⇒ String
The rule ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResultRuleCorrelationResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResultRuleCorrelationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResultRuleCorrelationResult
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResultRuleCorrelationResult.
11594 11595 11596 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#correlation_id ⇒ String
The correlation ID generated by the join key expression.
Corresponds to the JSON property correlationId
11577 11578 11579 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11577 def correlation_id @correlation_id end |
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
11587 11588 11589 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11587 def error @error end |
#rule_id ⇒ String
The rule ID.
Corresponds to the JSON property ruleId
11592 11593 11594 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11592 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11599 11600 11601 11602 11603 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11599 def update!(**args) @correlation_id = args[:correlation_id] if args.key?(:correlation_id) @error = args[:error] if args.key?(:error) @rule_id = args[:rule_id] if args.key?(:rule_id) end |