Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation source, which is a combination of transcript and audio.
Instance Attribute Summary collapse
-
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowSource
A Dialogflow source of conversation data.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource
A Cloud Storage source of conversation data.
-
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation metadata.
-
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio for each turn.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource.
12865 12866 12867 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowSource
A Dialogflow source of conversation data.
Corresponds to the JSON property dialogflowSource
12845 12846 12847 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12845 def dialogflow_source @dialogflow_source end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource
A Cloud Storage source of conversation data.
Corresponds to the JSON property gcsSource
12850 12851 12852 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12850 def gcs_source @gcs_source end |
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation
metadata.
Corresponds to the JSON property metadataUri
12856 12857 12858 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12856 def @metadata_uri end |
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio
for each turn. Assume the order of the URIs is the same as the order of the
transcript turns.
Corresponds to the JSON property turnLevelAudios
12863 12864 12865 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12863 def turn_level_audios @turn_level_audios end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12870 12871 12872 12873 12874 12875 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12870 def update!(**args) @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri) @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios) end |