Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation source, which is a combination of transcript and audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationDataSource.



10761
10762
10763
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialogflow_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowSource

A Dialogflow source of conversation data. Corresponds to the JSON property dialogflowSource



10748
10749
10750
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10748

def dialogflow_source
  @dialogflow_source
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource

A Cloud Storage source of conversation data. Corresponds to the JSON property gcsSource



10753
10754
10755
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10753

def gcs_source
  @gcs_source
end

#metadata_uriString

Cloud Storage URI that points to a file that contains the conversation metadata. Corresponds to the JSON property metadataUri

Returns:

  • (String)


10759
10760
10761
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10759

def 
  @metadata_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10766
10767
10768
10769
10770
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10766

def update!(**args)
  @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri)
end