Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation metadata related to quality management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata.



13028
13029
13030
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_infoArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo>

Information about agents involved in the call. Corresponds to the JSON property agentInfo



13006
13007
13008
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13006

def agent_info
  @agent_info
end

#customer_satisfaction_ratingFixnum

An arbitrary integer value indicating the customer's satisfaction rating. Corresponds to the JSON property customerSatisfactionRating

Returns:

  • (Fixnum)


13011
13012
13013
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13011

def customer_satisfaction_rating
  @customer_satisfaction_rating
end

#feedback_labelsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel>

Input only. The feedback labels associated with the conversation. Corresponds to the JSON property feedbackLabels



13016
13017
13018
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13016

def feedback_labels
  @feedback_labels
end

An arbitrary string value specifying the menu path the customer took. Corresponds to the JSON property menuPath

Returns:

  • (String)


13021
13022
13023
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13021

def menu_path
  @menu_path
end

#wait_durationString

The amount of time the customer waited to connect with an agent. Corresponds to the JSON property waitDuration

Returns:

  • (String)


13026
13027
13028
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13026

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13033
13034
13035
13036
13037
13038
13039
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13033

def update!(**args)
  @agent_info = args[:agent_info] if args.key?(:agent_info)
  @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating)
  @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels)
  @menu_path = args[:menu_path] if args.key?(:menu_path)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end