Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation metadata related to quality management.
Instance Attribute Summary collapse
-
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
-
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
-
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel>
Input only.
-
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
-
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadata.
10898 10899 10900 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
Corresponds to the JSON property agentInfo
10876 10877 10878 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10876 def agent_info @agent_info end |
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
Corresponds to the JSON property customerSatisfactionRating
10881 10882 10883 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10881 def @customer_satisfaction_rating end |
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel>
Input only. The feedback labels associated with the conversation.
Corresponds to the JSON property feedbackLabels
10886 10887 10888 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10886 def feedback_labels @feedback_labels end |
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
Corresponds to the JSON property menuPath
10891 10892 10893 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10891 def @menu_path end |
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Corresponds to the JSON property waitDuration
10896 10897 10898 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10896 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10903 10904 10905 10906 10907 10908 10909 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10903 def update!(**args) @agent_info = args[:agent_info] if args.key?(:agent_info) @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @menu_path = args[:menu_path] if args.key?(:menu_path) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |