Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation summarization suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData.



13179
13180
13181
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property answerRecord

Returns:

  • (String)


13143
13144
13145
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13143

def answer_record
  @answer_record
end

#confidenceFloat

The confidence score of the summarization. Corresponds to the JSON property confidence

Returns:

  • (Float)


13148
13149
13150
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13148

def confidence
  @confidence
end

#conversation_modelString

The name of the model that generates this summary. Format: projects/project/ locations/location/conversationModels/conversation_model Corresponds to the JSON property conversationModel

Returns:

  • (String)


13154
13155
13156
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13154

def conversation_model
  @conversation_model
end

#generator_idString

Agent Assist generator ID. Corresponds to the JSON property generatorId

Returns:

  • (String)


13159
13160
13161
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13159

def generator_id
  @generator_id
end

#metadataHash<String,String>

A map that contains metadata about the summarization and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


13165
13166
13167
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13165

def 
  @metadata
end

#textString

The summarization content that is concatenated into one string. Corresponds to the JSON property text

Returns:

  • (String)


13170
13171
13172
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13170

def text
  @text
end

#text_sectionsHash<String,String>

The summarization content that is divided into sections. The key is the section's name and the value is the section's content. There is no specific format for the key or value. Corresponds to the JSON property textSections

Returns:

  • (Hash<String,String>)


13177
13178
13179
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13177

def text_sections
  @text_sections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13184
13185
13186
13187
13188
13189
13190
13191
13192
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13184

def update!(**args)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @confidence = args[:confidence] if args.key?(:confidence)
  @conversation_model = args[:conversation_model] if args.key?(:conversation_model)
  @generator_id = args[:generator_id] if args.key?(:generator_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @text = args[:text] if args.key?(:text)
  @text_sections = args[:text_sections] if args.key?(:text_sections)
end