Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A segment of a full transcript.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel.
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment.
-
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
-
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag.
-
#message_time ⇒ String
The time that the message occurred, if provided.
-
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant
The call participant speaking for a given utterance.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
-
#text ⇒ String
The text of this segment.
-
#turn_level_audio ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
-
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment.
13197 13198 13199 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number
corresponding to the audio from that channel. For audioChannelCount = N, its
output values can range from '1' to 'N'. A channel tag of 0 indicates that the
audio is mono.
Corresponds to the JSON property channelTag
13148 13149 13150 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13148 def channel_tag @channel_tag end |
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
13154 13155 13156 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13154 def confidence @confidence end |
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
Corresponds to the JSON property dialogflowSegmentMetadata
13159 13160 13161 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13159 def @dialogflow_segment_metadata end |
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag. Example: "en-US".
Corresponds to the JSON property languageCode
13165 13166 13167 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13165 def language_code @language_code end |
#message_time ⇒ String
The time that the message occurred, if provided.
Corresponds to the JSON property messageTime
13170 13171 13172 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13170 def @message_time end |
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant
The call participant speaking for a given utterance.
Corresponds to the JSON property segmentParticipant
13175 13176 13177 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13175 def segment_participant @segment_participant end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
13180 13181 13182 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13180 def sentiment @sentiment end |
#text ⇒ String
The text of this segment.
Corresponds to the JSON property text
13185 13186 13187 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13185 def text @text end |
#turn_level_audio ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
Corresponds to the JSON property turnLevelAudio
13190 13191 13192 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13190 def turn_level_audio @turn_level_audio end |
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Corresponds to the JSON property words
13195 13196 13197 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13195 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13202 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @confidence = args[:confidence] if args.key?(:confidence) @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata) @language_code = args[:language_code] if args.key?(:language_code) @message_time = args[:message_time] if args.key?(:message_time) @segment_participant = args[:segment_participant] if args.key?(:segment_participant) @sentiment = args[:sentiment] if args.key?(:sentiment) @text = args[:text] if args.key?(:text) @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio) @words = args[:words] if args.key?(:words) end |