Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A segment of a full transcript.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel.
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment.
-
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
-
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag.
-
#message_time ⇒ String
The time that the message occurred, if provided.
-
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant
The call participant speaking for a given utterance.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
-
#text ⇒ String
The text of this segment.
-
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegment.
11126 11127 11128 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number
corresponding to the audio from that channel. For audioChannelCount = N, its
output values can range from '1' to 'N'. A channel tag of 0 indicates that the
audio is mono.
Corresponds to the JSON property channelTag
11082 11083 11084 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11082 def channel_tag @channel_tag end |
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
11088 11089 11090 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11088 def confidence @confidence end |
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
Corresponds to the JSON property dialogflowSegmentMetadata
11093 11094 11095 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11093 def @dialogflow_segment_metadata end |
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag. Example: "en-US".
Corresponds to the JSON property languageCode
11099 11100 11101 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11099 def language_code @language_code end |
#message_time ⇒ String
The time that the message occurred, if provided.
Corresponds to the JSON property messageTime
11104 11105 11106 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11104 def @message_time end |
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationParticipant
The call participant speaking for a given utterance.
Corresponds to the JSON property segmentParticipant
11109 11110 11111 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11109 def segment_participant @segment_participant end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
11114 11115 11116 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11114 def sentiment @sentiment end |
#text ⇒ String
The text of this segment.
Corresponds to the JSON property text
11119 11120 11121 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11119 def text @text end |
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Corresponds to the JSON property words
11124 11125 11126 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11124 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11131 11132 11133 11134 11135 11136 11137 11138 11139 11140 11141 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11131 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @confidence = args[:confidence] if args.key?(:confidence) @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata) @language_code = args[:language_code] if args.key?(:language_code) @message_time = args[:message_time] if args.key?(:message_time) @segment_participant = args[:segment_participant] if args.key?(:segment_participant) @sentiment = args[:sentiment] if args.key?(:sentiment) @text = args[:text] if args.key?(:text) @words = args[:words] if args.key?(:words) end |