Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Word-level info for words in a transcript.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ConversationTranscriptTranscriptSegmentWordInfo.



11192
11193
11194
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11192

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

A confidence estimate between 0.0 and 1.0 of the fidelity of this word. A default value of 0.0 indicates that the value is unset. Corresponds to the JSON property confidence

Returns:

  • (Float)


11173
11174
11175
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11173

def confidence
  @confidence
end

#end_offsetString

Time offset of the end of this word relative to the beginning of the total conversation. Corresponds to the JSON property endOffset

Returns:

  • (String)


11179
11180
11181
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11179

def end_offset
  @end_offset
end

#start_offsetString

Time offset of the start of this word relative to the beginning of the total conversation. Corresponds to the JSON property startOffset

Returns:

  • (String)


11185
11186
11187
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11185

def start_offset
  @start_offset
end

#wordString

The word itself. Includes punctuation marks that surround the word. Corresponds to the JSON property word

Returns:

  • (String)


11190
11191
11192
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11190

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11197
11198
11199
11200
11201
11202
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11197

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
  @word = args[:word] if args.key?(:word)
end