Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.



13544
13545
13546
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


13511
13512
13513
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13511

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


13516
13517
13518
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13516

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


13521
13522
13523
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13521

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


13527
13528
13529
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13527

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


13532
13533
13534
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13532

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


13537
13538
13539
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13537

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


13542
13543
13544
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13542

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13549
13550
13551
13552
13553
13554
13555
13556
13557
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13549

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end