Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.
13544 13545 13546 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
13511 13512 13513 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13511 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
13516 13517 13518 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13516 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
13521 13522 13523 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13521 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
13527 13528 13529 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13527 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
13532 13533 13534 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13532 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
13537 13538 13539 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13537 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
13542 13543 13544 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13542 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13549 13550 13551 13552 13553 13554 13555 13556 13557 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13549 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |