Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.
12736 12737 12738 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
12703 12704 12705 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12703 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
12708 12709 12710 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12708 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
12713 12714 12715 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12713 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
12719 12720 12721 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12719 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
12724 12725 12726 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12724 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
12729 12730 12731 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12729 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
12734 12735 12736 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12734 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12741 12742 12743 12744 12745 12746 12747 12748 12749 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12741 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |