Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.



11396
11397
11398
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


11363
11364
11365
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11363

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


11368
11369
11370
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11368

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


11373
11374
11375
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11373

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


11379
11380
11381
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11379

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


11384
11385
11386
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11384

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


11389
11390
11391
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11389

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


11394
11395
11396
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11394

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11401
11402
11403
11404
11405
11406
11407
11408
11409
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11401

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end