Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.



9114
9115
9116
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


9081
9082
9083
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9081

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


9086
9087
9088
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9086

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


9091
9092
9093
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9091

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


9097
9098
9099
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9097

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


9102
9103
9104
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9102

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


9107
9108
9109
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9107

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


9112
9113
9114
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9112

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9119
9120
9121
9122
9123
9124
9125
9126
9127
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9119

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end