Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dataset
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dataset.
9114 9115 9116 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
9081 9082 9083 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9081 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
9086 9087 9088 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9086 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
9091 9092 9093 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9091 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
9097 9098 9099 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9097 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
9102 9103 9104 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9102 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
9107 9108 9109 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9107 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
9112 9113 9114 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9112 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9119 9120 9121 9122 9123 9124 9125 9126 9127 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9119 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |