Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for a DiagnoseConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsMetadata.



13703
13704
13705
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13654
13655
13656
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13654

def create_time
  @create_time
end

#diagnostic_reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport

A diagnostic report containing aggregate metrics and intent breakdowns. Corresponds to the JSON property diagnosticReport



13659
13660
13661
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13659

def diagnostic_report
  @diagnostic_report
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


13664
13665
13666
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13664

def end_time
  @end_time
end

#full_reportBoolean Also known as: full_report?

Output only. If true, the agent generated a full diagnostic report for all sub- agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


13670
13671
13672
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13670

def full_report
  @full_report
end

#latest_stepGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep

A step in the agent's reasoning process (Trajectory Step). Corresponds to the JSON property latestStep



13676
13677
13678
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13676

def latest_step
  @latest_step
end

#metric_typeString

Output only. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


13681
13682
13683
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13681

def metric_type
  @metric_type
end

#partial_trajectoriesArray<String>

Output only. Deprecated: Use partial_trajectory_steps instead. Output only. The intermediate trajectory updates (partial trajectory). Corresponds to the JSON property partialTrajectories

Returns:

  • (Array<String>)


13687
13688
13689
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13687

def partial_trajectories
  @partial_trajectories
end

#partial_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep>

Output only. The intermediate trajectory updates. This can be used for live progress tracking of the agent's thoughts and actions as it works through the analysis. Corresponds to the JSON property partialTrajectorySteps



13694
13695
13696
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13694

def partial_trajectory_steps
  @partial_trajectory_steps
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution. Corresponds to the JSON property request



13701
13702
13703
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13701

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13708
13709
13710
13711
13712
13713
13714
13715
13716
13717
13718
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13708

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report)
  @end_time = args[:end_time] if args.key?(:end_time)
  @full_report = args[:full_report] if args.key?(:full_report)
  @latest_step = args[:latest_step] if args.key?(:latest_step)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories)
  @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps)
  @request = args[:request] if args.key?(:request)
end