Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for a DiagnoseConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsMetadata.



12971
12972
12973
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12922
12923
12924
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12922

def create_time
  @create_time
end

#diagnostic_reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport

A diagnostic report containing aggregate metrics and intent breakdowns. Corresponds to the JSON property diagnosticReport



12927
12928
12929
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12927

def diagnostic_report
  @diagnostic_report
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


12932
12933
12934
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12932

def end_time
  @end_time
end

#full_reportBoolean Also known as: full_report?

Output only. If true, the agent generated a full diagnostic report for all sub- agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


12938
12939
12940
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12938

def full_report
  @full_report
end

#latest_stepGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep

A step in the agent's reasoning process (Trajectory Step). Corresponds to the JSON property latestStep



12944
12945
12946
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12944

def latest_step
  @latest_step
end

#metric_typeString

Output only. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


12949
12950
12951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12949

def metric_type
  @metric_type
end

#partial_trajectoriesArray<String>

Output only. Deprecated: Use partial_trajectory_steps instead. The intermediate trajectory updates (partial trajectory). Corresponds to the JSON property partialTrajectories

Returns:

  • (Array<String>)


12955
12956
12957
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12955

def partial_trajectories
  @partial_trajectories
end

#partial_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep>

Output only. The intermediate trajectory updates. This can be used for live progress tracking of the agent's thoughts and actions as it works through the analysis. Corresponds to the JSON property partialTrajectorySteps



12962
12963
12964
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12962

def partial_trajectory_steps
  @partial_trajectory_steps
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution. Corresponds to the JSON property request



12969
12970
12971
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12969

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12976
12977
12978
12979
12980
12981
12982
12983
12984
12985
12986
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12976

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report)
  @end_time = args[:end_time] if args.key?(:end_time)
  @full_report = args[:full_report] if args.key?(:full_report)
  @latest_step = args[:latest_step] if args.key?(:latest_step)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories)
  @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps)
  @request = args[:request] if args.key?(:request)
end