Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.
Instance Attribute Summary collapse
-
#agent_display_name ⇒ String
ces agent display name (e.g., "Steering", "Billing").
-
#agent_id ⇒ String
ces agent id to diagnose.
-
#app_id ⇒ String
Required.
-
#app_version ⇒ String
Optional.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#filter ⇒ String
Optional.
-
#full_report ⇒ Boolean
(also: #full_report?)
Optional.
-
#group_id ⇒ String
Optional.
-
#instructions ⇒ String
Optional.
-
#max_steps ⇒ Fixnum
Optional.
-
#metric_type ⇒ String
Optional.
-
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1OutputConfig
Configuration for where to export or return the analysis findings.
-
#parent ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#task_query ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest.
13901 13902 13903 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_display_name ⇒ String
ces agent display name (e.g., "Steering", "Billing").
Corresponds to the JSON property agentDisplayName
13806 13807 13808 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13806 def agent_display_name @agent_display_name end |
#agent_id ⇒ String
ces agent id to diagnose.
Corresponds to the JSON property agentId
13811 13812 13813 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13811 def agent_id @agent_id end |
#app_id ⇒ String
Required. The CES App ID.
Corresponds to the JSON property appId
13816 13817 13818 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13816 def app_id @app_id end |
#app_version ⇒ String
Optional. Optional but highly recommended. ces app version. If provided,
specific version of agent instruction will be retrieved. If empty or set to '-'
, will use the latest draft version of instruction.
Corresponds to the JSON property appVersion
13823 13824 13825 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13823 def app_version @app_version end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. Deprecated: If true, the request will be validated and a simulation
of the analysis will be performed without actually executing the task. This
field is unused. Use validate_only instead.
Corresponds to the JSON property dryRun
13830 13831 13832 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13830 def dry_run @dry_run end |
#filter ⇒ String
Optional. AIP-160 compliant filter for selecting target conversations.
Corresponds to the JSON property filter
13836 13837 13838 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13836 def filter @filter end |
#full_report ⇒ Boolean Also known as: full_report?
Optional. Deprecated: If true, the agent will generate a full diagnostic
report for all sub-agents. Subagent reporting configuration is unused. The
final diagnostic details are already persisted inside the Diagnostic resource
instead.
Corresponds to the JSON property fullReport
13844 13845 13846 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13844 def full_report @full_report end |
#group_id ⇒ String
Optional. A unique identifier used to group multiple diagnostic requests
triggered under the same run batch or cron job.
Corresponds to the JSON property groupId
13851 13852 13853 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13851 def group_id @group_id end |
#instructions ⇒ String
Optional. Deprecated: Specific instructions for the agent. Use app_id and
subagent fields instead.
Corresponds to the JSON property instructions
13857 13858 13859 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13857 def instructions @instructions end |
#max_steps ⇒ Fixnum
Optional. The maximum number of steps the agent can take during the execution
of the task. Defaults to 10.
Corresponds to the JSON property maxSteps
13863 13864 13865 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13863 def max_steps @max_steps end |
#metric_type ⇒ String
Optional. The type of metric being diagnosed.
Corresponds to the JSON property metricType
13868 13869 13870 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13868 def metric_type @metric_type end |
#output_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1OutputConfig
Configuration for where to export or return the analysis findings.
Corresponds to the JSON property outputConfig
13873 13874 13875 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13873 def output_config @output_config end |
#parent ⇒ String
Required. The parent resource where the analysis will be performed.
Corresponds to the JSON property parent
13878 13879 13880 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13878 def parent @parent end |
#request_id ⇒ String
Optional. Required. A unique ID that identifies the request. If the service
receives two DiagnoseConversationsRequests with the same request_id, then
the second request will be ignored; instead, the response of the first request
will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9),
underscores (_), and hyphens (-). The maximum length is 40 characters.
Corresponds to the JSON property requestId
13887 13888 13889 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13887 def request_id @request_id end |
#task_query ⇒ String
Optional. A natural language description of the analysis goal or question.
Corresponds to the JSON property taskQuery
13892 13893 13894 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13892 def task_query @task_query end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If true, the request will only be validated (permissions, filter
syntax, etc.) without actually triggering the analysis.
Corresponds to the JSON property validateOnly
13898 13899 13900 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13898 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13906 13907 13908 13909 13910 13911 13912 13913 13914 13915 13916 13917 13918 13919 13920 13921 13922 13923 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13906 def update!(**args) @agent_display_name = args[:agent_display_name] if args.key?(:agent_display_name) @agent_id = args[:agent_id] if args.key?(:agent_id) @app_id = args[:app_id] if args.key?(:app_id) @app_version = args[:app_version] if args.key?(:app_version) @dry_run = args[:dry_run] if args.key?(:dry_run) @filter = args[:filter] if args.key?(:filter) @full_report = args[:full_report] if args.key?(:full_report) @group_id = args[:group_id] if args.key?(:group_id) @instructions = args[:instructions] if args.key?(:instructions) @max_steps = args[:max_steps] if args.key?(:max_steps) @metric_type = args[:metric_type] if args.key?(:metric_type) @output_config = args[:output_config] if args.key?(:output_config) @parent = args[:parent] if args.key?(:parent) @request_id = args[:request_id] if args.key?(:request_id) @task_query = args[:task_query] if args.key?(:task_query) @validate_only = args[:validate_only] if args.key?(:validate_only) end |