Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest.



13796
13797
13798
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dry_runBoolean Also known as: dry_run?

Optional. Deprecated: If true, the request will be validated and a simulation of the analysis will be performed without actually executing the task. This field is unused. Use validate_only instead. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


13732
13733
13734
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13732

def dry_run
  @dry_run
end

#filterString

Optional. AIP-160 compliant filter for selecting target conversations. Corresponds to the JSON property filter

Returns:

  • (String)


13738
13739
13740
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13738

def filter
  @filter
end

#full_reportBoolean Also known as: full_report?

Optional. Deprecated: If true, the agent will generate a full diagnostic report for all sub-agents. Subagent reporting configuration is unused. The final diagnostic details are already persisted inside the Diagnostic resource instead. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


13746
13747
13748
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13746

def full_report
  @full_report
end

#instructionsString

Optional. Specific instructions for the agent. Corresponds to the JSON property instructions

Returns:

  • (String)


13752
13753
13754
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13752

def instructions
  @instructions
end

#max_stepsFixnum

Optional. The maximum number of steps the agent can take during the execution of the task. Defaults to 10. Corresponds to the JSON property maxSteps

Returns:

  • (Fixnum)


13758
13759
13760
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13758

def max_steps
  @max_steps
end

#metric_typeString

Optional. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


13763
13764
13765
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13763

def metric_type
  @metric_type
end

#output_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1OutputConfig

Configuration for where to export or return the analysis findings. Corresponds to the JSON property outputConfig



13768
13769
13770
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13768

def output_config
  @output_config
end

#parentString

Required. The parent resource where the analysis will be performed. Corresponds to the JSON property parent

Returns:

  • (String)


13773
13774
13775
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13773

def parent
  @parent
end

#request_idString

Optional. Required. A unique ID that identifies the request. If the service receives two DiagnoseConversationsRequests with the same request_id, then the second request will be ignored; instead, the response of the first request will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


13782
13783
13784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13782

def request_id
  @request_id
end

#task_queryString

Optional. A natural language description of the analysis goal or question. Corresponds to the JSON property taskQuery

Returns:

  • (String)


13787
13788
13789
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13787

def task_query
  @task_query
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If true, the request will only be validated (permissions, filter syntax, etc.) without actually triggering the analysis. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


13793
13794
13795
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13793

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13801
13802
13803
13804
13805
13806
13807
13808
13809
13810
13811
13812
13813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13801

def update!(**args)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @filter = args[:filter] if args.key?(:filter)
  @full_report = args[:full_report] if args.key?(:full_report)
  @instructions = args[:instructions] if args.key?(:instructions)
  @max_steps = args[:max_steps] if args.key?(:max_steps)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @output_config = args[:output_config] if args.key?(:output_config)
  @parent = args[:parent] if args.key?(:parent)
  @request_id = args[:request_id] if args.key?(:request_id)
  @task_query = args[:task_query] if args.key?(:task_query)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end