Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsRequest.



13061
13062
13063
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dry_runBoolean Also known as: dry_run?

Optional. If true, the request will be validated and a simulation of the analysis will be performed without actually executing the task. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


12999
13000
13001
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12999

def dry_run
  @dry_run
end

#filterString

Optional. AIP-160 compliant filter for selecting target conversations. Corresponds to the JSON property filter

Returns:

  • (String)


13005
13006
13007
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13005

def filter
  @filter
end

#full_reportBoolean Also known as: full_report?

Optional. If true, the agent will generate a full diagnostic report for all sub-agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


13011
13012
13013
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13011

def full_report
  @full_report
end

#instructionsString

Optional. Specific instructions for the agent. Corresponds to the JSON property instructions

Returns:

  • (String)


13017
13018
13019
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13017

def instructions
  @instructions
end

#max_stepsFixnum

Optional. The maximum number of steps the agent can take during the execution of the task. Defaults to 10. Corresponds to the JSON property maxSteps

Returns:

  • (Fixnum)


13023
13024
13025
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13023

def max_steps
  @max_steps
end

#metric_typeString

Optional. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


13028
13029
13030
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13028

def metric_type
  @metric_type
end

#output_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1OutputConfig

Configuration for where to export or return the analysis findings. Corresponds to the JSON property outputConfig



13033
13034
13035
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13033

def output_config
  @output_config
end

#parentString

Required. The parent resource where the analysis will be performed. Corresponds to the JSON property parent

Returns:

  • (String)


13038
13039
13040
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13038

def parent
  @parent
end

#request_idString

Optional. Required. A unique ID that identifies the request. If the service receives two DiagnoseConversationsRequests with the same request_id, then the second request will be ignored; instead, the response of the first request will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


13047
13048
13049
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13047

def request_id
  @request_id
end

#task_queryString

Optional. A natural language description of the analysis goal or question. Corresponds to the JSON property taskQuery

Returns:

  • (String)


13052
13053
13054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13052

def task_query
  @task_query
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If true, the request will only be validated (permissions, filter syntax, etc.) without actually triggering the analysis. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


13058
13059
13060
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13058

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13066
13067
13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13066

def update!(**args)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @filter = args[:filter] if args.key?(:filter)
  @full_report = args[:full_report] if args.key?(:full_report)
  @instructions = args[:instructions] if args.key?(:instructions)
  @max_steps = args[:max_steps] if args.key?(:max_steps)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @output_config = args[:output_config] if args.key?(:output_config)
  @parent = args[:parent] if args.key?(:parent)
  @request_id = args[:request_id] if args.key?(:request_id)
  @task_query = args[:task_query] if args.key?(:task_query)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end