Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The response from a DiagnoseConversations request.
Instance Attribute Summary collapse
-
#answer ⇒ String
Output only.
-
#export_uri ⇒ String
Output only.
-
#full_trajectories ⇒ Array<String>
Output only.
-
#full_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse.
13957 13958 13959 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer ⇒ String
Output only. Deprecated: Output only. The final, high-level answer or
diagnostic summary returned by the Sherlock worker is deprecated. The
persistent analysis summary is stored inside the Diagnostic resource instead.
Corresponds to the JSON property answer
13935 13936 13937 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13935 def answer @answer end |
#export_uri ⇒ String
Output only. Deprecated: Output only. If an external destination was requested,
the URI of the exported data is deprecated. The persistent diagnostic details
are stored inside the Diagnostic resource instead.
Corresponds to the JSON property exportUri
13942 13943 13944 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13942 def export_uri @export_uri end |
#full_trajectories ⇒ Array<String>
Output only. Deprecated: Use full_trajectory_steps instead. Output only. The
complete sequence of thoughts and actions (full trajectory).
Corresponds to the JSON property fullTrajectories
13948 13949 13950 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13948 def full_trajectories @full_trajectories end |
#full_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep>
Output only. Deprecated: Output only. The complete sequence of thoughts and
actions taken by the agent is deprecated under LRO response completions. Use
the persistent details inside the Diagnostic resource instead.
Corresponds to the JSON property fullTrajectorySteps
13955 13956 13957 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13955 def full_trajectory_steps @full_trajectory_steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13962 13963 13964 13965 13966 13967 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13962 def update!(**args) @answer = args[:answer] if args.key?(:answer) @export_uri = args[:export_uri] if args.key?(:export_uri) @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories) @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps) end |