Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response from a DiagnoseConversations request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnoseConversationsResponse.



13108
13109
13110
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

Output only. The final, high-level answer or diagnostic summary returned by the Sherlock worker. Corresponds to the JSON property answer

Returns:

  • (String)


13089
13090
13091
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13089

def answer
  @answer
end

#export_uriString

Output only. If an external destination was requested, the URI of the exported data. Corresponds to the JSON property exportUri

Returns:

  • (String)


13095
13096
13097
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13095

def export_uri
  @export_uri
end

#full_trajectoriesArray<String>

Output only. Deprecated: Use full_trajectory_steps instead. The complete sequence of thoughts and actions (full trajectory). Corresponds to the JSON property fullTrajectories

Returns:

  • (Array<String>)


13101
13102
13103
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13101

def full_trajectories
  @full_trajectories
end

#full_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep>

Output only. The complete sequence of thoughts and actions taken by the agent. Corresponds to the JSON property fullTrajectorySteps



13106
13107
13108
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13106

def full_trajectory_steps
  @full_trajectory_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13113
13114
13115
13116
13117
13118
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13113

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @export_uri = args[:export_uri] if args.key?(:export_uri)
  @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories)
  @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps)
end