Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A diagnostic report containing aggregate metrics and intent breakdowns.
Instance Attribute Summary collapse
-
#conversation_slices ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReportConversationSlice>
Output only.
-
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReportIntentStats>
Output only.
-
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPattern>
Output only.
-
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1MetricValue>
Output only.
-
#report ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport.
13890 13891 13892 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_slices ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReportConversationSlice>
Output only. A map of conversation slices used in the report.
Corresponds to the JSON property conversationSlices
13867 13868 13869 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13867 def conversation_slices @conversation_slices end |
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReportIntentStats>
Output only. Deprecated: Intent breakdowns are no longer used.
Corresponds to the JSON property intentStats
13872 13873 13874 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13872 def intent_stats @intent_stats end |
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPattern>
Output only. A list of loss patterns identified for the entire project/dataset.
Corresponds to the JSON property lossPatterns
13877 13878 13879 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13877 def loss_patterns @loss_patterns end |
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1MetricValue>
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metrics
13883 13884 13885 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13883 def metrics @metrics end |
#report ⇒ String
Output only. The final report in markdown format.
Corresponds to the JSON property report
13888 13889 13890 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13888 def report @report end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13895 13896 13897 13898 13899 13900 13901 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13895 def update!(**args) @conversation_slices = args[:conversation_slices] if args.key?(:conversation_slices) @intent_stats = args[:intent_stats] if args.key?(:intent_stats) @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns) @metrics = args[:metrics] if args.key?(:metrics) @report = args[:report] if args.key?(:report) end |