Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A diagnostic report containing aggregate metrics and intent breakdowns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1DiagnosticReport.



13141
13142
13143
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intent_statsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DiagnosticReportIntentStats>

Output only. A breakdown of metrics grouped by intent. Corresponds to the JSON property intentStats



13128
13129
13130
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13128

def intent_stats
  @intent_stats
end

#loss_patternsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPattern>

Output only. A list of loss patterns identified for the entire project/dataset. Corresponds to the JSON property lossPatterns



13133
13134
13135
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13133

def loss_patterns
  @loss_patterns
end

#metricsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1MetricValue>

Output only. Deprecated: The type of the metric. Metrics for Outcome Based Insights derived from QueryMetrics. Corresponds to the JSON property metrics



13139
13140
13141
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13139

def metrics
  @metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13146
13147
13148
13149
13150
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13146

def update!(**args)
  @intent_stats = args[:intent_stats] if args.key?(:intent_stats)
  @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns)
  @metrics = args[:metrics] if args.key?(:metrics)
end