Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dimension
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Dimension
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.
Instance Attribute Summary collapse
-
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionAgentDimensionMetadata
Metadata about the agent dimension.
-
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
-
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
-
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
-
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
-
#dimension_key ⇒ String
The key of the dimension.
-
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionIssueDimensionMetadata
Metadata about the issue dimension.
-
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionLabelDimensionMetadata
Metadata about conversation labels.
-
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
-
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension.
-
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
-
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dimension
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Dimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Dimension
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Dimension.
12438 12439 12440 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionAgentDimensionMetadata
Metadata about the agent dimension.
Corresponds to the JSON property agentDimensionMetadata
12380 12381 12382 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12380 def @agent_dimension_metadata end |
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
Corresponds to the JSON property clientSentimentCategoryDimensionMetadata
12385 12386 12387 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12385 def @client_sentiment_category_dimension_metadata end |
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
Corresponds to the JSON property conversationProfileDimensionMetadata
12390 12391 12392 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12390 def @conversation_profile_dimension_metadata end |
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata
12395 12396 12397 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12395 def @conversational_agents_playbook_dimension_metadata end |
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
Corresponds to the JSON property conversationalAgentsToolDimensionMetadata
12400 12401 12402 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12400 def @conversational_agents_tool_dimension_metadata end |
#dimension_key ⇒ String
The key of the dimension.
Corresponds to the JSON property dimensionKey
12405 12406 12407 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12405 def dimension_key @dimension_key end |
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionIssueDimensionMetadata
Metadata about the issue dimension.
Corresponds to the JSON property issueDimensionMetadata
12410 12411 12412 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12410 def @issue_dimension_metadata end |
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionLabelDimensionMetadata
Metadata about conversation labels.
Corresponds to the JSON property labelDimensionMetadata
12415 12416 12417 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12415 def @label_dimension_metadata end |
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
Corresponds to the JSON property mediumDimensionMetadata
12420 12421 12422 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12420 def @medium_dimension_metadata end |
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension. This is useful for showing
the answer distribution for questions for a given scorecard.
Corresponds to the JSON property qaQuestionAnswerDimensionMetadata
12426 12427 12428 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12426 def @qa_question_answer_dimension_metadata end |
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
Corresponds to the JSON property qaQuestionDimensionMetadata
12431 12432 12433 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12431 def @qa_question_dimension_metadata end |
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Corresponds to the JSON property qaScorecardDimensionMetadata
12436 12437 12438 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12436 def @qa_scorecard_dimension_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 12453 12454 12455 12456 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12443 def update!(**args) @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata) @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata) @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata) @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata) @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata) @dimension_key = args[:dimension_key] if args.key?(:dimension_key) @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata) @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata) @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata) @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata) @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata) @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata) end |