Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Entity
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Entity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The data for an entity annotation. Represents a phrase in the conversation that is a known entity, such as a person, an organization, or location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The representative name for the entity.
-
#metadata ⇒ Hash<String,String>
Metadata associated with the entity.
-
#salience ⇒ Float
The salience score associated with the entity in the [0, 1.0] range.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
-
#type ⇒ String
The entity type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Entity
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Entity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Entity
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Entity.
13739 13740 13741 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The representative name for the entity.
Corresponds to the JSON property displayName
13711 13712 13713 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13711 def display_name @display_name end |
#metadata ⇒ Hash<String,String>
Metadata associated with the entity. For most entity types, the metadata is a
Wikipedia URL (wikipedia_url) and Knowledge Graph MID (mid), if they are
available. For the metadata associated with other entity types, see the Type
table below.
Corresponds to the JSON property metadata
13719 13720 13721 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13719 def @metadata end |
#salience ⇒ Float
The salience score associated with the entity in the [0, 1.0] range. The
salience score for an entity provides information about the importance or
centrality of that entity to the entire document text. Scores closer to 0 are
less salient, while scores closer to 1.0 are highly salient.
Corresponds to the JSON property salience
13727 13728 13729 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13727 def salience @salience end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
13732 13733 13734 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13732 def sentiment @sentiment end |
#type ⇒ String
The entity type.
Corresponds to the JSON property type
13737 13738 13739 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13737 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13744 13745 13746 13747 13748 13749 13750 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13744 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @salience = args[:salience] if args.key?(:salience) @sentiment = args[:sentiment] if args.key?(:sentiment) @type = args[:type] if args.key?(:type) end |