Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for an export insights operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata.



12199
12200
12201
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_export_countFixnum

The number of conversations that were exported successfully. Corresponds to the JSON property completedExportCount

Returns:

  • (Fixnum)


12171
12172
12173
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12171

def completed_export_count
  @completed_export_count
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12176
12177
12178
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12176

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


12181
12182
12183
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12181

def end_time
  @end_time
end

#failed_export_countFixnum

The number of conversations that failed to be exported. Corresponds to the JSON property failedExportCount

Returns:

  • (Fixnum)


12186
12187
12188
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12186

def failed_export_count
  @failed_export_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Partial errors during export operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



12192
12193
12194
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12192

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest

The request to export insights. Corresponds to the JSON property request



12197
12198
12199
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12197

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12204
12205
12206
12207
12208
12209
12210
12211
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12204

def update!(**args)
  @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
end