Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for an export insights operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataMetadata.



9917
9918
9919
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_export_countFixnum

The number of conversations that were exported successfully. Corresponds to the JSON property completedExportCount

Returns:

  • (Fixnum)


9889
9890
9891
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9889

def completed_export_count
  @completed_export_count
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9894
9895
9896
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9894

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


9899
9900
9901
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9899

def end_time
  @end_time
end

#failed_export_countFixnum

The number of conversations that failed to be exported. Corresponds to the JSON property failedExportCount

Returns:

  • (Fixnum)


9904
9905
9906
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9904

def failed_export_count
  @failed_export_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Partial errors during export operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



9910
9911
9912
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9910

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequest

The request to export insights. Corresponds to the JSON property request



9915
9916
9917
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9915

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9922
9923
9924
9925
9926
9927
9928
9929
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 9922

def update!(**args)
  @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
end