Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A BigQuery Table Reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination.



13206
13207
13208
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetString

Required. The name of the BigQuery dataset that the snapshot result should be exported to. If this dataset does not exist, the export call returns an INVALID_ARGUMENT error. Corresponds to the JSON property dataset

Returns:

  • (String)


13191
13192
13193
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13191

def dataset
  @dataset
end

#project_idString

A project ID or number. If specified, then export will attempt to write data to this project instead of the resource project. Otherwise, the resource project will be used. Corresponds to the JSON property projectId

Returns:

  • (String)


13198
13199
13200
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13198

def project_id
  @project_id
end

#tableString

The BigQuery table name to which the insights data should be written. If this table does not exist, the export call returns an INVALID_ARGUMENT error. Corresponds to the JSON property table

Returns:

  • (String)


13204
13205
13206
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13204

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13211
13212
13213
13214
13215
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13211

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table = args[:table] if args.key?(:table)
end