Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A BigQuery Table Reference.
Instance Attribute Summary collapse
-
#dataset ⇒ String
Required.
-
#project_id ⇒ String
A project ID or number.
-
#table ⇒ String
The BigQuery table name to which the insights data should be written.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ExportInsightsDataRequestBigQueryDestination.
13013 13014 13015 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset ⇒ String
Required. The name of the BigQuery dataset that the snapshot result should be
exported to. If this dataset does not exist, the export call returns an
INVALID_ARGUMENT error.
Corresponds to the JSON property dataset
12998 12999 13000 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12998 def dataset @dataset end |
#project_id ⇒ String
A project ID or number. If specified, then export will attempt to write data
to this project instead of the resource project. Otherwise, the resource
project will be used.
Corresponds to the JSON property projectId
13005 13006 13007 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13005 def project_id @project_id end |
#table ⇒ String
The BigQuery table name to which the insights data should be written. If this
table does not exist, the export call returns an INVALID_ARGUMENT error.
Corresponds to the JSON property table
13011 13012 13013 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13011 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13018 13019 13020 13021 13022 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13018 def update!(**args) @dataset = args[:dataset] if args.key?(:dataset) @project_id = args[:project_id] if args.key?(:project_id) @table = args[:table] if args.key?(:table) end |