Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Represents a conversation, resource, and label provided by the user. Can take the form of a string label or a QaAnswer label. QaAnswer labels are used for Quality AI example conversations. String labels are used for Topic Modeling. AgentAssistSummary labels are used for Agent Assist Summarization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel.



14123
14124
14125
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the label. Corresponds to the JSON property createTime

Returns:

  • (String)


14089
14090
14091
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14089

def create_time
  @create_time
end

#labelString

String label used for Topic Modeling. Corresponds to the JSON property label

Returns:

  • (String)


14094
14095
14096
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14094

def label
  @label
end

#labeled_resourceString

Name of the resource to be labeled. Supported resources are: * projects/ project/locations/location/qaScorecards/scorecard/revisions/revision/ qaQuestions/question* `projects/`project`/locations/`location`/issueModels/ `issue_model * projects/project/locations/location/generators/ generator_id` Corresponds to the JSON propertylabeledResource`

Returns:

  • (String)


14103
14104
14105
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14103

def labeled_resource
  @labeled_resource
end

#nameString

Immutable. Resource name of the FeedbackLabel. Format: projects/project/ locations/location/conversations/conversation/feedbackLabels/ feedback_label Corresponds to the JSON property name

Returns:

  • (String)


14110
14111
14112
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14110

def name
  @name
end

#qa_answer_labelGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property qaAnswerLabel



14116
14117
14118
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14116

def qa_answer_label
  @qa_answer_label
end

#update_timeString

Output only. Update time of the label. Corresponds to the JSON property updateTime

Returns:

  • (String)


14121
14122
14123
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14121

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14128
14129
14130
14131
14132
14133
14134
14135
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14128

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @label = args[:label] if args.key?(:label)
  @labeled_resource = args[:labeled_resource] if args.key?(:labeled_resource)
  @name = args[:name] if args.key?(:name)
  @qa_answer_label = args[:qa_answer_label] if args.key?(:qa_answer_label)
  @update_time = args[:update_time] if args.key?(:update_time)
end