Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Represents a conversation, resource, and label provided by the user. Can take the form of a string label or a QaAnswer label. QaAnswer labels are used for Quality AI example conversations. String labels are used for Topic Modeling. AgentAssistSummary labels are used for Agent Assist Summarization.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#label ⇒ String
String label used for Topic Modeling.
-
#labeled_resource ⇒ String
Name of the resource to be labeled.
-
#name ⇒ String
Immutable.
-
#qa_answer_label ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1FeedbackLabel.
10219 10220 10221 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time of the label.
Corresponds to the JSON property createTime
10185 10186 10187 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10185 def create_time @create_time end |
#label ⇒ String
String label used for Topic Modeling.
Corresponds to the JSON property label
10190 10191 10192 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10190 def label @label end |
#labeled_resource ⇒ String
Name of the resource to be labeled. Supported resources are: * projects/
project/locations/location/qaScorecards/scorecard/revisions/revision/
qaQuestions/question* `projects/`project`/locations/`location`/issueModels/
`issue_model * projects/project/locations/location/generators/
generator_id`
Corresponds to the JSON propertylabeledResource`
10199 10200 10201 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10199 def labeled_resource @labeled_resource end |
#name ⇒ String
Immutable. Resource name of the FeedbackLabel. Format: projects/project/
locations/location/conversations/conversation/feedbackLabels/
feedback_label
Corresponds to the JSON property name
10206 10207 10208 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10206 def name @name end |
#qa_answer_label ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property qaAnswerLabel
10212 10213 10214 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10212 def qa_answer_label @qa_answer_label end |
#update_time ⇒ String
Output only. Update time of the label.
Corresponds to the JSON property updateTime
10217 10218 10219 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10217 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10224 10225 10226 10227 10228 10229 10230 10231 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10224 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @label = args[:label] if args.key?(:label) @labeled_resource = args[:labeled_resource] if args.key?(:labeled_resource) @name = args[:name] if args.key?(:name) @qa_answer_label = args[:qa_answer_label] if args.key?(:qa_answer_label) @update_time = args[:update_time] if args.key?(:update_time) end |