Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GcsSource.



14923
14924
14925
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


14915
14916
14917
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14915

def audio_uri
  @audio_uri
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


14921
14922
14923
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14921

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14928
14929
14930
14931
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14928

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end