Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GcsSource.



10249
10250
10251
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


10241
10242
10243
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10241

def audio_uri
  @audio_uri
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


10247
10248
10249
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10247

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10254
10255
10256
10257
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10254

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end