Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation transcript for the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
Output only.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript.
15068 15069 15070 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
15051 15052 15053 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15051 def conversation_id @conversation_id end |
#create_time ⇒ String
Output only. The create time of the conversation.
Corresponds to the JSON property createTime
15056 15057 15058 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15056 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
15061 15062 15063 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15061 def @messages end |
#update_time ⇒ String
Output only. The update time of the conversation.
Corresponds to the JSON property updateTime
15066 15067 15068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15066 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15073 15074 15075 15076 15077 15078 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15073 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |