Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation transcript for the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
Output only.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscript.
14958 14959 14960 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
14941 14942 14943 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14941 def conversation_id @conversation_id end |
#create_time ⇒ String
Output only. The create time of the conversation.
Corresponds to the JSON property createTime
14946 14947 14948 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14946 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
14951 14952 14953 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14951 def @messages end |
#update_time ⇒ String
Output only. The update time of the conversation.
Corresponds to the JSON property updateTime
14956 14957 14958 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14956 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14963 14964 14965 14966 14967 14968 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14963 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |