Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The message in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage.



13521
13522
13523
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. For user messages, this is the time at which the system received the message. For system messages, this is the time at which the system generated the message. Corresponds to the JSON property createTime

Returns:

  • (String)


13504
13505
13506
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13504

def create_time
  @create_time
end

#message_idString

The message id of the message. Corresponds to the JSON property messageId

Returns:

  • (String)


13509
13510
13511
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13509

def message_id
  @message_id
end

#system_message_wrapperGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages

A wrapper for system messages per turn. Corresponds to the JSON property systemMessageWrapper



13514
13515
13516
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13514

def system_message_wrapper
  @system_message_wrapper
end

#user_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageUserMessage

The user message. Corresponds to the JSON property userMessage



13519
13520
13521
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13519

def user_message
  @user_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13526
13527
13528
13529
13530
13531
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13526

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @message_id = args[:message_id] if args.key?(:message_id)
  @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper)
  @user_message = args[:user_message] if args.key?(:user_message)
end