Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The message in the conversation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#message_id ⇒ String
The message id of the message.
-
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
-
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessage.
14997 14998 14999 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. For user messages, this is the time at which the system received
the message. For system messages, this is the time at which the system
generated the message.
Corresponds to the JSON property createTime
14980 14981 14982 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14980 def create_time @create_time end |
#message_id ⇒ String
The message id of the message.
Corresponds to the JSON property messageId
14985 14986 14987 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14985 def @message_id end |
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
Corresponds to the JSON property systemMessageWrapper
14990 14991 14992 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14990 def @system_message_wrapper end |
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Corresponds to the JSON property userMessage
14995 14996 14997 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14995 def @user_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15002 15003 15004 15005 15006 15007 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15002 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @message_id = args[:message_id] if args.key?(:message_id) @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper) @user_message = args[:user_message] if args.key?(:user_message) end |