Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessage.



14271
14272
14273
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_specHash<String,Object>

Chart spec from LLM Corresponds to the JSON property chartSpec

Returns:

  • (Hash<String,Object>)


14249
14250
14251
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14249

def chart_spec
  @chart_spec
end

#generated_sql_queryString

Raw SQL from LLM, before templatization Corresponds to the JSON property generatedSqlQuery

Returns:

  • (String)


14254
14255
14256
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14254

def generated_sql_query
  @generated_sql_query
end

#text_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1GenerativeInsightConversationTranscriptMessageSystemMessageTextOutput

A text output message from the system. Corresponds to the JSON property textMessage



14259
14260
14261
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14259

def text_message
  @text_message
end

#user_provided_chart_specHash<String,Object>

Optional. User provided chart spec Corresponds to the JSON property userProvidedChartSpec

Returns:

  • (Hash<String,Object>)


14264
14265
14266
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14264

def user_provided_chart_spec
  @user_provided_chart_spec
end

#user_provided_sql_queryString

Optional. User provided SQL query Corresponds to the JSON property userProvidedSqlQuery

Returns:

  • (String)


14269
14270
14271
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14269

def user_provided_sql_query
  @user_provided_sql_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14276
14277
14278
14279
14280
14281
14282
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14276

def update!(**args)
  @chart_spec = args[:chart_spec] if args.key?(:chart_spec)
  @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query)
  @text_message = args[:text_message] if args.key?(:text_message)
  @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec)
  @user_provided_sql_query = args[:user_provided_sql_query] if args.key?(:user_provided_sql_query)
end