Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to import an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest.



13632
13633
13634
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_new_modelBoolean Also known as: create_new_model?

Optional. If set to true, will create an issue model from the imported file with randomly generated IDs for the issue model and corresponding issues. Otherwise, replaces an existing model with the same ID as the file. Corresponds to the JSON property createNewModel

Returns:

  • (Boolean)


13619
13620
13621
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13619

def create_new_model
  @create_new_model
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequestGcsSource

Google Cloud Storage Object URI to get the issue model file from. Corresponds to the JSON property gcsSource



13625
13626
13627
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13625

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource of the issue model. Corresponds to the JSON property parent

Returns:

  • (String)


13630
13631
13632
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13630

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13637
13638
13639
13640
13641
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13637

def update!(**args)
  @create_new_model = args[:create_new_model] if args.key?(:create_new_model)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
end