Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to import an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequest.



15295
15296
15297
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_new_modelBoolean Also known as: create_new_model?

Optional. If set to true, will create an issue model from the imported file with randomly generated IDs for the issue model and corresponding issues. Otherwise, replaces an existing model with the same ID as the file. Corresponds to the JSON property createNewModel

Returns:

  • (Boolean)


15282
15283
15284
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15282

def create_new_model
  @create_new_model
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ImportIssueModelRequestGcsSource

Google Cloud Storage Object URI to get the issue model file from. Corresponds to the JSON property gcsSource



15288
15289
15290
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15288

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource of the issue model. Corresponds to the JSON property parent

Returns:

  • (String)


15293
15294
15295
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15293

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15300
15301
15302
15303
15304
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15300

def update!(**args)
  @create_new_model = args[:create_new_model] if args.key?(:create_new_model)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
end