Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an IngestConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata.



14611
14612
14613
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


14582
14583
14584
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14582

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


14587
14588
14589
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14587

def end_time
  @end_time
end

#ingest_conversations_statsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats

Statistics for IngestConversations operation. Corresponds to the JSON property ingestConversationsStats



14592
14593
14594
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14592

def ingest_conversations_stats
  @ingest_conversations_stats
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during ingest operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



14598
14599
14600
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14598

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest

The request to ingest conversations. Corresponds to the JSON property request



14603
14604
14605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14603

def request
  @request
end

#sampled_conversationsArray<String>

Output only. Stores the conversation resources produced by ingest sampling operations. Corresponds to the JSON property sampledConversations

Returns:

  • (Array<String>)


14609
14610
14611
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14609

def sampled_conversations
  @sampled_conversations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14616
14617
14618
14619
14620
14621
14622
14623
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14616

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @ingest_conversations_stats = args[:ingest_conversations_stats] if args.key?(:ingest_conversations_stats)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
  @sampled_conversations = args[:sampled_conversations] if args.key?(:sampled_conversations)
end