Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an IngestConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadata.



10412
10413
10414
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10383
10384
10385
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10383

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


10388
10389
10390
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10388

def end_time
  @end_time
end

#ingest_conversations_statsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsMetadataIngestConversationsStats

Statistics for IngestConversations operation. Corresponds to the JSON property ingestConversationsStats



10393
10394
10395
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10393

def ingest_conversations_stats
  @ingest_conversations_stats
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during ingest operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



10399
10400
10401
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10399

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest

The request to ingest conversations. Corresponds to the JSON property request



10404
10405
10406
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10404

def request
  @request
end

#sampled_conversationsArray<String>

Output only. Stores the conversation resources produced by ingest sampling operations. Corresponds to the JSON property sampledConversations

Returns:

  • (Array<String>)


10410
10411
10412
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10410

def sampled_conversations
  @sampled_conversations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10417
10418
10419
10420
10421
10422
10423
10424
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10417

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @ingest_conversations_stats = args[:ingest_conversations_stats] if args.key?(:ingest_conversations_stats)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
  @sampled_conversations = args[:sampled_conversations] if args.key?(:sampled_conversations)
end