Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to ingest conversations.
Instance Attribute Summary collapse
-
#conversation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig
Configuration that applies to all conversations.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestGcsSource
Configuration for Cloud Storage bucket sources.
-
#parent ⇒ String
Required.
-
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#sample_size ⇒ Fixnum
Optional.
-
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SpeechConfig
Speech-to-Text configuration.
-
#transcript_object_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestTranscriptObjectConfig
Configuration for processing transcript objects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest.
14011 14012 14013 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig
Configuration that applies to all conversations.
Corresponds to the JSON property conversationConfig
13967 13968 13969 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13967 def conversation_config @conversation_config end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestGcsSource
Configuration for Cloud Storage bucket sources.
Corresponds to the JSON property gcsSource
13972 13973 13974 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13972 def gcs_source @gcs_source end |
#parent ⇒ String
Required. The parent resource for new conversations.
Corresponds to the JSON property parent
13977 13978 13979 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13977 def parent @parent end |
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property redactionConfig
13988 13989 13990 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13988 def redaction_config @redaction_config end |
#sample_size ⇒ Fixnum
Optional. If set, this fields indicates the number of objects to ingest from
the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless
they are first deleted, conversations produced through sampling won't be
ingested by subsequent ingest requests.
Corresponds to the JSON property sampleSize
13996 13997 13998 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13996 def sample_size @sample_size end |
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SpeechConfig
Speech-to-Text configuration. Speech-to-Text settings are applied to
conversations ingested from the UploadConversation and IngestConversations
endpoints, including conversation coming from CCAI Platform. They are not
applied to conversations ingested from the CreateConversation endpoint.
Corresponds to the JSON property speechConfig
14004 14005 14006 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14004 def speech_config @speech_config end |
#transcript_object_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestTranscriptObjectConfig
Configuration for processing transcript objects.
Corresponds to the JSON property transcriptObjectConfig
14009 14010 14011 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14009 def transcript_object_config @transcript_object_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14016 14017 14018 14019 14020 14021 14022 14023 14024 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14016 def update!(**args) @conversation_config = args[:conversation_config] if args.key?(:conversation_config) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @parent = args[:parent] if args.key?(:parent) @redaction_config = args[:redaction_config] if args.key?(:redaction_config) @sample_size = args[:sample_size] if args.key?(:sample_size) @speech_config = args[:speech_config] if args.key?(:speech_config) @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config) end |