Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to ingest conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequest.



13818
13819
13820
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestConversationConfig

Configuration that applies to all conversations. Corresponds to the JSON property conversationConfig



13774
13775
13776
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13774

def conversation_config
  @conversation_config
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestGcsSource

Configuration for Cloud Storage bucket sources. Corresponds to the JSON property gcsSource



13779
13780
13781
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13779

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource for new conversations. Corresponds to the JSON property parent

Returns:

  • (String)


13784
13785
13786
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13784

def parent
  @parent
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



13795
13796
13797
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13795

def redaction_config
  @redaction_config
end

#sample_sizeFixnum

Optional. If set, this fields indicates the number of objects to ingest from the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless they are first deleted, conversations produced through sampling won't be ingested by subsequent ingest requests. Corresponds to the JSON property sampleSize

Returns:

  • (Fixnum)


13803
13804
13805
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13803

def sample_size
  @sample_size
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



13811
13812
13813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13811

def speech_config
  @speech_config
end

#transcript_object_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1IngestConversationsRequestTranscriptObjectConfig

Configuration for processing transcript objects. Corresponds to the JSON property transcriptObjectConfig



13816
13817
13818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13816

def transcript_object_config
  @transcript_object_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13823
13824
13825
13826
13827
13828
13829
13830
13831
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13823

def update!(**args)
  @conversation_config = args[:conversation_config] if args.key?(:conversation_config)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @sample_size = args[:sample_size] if args.key?(:sample_size)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config)
end