Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Issue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Issue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_description ⇒ String
Representative description of the issue.
-
#display_name ⇒ String
The representative name for the issue.
-
#name ⇒ String
Immutable.
-
#sample_utterances ⇒ Array<String>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Issue
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Issue
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Issue.
15916 15917 15918 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue was created.
Corresponds to the JSON property createTime
15887 15888 15889 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15887 def create_time @create_time end |
#display_description ⇒ String
Representative description of the issue.
Corresponds to the JSON property displayDescription
15892 15893 15894 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15892 def display_description @display_description end |
#display_name ⇒ String
The representative name for the issue.
Corresponds to the JSON property displayName
15897 15898 15899 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15897 def display_name @display_name end |
#name ⇒ String
Immutable. The resource name of the issue. Format: projects/project/
locations/location/issueModels/issue_model/issues/issue
Corresponds to the JSON property name
15903 15904 15905 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15903 def name @name end |
#sample_utterances ⇒ Array<String>
Output only. Resource names of the sample representative utterances that match
to this issue.
Corresponds to the JSON property sampleUtterances
15909 15910 15911 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15909 def sample_utterances @sample_utterances end |
#update_time ⇒ String
Output only. The most recent time that this issue was updated.
Corresponds to the JSON property updateTime
15914 15915 15916 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15914 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15921 15922 15923 15924 15925 15926 15927 15928 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15921 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_description = args[:display_description] if args.key?(:display_description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances) @update_time = args[:update_time] if args.key?(:update_time) end |