Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1Issue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1Issue

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1Issue.



10837
10838
10839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10808
10809
10810
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10808

def create_time
  @create_time
end

#display_descriptionString

Representative description of the issue. Corresponds to the JSON property displayDescription

Returns:

  • (String)


10813
10814
10815
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10813

def display_description
  @display_description
end

#display_nameString

The representative name for the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


10818
10819
10820
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10818

def display_name
  @display_name
end

#nameString

Immutable. The resource name of the issue. Format: projects/project/ locations/location/issueModels/issue_model/issues/issue Corresponds to the JSON property name

Returns:

  • (String)


10824
10825
10826
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10824

def name
  @name
end

#sample_utterancesArray<String>

Output only. Resource names of the sample representative utterances that match to this issue. Corresponds to the JSON property sampleUtterances

Returns:

  • (Array<String>)


10830
10831
10832
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10830

def sample_utterances
  @sample_utterances
end

#update_timeString

Output only. The most recent time that this issue was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10835
10836
10837
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10835

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10842
10843
10844
10845
10846
10847
10848
10849
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 10842

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_description = args[:display_description] if args.key?(:display_description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances)
  @update_time = args[:update_time] if args.key?(:update_time)
end