Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPattern
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPattern
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A loss pattern of a virtual agent and suggested fixes.
Instance Attribute Summary collapse
-
#conversation_ids ⇒ Array<String>
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#examples ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#percentage ⇒ Float
Output only.
-
#suggested_fixes ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1LossPattern
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1LossPattern.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1LossPattern
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1LossPattern.
15392 15393 15394 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_ids ⇒ Array<String>
Output only. A list of conversation IDs that match this loss pattern.
Corresponds to the JSON property conversationIds
15360 15361 15362 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15360 def conversation_ids @conversation_ids end |
#description ⇒ String
Output only. A markdown description of the loss pattern.
Corresponds to the JSON property description
15365 15366 15367 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15365 def description @description end |
#display_name ⇒ String
Output only. The display name of the loss pattern.
Corresponds to the JSON property displayName
15370 15371 15372 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15370 def display_name @display_name end |
#examples ⇒ String
Output only. A markdown of loss pattern examples.
Corresponds to the JSON property examples
15375 15376 15377 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15375 def examples @examples end |
#id ⇒ String
Output only. The unique identifier for the loss pattern.
Corresponds to the JSON property id
15380 15381 15382 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15380 def id @id end |
#percentage ⇒ Float
Output only. The percentage of conversations that match this loss pattern.
Corresponds to the JSON property percentage
15385 15386 15387 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15385 def percentage @percentage end |
#suggested_fixes ⇒ String
Output only. A markdown description of the suggested fixes.
Corresponds to the JSON property suggestedFixes
15390 15391 15392 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15390 def suggested_fixes @suggested_fixes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15397 15398 15399 15400 15401 15402 15403 15404 15405 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15397 def update!(**args) @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @examples = args[:examples] if args.key?(:examples) @id = args[:id] if args.key?(:id) @percentage = args[:percentage] if args.key?(:percentage) @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes) end |