Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPatternLink
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPatternLink
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A link to a conversation or bot instruction.
Instance Attribute Summary collapse
-
#bot_instruction_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPatternLinkBotInstructionLink
A link to a bot instruction.
-
#conversation_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPatternLinkConversationLink
A link to a conversation.
-
#end_byte_index ⇒ Fixnum
The end byte index of the highlighted text (exclusive).
-
#highlighted_text ⇒ String
The text that is highlighted.
-
#location_type ⇒ String
The location type.
-
#start_byte_index ⇒ Fixnum
The start byte index of the highlighted text (inclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1LossPatternLink
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1LossPatternLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1LossPatternLink
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1LossPatternLink.
16218 16219 16220 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bot_instruction_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPatternLinkBotInstructionLink
A link to a bot instruction.
Corresponds to the JSON property botInstructionLink
16191 16192 16193 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16191 def bot_instruction_link @bot_instruction_link end |
#conversation_link ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1LossPatternLinkConversationLink
A link to a conversation.
Corresponds to the JSON property conversationLink
16196 16197 16198 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16196 def conversation_link @conversation_link end |
#end_byte_index ⇒ Fixnum
The end byte index of the highlighted text (exclusive).
Corresponds to the JSON property endByteIndex
16201 16202 16203 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16201 def end_byte_index @end_byte_index end |
#highlighted_text ⇒ String
The text that is highlighted. (populated for debugging purposes)
Corresponds to the JSON property highlightedText
16206 16207 16208 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16206 def highlighted_text @highlighted_text end |
#location_type ⇒ String
The location type.
Corresponds to the JSON property locationType
16211 16212 16213 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16211 def location_type @location_type end |
#start_byte_index ⇒ Fixnum
The start byte index of the highlighted text (inclusive).
Corresponds to the JSON property startByteIndex
16216 16217 16218 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16216 def start_byte_index @start_byte_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16223 16224 16225 16226 16227 16228 16229 16230 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16223 def update!(**args) @bot_instruction_link = args[:bot_instruction_link] if args.key?(:bot_instruction_link) @conversation_link = args[:conversation_link] if args.key?(:conversation_link) @end_byte_index = args[:end_byte_index] if args.key?(:end_byte_index) @highlighted_text = args[:highlighted_text] if args.key?(:highlighted_text) @location_type = args[:location_type] if args.key?(:location_type) @start_byte_index = args[:start_byte_index] if args.key?(:start_byte_index) end |