Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1MetricValue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1MetricValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Deprecated: MetricValue is no longer used for diagnostics.
Instance Attribute Summary collapse
-
#conversations ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Output only.
-
#hit_count ⇒ Fixnum
Output only.
-
#metric_type ⇒ String
Output only.
-
#source_id ⇒ String
Output only.
-
#total_count ⇒ Fixnum
Output only.
-
#value ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1MetricValue
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1MetricValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1MetricValue
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1MetricValue.
15452 15453 15454 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversations ⇒ Array<String>
Output only. The list of conversation names that contributed to this metric (
hits). Format: projects/project/locations/location/conversations/
conversation`
Corresponds to the JSON propertyconversations`
15417 15418 15419 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15417 def conversations @conversations end |
#display_name ⇒ String
Output only. The user-visible name of the metric (e.g., "Containment Rate").
Corresponds to the JSON property displayName
15422 15423 15424 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15422 def display_name @display_name end |
#hit_count ⇒ Fixnum
Output only. The number of positive matches (hits) for this metric.
Corresponds to the JSON property hitCount
15427 15428 15429 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15427 def hit_count @hit_count end |
#metric_type ⇒ String
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metricType
15433 15434 15435 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15433 def metric_type @metric_type end |
#source_id ⇒ String
Output only. The resource name of the underlying Insights primitive (e.g., Tag
or QaQuestion) used to calculate this metric.
Corresponds to the JSON property sourceId
15439 15440 15441 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15439 def source_id @source_id end |
#total_count ⇒ Fixnum
Output only. The total number of items evaluated for this metric.
Corresponds to the JSON property totalCount
15444 15445 15446 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15444 def total_count @total_count end |
#value ⇒ Float
Output only. The calculated value of the metric (usually a ratio or rate 0.0 -
1.0).
Corresponds to the JSON property value
15450 15451 15452 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15450 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15457 15458 15459 15460 15461 15462 15463 15464 15465 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15457 def update!(**args) @conversations = args[:conversations] if args.key?(:conversations) @display_name = args[:display_name] if args.key?(:display_name) @hit_count = args[:hit_count] if args.key?(:hit_count) @metric_type = args[:metric_type] if args.key?(:metric_type) @source_id = args[:source_id] if args.key?(:source_id) @total_count = args[:total_count] if args.key?(:total_count) @value = args[:value] if args.key?(:value) end |