Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An answer to a QaQuestion.
Instance Attribute Summary collapse
-
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources.
-
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#conversation ⇒ String
The conversation the answer applies to.
-
#qa_question ⇒ String
The QaQuestion answered by this answer.
-
#question_body ⇒ String
Question text.
-
#tags ⇒ Array<String>
User-defined list of arbitrary tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
15639 15640 15641 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific
source type, e.g., all system-generated answer sources, or all manual edit
answer sources.
Corresponds to the JSON property answerSources
15609 15610 15611 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15609 def answer_sources @answer_sources end |
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property answerValue
15615 15616 15617 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15615 def answer_value @answer_value end |
#conversation ⇒ String
The conversation the answer applies to.
Corresponds to the JSON property conversation
15620 15621 15622 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15620 def conversation @conversation end |
#qa_question ⇒ String
The QaQuestion answered by this answer.
Corresponds to the JSON property qaQuestion
15625 15626 15627 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15625 def qa_question @qa_question end |
#question_body ⇒ String
Question text. E.g., "Did the agent greet the customer?"
Corresponds to the JSON property questionBody
15630 15631 15632 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15630 def question_body @question_body end |
#tags ⇒ Array<String>
User-defined list of arbitrary tags. Matches the value from QaScorecard.
ScorecardQuestion.tags. Used for grouping/organization and for weighting the
score of each answer.
Corresponds to the JSON property tags
15637 15638 15639 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15637 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15644 15645 15646 15647 15648 15649 15650 15651 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15644 def update!(**args) @answer_sources = args[:answer_sources] if args.key?(:answer_sources) @answer_value = args[:answer_value] if args.key?(:answer_value) @conversation = args[:conversation] if args.key?(:conversation) @qa_question = args[:qa_question] if args.key?(:qa_question) @question_body = args[:question_body] if args.key?(:question_body) @tags = args[:tags] if args.key?(:tags) end |