Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An answer to a QaQuestion.
Instance Attribute Summary collapse
-
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources.
-
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#conversation ⇒ String
The conversation the answer applies to.
-
#qa_question ⇒ String
The QaQuestion answered by this answer.
-
#question_body ⇒ String
Question text.
-
#tags ⇒ Array<String>
User-defined list of arbitrary tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
13796 13797 13798 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific
source type, e.g., all system-generated answer sources, or all manual edit
answer sources.
Corresponds to the JSON property answerSources
13766 13767 13768 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13766 def answer_sources @answer_sources end |
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property answerValue
13772 13773 13774 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13772 def answer_value @answer_value end |
#conversation ⇒ String
The conversation the answer applies to.
Corresponds to the JSON property conversation
13777 13778 13779 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13777 def conversation @conversation end |
#qa_question ⇒ String
The QaQuestion answered by this answer.
Corresponds to the JSON property qaQuestion
13782 13783 13784 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13782 def qa_question @qa_question end |
#question_body ⇒ String
Question text. E.g., "Did the agent greet the customer?"
Corresponds to the JSON property questionBody
13787 13788 13789 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13787 def question_body @question_body end |
#tags ⇒ Array<String>
User-defined list of arbitrary tags. Matches the value from QaScorecard.
ScorecardQuestion.tags. Used for grouping/organization and for weighting the
score of each answer.
Corresponds to the JSON property tags
13794 13795 13796 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13794 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13801 13802 13803 13804 13805 13806 13807 13808 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13801 def update!(**args) @answer_sources = args[:answer_sources] if args.key?(:answer_sources) @answer_value = args[:answer_value] if args.key?(:answer_value) @conversation = args[:conversation] if args.key?(:conversation) @qa_question = args[:qa_question] if args.key?(:qa_question) @question_body = args[:question_body] if args.key?(:question_body) @tags = args[:tags] if args.key?(:tags) end |