Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An answer to a QaQuestion.
Instance Attribute Summary collapse
-
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources.
-
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#conversation ⇒ String
The conversation the answer applies to.
-
#qa_question ⇒ String
The QaQuestion answered by this answer.
-
#question_body ⇒ String
Question text.
-
#tags ⇒ Array<String>
User-defined list of arbitrary tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswer
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswer.
11219 11220 11221 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource>
Lists all answer sources containing one or more answer values of a specific
source type, e.g., all system-generated answer sources, or all manual edit
answer sources.
Corresponds to the JSON property answerSources
11189 11190 11191 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11189 def answer_sources @answer_sources end |
#answer_value ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property answerValue
11195 11196 11197 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11195 def answer_value @answer_value end |
#conversation ⇒ String
The conversation the answer applies to.
Corresponds to the JSON property conversation
11200 11201 11202 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11200 def conversation @conversation end |
#qa_question ⇒ String
The QaQuestion answered by this answer.
Corresponds to the JSON property qaQuestion
11205 11206 11207 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11205 def qa_question @qa_question end |
#question_body ⇒ String
Question text. E.g., "Did the agent greet the customer?"
Corresponds to the JSON property questionBody
11210 11211 11212 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11210 def question_body @question_body end |
#tags ⇒ Array<String>
User-defined list of arbitrary tags. Matches the value from QaScorecard.
ScorecardQuestion.tags. Used for grouping/organization and for weighting the
score of each answer.
Corresponds to the JSON property tags
11217 11218 11219 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11217 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11224 11225 11226 11227 11228 11229 11230 11231 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11224 def update!(**args) @answer_sources = args[:answer_sources] if args.key?(:answer_sources) @answer_value = args[:answer_value] if args.key?(:answer_value) @conversation = args[:conversation] if args.key?(:conversation) @qa_question = args[:qa_question] if args.key?(:qa_question) @question_body = args[:question_body] if args.key?(:question_body) @tags = args[:tags] if args.key?(:tags) end |