Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A question may have multiple answers from varying sources, one of which becomes the "main" answer above. AnswerSource represents each individual answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerSource.



14557
14558
14559
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_valueGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property answerValue



14550
14551
14552
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14550

def answer_value
  @answer_value
end

#source_typeString

What created the answer. Corresponds to the JSON property sourceType

Returns:

  • (String)


14555
14556
14557
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14555

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14562
14563
14564
14565
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14562

def update!(**args)
  @answer_value = args[:answer_value] if args.key?(:answer_value)
  @source_type = args[:source_type] if args.key?(:source_type)
end