Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#key ⇒ String
A short string used as an identifier.
-
#na_value ⇒ Boolean
(also: #na_value?)
A value of "Not Applicable (N/A)".
-
#normalized_score ⇒ Float
Output only.
-
#num_value ⇒ Float
Numerical value.
-
#potential_score ⇒ Float
Output only.
-
#score ⇒ Float
Output only.
-
#skip_value ⇒ Boolean
(also: #skip_value?)
Output only.
-
#str_value ⇒ String
String value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue.
16614 16615 16616 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
16565 16566 16567 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16565 def bool_value @bool_value end |
#key ⇒ String
A short string used as an identifier. Matches the value used in QaQuestion.
AnswerChoice.key.
Corresponds to the JSON property key
16572 16573 16574 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16572 def key @key end |
#na_value ⇒ Boolean Also known as: na_value?
A value of "Not Applicable (N/A)". Should only ever be true.
Corresponds to the JSON property naValue
16577 16578 16579 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16577 def na_value @na_value end |
#normalized_score ⇒ Float
Output only. Normalized score of the questions. Calculated as score /
potential_score.
Corresponds to the JSON property normalizedScore
16584 16585 16586 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16584 def normalized_score @normalized_score end |
#num_value ⇒ Float
Numerical value.
Corresponds to the JSON property numValue
16589 16590 16591 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16589 def num_value @num_value end |
#potential_score ⇒ Float
Output only. The maximum potential score of the question.
Corresponds to the JSON property potentialScore
16594 16595 16596 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16594 def potential_score @potential_score end |
#score ⇒ Float
Output only. Numerical score of the answer.
Corresponds to the JSON property score
16599 16600 16601 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16599 def score @score end |
#skip_value ⇒ Boolean Also known as: skip_value?
Output only. A value of "Skip". If provided, this field may only be set to
true. If a question receives this answer, it will be excluded from any score
calculations. This would mean that the question was not evaluated.
Corresponds to the JSON property skipValue
16606 16607 16608 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16606 def skip_value @skip_value end |
#str_value ⇒ String
String value.
Corresponds to the JSON property strValue
16612 16613 16614 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16612 def str_value @str_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16619 16620 16621 16622 16623 16624 16625 16626 16627 16628 16629 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16619 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @key = args[:key] if args.key?(:key) @na_value = args[:na_value] if args.key?(:na_value) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @num_value = args[:num_value] if args.key?(:num_value) @potential_score = args[:potential_score] if args.key?(:potential_score) @score = args[:score] if args.key?(:score) @skip_value = args[:skip_value] if args.key?(:skip_value) @str_value = args[:str_value] if args.key?(:str_value) end |