Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaAnswerAnswerValue.



11319
11320
11321
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


11270
11271
11272
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11270

def bool_value
  @bool_value
end

#keyString

A short string used as an identifier. Matches the value used in QaQuestion. AnswerChoice.key. Corresponds to the JSON property key

Returns:

  • (String)


11277
11278
11279
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11277

def key
  @key
end

#na_valueBoolean Also known as: na_value?

A value of "Not Applicable (N/A)". Should only ever be true. Corresponds to the JSON property naValue

Returns:

  • (Boolean)


11282
11283
11284
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11282

def na_value
  @na_value
end

#normalized_scoreFloat

Output only. Normalized score of the questions. Calculated as score / potential_score. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


11289
11290
11291
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11289

def normalized_score
  @normalized_score
end

#num_valueFloat

Numerical value. Corresponds to the JSON property numValue

Returns:

  • (Float)


11294
11295
11296
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11294

def num_value
  @num_value
end

#potential_scoreFloat

Output only. The maximum potential score of the question. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


11299
11300
11301
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11299

def potential_score
  @potential_score
end

#scoreFloat

Output only. Numerical score of the answer. Corresponds to the JSON property score

Returns:

  • (Float)


11304
11305
11306
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11304

def score
  @score
end

#skip_valueBoolean Also known as: skip_value?

Output only. A value of "Skip". If provided, this field may only be set to true. If a question receives this answer, it will be excluded from any score calculations. This would mean that the question was not evaluated. Corresponds to the JSON property skipValue

Returns:

  • (Boolean)


11311
11312
11313
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11311

def skip_value
  @skip_value
end

#str_valueString

String value. Corresponds to the JSON property strValue

Returns:

  • (String)


11317
11318
11319
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11317

def str_value
  @str_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11324

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @key = args[:key] if args.key?(:key)
  @na_value = args[:na_value] if args.key?(:na_value)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @num_value = args[:num_value] if args.key?(:num_value)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @score = args[:score] if args.key?(:score)
  @skip_value = args[:skip_value] if args.key?(:skip_value)
  @str_value = args[:str_value] if args.key?(:str_value)
end