Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A tag is a resource which aims to categorize a set of questions across multiple scorecards, e.g., "Customer Satisfaction","Billing", etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag.



13950
13951
13952
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the question tag was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13922
13923
13924
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13922

def create_time
  @create_time
end

#display_nameString

Required. A user-specified display name for the tag. Corresponds to the JSON property displayName

Returns:

  • (String)


13927
13928
13929
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13927

def display_name
  @display_name
end

#nameString

Identifier. Resource name for the QaQuestionTag Format projects/project/ locations/location/qaQuestionTags/qa_question_tag In the above format, the last segment, i.e., qa_question_tag, is a server-generated ID corresponding to the tag resource. Corresponds to the JSON property name

Returns:

  • (String)


13935
13936
13937
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13935

def name
  @name
end

#qa_question_idsArray<String>

Optional. The list of Scorecard Question IDs that the tag applies to. Each QaQuestionId is represented as a full resource name containing the Question ID. Lastly, Since a tag may not necessarily be referenced by any Scorecard Questions, we treat this field as optional. Corresponds to the JSON property qaQuestionIds

Returns:

  • (Array<String>)


13943
13944
13945
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13943

def qa_question_ids
  @qa_question_ids
end

#update_timeString

Output only. The most recent time at which the question tag was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


13948
13949
13950
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13948

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13955
13956
13957
13958
13959
13960
13961
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13955

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @qa_question_ids = args[:qa_question_ids] if args.key?(:qa_question_ids)
  @update_time = args[:update_time] if args.key?(:update_time)
end