Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A tag is a resource which aims to categorize a set of questions across multiple scorecards, e.g., "Customer Satisfaction","Billing", etc.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#qa_question_ids ⇒ Array<String>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaQuestionTag.
11373 11374 11375 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the question tag was created.
Corresponds to the JSON property createTime
11345 11346 11347 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11345 def create_time @create_time end |
#display_name ⇒ String
Required. A user-specified display name for the tag.
Corresponds to the JSON property displayName
11350 11351 11352 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11350 def display_name @display_name end |
#name ⇒ String
Identifier. Resource name for the QaQuestionTag Format projects/project/
locations/location/qaQuestionTags/qa_question_tag In the above format, the
last segment, i.e., qa_question_tag, is a server-generated ID corresponding to
the tag resource.
Corresponds to the JSON property name
11358 11359 11360 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11358 def name @name end |
#qa_question_ids ⇒ Array<String>
Optional. The list of Scorecard Question IDs that the tag applies to. Each
QaQuestionId is represented as a full resource name containing the Question ID.
Lastly, Since a tag may not necessarily be referenced by any Scorecard
Questions, we treat this field as optional.
Corresponds to the JSON property qaQuestionIds
11366 11367 11368 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11366 def qa_question_ids @qa_question_ids end |
#update_time ⇒ String
Output only. The most recent time at which the question tag was updated.
Corresponds to the JSON property updateTime
11371 11372 11373 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11371 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11378 11379 11380 11381 11382 11383 11384 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11378 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @qa_question_ids = args[:qa_question_ids] if args.key?(:qa_question_ids) @update_time = args[:update_time] if args.key?(:update_time) end |