Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult.



14944
14945
14946
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


14888
14889
14890
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14888

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


14893
14894
14895
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14893

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


14898
14899
14900
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14898

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


14904
14905
14906
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14904

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


14910
14911
14912
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14910

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


14916
14917
14918
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14916

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



14921
14922
14923
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14921

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


14926
14927
14928
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14926

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



14931
14932
14933
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14931

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


14937
14938
14939
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14937

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



14942
14943
14944
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14942

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14949
14950
14951
14952
14953
14954
14955
14956
14957
14958
14959
14960
14961
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14949

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end