Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult.



15871
15872
15873
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


15815
15816
15817
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15815

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


15820
15821
15822
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15820

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15825
15826
15827
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15825

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


15831
15832
15833
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15831

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


15837
15838
15839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15837

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


15843
15844
15845
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15843

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



15848
15849
15850
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15848

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


15853
15854
15855
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15853

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



15858
15859
15860
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15858

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


15864
15865
15866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15864

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



15869
15870
15871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15869

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15876
15877
15878
15879
15880
15881
15882
15883
15884
15885
15886
15887
15888
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15876

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end