Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
ID of the agent that handled the conversation.
-
#conversation ⇒ String
The conversation scored by this result.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_answers ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer>
Set of QaAnswers represented in the result.
-
#qa_scorecard_revision ⇒ String
The QaScorecardRevision scored by this result.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result, incorporating any manual edits if they exist.
-
#score_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource>
List of all individual score sets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResult.
11451 11452 11453 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
ID of the agent that handled the conversation.
Corresponds to the JSON property agentId
11395 11396 11397 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11395 def agent_id @agent_id end |
#conversation ⇒ String
The conversation scored by this result.
Corresponds to the JSON property conversation
11400 11401 11402 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11400 def conversation @conversation end |
#create_time ⇒ String
Output only. The timestamp that the revision was created.
Corresponds to the JSON property createTime
11405 11406 11407 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11405 def create_time @create_time end |
#name ⇒ String
Identifier. The name of the scorecard result. Format: projects/project/
locations/location/qaScorecardResults/qa_scorecard_result
Corresponds to the JSON property name
11411 11412 11413 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11411 def name @name end |
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score. Any
manual edits are included if they exist.
Corresponds to the JSON property normalizedScore
11417 11418 11419 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11417 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
11423 11424 11425 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11423 def potential_score @potential_score end |
#qa_answers ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaAnswer>
Set of QaAnswers represented in the result.
Corresponds to the JSON property qaAnswers
11428 11429 11430 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11428 def qa_answers @qa_answers end |
#qa_scorecard_revision ⇒ String
The QaScorecardRevision scored by this result.
Corresponds to the JSON property qaScorecardRevision
11433 11434 11435 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11433 def qa_scorecard_revision @qa_scorecard_revision end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
11438 11439 11440 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11438 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result, incorporating any manual edits if
they exist.
Corresponds to the JSON property score
11444 11445 11446 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11444 def score @score end |
#score_sources ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource>
List of all individual score sets.
Corresponds to the JSON property scoreSources
11449 11450 11451 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11449 def score_sources @score_sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11456 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @conversation = args[:conversation] if args.key?(:conversation) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_answers = args[:qa_answers] if args.key?(:qa_answers) @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @score_sources = args[:score_sources] if args.key?(:score_sources) end |