Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.
Instance Attribute Summary collapse
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result.
-
#source_type ⇒ String
What created the score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource.
14840 14841 14842 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
Corresponds to the JSON property normalizedScore
14817 14818 14819 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14817 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
14823 14824 14825 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14823 def potential_score @potential_score end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
14828 14829 14830 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14828 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result.
Corresponds to the JSON property score
14833 14834 14835 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14833 def score @score end |
#source_type ⇒ String
What created the score.
Corresponds to the JSON property sourceType
14838 14839 14840 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14838 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14845 14846 14847 14848 14849 14850 14851 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14845 def update!(**args) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @source_type = args[:source_type] if args.key?(:source_type) end |