Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.
Instance Attribute Summary collapse
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result.
-
#source_type ⇒ String
What created the score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultScoreSource.
11540 11541 11542 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
Corresponds to the JSON property normalizedScore
11517 11518 11519 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11517 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
11523 11524 11525 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11523 def potential_score @potential_score end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
11528 11529 11530 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11528 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result.
Corresponds to the JSON property score
11533 11534 11535 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11533 def score @score end |
#source_type ⇒ String
What created the score.
Corresponds to the JSON property sourceType
11538 11539 11540 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11538 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11545 11546 11547 11548 11549 11550 11551 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11545 def update!(**args) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @source_type = args[:source_type] if args.key?(:source_type) end |