Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A data point contains the metric values mapped to an interval.
Instance Attribute Summary collapse
-
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
-
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
-
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint.
15172 15173 15174 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
Corresponds to the JSON property conversationMeasure
15157 15158 15159 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15157 def conversation_measure @conversation_measure end |
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
Corresponds to the JSON property dialogflowInteractionMeasure
15162 15163 15164 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15162 def dialogflow_interaction_measure @dialogflow_interaction_measure end |
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
15170 15171 15172 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15170 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15177 15178 15179 15180 15181 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15177 def update!(**args) @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure) @dialogflow_interaction_measure = args[:dialogflow_interaction_measure] if args.key?(:dialogflow_interaction_measure) @interval = args[:interval] if args.key?(:interval) end |