Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A data point contains the metric values mapped to an interval.
Instance Attribute Summary collapse
-
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
-
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
-
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPoint.
16099 16100 16101 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
Corresponds to the JSON property conversationMeasure
16084 16085 16086 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16084 def conversation_measure @conversation_measure end |
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1QueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
Corresponds to the JSON property dialogflowInteractionMeasure
16089 16090 16091 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16089 def dialogflow_interaction_measure @dialogflow_interaction_measure end |
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
16097 16098 16099 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16097 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16104 16105 16106 16107 16108 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16104 def update!(**args) @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure) @dialogflow_interaction_measure = args[:dialogflow_interaction_measure] if args.key?(:dialogflow_interaction_measure) @interval = args[:interval] if args.key?(:interval) end |