Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RedactionConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1RedactionConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1RedactionConfig.



11862
11863
11864
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deidentify_templateString

The fully-qualified DLP deidentify template resource name. Format: projects/ project/deidentifyTemplates/template` Corresponds to the JSON propertydeidentifyTemplate`

Returns:

  • (String)


11854
11855
11856
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11854

def deidentify_template
  @deidentify_template
end

#inspect_templateString

The fully-qualified DLP inspect template resource name. Format: projects/ project/locations/location/inspectTemplates/template` Corresponds to the JSON propertyinspectTemplate`

Returns:

  • (String)


11860
11861
11862
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11860

def inspect_template
  @inspect_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11867
11868
11869
11870
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 11867

def update!(**args)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
end