Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation.



15645
15646
15647
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


15578
15579
15580
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15578

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



15583
15584
15585
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15583

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



15588
15589
15590
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15588

def article_suggestion
  @article_suggestion
end

#ces_end_session_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation

The CES end session annotation. Corresponds to the JSON property cesEndSessionAnnotation



15593
15594
15595
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15593

def ces_end_session_annotation
  @ces_end_session_annotation
end

#ces_turn_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation

The CES diagnostic information. Corresponds to the JSON property cesTurnAnnotation



15598
15599
15600
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15598

def ces_turn_annotation
  @ces_turn_annotation
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



15603
15604
15605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15603

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15608
15609
15610
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15608

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



15613
15614
15615
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15613

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



15618
15619
15620
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15618

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



15623
15624
15625
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15623

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



15628
15629
15630
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15628

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



15633
15634
15635
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15633

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



15638
15639
15640
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15638

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



15643
15644
15645
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15643

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15650
15651
15652
15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
15663
15664
15665
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15650

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation)
  @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end