Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An annotation that was generated during the customer and agent interaction.
Instance Attribute Summary collapse
-
#annotation_id ⇒ String
The unique identifier of the annotation.
-
#answer_feedback ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
-
#article_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData
Agent Assist Article Suggestion data.
-
#ces_end_session_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation
The CES end session annotation.
-
#ces_turn_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
The CES diagnostic information.
-
#conversation_summarization_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
-
#create_time ⇒ String
The time at which this annotation was created.
-
#dialogflow_interaction ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData
Dialogflow interaction data.
-
#end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#faq_answer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData
Agent Assist frequently-asked-question answer data.
-
#smart_compose_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
-
#smart_reply ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartReplyData
Agent Assist Smart Reply data.
-
#start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
-
#user_input ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput
Explicit input used for generating the answer Corresponds to the JSON property
userInput.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation.
15639 15640 15641 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_id ⇒ String
The unique identifier of the annotation. Format: projects/project/locations/
location/conversationDatasets/dataset/conversationDataItems/data_item/
conversationAnnotations/annotation
Corresponds to the JSON property annotationId
15572 15573 15574 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15572 def annotation_id @annotation_id end |
#answer_feedback ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
Corresponds to the JSON property answerFeedback
15577 15578 15579 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15577 def answer_feedback @answer_feedback end |
#article_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData
Agent Assist Article Suggestion data.
Corresponds to the JSON property articleSuggestion
15582 15583 15584 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15582 def article_suggestion @article_suggestion end |
#ces_end_session_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation
The CES end session annotation.
Corresponds to the JSON property cesEndSessionAnnotation
15587 15588 15589 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15587 def ces_end_session_annotation @ces_end_session_annotation end |
#ces_turn_annotation ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation
The CES diagnostic information.
Corresponds to the JSON property cesTurnAnnotation
15592 15593 15594 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15592 def ces_turn_annotation @ces_turn_annotation end |
#conversation_summarization_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
Corresponds to the JSON property conversationSummarizationSuggestion
15597 15598 15599 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15597 def conversation_summarization_suggestion @conversation_summarization_suggestion end |
#create_time ⇒ String
The time at which this annotation was created.
Corresponds to the JSON property createTime
15602 15603 15604 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15602 def create_time @create_time end |
#dialogflow_interaction ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData
Dialogflow interaction data.
Corresponds to the JSON property dialogflowInteraction
15607 15608 15609 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15607 def dialogflow_interaction @dialogflow_interaction end |
#end_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property endBoundary
15612 15613 15614 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15612 def end_boundary @end_boundary end |
#faq_answer ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData
Agent Assist frequently-asked-question answer data.
Corresponds to the JSON property faqAnswer
15617 15618 15619 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15617 def faq_answer @faq_answer end |
#smart_compose_suggestion ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
Corresponds to the JSON property smartComposeSuggestion
15622 15623 15624 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15622 def smart_compose_suggestion @smart_compose_suggestion end |
#smart_reply ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartReplyData
Agent Assist Smart Reply data.
Corresponds to the JSON property smartReply
15627 15628 15629 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15627 def smart_reply @smart_reply end |
#start_boundary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
Corresponds to the JSON property startBoundary
15632 15633 15634 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15632 def start_boundary @start_boundary end |
#user_input ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput
Explicit input used for generating the answer
Corresponds to the JSON property userInput
15637 15638 15639 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15637 def user_input @user_input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 15655 15656 15657 15658 15659 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15644 def update!(**args) @annotation_id = args[:annotation_id] if args.key?(:annotation_id) @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback) @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion) @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation) @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation) @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion) @create_time = args[:create_time] if args.key?(:create_time) @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction) @end_boundary = args[:end_boundary] if args.key?(:end_boundary) @faq_answer = args[:faq_answer] if args.key?(:faq_answer) @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion) @smart_reply = args[:smart_reply] if args.key?(:smart_reply) @start_boundary = args[:start_boundary] if args.key?(:start_boundary) @user_input = args[:user_input] if args.key?(:user_input) end |