Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation.



17744
17745
17746
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


17677
17678
17679
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17677

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



17682
17683
17684
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17682

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



17687
17688
17689
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17687

def article_suggestion
  @article_suggestion
end

#ces_end_session_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesEndSessionAnnotation

The CES end session annotation. Corresponds to the JSON property cesEndSessionAnnotation



17692
17693
17694
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17692

def ces_end_session_annotation
  @ces_end_session_annotation
end

#ces_turn_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1CesTurnAnnotation

The CES diagnostic information. Corresponds to the JSON property cesTurnAnnotation



17697
17698
17699
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17697

def ces_turn_annotation
  @ces_turn_annotation
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



17702
17703
17704
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17702

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17707
17708
17709
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17707

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



17712
17713
17714
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17712

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



17717
17718
17719
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17717

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



17722
17723
17724
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17722

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



17727
17728
17729
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17727

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



17732
17733
17734
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17732

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



17737
17738
17739
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17737

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



17742
17743
17744
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17742

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17749
17750
17751
17752
17753
17754
17755
17756
17757
17758
17759
17760
17761
17762
17763
17764
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17749

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation)
  @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end