Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotation.



14906
14907
14908
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


14849
14850
14851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14849

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



14854
14855
14856
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14854

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



14859
14860
14861
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14859

def article_suggestion
  @article_suggestion
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



14864
14865
14866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14864

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


14869
14870
14871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14869

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1DialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



14874
14875
14876
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14874

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



14879
14880
14881
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14879

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1FaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



14884
14885
14886
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14884

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



14889
14890
14891
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14889

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



14894
14895
14896
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14894

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1AnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



14899
14900
14901
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14899

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



14904
14905
14906
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14904

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14911
14912
14913
14914
14915
14916
14917
14918
14919
14920
14921
14922
14923
14924
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14911

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end