Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SampleRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for sampling conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1SampleRule

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1SampleRule.



16960
16961
16962
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_filterString

To specify the filter for the conversions that should apply this sample rule. An empty filter means this sample rule applies to all conversations. Corresponds to the JSON property conversationFilter

Returns:

  • (String)


16940
16941
16942
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16940

def conversation_filter
  @conversation_filter
end

#dimensionString

Optional. Group by dimension to sample the conversation. If no dimension is provided, the sampling will be applied to the project level. Current supported dimensions is 'quality_metadata.agent_info.agent_id'. Corresponds to the JSON property dimension

Returns:

  • (String)


16947
16948
16949
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16947

def dimension
  @dimension
end

#sample_percentageFloat

Percentage of conversations that we should sample based on the dimension between [0, 100]. Corresponds to the JSON property samplePercentage

Returns:

  • (Float)


16953
16954
16955
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16953

def sample_percentage
  @sample_percentage
end

#sample_rowFixnum

Number of the conversations that we should sample based on the dimension. Corresponds to the JSON property sampleRow

Returns:

  • (Fixnum)


16958
16959
16960
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16958

def sample_row
  @sample_row
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16965
16966
16967
16968
16969
16970
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16965

def update!(**args)
  @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter)
  @dimension = args[:dimension] if args.key?(:dimension)
  @sample_percentage = args[:sample_percentage] if args.key?(:sample_percentage)
  @sample_row = args[:sample_row] if args.key?(:sample_row)
end