Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A step in the agent's reasoning process (Trajectory Step).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1SherlockStep

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1SherlockStep.



17920
17921
17922
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

Output only. The ID of the agent that produced/received this content. Corresponds to the JSON property agentId

Returns:

  • (String)


17881
17882
17883
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17881

def agent_id
  @agent_id
end

#contentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



17888
17889
17890
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17888

def content
  @content
end

#state_deltasArray<Hash<String,Object>>

Output only. List of state changes caused by this specific turn. Corresponds to the JSON property stateDeltas

Returns:

  • (Array<Hash<String,Object>>)


17893
17894
17895
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17893

def state_deltas
  @state_deltas
end

#step_idString

Output only. Unique ID for this specific turn. Corresponds to the JSON property stepId

Returns:

  • (String)


17898
17899
17900
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17898

def step_id
  @step_id
end

#text_inputArray<String>

Output only. Deprecated: Use content instead. Corresponds to the JSON property textInput

Returns:

  • (Array<String>)


17903
17904
17905
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17903

def text_input
  @text_input
end

#thoughtString

Output only. Deprecated: Use content instead. Corresponds to the JSON property thought

Returns:

  • (String)


17908
17909
17910
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17908

def thought
  @thought
end

#tool_callsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ToolCall>

Output only. Deprecated: Use content instead. Corresponds to the JSON property toolCalls



17913
17914
17915
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17913

def tool_calls
  @tool_calls
end

#tool_outputHash<String,Object>

Output only. Deprecated: Use content instead. Corresponds to the JSON property toolOutput

Returns:

  • (Hash<String,Object>)


17918
17919
17920
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17918

def tool_output
  @tool_output
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17925
17926
17927
17928
17929
17930
17931
17932
17933
17934
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17925

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @content = args[:content] if args.key?(:content)
  @state_deltas = args[:state_deltas] if args.key?(:state_deltas)
  @step_id = args[:step_id] if args.key?(:step_id)
  @text_input = args[:text_input] if args.key?(:text_input)
  @thought = args[:thought] if args.key?(:thought)
  @tool_calls = args[:tool_calls] if args.key?(:tool_calls)
  @tool_output = args[:tool_output] if args.key?(:tool_output)
end