Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1SherlockStep
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A step in the agent's reasoning process (Trajectory Step).
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Output only.
-
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#state_deltas ⇒ Array<Hash<String,Object>>
Output only.
-
#step_id ⇒ String
Output only.
-
#text_input ⇒ Array<String>
Output only.
-
#thought ⇒ String
Output only.
-
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ToolCall>
Output only.
-
#tool_output ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1SherlockStep
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1SherlockStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1SherlockStep
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1SherlockStep.
17920 17921 17922 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Output only. The ID of the agent that produced/received this content.
Corresponds to the JSON property agentId
17881 17882 17883 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17881 def agent_id @agent_id end |
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
17888 17889 17890 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17888 def content @content end |
#state_deltas ⇒ Array<Hash<String,Object>>
Output only. List of state changes caused by this specific turn.
Corresponds to the JSON property stateDeltas
17893 17894 17895 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17893 def state_deltas @state_deltas end |
#step_id ⇒ String
Output only. Unique ID for this specific turn.
Corresponds to the JSON property stepId
17898 17899 17900 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17898 def step_id @step_id end |
#text_input ⇒ Array<String>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property textInput
17903 17904 17905 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17903 def text_input @text_input end |
#thought ⇒ String
Output only. Deprecated: Use content instead.
Corresponds to the JSON property thought
17908 17909 17910 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17908 def thought @thought end |
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ToolCall>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolCalls
17913 17914 17915 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17913 def tool_calls @tool_calls end |
#tool_output ⇒ Hash<String,Object>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolOutput
17918 17919 17920 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17918 def tool_output @tool_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17925 17926 17927 17928 17929 17930 17931 17932 17933 17934 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17925 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @content = args[:content] if args.key?(:content) @state_deltas = args[:state_deltas] if args.key?(:state_deltas) @step_id = args[:step_id] if args.key?(:step_id) @text_input = args[:text_input] if args.key?(:text_input) @thought = args[:thought] if args.key?(:thought) @tool_calls = args[:tool_calls] if args.key?(:tool_calls) @tool_output = args[:tool_output] if args.key?(:tool_output) end |