Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An error that occurred during correlation for a specific conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError.



18158
18159
18160
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationString

The conversation resource name that had an error during correlation. Corresponds to the JSON property conversation

Returns:

  • (String)


18146
18147
18148
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18146

def conversation
  @conversation
end

#statusGoogle::Apis::ContactcenterinsightsV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



18156
18157
18158
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18156

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18163
18164
18165
18166
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18163

def update!(**args)
  @conversation = args[:conversation] if args.key?(:conversation)
  @status = args[:status] if args.key?(:status)
end