Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Wrapper for detailed, step-by-step results.
Instance Attribute Summary collapse
-
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
-
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
constructor
A new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults
Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1TestCorrelationConfigResponseDetailedCorrelationResults.
18319 18320 18321 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraint_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConstraintEvaluationResult>
A list of constraint evaluation results for each pair of conversations.
Corresponds to the JSON property constraintResults
18312 18313 18314 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18312 def constraint_results @constraint_results end |
#join_key_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1ConversationCorrelationResult>
A list of join key correlation results for each conversation tested.
Corresponds to the JSON property joinKeyResults
18317 18318 18319 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18317 def join_key_results @join_key_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18324 18325 18326 18327 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18324 def update!(**args) @constraint_results = args[:constraint_results] if args.key?(:constraint_results) @join_key_results = args[:join_key_results] if args.key?(:join_key_results) end |