Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an UploadConversation operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1alpha1UploadConversationMetadata.



15586
15587
15588
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_operationString

Output only. The operation name for a successfully created analysis operation, if any. Corresponds to the JSON property analysisOperation

Returns:

  • (String)


15558
15559
15560
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15558

def analysis_operation
  @analysis_operation
end

#applied_redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1RedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property appliedRedactionConfig



15569
15570
15571
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15569

def applied_redaction_config
  @applied_redaction_config
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15574
15575
15576
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15574

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


15579
15580
15581
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15579

def end_time
  @end_time
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1alpha1UploadConversationRequest

Request to upload a conversation. Corresponds to the JSON property request



15584
15585
15586
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15584

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15591
15592
15593
15594
15595
15596
15597
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15591

def update!(**args)
  @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation)
  @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @request = args[:request] if args.key?(:request)
end