Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The analysis resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnalysis

Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnalysis.



18504
18505
18506
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysisResult

The result of an analysis. Corresponds to the JSON property analysisResult



18480
18481
18482
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18480

def analysis_result
  @analysis_result
end

#annotator_selectorGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector

Selector of all available annotators and phrase matchers to run. Corresponds to the JSON property annotatorSelector



18485
18486
18487
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18485

def annotator_selector
  @annotator_selector
end

#create_timeString

Output only. The time at which the analysis was created, which occurs when the long-running operation completes. Corresponds to the JSON property createTime

Returns:

  • (String)


18491
18492
18493
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18491

def create_time
  @create_time
end

#nameString

Immutable. The resource name of the analysis. Format: projects/project/ locations/location/conversations/conversation/analyses/analysis Corresponds to the JSON property name

Returns:

  • (String)


18497
18498
18499
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18497

def name
  @name
end

#request_timeString

Output only. The time at which the analysis was requested. Corresponds to the JSON property requestTime

Returns:

  • (String)


18502
18503
18504
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18502

def request_time
  @request_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18509
18510
18511
18512
18513
18514
18515
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18509

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
end