Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The analysis resource.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysisResult
The result of an analysis.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#request_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnalysis
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnalysis
Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnalysis.
17603 17604 17605 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17603 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysisResult
The result of an analysis.
Corresponds to the JSON property analysisResult
17579 17580 17581 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17579 def analysis_result @analysis_result end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
17584 17585 17586 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17584 def annotator_selector @annotator_selector end |
#create_time ⇒ String
Output only. The time at which the analysis was created, which occurs when the
long-running operation completes.
Corresponds to the JSON property createTime
17590 17591 17592 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17590 def create_time @create_time end |
#name ⇒ String
Immutable. The resource name of the analysis. Format: projects/project/
locations/location/conversations/conversation/analyses/analysis
Corresponds to the JSON property name
17596 17597 17598 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17596 def name @name end |
#request_time ⇒ String
Output only. The time at which the analysis was requested.
Corresponds to the JSON property requestTime
17601 17602 17603 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17601 def request_time @request_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17608 17609 17610 17611 17612 17613 17614 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17608 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) end |