Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A point in a conversation that marks the start or the end of an annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnnotationBoundary.



12678
12679
12680
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#transcript_indexFixnum

The index in the sequence of transcribed pieces of the conversation where the boundary is located. This index starts at zero. Corresponds to the JSON property transcriptIndex

Returns:

  • (Fixnum)


12670
12671
12672
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12670

def transcript_index
  @transcript_index
end

#word_indexFixnum

The word index of this boundary with respect to the first word in the transcript piece. This index starts at zero. Corresponds to the JSON property wordIndex

Returns:

  • (Fixnum)


12676
12677
12678
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12676

def word_index
  @word_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12683
12684
12685
12686
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12683

def update!(**args)
  @transcript_index = args[:transcript_index] if args.key?(:transcript_index)
  @word_index = args[:word_index] if args.key?(:word_index)
end