Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Selector of all available annotators and phrase matchers to run.
Instance Attribute Summary collapse
-
#issue_models ⇒ Array<String>
The issue model to run.
-
#phrase_matchers ⇒ Array<String>
The list of phrase matchers to run.
-
#qa_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelectorQaConfig
Configuration for the QA feature.
-
#run_auto_labeling_annotator ⇒ Boolean
(also: #run_auto_labeling_annotator?)
Optional.
-
#run_entity_annotator ⇒ Boolean
(also: #run_entity_annotator?)
Whether to run the entity annotator.
-
#run_intent_annotator ⇒ Boolean
(also: #run_intent_annotator?)
Whether to run the intent annotator.
-
#run_interruption_annotator ⇒ Boolean
(also: #run_interruption_annotator?)
Whether to run the interruption annotator.
-
#run_issue_model_annotator ⇒ Boolean
(also: #run_issue_model_annotator?)
Whether to run the issue model annotator.
-
#run_phrase_matcher_annotator ⇒ Boolean
(also: #run_phrase_matcher_annotator?)
Whether to run the active phrase matcher annotator(s).
-
#run_qa_annotator ⇒ Boolean
(also: #run_qa_annotator?)
Whether to run the QA annotator.
-
#run_sentiment_annotator ⇒ Boolean
(also: #run_sentiment_annotator?)
Whether to run the sentiment annotator.
-
#run_silence_annotator ⇒ Boolean
(also: #run_silence_annotator?)
Whether to run the silence annotator.
-
#run_summarization_annotator ⇒ Boolean
(also: #run_summarization_annotator?)
Whether to run the summarization annotator.
-
#summarization_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelectorSummarizationConfig
Configuration for summarization.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainAnnotatorSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnnotatorSelector.
17825 17826 17827 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issue_models ⇒ Array<String>
The issue model to run. If not provided, the most recently deployed topic
model will be used. The provided issue model will only be used for inference
if the issue model is deployed and if run_issue_model_annotator is set to true.
If more than one issue model is provided, only the first provided issue model
will be used for inference.
Corresponds to the JSON property issueModels
17741 17742 17743 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17741 def issue_models @issue_models end |
#phrase_matchers ⇒ Array<String>
The list of phrase matchers to run. If not provided, all active phrase
matchers will be used. If inactive phrase matchers are provided, they will not
be used. Phrase matchers will be run only if run_phrase_matcher_annotator is
set to true. Format: projects/project/locations/location/phraseMatchers/
phrase_matcher
Corresponds to the JSON property phraseMatchers
17750 17751 17752 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17750 def phrase_matchers @phrase_matchers end |
#qa_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelectorQaConfig
Configuration for the QA feature.
Corresponds to the JSON property qaConfig
17755 17756 17757 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17755 def qa_config @qa_config end |
#run_auto_labeling_annotator ⇒ Boolean Also known as: run_auto_labeling_annotator?
Optional. Whether to run the auto-labeling annotator. If true, the auto-
labeling annotator will be run. This is a non-billable operation designed for
fixing or backfilling custom labels.
Corresponds to the JSON property runAutoLabelingAnnotator
17762 17763 17764 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17762 def run_auto_labeling_annotator @run_auto_labeling_annotator end |
#run_entity_annotator ⇒ Boolean Also known as: run_entity_annotator?
Whether to run the entity annotator.
Corresponds to the JSON property runEntityAnnotator
17768 17769 17770 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17768 def run_entity_annotator @run_entity_annotator end |
#run_intent_annotator ⇒ Boolean Also known as: run_intent_annotator?
Whether to run the intent annotator.
Corresponds to the JSON property runIntentAnnotator
17774 17775 17776 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17774 def run_intent_annotator @run_intent_annotator end |
#run_interruption_annotator ⇒ Boolean Also known as: run_interruption_annotator?
Whether to run the interruption annotator.
Corresponds to the JSON property runInterruptionAnnotator
17780 17781 17782 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17780 def run_interruption_annotator @run_interruption_annotator end |
#run_issue_model_annotator ⇒ Boolean Also known as: run_issue_model_annotator?
Whether to run the issue model annotator. A model should have already been
deployed for this to take effect.
Corresponds to the JSON property runIssueModelAnnotator
17787 17788 17789 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17787 def run_issue_model_annotator @run_issue_model_annotator end |
#run_phrase_matcher_annotator ⇒ Boolean Also known as: run_phrase_matcher_annotator?
Whether to run the active phrase matcher annotator(s).
Corresponds to the JSON property runPhraseMatcherAnnotator
17793 17794 17795 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17793 def run_phrase_matcher_annotator @run_phrase_matcher_annotator end |
#run_qa_annotator ⇒ Boolean Also known as: run_qa_annotator?
Whether to run the QA annotator.
Corresponds to the JSON property runQaAnnotator
17799 17800 17801 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17799 def run_qa_annotator @run_qa_annotator end |
#run_sentiment_annotator ⇒ Boolean Also known as: run_sentiment_annotator?
Whether to run the sentiment annotator.
Corresponds to the JSON property runSentimentAnnotator
17805 17806 17807 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17805 def run_sentiment_annotator @run_sentiment_annotator end |
#run_silence_annotator ⇒ Boolean Also known as: run_silence_annotator?
Whether to run the silence annotator.
Corresponds to the JSON property runSilenceAnnotator
17811 17812 17813 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17811 def run_silence_annotator @run_silence_annotator end |
#run_summarization_annotator ⇒ Boolean Also known as: run_summarization_annotator?
Whether to run the summarization annotator.
Corresponds to the JSON property runSummarizationAnnotator
17817 17818 17819 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17817 def run_summarization_annotator @run_summarization_annotator end |
#summarization_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelectorSummarizationConfig
Configuration for summarization.
Corresponds to the JSON property summarizationConfig
17823 17824 17825 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17823 def summarization_config @summarization_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17830 17831 17832 17833 17834 17835 17836 17837 17838 17839 17840 17841 17842 17843 17844 17845 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17830 def update!(**args) @issue_models = args[:issue_models] if args.key?(:issue_models) @phrase_matchers = args[:phrase_matchers] if args.key?(:phrase_matchers) @qa_config = args[:qa_config] if args.key?(:qa_config) @run_auto_labeling_annotator = args[:run_auto_labeling_annotator] if args.key?(:run_auto_labeling_annotator) @run_entity_annotator = args[:run_entity_annotator] if args.key?(:run_entity_annotator) @run_intent_annotator = args[:run_intent_annotator] if args.key?(:run_intent_annotator) @run_interruption_annotator = args[:run_interruption_annotator] if args.key?(:run_interruption_annotator) @run_issue_model_annotator = args[:run_issue_model_annotator] if args.key?(:run_issue_model_annotator) @run_phrase_matcher_annotator = args[:run_phrase_matcher_annotator] if args.key?(:run_phrase_matcher_annotator) @run_qa_annotator = args[:run_qa_annotator] if args.key?(:run_qa_annotator) @run_sentiment_annotator = args[:run_sentiment_annotator] if args.key?(:run_sentiment_annotator) @run_silence_annotator = args[:run_silence_annotator] if args.key?(:run_silence_annotator) @run_summarization_annotator = args[:run_summarization_annotator] if args.key?(:run_summarization_annotator) @summarization_config = args[:summarization_config] if args.key?(:summarization_config) end |