Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The feedback that the customer has about a certain answer in the conversation.
Instance Attribute Summary collapse
-
#clicked ⇒ Boolean
(also: #clicked?)
Indicates whether an answer or item was clicked by the human agent.
-
#correctness_level ⇒ String
The correctness level of an answer.
-
#displayed ⇒ Boolean
(also: #displayed?)
Indicates whether an answer or item was displayed to the human agent in the agent desktop UI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnswerFeedback
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainAnswerFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainAnswerFeedback
Returns a new instance of GoogleCloudContactcenterinsightsV1mainAnswerFeedback.
12891 12892 12893 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clicked ⇒ Boolean Also known as: clicked?
Indicates whether an answer or item was clicked by the human agent.
Corresponds to the JSON property clicked
12876 12877 12878 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12876 def clicked @clicked end |
#correctness_level ⇒ String
The correctness level of an answer.
Corresponds to the JSON property correctnessLevel
12882 12883 12884 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12882 def correctness_level @correctness_level end |
#displayed ⇒ Boolean Also known as: displayed?
Indicates whether an answer or item was displayed to the human agent in the
agent desktop UI.
Corresponds to the JSON property displayed
12888 12889 12890 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12888 def displayed @displayed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12896 12897 12898 12899 12900 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12896 def update!(**args) @clicked = args[:clicked] if args.key?(:clicked) @correctness_level = args[:correctness_level] if args.key?(:correctness_level) @displayed = args[:displayed] if args.key?(:displayed) end |