Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Agent Assist Article Suggestion data.
Instance Attribute Summary collapse
-
#confidence_score ⇒ Float
The system's confidence score that this article is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain).
-
#metadata ⇒ Hash<String,String>
Map that contains metadata about the Article Suggestion and the document that it originates from.
-
#query_record ⇒ String
The name of the answer record.
-
#source ⇒ String
The knowledge document that this answer was extracted from.
-
#title ⇒ String
Article title.
-
#uri ⇒ String
Article URI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainArticleSuggestionData
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainArticleSuggestionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainArticleSuggestionData
Returns a new instance of GoogleCloudContactcenterinsightsV1mainArticleSuggestionData.
17992 17993 17994 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_score ⇒ Float
The system's confidence score that this article is a good match for this
conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely
certain).
Corresponds to the JSON property confidenceScore
17962 17963 17964 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17962 def confidence_score @confidence_score end |
#metadata ⇒ Hash<String,String>
Map that contains metadata about the Article Suggestion and the document that
it originates from.
Corresponds to the JSON property metadata
17968 17969 17970 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17968 def @metadata end |
#query_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property queryRecord
17974 17975 17976 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17974 def query_record @query_record end |
#source ⇒ String
The knowledge document that this answer was extracted from. Format: projects/
project/knowledgeBases/knowledge_base/documents/document
Corresponds to the JSON property source
17980 17981 17982 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17980 def source @source end |
#title ⇒ String
Article title.
Corresponds to the JSON property title
17985 17986 17987 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17985 def title @title end |
#uri ⇒ String
Article URI.
Corresponds to the JSON property uri
17990 17991 17992 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17990 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17997 17998 17999 18000 18001 18002 18003 18004 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17997 def update!(**args) @confidence_score = args[:confidence_score] if args.key?(:confidence_score) @metadata = args[:metadata] if args.key?(:metadata) @query_record = args[:query_record] if args.key?(:query_record) @source = args[:source] if args.key?(:source) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |