Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for a bulk analyze conversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.



16873
16874
16875
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_analyses_countFixnum

The number of requested analyses that have completed successfully so far. Corresponds to the JSON property completedAnalysesCount

Returns:

  • (Fixnum)


16832
16833
16834
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16832

def completed_analyses_count
  @completed_analyses_count
end

#create_timeString

The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


16837
16838
16839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16837

def create_time
  @create_time
end

#end_timeString

The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


16842
16843
16844
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16842

def end_time
  @end_time
end

#failed_analyses_countFixnum

The number of requested analyses that have failed so far. Corresponds to the JSON property failedAnalysesCount

Returns:

  • (Fixnum)


16847
16848
16849
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16847

def failed_analyses_count
  @failed_analyses_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during bulk analyze operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



16853
16854
16855
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16853

def partial_errors
  @partial_errors
end

#relabelBoolean Also known as: relabel?

Output only. If true, the labeling rules will be re-evaluated for the conversations. Corresponds to the JSON property relabel

Returns:

  • (Boolean)


16859
16860
16861
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16859

def relabel
  @relabel
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest

The request to analyze conversations in bulk. Corresponds to the JSON property request



16865
16866
16867
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16865

def request
  @request
end

#total_requested_analyses_countFixnum

Total number of analyses requested. Computed by the number of conversations returned by filter multiplied by analysis_percentage in the request. Corresponds to the JSON property totalRequestedAnalysesCount

Returns:

  • (Fixnum)


16871
16872
16873
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16871

def total_requested_analyses_count
  @total_requested_analyses_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16878
16879
16880
16881
16882
16883
16884
16885
16886
16887
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16878

def update!(**args)
  @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @relabel = args[:relabel] if args.key?(:relabel)
  @request = args[:request] if args.key?(:request)
  @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count)
end