Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for a bulk analyze conversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.



19066
19067
19068
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_analyses_countFixnum

The number of requested analyses that have completed successfully so far. Corresponds to the JSON property completedAnalysesCount

Returns:

  • (Fixnum)


19025
19026
19027
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19025

def completed_analyses_count
  @completed_analyses_count
end

#create_timeString

The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19030
19031
19032
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19030

def create_time
  @create_time
end

#end_timeString

The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


19035
19036
19037
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19035

def end_time
  @end_time
end

#failed_analyses_countFixnum

The number of requested analyses that have failed so far. Corresponds to the JSON property failedAnalysesCount

Returns:

  • (Fixnum)


19040
19041
19042
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19040

def failed_analyses_count
  @failed_analyses_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during bulk analyze operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



19046
19047
19048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19046

def partial_errors
  @partial_errors
end

#relabelBoolean Also known as: relabel?

Output only. If true, the labeling rules will be re-evaluated for the conversations. Corresponds to the JSON property relabel

Returns:

  • (Boolean)


19052
19053
19054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19052

def relabel
  @relabel
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest

The request to analyze conversations in bulk. Corresponds to the JSON property request



19058
19059
19060
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19058

def request
  @request
end

#total_requested_analyses_countFixnum

Total number of analyses requested. Computed by the number of conversations returned by filter multiplied by analysis_percentage in the request. Corresponds to the JSON property totalRequestedAnalysesCount

Returns:

  • (Fixnum)


19064
19065
19066
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19064

def total_requested_analyses_count
  @total_requested_analyses_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19071
19072
19073
19074
19075
19076
19077
19078
19079
19080
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19071

def update!(**args)
  @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @relabel = args[:relabel] if args.key?(:relabel)
  @request = args[:request] if args.key?(:request)
  @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count)
end