Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk analyze conversations operation.
Instance Attribute Summary collapse
-
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only.
-
#relabel ⇒ Boolean
(also: #relabel?)
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
-
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.
18956 18957 18958 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
Corresponds to the JSON property completedAnalysesCount
18915 18916 18917 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18915 def completed_analyses_count @completed_analyses_count end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
18920 18921 18922 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18920 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
18925 18926 18927 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18925 def end_time @end_time end |
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
Corresponds to the JSON property failedAnalysesCount
18930 18931 18932 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18930 def failed_analyses_count @failed_analyses_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only. Partial errors during bulk analyze operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
18936 18937 18938 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18936 def partial_errors @partial_errors end |
#relabel ⇒ Boolean Also known as: relabel?
Output only. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
18942 18943 18944 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18942 def relabel @relabel end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
Corresponds to the JSON property request
18948 18949 18950 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18948 def request @request end |
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested. Computed by the number of conversations
returned by filter multiplied by analysis_percentage in the request.
Corresponds to the JSON property totalRequestedAnalysesCount
18954 18955 18956 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18954 def total_requested_analyses_count @total_requested_analyses_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18961 18962 18963 18964 18965 18966 18967 18968 18969 18970 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18961 def update!(**args) @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @relabel = args[:relabel] if args.key?(:relabel) @request = args[:request] if args.key?(:request) @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count) end |