Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk analyze conversations operation.
Instance Attribute Summary collapse
-
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only.
-
#relabel ⇒ Boolean
(also: #relabel?)
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
-
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.
18055 18056 18057 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
Corresponds to the JSON property completedAnalysesCount
18014 18015 18016 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18014 def completed_analyses_count @completed_analyses_count end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
18019 18020 18021 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18019 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
18024 18025 18026 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18024 def end_time @end_time end |
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
Corresponds to the JSON property failedAnalysesCount
18029 18030 18031 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18029 def failed_analyses_count @failed_analyses_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only. Partial errors during bulk analyze operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
18035 18036 18037 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18035 def partial_errors @partial_errors end |
#relabel ⇒ Boolean Also known as: relabel?
Output only. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
18041 18042 18043 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18041 def relabel @relabel end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
Corresponds to the JSON property request
18047 18048 18049 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18047 def request @request end |
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested. Computed by the number of conversations
returned by filter multiplied by analysis_percentage in the request.
Corresponds to the JSON property totalRequestedAnalysesCount
18053 18054 18055 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18053 def total_requested_analyses_count @total_requested_analyses_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18060 18061 18062 18063 18064 18065 18066 18067 18068 18069 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18060 def update!(**args) @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @relabel = args[:relabel] if args.key?(:relabel) @request = args[:request] if args.key?(:request) @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count) end |