Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for a bulk analyze conversations operation.
Instance Attribute Summary collapse
-
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
-
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsMetadata.
12998 12999 13000 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_analyses_count ⇒ Fixnum
The number of requested analyses that have completed successfully so far.
Corresponds to the JSON property completedAnalysesCount
12964 12965 12966 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12964 def completed_analyses_count @completed_analyses_count end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
12969 12970 12971 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12969 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
12974 12975 12976 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12974 def end_time @end_time end |
#failed_analyses_count ⇒ Fixnum
The number of requested analyses that have failed so far.
Corresponds to the JSON property failedAnalysesCount
12979 12980 12981 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12979 def failed_analyses_count @failed_analyses_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Output only. Partial errors during bulk analyze operation that might cause the
operation output to be incomplete.
Corresponds to the JSON property partialErrors
12985 12986 12987 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12985 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
Corresponds to the JSON property request
12990 12991 12992 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12990 def request @request end |
#total_requested_analyses_count ⇒ Fixnum
Total number of analyses requested. Computed by the number of conversations
returned by filter multiplied by analysis_percentage in the request.
Corresponds to the JSON property totalRequestedAnalysesCount
12996 12997 12998 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 12996 def total_requested_analyses_count @total_requested_analyses_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13003 13004 13005 13006 13007 13008 13009 13010 13011 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13003 def update!(**args) @completed_analyses_count = args[:completed_analyses_count] if args.key?(:completed_analyses_count) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @failed_analyses_count = args[:failed_analyses_count] if args.key?(:failed_analyses_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) @total_requested_analyses_count = args[:total_requested_analyses_count] if args.key?(:total_requested_analyses_count) end |