Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversations in bulk.
Instance Attribute Summary collapse
-
#analysis_percentage ⇒ Float
Required.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#filter ⇒ String
Required.
-
#parent ⇒ String
Required.
-
#relabel ⇒ Boolean
(also: #relabel?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.
17171 17172 17173 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_percentage ⇒ Float
Required. Percentage of selected conversation to analyze, between [0, 100].
Corresponds to the JSON property analysisPercentage
17147 17148 17149 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17147 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
17152 17153 17154 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17152 def annotator_selector @annotator_selector end |
#filter ⇒ String
Required. Filter used to select the subset of conversations to analyze.
Corresponds to the JSON property filter
17157 17158 17159 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17157 def filter @filter end |
#parent ⇒ String
Required. The parent resource to create analyses in.
Corresponds to the JSON property parent
17162 17163 17164 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17162 def parent @parent end |
#relabel ⇒ Boolean Also known as: relabel?
Optional. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
17168 17169 17170 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17168 def relabel @relabel end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17176 17177 17178 17179 17180 17181 17182 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17176 def update!(**args) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @filter = args[:filter] if args.key?(:filter) @parent = args[:parent] if args.key?(:parent) @relabel = args[:relabel] if args.key?(:relabel) end |