Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversations in bulk.
Instance Attribute Summary collapse
-
#analysis_percentage ⇒ Float
Required.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#filter ⇒ String
Required.
-
#parent ⇒ String
Required.
-
#relabel ⇒ Boolean
(also: #relabel?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.
18103 18104 18105 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_percentage ⇒ Float
Required. Percentage of selected conversation to analyze, between [0, 100].
Corresponds to the JSON property analysisPercentage
18079 18080 18081 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18079 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
18084 18085 18086 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18084 def annotator_selector @annotator_selector end |
#filter ⇒ String
Required. Filter used to select the subset of conversations to analyze.
Corresponds to the JSON property filter
18089 18090 18091 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18089 def filter @filter end |
#parent ⇒ String
Required. The parent resource to create analyses in.
Corresponds to the JSON property parent
18094 18095 18096 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18094 def parent @parent end |
#relabel ⇒ Boolean Also known as: relabel?
Optional. If true, the labeling rules will be re-evaluated for the
conversations.
Corresponds to the JSON property relabel
18100 18101 18102 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18100 def relabel @relabel end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18108 18109 18110 18111 18112 18113 18114 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18108 def update!(**args) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @filter = args[:filter] if args.key?(:filter) @parent = args[:parent] if args.key?(:parent) @relabel = args[:relabel] if args.key?(:relabel) end |