Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to analyze conversations in bulk.
Instance Attribute Summary collapse
-
#analysis_percentage ⇒ Float
Required.
-
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
-
#filter ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.
16162 16163 16164 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_percentage ⇒ Float
Required. Percentage of selected conversation to analyze, between [0, 100].
Corresponds to the JSON property analysisPercentage
16145 16146 16147 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16145 def analysis_percentage @analysis_percentage end |
#annotator_selector ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector
Selector of all available annotators and phrase matchers to run.
Corresponds to the JSON property annotatorSelector
16150 16151 16152 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16150 def annotator_selector @annotator_selector end |
#filter ⇒ String
Required. Filter used to select the subset of conversations to analyze.
Corresponds to the JSON property filter
16155 16156 16157 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16155 def filter @filter end |
#parent ⇒ String
Required. The parent resource to create analyses in.
Corresponds to the JSON property parent
16160 16161 16162 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16160 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16167 16168 16169 16170 16171 16172 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16167 def update!(**args) @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage) @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector) @filter = args[:filter] if args.key?(:filter) @parent = args[:parent] if args.key?(:parent) end |