Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to analyze conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkAnalyzeConversationsRequest.



13038
13039
13040
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_percentageFloat

Required. Percentage of selected conversation to analyze, between [0, 100]. Corresponds to the JSON property analysisPercentage

Returns:

  • (Float)


13021
13022
13023
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13021

def analysis_percentage
  @analysis_percentage
end

#annotator_selectorGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotatorSelector

Selector of all available annotators and phrase matchers to run. Corresponds to the JSON property annotatorSelector



13026
13027
13028
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13026

def annotator_selector
  @annotator_selector
end

#filterString

Required. Filter used to select the subset of conversations to analyze. Corresponds to the JSON property filter

Returns:

  • (String)


13031
13032
13033
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13031

def filter
  @filter
end

#parentString

Required. The parent resource to create analyses in. Corresponds to the JSON property parent

Returns:

  • (String)


13036
13037
13038
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13036

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13043
13044
13045
13046
13047
13048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13043

def update!(**args)
  @analysis_percentage = args[:analysis_percentage] if args.key?(:analysis_percentage)
  @annotator_selector = args[:annotator_selector] if args.key?(:annotator_selector)
  @filter = args[:filter] if args.key?(:filter)
  @parent = args[:parent] if args.key?(:parent)
end