Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to delete conversations in bulk.
Instance Attribute Summary collapse
-
#filter ⇒ String
Filter used to select the subset of conversations to delete.
-
#force ⇒ Boolean
(also: #force?)
If set to true, all of this conversation's analyses will also be deleted.
-
#max_delete_count ⇒ Fixnum
Maximum number of conversations to delete.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest.
19108 19109 19110 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Filter used to select the subset of conversations to delete.
Corresponds to the JSON property filter
19088 19089 19090 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19088 def filter @filter end |
#force ⇒ Boolean Also known as: force?
If set to true, all of this conversation's analyses will also be deleted.
Otherwise, the request will only succeed if the conversation has no analyses.
Corresponds to the JSON property force
19094 19095 19096 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19094 def force @force end |
#max_delete_count ⇒ Fixnum
Maximum number of conversations to delete.
Corresponds to the JSON property maxDeleteCount
19100 19101 19102 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19100 def max_delete_count @max_delete_count end |
#parent ⇒ String
Required. The parent resource to delete conversations from. Format: projects/
project/locations/location
Corresponds to the JSON property parent
19106 19107 19108 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19106 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19113 19114 19115 19116 19117 19118 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19113 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count) @parent = args[:parent] if args.key?(:parent) end |