Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest.



18207
18208
18209
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


18187
18188
18189
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18187

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


18193
18194
18195
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18193

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


18199
18200
18201
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18199

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


18205
18206
18207
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18205

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18212
18213
18214
18215
18216
18217
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18212

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end