Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to delete conversations in bulk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDeleteConversationsRequest.



13141
13142
13143
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Filter used to select the subset of conversations to delete. Corresponds to the JSON property filter

Returns:

  • (String)


13121
13122
13123
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13121

def filter
  @filter
end

#forceBoolean Also known as: force?

If set to true, all of this conversation's analyses will also be deleted. Otherwise, the request will only succeed if the conversation has no analyses. Corresponds to the JSON property force

Returns:

  • (Boolean)


13127
13128
13129
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13127

def force
  @force
end

#max_delete_countFixnum

Maximum number of conversations to delete. Corresponds to the JSON property maxDeleteCount

Returns:

  • (Fixnum)


13133
13134
13135
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13133

def max_delete_count
  @max_delete_count
end

#parentString

Required. The parent resource to delete conversations from. Format: projects/ project/locations/location Corresponds to the JSON property parent

Returns:

  • (String)


13139
13140
13141
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13139

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13146
13147
13148
13149
13150
13151
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13146

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
  @max_delete_count = args[:max_delete_count] if args.key?(:max_delete_count)
  @parent = args[:parent] if args.key?(:parent)
end