Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for the BulkDownloadFeedbackLabel endpoint.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadata.
13265 13266 13267 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
13242 13243 13244 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13242 def create_time @create_time end |
#download_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadataDownloadStats
Statistics for BulkDownloadFeedbackLabels operation.
Corresponds to the JSON property downloadStats
13247 13248 13249 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13247 def download_stats @download_stats end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
13252 13253 13254 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13252 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during ingest operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
13258 13259 13260 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13258 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
Corresponds to the JSON property request
13263 13264 13265 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13263 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13270 13271 13272 13273 13274 13275 13276 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13270 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @download_stats = args[:download_stats] if args.key?(:download_stats) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |