Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadataDownloadStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Statistics for BulkDownloadFeedbackLabels operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadataDownloadStats

Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsMetadataDownloadStats.



18370
18371
18372
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_namesArray<String>

Output only. Full name of the files written to Cloud storage. Corresponds to the JSON property fileNames

Returns:

  • (Array<String>)


18352
18353
18354
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18352

def file_names
  @file_names
end

#processed_object_countFixnum

The number of objects processed during the download operation. Corresponds to the JSON property processedObjectCount

Returns:

  • (Fixnum)


18357
18358
18359
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18357

def processed_object_count
  @processed_object_count
end

#successful_download_countFixnum

The number of new feedback labels downloaded during this operation. Different from "processed" because some labels might not be downloaded because an error. Corresponds to the JSON property successfulDownloadCount

Returns:

  • (Fixnum)


18363
18364
18365
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18363

def successful_download_count
  @successful_download_count
end

#total_files_writtenFixnum

Total number of files written to the provided Cloud Storage bucket. Corresponds to the JSON property totalFilesWritten

Returns:

  • (Fixnum)


18368
18369
18370
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18368

def total_files_written
  @total_files_written
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18375
18376
18377
18378
18379
18380
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18375

def update!(**args)
  @file_names = args[:file_names] if args.key?(:file_names)
  @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count)
  @successful_download_count = args[:successful_download_count] if args.key?(:successful_download_count)
  @total_files_written = args[:total_files_written] if args.key?(:total_files_written)
end