Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Request for the BulkDownloadFeedbackLabel endpoint.
Instance Attribute Summary collapse
-
#conversation_filter ⇒ String
Optional.
-
#feedback_label_type ⇒ String
Optional.
-
#filter ⇒ String
Optional.
-
#gcs_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestGcsDestination
Google Cloud Storage Object details to write the feedback labels to.
-
#max_download_count ⇒ Fixnum
Optional.
-
#parent ⇒ String
Required.
-
#sheets_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination
Google Sheets document details to write the feedback labels to.
-
#template_qa_scorecard_id ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequest.
18438 18439 18440 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_filter ⇒ String
Optional. Filter parent conversations to download feedback labels for. When
specified, the feedback labels will be downloaded for the conversations that
match the filter. If template_qa_scorecard_id is set, all the conversations
that match the filter will be paired with the questions under the scorecard
for labeling.
Corresponds to the JSON property conversationFilter
18394 18395 18396 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18394 def conversation_filter @conversation_filter end |
#feedback_label_type ⇒ String
Optional. The type of feedback labels that will be downloaded.
Corresponds to the JSON property feedbackLabelType
18399 18400 18401 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18399 def feedback_label_type @feedback_label_type end |
#filter ⇒ String
Optional. A filter to reduce results to a specific subset. Supports
disjunctions (OR) and conjunctions (AND). Supported fields: * issue_model_id
qa_question_id*qa_scorecard_id*min_create_time*max_create_timemin_update_time*max_update_time*feedback_label_type: QUALITY_AI, TOPIC_MODELING Corresponds to the JSON propertyfilter
18408 18409 18410 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18408 def filter @filter end |
#gcs_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestGcsDestination
Google Cloud Storage Object details to write the feedback labels to.
Corresponds to the JSON property gcsDestination
18413 18414 18415 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18413 def gcs_destination @gcs_destination end |
#max_download_count ⇒ Fixnum
Optional. Limits the maximum number of feedback labels that will be downloaded.
The first N feedback labels will be downloaded.
Corresponds to the JSON property maxDownloadCount
18419 18420 18421 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18419 def max_download_count @max_download_count end |
#parent ⇒ String
Required. The parent resource for new feedback labels.
Corresponds to the JSON property parent
18424 18425 18426 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18424 def parent @parent end |
#sheets_destination ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainBulkDownloadFeedbackLabelsRequestSheetsDestination
Google Sheets document details to write the feedback labels to.
Corresponds to the JSON property sheetsDestination
18429 18430 18431 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18429 def sheets_destination @sheets_destination end |
#template_qa_scorecard_id ⇒ Array<String>
Optional. If set, a template for labeling conversations and scorecard
questions will be created from the conversation_filter and the questions under
the scorecard(s). The feedback label filter will be ignored.
Corresponds to the JSON property templateQaScorecardId
18436 18437 18438 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18436 def template_qa_scorecard_id @template_qa_scorecard_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18443 18444 18445 18446 18447 18448 18449 18450 18451 18452 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18443 def update!(**args) @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter) @feedback_label_type = args[:feedback_label_type] if args.key?(:feedback_label_type) @filter = args[:filter] if args.key?(:filter) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @max_download_count = args[:max_download_count] if args.key?(:max_download_count) @parent = args[:parent] if args.key?(:parent) @sheets_destination = args[:sheets_destination] if args.key?(:sheets_destination) @template_qa_scorecard_id = args[:template_qa_scorecard_id] if args.key?(:template_qa_scorecard_id) end |