Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCallAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A piece of metadata that applies to a window of a call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainCallAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainCallAnnotation.



18613
18614
18615
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationEndBoundary



18556
18557
18558
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18556

def annotation_end_boundary
  @annotation_end_boundary
end

#annotation_start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property annotationStartBoundary



18561
18562
18563
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18561

def annotation_start_boundary
  @annotation_start_boundary
end

#channel_tagFixnum

The channel of the audio where the annotation occurs. For single-channel audio, this field is not populated. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


18567
18568
18569
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18567

def channel_tag
  @channel_tag
end

#entity_mention_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEntityMentionData

The data for an entity mention annotation. This represents a mention of an Entity in the conversation. Corresponds to the JSON property entityMentionData



18573
18574
18575
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18573

def entity_mention_data
  @entity_mention_data
end

#hold_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainHoldData

The data for a hold annotation. Corresponds to the JSON property holdData



18578
18579
18580
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18578

def hold_data
  @hold_data
end

#intent_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIntentMatchData

The data for an intent match. Represents an intent match for a text segment in the conversation. A text segment can be part of a sentence, a complete sentence, or an utterance with multiple sentences. Corresponds to the JSON property intentMatchData



18585
18586
18587
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18585

def intent_match_data
  @intent_match_data
end

#interruption_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInterruptionData

The data for an interruption annotation. Corresponds to the JSON property interruptionData



18590
18591
18592
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18590

def interruption_data
  @interruption_data
end

#issue_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueMatchData

The data for an issue match annotation. Corresponds to the JSON property issueMatchData



18595
18596
18597
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18595

def issue_match_data
  @issue_match_data
end

#phrase_match_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainPhraseMatchData

The data for a matched phrase matcher. Represents information identifying a phrase matcher for a given match. Corresponds to the JSON property phraseMatchData



18601
18602
18603
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18601

def phrase_match_data
  @phrase_match_data
end

#sentiment_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentimentData



18606
18607
18608
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18606

def sentiment_data
  @sentiment_data
end

#silence_dataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSilenceData

The data for a silence annotation. Corresponds to the JSON property silenceData



18611
18612
18613
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18611

def silence_data
  @silence_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18618
18619
18620
18621
18622
18623
18624
18625
18626
18627
18628
18629
18630
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18618

def update!(**args)
  @annotation_end_boundary = args[:annotation_end_boundary] if args.key?(:annotation_end_boundary)
  @annotation_start_boundary = args[:annotation_start_boundary] if args.key?(:annotation_start_boundary)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @entity_mention_data = args[:entity_mention_data] if args.key?(:entity_mention_data)
  @hold_data = args[:hold_data] if args.key?(:hold_data)
  @intent_match_data = args[:intent_match_data] if args.key?(:intent_match_data)
  @interruption_data = args[:interruption_data] if args.key?(:interruption_data)
  @issue_match_data = args[:issue_match_data] if args.key?(:issue_match_data)
  @phrase_match_data = args[:phrase_match_data] if args.key?(:phrase_match_data)
  @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data)
  @silence_data = args[:silence_data] if args.key?(:silence_data)
end