Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesEndSessionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The CES end session annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainCesEndSessionAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainCesEndSessionAnnotation.



18645
18646
18647
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_sessionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudCesV1mainEndSession

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent. Corresponds to the JSON property endSession



18643
18644
18645
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18643

def end_session
  @end_session
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18650
18651
18652
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18650

def update!(**args)
  @end_session = args[:end_session] if args.key?(:end_session)
end