Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The result of a single constraint rule on the pair of conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConstraintEvaluationResultRuleConstraintResult.



19747
19748
19749
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraint_metBoolean Also known as: constraint_met?

Whether the constraint expression evaluated to true for (A, B) or (B, A). Corresponds to the JSON property constraintMet

Returns:

  • (Boolean)


19729
19730
19731
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19729

def constraint_met
  @constraint_met
end

#errorGoogle::Apis::ContactcenterinsightsV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



19740
19741
19742
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19740

def error
  @error
end

#rule_idString

The rule ID. Corresponds to the JSON property ruleId

Returns:

  • (String)


19745
19746
19747
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19745

def rule_id
  @rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19752
19753
19754
19755
19756
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19752

def update!(**args)
  @constraint_met = args[:constraint_met] if args.key?(:constraint_met)
  @error = args[:error] if args.key?(:error)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
end