Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversation.



17888
17889
17890
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


17767
17768
17769
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17767

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



17772
17773
17774
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17772

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



17777
17778
17779
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17777

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17782
17783
17784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17782

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



17787
17788
17789
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17787

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



17794
17795
17796
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17794

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


17799
17800
17801
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17799

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


17805
17806
17807
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17805

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


17811
17812
17813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17811

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


17816
17817
17818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17816

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis

The analysis resource. Corresponds to the JSON property latestAnalysis



17821
17822
17823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17821

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



17826
17827
17828
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17826

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


17831
17832
17833
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17831

def medium
  @medium
end

#metadata_jsonString

Optional. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


17838
17839
17840
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17838

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


17844
17845
17846
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17844

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


17849
17850
17851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17849

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



17854
17855
17856
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17854

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



17860
17861
17862
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17860

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


17865
17866
17867
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17865

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



17870
17871
17872
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17870

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


17876
17877
17878
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17876

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


17881
17882
17883
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17881

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


17886
17887
17888
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17886

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17893
17894
17895
17896
17897
17898
17899
17900
17901
17902
17903
17904
17905
17906
17907
17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17893

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end