Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversation.



17701
17702
17703
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


17580
17581
17582
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17580

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



17585
17586
17587
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17585

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



17590
17591
17592
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17590

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17595
17596
17597
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17595

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



17600
17601
17602
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17600

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



17607
17608
17609
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17607

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


17612
17613
17614
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17612

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


17618
17619
17620
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17618

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


17624
17625
17626
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17624

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


17629
17630
17631
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17629

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis

The analysis resource. Corresponds to the JSON property latestAnalysis



17634
17635
17636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17634

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



17639
17640
17641
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17639

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


17644
17645
17646
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17644

def medium
  @medium
end

#metadata_jsonString

Optional. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


17651
17652
17653
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17651

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


17657
17658
17659
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17657

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


17662
17663
17664
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17662

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



17667
17668
17669
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17667

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



17673
17674
17675
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17673

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


17678
17679
17680
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17678

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



17683
17684
17685
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17683

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


17689
17690
17691
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17689

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


17694
17695
17696
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17694

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


17699
17700
17701
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17699

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17706
17707
17708
17709
17710
17711
17712
17713
17714
17715
17716
17717
17718
17719
17720
17721
17722
17723
17724
17725
17726
17727
17728
17729
17730
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17706

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end