Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversation.



19888
19889
19890
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


19767
19768
19769
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19767

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



19772
19773
19774
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19772

def 
  @call_metadata
end

#correlation_infoGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo

Info for correlating across conversations. Corresponds to the JSON property correlationInfo



19777
19778
19779
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19777

def correlation_info
  @correlation_info
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19782
19783
19784
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19782

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



19787
19788
19789
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19787

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



19794
19795
19796
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19794

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


19799
19800
19801
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19799

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


19805
19806
19807
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19805

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


19811
19812
19813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19811

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


19816
19817
19818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19816

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis

The analysis resource. Corresponds to the JSON property latestAnalysis



19821
19822
19823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19821

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



19826
19827
19828
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19826

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium. Corresponds to the JSON property medium

Returns:

  • (String)


19831
19832
19833
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19831

def medium
  @medium
end

#metadata_jsonString

Input only. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


19838
19839
19840
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19838

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


19844
19845
19846
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19844

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


19849
19850
19851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19849

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



19854
19855
19856
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19854

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



19860
19861
19862
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19860

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


19865
19866
19867
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19865

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



19870
19871
19872
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19870

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


19876
19877
19878
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19876

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


19881
19882
19883
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19881

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


19886
19887
19888
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19886

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19893
19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
19909
19910
19911
19912
19913
19914
19915
19916
19917
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19893

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @correlation_info = args[:correlation_info] if args.key?(:correlation_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end