Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversation
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation resource.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
An opaque, user-specified string representing the human agent who handled the conversation.
-
#call_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCallMetadata
Call-specific metadata.
-
#correlation_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo
Info for correlating across conversations.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource
The conversation source, which is a combination of transcript and audio.
-
#dialogflow_intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowIntent>
Output only.
-
#duration ⇒ String
Output only.
-
#expire_time ⇒ String
The time at which this conversation should expire.
-
#labels ⇒ Hash<String,String>
A map for the user to specify any custom fields.
-
#language_code ⇒ String
A user-specified language code for the conversation.
-
#latest_analysis ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis
The analysis resource.
-
#latest_summary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
Conversation summarization suggestion data.
-
#medium ⇒ String
Immutable.
-
#metadata_json ⇒ String
Input only.
-
#name ⇒ String
Immutable.
-
#obfuscated_user_id ⇒ String
Obfuscated user ID which the customer sent to us.
-
#quality_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata
Conversation metadata related to quality management.
-
#runtime_annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation>
Output only.
-
#start_time ⇒ String
The time at which the conversation started.
-
#transcript ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript
A message representing the transcript of a conversation.
-
#ttl ⇒ String
Input only.
-
#turn_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversation
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversation
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversation.
18877 18878 18879 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
An opaque, user-specified string representing the human agent who handled the
conversation.
Corresponds to the JSON property agentId
18756 18757 18758 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18756 def agent_id @agent_id end |
#call_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCallMetadata
Call-specific metadata.
Corresponds to the JSON property callMetadata
18761 18762 18763 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18761 def @call_metadata end |
#correlation_info ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationInfo
Info for correlating across conversations.
Corresponds to the JSON property correlationInfo
18766 18767 18768 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18766 def correlation_info @correlation_info end |
#create_time ⇒ String
Output only. The time at which the conversation was created.
Corresponds to the JSON property createTime
18771 18772 18773 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18771 def create_time @create_time end |
#data_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource
The conversation source, which is a combination of transcript and audio.
Corresponds to the JSON property dataSource
18776 18777 18778 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18776 def data_source @data_source end |
#dialogflow_intents ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowIntent>
Output only. All the matched Dialogflow intents in the call. The key
corresponds to a Dialogflow intent, format: projects/project/agent/agent/
intents/intent
Corresponds to the JSON property dialogflowIntents
18783 18784 18785 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18783 def dialogflow_intents @dialogflow_intents end |
#duration ⇒ String
Output only. The duration of the conversation.
Corresponds to the JSON property duration
18788 18789 18790 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18788 def duration @duration end |
#expire_time ⇒ String
The time at which this conversation should expire. After this time, the
conversation data and any associated analyses will be deleted.
Corresponds to the JSON property expireTime
18794 18795 18796 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18794 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
A map for the user to specify any custom fields. A maximum of 100 labels per
conversation is allowed, with a maximum of 256 characters per entry.
Corresponds to the JSON property labels
18800 18801 18802 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18800 def labels @labels end |
#language_code ⇒ String
A user-specified language code for the conversation.
Corresponds to the JSON property languageCode
18805 18806 18807 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18805 def language_code @language_code end |
#latest_analysis ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis
The analysis resource.
Corresponds to the JSON property latestAnalysis
18810 18811 18812 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18810 def latest_analysis @latest_analysis end |
#latest_summary ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
Conversation summarization suggestion data.
Corresponds to the JSON property latestSummary
18815 18816 18817 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18815 def latest_summary @latest_summary end |
#medium ⇒ String
Immutable. The conversation medium.
Corresponds to the JSON property medium
18820 18821 18822 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18820 def medium @medium end |
#metadata_json ⇒ String
Input only. JSON metadata encoded as a string. This field is primarily used by
Insights integrations with various telephony systems and must be in one of
Insight's supported formats.
Corresponds to the JSON property metadataJson
18827 18828 18829 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18827 def @metadata_json end |
#name ⇒ String
Immutable. The resource name of the conversation. Format: projects/project/
locations/location/conversations/conversation
Corresponds to the JSON property name
18833 18834 18835 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18833 def name @name end |
#obfuscated_user_id ⇒ String
Obfuscated user ID which the customer sent to us.
Corresponds to the JSON property obfuscatedUserId
18838 18839 18840 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18838 def @obfuscated_user_id end |
#quality_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata
Conversation metadata related to quality management.
Corresponds to the JSON property qualityMetadata
18843 18844 18845 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18843 def @quality_metadata end |
#runtime_annotations ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation>
Output only. The annotations that were generated during the customer and agent
interaction.
Corresponds to the JSON property runtimeAnnotations
18849 18850 18851 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18849 def runtime_annotations @runtime_annotations end |
#start_time ⇒ String
The time at which the conversation started.
Corresponds to the JSON property startTime
18854 18855 18856 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18854 def start_time @start_time end |
#transcript ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript
A message representing the transcript of a conversation.
Corresponds to the JSON property transcript
18859 18860 18861 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18859 def transcript @transcript end |
#ttl ⇒ String
Input only. The TTL for this resource. If specified, then this TTL will be
used to calculate the expire time.
Corresponds to the JSON property ttl
18865 18866 18867 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18865 def ttl @ttl end |
#turn_count ⇒ Fixnum
Output only. The number of turns in the conversation.
Corresponds to the JSON property turnCount
18870 18871 18872 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18870 def turn_count @turn_count end |
#update_time ⇒ String
Output only. The most recent time at which the conversation was updated.
Corresponds to the JSON property updateTime
18875 18876 18877 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18875 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18882 18883 18884 18885 18886 18887 18888 18889 18890 18891 18892 18893 18894 18895 18896 18897 18898 18899 18900 18901 18902 18903 18904 18905 18906 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18882 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @call_metadata = args[:call_metadata] if args.key?(:call_metadata) @correlation_info = args[:correlation_info] if args.key?(:correlation_info) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents) @duration = args[:duration] if args.key?(:duration) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @language_code = args[:language_code] if args.key?(:language_code) @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis) @latest_summary = args[:latest_summary] if args.key?(:latest_summary) @medium = args[:medium] if args.key?(:medium) @metadata_json = args[:metadata_json] if args.key?(:metadata_json) @name = args[:name] if args.key?(:name) @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id) @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata) @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations) @start_time = args[:start_time] if args.key?(:start_time) @transcript = args[:transcript] if args.key?(:transcript) @ttl = args[:ttl] if args.key?(:ttl) @turn_count = args[:turn_count] if args.key?(:turn_count) @update_time = args[:update_time] if args.key?(:update_time) end |