Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversation.



13691
13692
13693
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

An opaque, user-specified string representing the human agent who handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


13575
13576
13577
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13575

def agent_id
  @agent_id
end

#call_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCallMetadata

Call-specific metadata. Corresponds to the JSON property callMetadata



13580
13581
13582
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13580

def 
  @call_metadata
end

#create_timeString

Output only. The time at which the conversation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13585
13586
13587
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13585

def create_time
  @create_time
end

#data_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource

The conversation source, which is a combination of transcript and audio. Corresponds to the JSON property dataSource



13590
13591
13592
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13590

def data_source
  @data_source
end

#dialogflow_intentsHash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowIntent>

Output only. All the matched Dialogflow intents in the call. The key corresponds to a Dialogflow intent, format: projects/project/agent/agent/ intents/intent Corresponds to the JSON property dialogflowIntents



13597
13598
13599
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13597

def dialogflow_intents
  @dialogflow_intents
end

#durationString

Output only. The duration of the conversation. Corresponds to the JSON property duration

Returns:

  • (String)


13602
13603
13604
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13602

def duration
  @duration
end

#expire_timeString

The time at which this conversation should expire. After this time, the conversation data and any associated analyses will be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


13608
13609
13610
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13608

def expire_time
  @expire_time
end

#labelsHash<String,String>

A map for the user to specify any custom fields. A maximum of 100 labels per conversation is allowed, with a maximum of 256 characters per entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13614
13615
13616
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13614

def labels
  @labels
end

#language_codeString

A user-specified language code for the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


13619
13620
13621
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13619

def language_code
  @language_code
end

#latest_analysisGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnalysis

The analysis resource. Corresponds to the JSON property latestAnalysis



13624
13625
13626
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13624

def latest_analysis
  @latest_analysis
end

#latest_summaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property latestSummary



13629
13630
13631
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13629

def latest_summary
  @latest_summary
end

#mediumString

Immutable. The conversation medium, if unspecified will default to PHONE_CALL. Corresponds to the JSON property medium

Returns:

  • (String)


13634
13635
13636
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13634

def medium
  @medium
end

#metadata_jsonString

Input only. JSON metadata encoded as a string. This field is primarily used by Insights integrations with various telephony systems and must be in one of Insight's supported formats. Corresponds to the JSON property metadataJson

Returns:

  • (String)


13641
13642
13643
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13641

def 
  @metadata_json
end

#nameString

Immutable. The resource name of the conversation. Format: projects/project/ locations/location/conversations/conversation Corresponds to the JSON property name

Returns:

  • (String)


13647
13648
13649
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13647

def name
  @name
end

#obfuscated_user_idString

Obfuscated user ID which the customer sent to us. Corresponds to the JSON property obfuscatedUserId

Returns:

  • (String)


13652
13653
13654
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13652

def obfuscated_user_id
  @obfuscated_user_id
end

#quality_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata

Conversation metadata related to quality management. Corresponds to the JSON property qualityMetadata



13657
13658
13659
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13657

def 
  @quality_metadata
end

#runtime_annotationsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation>

Output only. The annotations that were generated during the customer and agent interaction. Corresponds to the JSON property runtimeAnnotations



13663
13664
13665
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13663

def runtime_annotations
  @runtime_annotations
end

#start_timeString

The time at which the conversation started. Corresponds to the JSON property startTime

Returns:

  • (String)


13668
13669
13670
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13668

def start_time
  @start_time
end

#transcriptGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscript

A message representing the transcript of a conversation. Corresponds to the JSON property transcript



13673
13674
13675
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13673

def transcript
  @transcript
end

#ttlString

Input only. The TTL for this resource. If specified, then this TTL will be used to calculate the expire time. Corresponds to the JSON property ttl

Returns:

  • (String)


13679
13680
13681
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13679

def ttl
  @ttl
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


13684
13685
13686
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13684

def turn_count
  @turn_count
end

#update_timeString

Output only. The most recent time at which the conversation was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


13689
13690
13691
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13689

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13696
13697
13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
13710
13711
13712
13713
13714
13715
13716
13717
13718
13719
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13696

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @call_metadata = args[:call_metadata] if args.key?(:call_metadata)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @dialogflow_intents = args[:dialogflow_intents] if args.key?(:dialogflow_intents)
  @duration = args[:duration] if args.key?(:duration)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @latest_analysis = args[:latest_analysis] if args.key?(:latest_analysis)
  @latest_summary = args[:latest_summary] if args.key?(:latest_summary)
  @medium = args[:medium] if args.key?(:medium)
  @metadata_json = args[:metadata_json] if args.key?(:metadata_json)
  @name = args[:name] if args.key?(:name)
  @obfuscated_user_id = args[:obfuscated_user_id] if args.key?(:obfuscated_user_id)
  @quality_metadata = args[:quality_metadata] if args.key?(:quality_metadata)
  @runtime_annotations = args[:runtime_annotations] if args.key?(:runtime_annotations)
  @start_time = args[:start_time] if args.key?(:start_time)
  @transcript = args[:transcript] if args.key?(:transcript)
  @ttl = args[:ttl] if args.key?(:ttl)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @update_time = args[:update_time] if args.key?(:update_time)
end