Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The result of a single correlation rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult.



17842
17843
17844
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#correlation_idString

The correlation ID generated by the join key expression. Corresponds to the JSON property correlationId

Returns:

  • (String)


17825
17826
17827
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17825

def correlation_id
  @correlation_id
end

#errorGoogle::Apis::ContactcenterinsightsV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



17835
17836
17837
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17835

def error
  @error
end

#rule_idString

The rule ID. Corresponds to the JSON property ruleId

Returns:

  • (String)


17840
17841
17842
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17840

def rule_id
  @rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17847
17848
17849
17850
17851
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17847

def update!(**args)
  @correlation_id = args[:correlation_id] if args.key?(:correlation_id)
  @error = args[:error] if args.key?(:error)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
end