Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The result of a single correlation rule.
Instance Attribute Summary collapse
-
#correlation_id ⇒ String
The correlation ID generated by the join key expression.
-
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#rule_id ⇒ String
The rule ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationCorrelationResultRuleCorrelationResult.
19919 19920 19921 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#correlation_id ⇒ String
The correlation ID generated by the join key expression.
Corresponds to the JSON property correlationId
19902 19903 19904 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19902 def correlation_id @correlation_id end |
#error ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
19912 19913 19914 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19912 def error @error end |
#rule_id ⇒ String
The rule ID.
Corresponds to the JSON property ruleId
19917 19918 19919 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19917 def rule_id @rule_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19924 19925 19926 19927 19928 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19924 def update!(**args) @correlation_id = args[:correlation_id] if args.key?(:correlation_id) @error = args[:error] if args.key?(:error) @rule_id = args[:rule_id] if args.key?(:rule_id) end |