Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation source, which is a combination of transcript and audio.
Instance Attribute Summary collapse
-
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource
A Dialogflow source of conversation data.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource
A Cloud Storage source of conversation data.
-
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation metadata.
-
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio for each turn.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationDataSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationDataSource
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationDataSource.
18068 18069 18070 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource
A Dialogflow source of conversation data.
Corresponds to the JSON property dialogflowSource
18048 18049 18050 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18048 def dialogflow_source @dialogflow_source end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource
A Cloud Storage source of conversation data.
Corresponds to the JSON property gcsSource
18053 18054 18055 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18053 def gcs_source @gcs_source end |
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation
metadata.
Corresponds to the JSON property metadataUri
18059 18060 18061 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18059 def @metadata_uri end |
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio
for each turn. Assume the order of the URIs is the same as the order of the
transcript turns.
Corresponds to the JSON property turnLevelAudios
18066 18067 18068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18066 def turn_level_audios @turn_level_audios end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18073 18074 18075 18076 18077 18078 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18073 def update!(**args) @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri) @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios) end |