Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation source, which is a combination of transcript and audio.
Instance Attribute Summary collapse
-
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource
A Dialogflow source of conversation data.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource
A Cloud Storage source of conversation data.
-
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation metadata.
-
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio for each turn.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationDataSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationDataSource
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationDataSource.
17875 17876 17877 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dialogflow_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource
A Dialogflow source of conversation data.
Corresponds to the JSON property dialogflowSource
17855 17856 17857 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17855 def dialogflow_source @dialogflow_source end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource
A Cloud Storage source of conversation data.
Corresponds to the JSON property gcsSource
17860 17861 17862 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17860 def gcs_source @gcs_source end |
#metadata_uri ⇒ String
Cloud Storage URI that points to a file that contains the conversation
metadata.
Corresponds to the JSON property metadataUri
17866 17867 17868 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17866 def @metadata_uri end |
#turn_level_audios ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio>
Cloud Storage URIs that points to files that contain the conversation audio
for each turn. Assume the order of the URIs is the same as the order of the
transcript turns.
Corresponds to the JSON property turnLevelAudios
17873 17874 17875 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17873 def turn_level_audios @turn_level_audios end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17880 17881 17882 17883 17884 17885 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17880 def update!(**args) @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri) @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios) end |