Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation source, which is a combination of transcript and audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationDataSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationDataSource.



19057
19058
19059
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialogflow_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource

A Dialogflow source of conversation data. Corresponds to the JSON property dialogflowSource



19037
19038
19039
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19037

def dialogflow_source
  @dialogflow_source
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource

A Cloud Storage source of conversation data. Corresponds to the JSON property gcsSource



19042
19043
19044
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19042

def gcs_source
  @gcs_source
end

#metadata_uriString

Cloud Storage URI that points to a file that contains the conversation metadata. Corresponds to the JSON property metadataUri

Returns:

  • (String)


19048
19049
19050
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19048

def 
  @metadata_uri
end

#turn_level_audiosArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio>

Cloud Storage URIs that points to files that contain the conversation audio for each turn. Assume the order of the URIs is the same as the order of the transcript turns. Corresponds to the JSON property turnLevelAudios



19055
19056
19057
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19055

def turn_level_audios
  @turn_level_audios
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19062
19063
19064
19065
19066
19067
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19062

def update!(**args)
  @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri)
  @turn_level_audios = args[:turn_level_audios] if args.key?(:turn_level_audios)
end