Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The conversation source, which is a combination of transcript and audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationDataSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationDataSource.



13767
13768
13769
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialogflow_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowSource

A Dialogflow source of conversation data. Corresponds to the JSON property dialogflowSource



13754
13755
13756
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13754

def dialogflow_source
  @dialogflow_source
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource

A Cloud Storage source of conversation data. Corresponds to the JSON property gcsSource



13759
13760
13761
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13759

def gcs_source
  @gcs_source
end

#metadata_uriString

Cloud Storage URI that points to a file that contains the conversation metadata. Corresponds to the JSON property metadataUri

Returns:

  • (String)


13765
13766
13767
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13765

def 
  @metadata_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13772
13773
13774
13775
13776
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 13772

def update!(**args)
  @dialogflow_source = args[:dialogflow_source] if args.key?(:dialogflow_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @metadata_uri = args[:metadata_uri] if args.key?(:metadata_uri)
end