Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationLevelSentiment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationLevelSentiment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
One channel of conversation-level sentiment data.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
The channel of the audio that the data applies to.
-
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationLevelSentiment
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationLevelSentiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationLevelSentiment
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationLevelSentiment.
17087 17088 17089 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
The channel of the audio that the data applies to.
Corresponds to the JSON property channelTag
17080 17081 17082 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17080 def channel_tag @channel_tag end |
#sentiment_data ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentimentData
17085 17086 17087 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17085 def sentiment_data @sentiment_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17092 17093 17094 17095 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17092 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @sentiment_data = args[:sentiment_data] if args.key?(:sentiment_data) end |