Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation metadata related to quality management.
Instance Attribute Summary collapse
-
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
-
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
-
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFeedbackLabel>
Input only.
-
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
-
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationQualityMetadata.
19220 19221 19222 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_info ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationQualityMetadataAgentInfo>
Information about agents involved in the call.
Corresponds to the JSON property agentInfo
19198 19199 19200 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19198 def agent_info @agent_info end |
#customer_satisfaction_rating ⇒ Fixnum
An arbitrary integer value indicating the customer's satisfaction rating.
Corresponds to the JSON property customerSatisfactionRating
19203 19204 19205 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19203 def @customer_satisfaction_rating end |
#feedback_labels ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFeedbackLabel>
Input only. The feedback labels associated with the conversation.
Corresponds to the JSON property feedbackLabels
19208 19209 19210 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19208 def feedback_labels @feedback_labels end |
#menu_path ⇒ String
An arbitrary string value specifying the menu path the customer took.
Corresponds to the JSON property menuPath
19213 19214 19215 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19213 def @menu_path end |
#wait_duration ⇒ String
The amount of time the customer waited to connect with an agent.
Corresponds to the JSON property waitDuration
19218 19219 19220 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19218 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19225 19226 19227 19228 19229 19230 19231 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19225 def update!(**args) @agent_info = args[:agent_info] if args.key?(:agent_info) @customer_satisfaction_rating = args[:customer_satisfaction_rating] if args.key?(:customer_satisfaction_rating) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @menu_path = args[:menu_path] if args.key?(:menu_path) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |