Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Conversation summarization suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData.



18382
18383
18384
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property answerRecord

Returns:

  • (String)


18346
18347
18348
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18346

def answer_record
  @answer_record
end

#confidenceFloat

The confidence score of the summarization. Corresponds to the JSON property confidence

Returns:

  • (Float)


18351
18352
18353
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18351

def confidence
  @confidence
end

#conversation_modelString

The name of the model that generates this summary. Format: projects/project/ locations/location/conversationModels/conversation_model Corresponds to the JSON property conversationModel

Returns:

  • (String)


18357
18358
18359
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18357

def conversation_model
  @conversation_model
end

#generator_idString

Agent Assist generator ID. Corresponds to the JSON property generatorId

Returns:

  • (String)


18362
18363
18364
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18362

def generator_id
  @generator_id
end

#metadataHash<String,String>

A map that contains metadata about the summarization and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


18368
18369
18370
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18368

def 
  @metadata
end

#textString

The summarization content that is concatenated into one string. Corresponds to the JSON property text

Returns:

  • (String)


18373
18374
18375
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18373

def text
  @text
end

#text_sectionsHash<String,String>

The summarization content that is divided into sections. The key is the section's name and the value is the section's content. There is no specific format for the key or value. Corresponds to the JSON property textSections

Returns:

  • (Hash<String,String>)


18380
18381
18382
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18380

def text_sections
  @text_sections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18387
18388
18389
18390
18391
18392
18393
18394
18395
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18387

def update!(**args)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @confidence = args[:confidence] if args.key?(:confidence)
  @conversation_model = args[:conversation_model] if args.key?(:conversation_model)
  @generator_id = args[:generator_id] if args.key?(:generator_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @text = args[:text] if args.key?(:text)
  @text_sections = args[:text_sections] if args.key?(:text_sections)
end