Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Conversation summarization suggestion data.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
The name of the answer record.
-
#confidence ⇒ Float
The confidence score of the summarization.
-
#conversation_model ⇒ String
The name of the model that generates this summary.
-
#generator_id ⇒ String
Agent Assist generator ID.
-
#metadata ⇒ Hash<String,String>
A map that contains metadata about the summarization and the document from which it originates.
-
#text ⇒ String
The summarization content that is concatenated into one string.
-
#text_sections ⇒ Hash<String,String>
The summarization content that is divided into sections.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData.
18189 18190 18191 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property answerRecord
18153 18154 18155 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18153 def answer_record @answer_record end |
#confidence ⇒ Float
The confidence score of the summarization.
Corresponds to the JSON property confidence
18158 18159 18160 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18158 def confidence @confidence end |
#conversation_model ⇒ String
The name of the model that generates this summary. Format: projects/project/
locations/location/conversationModels/conversation_model
Corresponds to the JSON property conversationModel
18164 18165 18166 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18164 def conversation_model @conversation_model end |
#generator_id ⇒ String
Agent Assist generator ID.
Corresponds to the JSON property generatorId
18169 18170 18171 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18169 def generator_id @generator_id end |
#metadata ⇒ Hash<String,String>
A map that contains metadata about the summarization and the document from
which it originates.
Corresponds to the JSON property metadata
18175 18176 18177 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18175 def @metadata end |
#text ⇒ String
The summarization content that is concatenated into one string.
Corresponds to the JSON property text
18180 18181 18182 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18180 def text @text end |
#text_sections ⇒ Hash<String,String>
The summarization content that is divided into sections. The key is the
section's name and the value is the section's content. There is no specific
format for the key or value.
Corresponds to the JSON property textSections
18187 18188 18189 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18187 def text_sections @text_sections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18194 18195 18196 18197 18198 18199 18200 18201 18202 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18194 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @confidence = args[:confidence] if args.key?(:confidence) @conversation_model = args[:conversation_model] if args.key?(:conversation_model) @generator_id = args[:generator_id] if args.key?(:generator_id) @metadata = args[:metadata] if args.key?(:metadata) @text = args[:text] if args.key?(:text) @text_sections = args[:text_sections] if args.key?(:text_sections) end |