Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A segment of a full transcript.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment.



20360
20361
20362
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_tagFixnum

For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel. For audioChannelCount = N, its output values can range from '1' to 'N'. A channel tag of 0 indicates that the audio is mono. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


20311
20312
20313
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20311

def channel_tag
  @channel_tag
end

#confidenceFloat

A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A default value of 0.0 indicates that the value is unset. Corresponds to the JSON property confidence

Returns:

  • (Float)


20317
20318
20319
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20317

def confidence
  @confidence
end

#dialogflow_segment_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Metadata from Dialogflow relating to the current transcript segment. Corresponds to the JSON property dialogflowSegmentMetadata



20322
20323
20324
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20322

def 
  @dialogflow_segment_metadata
end

#language_codeString

The language code of this segment as a BCP-47 language tag. Example: "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


20328
20329
20330
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20328

def language_code
  @language_code
end

#message_timeString

The time that the message occurred, if provided. Corresponds to the JSON property messageTime

Returns:

  • (String)


20333
20334
20335
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20333

def message_time
  @message_time
end

#segment_participantGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationParticipant

The call participant speaking for a given utterance. Corresponds to the JSON property segmentParticipant



20338
20339
20340
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20338

def segment_participant
  @segment_participant
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



20343
20344
20345
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20343

def sentiment
  @sentiment
end

#textString

The text of this segment. Corresponds to the JSON property text

Returns:

  • (String)


20348
20349
20350
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20348

def text
  @text
end

#turn_level_audioGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio

A wrapper for holding the audio for any given turn. Corresponds to the JSON property turnLevelAudio



20353
20354
20355
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20353

def turn_level_audio
  @turn_level_audio
end

#wordsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo>

A list of the word-specific information for each word in the segment. Corresponds to the JSON property words



20358
20359
20360
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20358

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20365
20366
20367
20368
20369
20370
20371
20372
20373
20374
20375
20376
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20365

def update!(**args)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @confidence = args[:confidence] if args.key?(:confidence)
  @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata)
  @language_code = args[:language_code] if args.key?(:language_code)
  @message_time = args[:message_time] if args.key?(:message_time)
  @segment_participant = args[:segment_participant] if args.key?(:segment_participant)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @text = args[:text] if args.key?(:text)
  @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio)
  @words = args[:words] if args.key?(:words)
end