Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A segment of a full transcript.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment.



19459
19460
19461
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_tagFixnum

For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel. For audioChannelCount = N, its output values can range from '1' to 'N'. A channel tag of 0 indicates that the audio is mono. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


19410
19411
19412
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19410

def channel_tag
  @channel_tag
end

#confidenceFloat

A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A default value of 0.0 indicates that the value is unset. Corresponds to the JSON property confidence

Returns:

  • (Float)


19416
19417
19418
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19416

def confidence
  @confidence
end

#dialogflow_segment_metadataGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Metadata from Dialogflow relating to the current transcript segment. Corresponds to the JSON property dialogflowSegmentMetadata



19421
19422
19423
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19421

def 
  @dialogflow_segment_metadata
end

#language_codeString

The language code of this segment as a BCP-47 language tag. Example: "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


19427
19428
19429
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19427

def language_code
  @language_code
end

#message_timeString

The time that the message occurred, if provided. Corresponds to the JSON property messageTime

Returns:

  • (String)


19432
19433
19434
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19432

def message_time
  @message_time
end

#segment_participantGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationParticipant

The call participant speaking for a given utterance. Corresponds to the JSON property segmentParticipant



19437
19438
19439
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19437

def segment_participant
  @segment_participant
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



19442
19443
19444
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19442

def sentiment
  @sentiment
end

#textString

The text of this segment. Corresponds to the JSON property text

Returns:

  • (String)


19447
19448
19449
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19447

def text
  @text
end

#turn_level_audioGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationDataSourceTurnLevelAudio

A wrapper for holding the audio for any given turn. Corresponds to the JSON property turnLevelAudio



19452
19453
19454
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19452

def turn_level_audio
  @turn_level_audio
end

#wordsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo>

A list of the word-specific information for each word in the segment. Corresponds to the JSON property words



19457
19458
19459
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19457

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19464
19465
19466
19467
19468
19469
19470
19471
19472
19473
19474
19475
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19464

def update!(**args)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @confidence = args[:confidence] if args.key?(:confidence)
  @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata)
  @language_code = args[:language_code] if args.key?(:language_code)
  @message_time = args[:message_time] if args.key?(:message_time)
  @segment_participant = args[:segment_participant] if args.key?(:segment_participant)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @text = args[:text] if args.key?(:text)
  @turn_level_audio = args[:turn_level_audio] if args.key?(:turn_level_audio)
  @words = args[:words] if args.key?(:words)
end