Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A segment of a full transcript.
Instance Attribute Summary collapse
-
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number corresponding to the audio from that channel.
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment.
-
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
-
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag.
-
#message_time ⇒ String
The time that the message occurred, if provided.
-
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationParticipant
The call participant speaking for a given utterance.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
-
#text ⇒ String
The text of this segment.
-
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegment.
14132 14133 14134 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_tag ⇒ Fixnum
For conversations derived from multi-channel audio, this is the channel number
corresponding to the audio from that channel. For audioChannelCount = N, its
output values can range from '1' to 'N'. A channel tag of 0 indicates that the
audio is mono.
Corresponds to the JSON property channelTag
14088 14089 14090 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14088 def channel_tag @channel_tag end |
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this segment. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
14094 14095 14096 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14094 def confidence @confidence end |
#dialogflow_segment_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
Corresponds to the JSON property dialogflowSegmentMetadata
14099 14100 14101 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14099 def @dialogflow_segment_metadata end |
#language_code ⇒ String
The language code of this segment as a BCP-47 language tag. Example: "en-US".
Corresponds to the JSON property languageCode
14105 14106 14107 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14105 def language_code @language_code end |
#message_time ⇒ String
The time that the message occurred, if provided.
Corresponds to the JSON property messageTime
14110 14111 14112 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14110 def @message_time end |
#segment_participant ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationParticipant
The call participant speaking for a given utterance.
Corresponds to the JSON property segmentParticipant
14115 14116 14117 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14115 def segment_participant @segment_participant end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
14120 14121 14122 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14120 def sentiment @sentiment end |
#text ⇒ String
The text of this segment.
Corresponds to the JSON property text
14125 14126 14127 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14125 def text @text end |
#words ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo>
A list of the word-specific information for each word in the segment.
Corresponds to the JSON property words
14130 14131 14132 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14130 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14137 14138 14139 14140 14141 14142 14143 14144 14145 14146 14147 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14137 def update!(**args) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @confidence = args[:confidence] if args.key?(:confidence) @dialogflow_segment_metadata = args[:dialogflow_segment_metadata] if args.key?(:dialogflow_segment_metadata) @language_code = args[:language_code] if args.key?(:language_code) @message_time = args[:message_time] if args.key?(:message_time) @segment_participant = args[:segment_participant] if args.key?(:segment_participant) @sentiment = args[:sentiment] if args.key?(:sentiment) @text = args[:text] if args.key?(:text) @words = args[:words] if args.key?(:words) end |