Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata from Dialogflow relating to the current transcript segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata.



17455
17456
17457
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#smart_reply_allowlist_coveredBoolean Also known as: smart_reply_allowlist_covered?

Whether the transcript segment was covered under the configured smart reply allowlist in Agent Assist. Corresponds to the JSON property smartReplyAllowlistCovered

Returns:

  • (Boolean)


17452
17453
17454
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17452

def smart_reply_allowlist_covered
  @smart_reply_allowlist_covered
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17460
17461
17462
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17460

def update!(**args)
  @smart_reply_allowlist_covered = args[:smart_reply_allowlist_covered] if args.key?(:smart_reply_allowlist_covered)
end