Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Word-level info for words in a transcript.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word.
-
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total conversation.
-
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total conversation.
-
#word ⇒ String
The word itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo.
18356 18357 18358 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
18337 18338 18339 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18337 def confidence @confidence end |
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property endOffset
18343 18344 18345 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18343 def end_offset @end_offset end |
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property startOffset
18349 18350 18351 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18349 def start_offset @start_offset end |
#word ⇒ String
The word itself. Includes punctuation marks that surround the word.
Corresponds to the JSON property word
18354 18355 18356 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18354 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18361 18362 18363 18364 18365 18366 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18361 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |