Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Word-level info for words in a transcript.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word.
-
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total conversation.
-
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total conversation.
-
#word ⇒ String
The word itself.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo
Returns a new instance of GoogleCloudContactcenterinsightsV1mainConversationTranscriptTranscriptSegmentWordInfo.
17492 17493 17494 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
A confidence estimate between 0.0 and 1.0 of the fidelity of this word. A
default value of 0.0 indicates that the value is unset.
Corresponds to the JSON property confidence
17473 17474 17475 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17473 def confidence @confidence end |
#end_offset ⇒ String
Time offset of the end of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property endOffset
17479 17480 17481 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17479 def end_offset @end_offset end |
#start_offset ⇒ String
Time offset of the start of this word relative to the beginning of the total
conversation.
Corresponds to the JSON property startOffset
17485 17486 17487 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17485 def start_offset @start_offset end |
#word ⇒ String
The word itself. Includes punctuation marks that surround the word.
Corresponds to the JSON property word
17490 17491 17492 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17490 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17497 17498 17499 17500 17501 17502 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17497 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |