Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDataset

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDataset.



20747
20748
20749
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


20714
20715
20716
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20714

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


20719
20720
20721
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20719

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


20724
20725
20726
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20724

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


20730
20731
20732
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20730

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


20735
20736
20737
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20735

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


20740
20741
20742
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20740

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


20745
20746
20747
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20745

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20752
20753
20754
20755
20756
20757
20758
20759
20760
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20752

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end