Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDataset

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDataset.



20631
20632
20633
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


20598
20599
20600
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20598

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


20603
20604
20605
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20603

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


20608
20609
20610
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20608

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


20614
20615
20616
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20614

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


20619
20620
20621
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20619

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


20624
20625
20626
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20624

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


20629
20630
20631
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20629

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20636
20637
20638
20639
20640
20641
20642
20643
20644
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20636

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end