Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Dataset description.
-
#display_name ⇒ String
Display name for the dataaset Corresponds to the JSON property
displayName. -
#name ⇒ String
Immutable.
-
#ttl ⇒ String
Optional.
-
#type ⇒ String
Dataset usage type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDataset
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDataset
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDataset.
19730 19731 19732 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Dataset create time.
Corresponds to the JSON property createTime
19697 19698 19699 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19697 def create_time @create_time end |
#description ⇒ String
Dataset description.
Corresponds to the JSON property description
19702 19703 19704 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19702 def description @description end |
#display_name ⇒ String
Display name for the dataaset
Corresponds to the JSON property displayName
19707 19708 19709 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19707 def display_name @display_name end |
#name ⇒ String
Immutable. Identifier. Resource name of the dataset. Format: projects/project
/locations/location/datasets/dataset
Corresponds to the JSON property name
19713 19714 19715 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19713 def name @name end |
#ttl ⇒ String
Optional. Option TTL for the dataset.
Corresponds to the JSON property ttl
19718 19719 19720 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19718 def ttl @ttl end |
#type ⇒ String
Dataset usage type.
Corresponds to the JSON property type
19723 19724 19725 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19723 def type @type end |
#update_time ⇒ String
Output only. Dataset update time.
Corresponds to the JSON property updateTime
19728 19729 19730 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19728 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19735 19736 19737 19738 19739 19740 19741 19742 19743 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19735 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |