Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDataset

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDataset.



14402
14403
14404
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Dataset create time. Corresponds to the JSON property createTime

Returns:

  • (String)


14369
14370
14371
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14369

def create_time
  @create_time
end

#descriptionString

Dataset description. Corresponds to the JSON property description

Returns:

  • (String)


14374
14375
14376
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14374

def description
  @description
end

#display_nameString

Display name for the dataaset Corresponds to the JSON property displayName

Returns:

  • (String)


14379
14380
14381
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14379

def display_name
  @display_name
end

#nameString

Immutable. Identifier. Resource name of the dataset. Format: projects/project /locations/location/datasets/dataset Corresponds to the JSON property name

Returns:

  • (String)


14385
14386
14387
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14385

def name
  @name
end

#ttlString

Optional. Option TTL for the dataset. Corresponds to the JSON property ttl

Returns:

  • (String)


14390
14391
14392
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14390

def ttl
  @ttl
end

#typeString

Dataset usage type. Corresponds to the JSON property type

Returns:

  • (String)


14395
14396
14397
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14395

def type
  @type
end

#update_timeString

Output only. Dataset update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


14400
14401
14402
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14400

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14407
14408
14409
14410
14411
14412
14413
14414
14415
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 14407

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end