Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for a DiagnoseConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata.



20866
20867
20868
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20817
20818
20819
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20817

def create_time
  @create_time
end

#diagnostic_reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport

A diagnostic report containing aggregate metrics and intent breakdowns. Corresponds to the JSON property diagnosticReport



20822
20823
20824
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20822

def diagnostic_report
  @diagnostic_report
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


20827
20828
20829
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20827

def end_time
  @end_time
end

#full_reportBoolean Also known as: full_report?

Output only. If true, the agent generated a full diagnostic report for all sub- agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


20833
20834
20835
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20833

def full_report
  @full_report
end

#latest_stepGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep

A step in the agent's reasoning process (Trajectory Step). Corresponds to the JSON property latestStep



20839
20840
20841
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20839

def latest_step
  @latest_step
end

#metric_typeString

Output only. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


20844
20845
20846
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20844

def metric_type
  @metric_type
end

#partial_trajectoriesArray<String>

Output only. Deprecated: Use partial_trajectory_steps instead. Output only. The intermediate trajectory updates (partial trajectory). Corresponds to the JSON property partialTrajectories

Returns:

  • (Array<String>)


20850
20851
20852
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20850

def partial_trajectories
  @partial_trajectories
end

#partial_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>

Output only. The intermediate trajectory updates. This can be used for live progress tracking of the agent's thoughts and actions as it works through the analysis. Corresponds to the JSON property partialTrajectorySteps



20857
20858
20859
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20857

def partial_trajectory_steps
  @partial_trajectory_steps
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution. Corresponds to the JSON property request



20864
20865
20866
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20864

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20871
20872
20873
20874
20875
20876
20877
20878
20879
20880
20881
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20871

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report)
  @end_time = args[:end_time] if args.key?(:end_time)
  @full_report = args[:full_report] if args.key?(:full_report)
  @latest_step = args[:latest_step] if args.key?(:latest_step)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories)
  @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps)
  @request = args[:request] if args.key?(:request)
end