Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for a DiagnoseConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsMetadata.



19965
19966
19967
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19916
19917
19918
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19916

def create_time
  @create_time
end

#diagnostic_reportGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport

A diagnostic report containing aggregate metrics and intent breakdowns. Corresponds to the JSON property diagnosticReport



19921
19922
19923
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19921

def diagnostic_report
  @diagnostic_report
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


19926
19927
19928
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19926

def end_time
  @end_time
end

#full_reportBoolean Also known as: full_report?

Output only. If true, the agent generated a full diagnostic report for all sub- agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


19932
19933
19934
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19932

def full_report
  @full_report
end

#latest_stepGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep

A step in the agent's reasoning process (Trajectory Step). Corresponds to the JSON property latestStep



19938
19939
19940
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19938

def latest_step
  @latest_step
end

#metric_typeString

Output only. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


19943
19944
19945
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19943

def metric_type
  @metric_type
end

#partial_trajectoriesArray<String>

Output only. Deprecated: Use partial_trajectory_steps instead. The intermediate trajectory updates (partial trajectory). Corresponds to the JSON property partialTrajectories

Returns:

  • (Array<String>)


19949
19950
19951
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19949

def partial_trajectories
  @partial_trajectories
end

#partial_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>

Output only. The intermediate trajectory updates. This can be used for live progress tracking of the agent's thoughts and actions as it works through the analysis. Corresponds to the JSON property partialTrajectorySteps



19956
19957
19958
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19956

def partial_trajectory_steps
  @partial_trajectory_steps
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution. Corresponds to the JSON property request



19963
19964
19965
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19963

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19970
19971
19972
19973
19974
19975
19976
19977
19978
19979
19980
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19970

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @diagnostic_report = args[:diagnostic_report] if args.key?(:diagnostic_report)
  @end_time = args[:end_time] if args.key?(:end_time)
  @full_report = args[:full_report] if args.key?(:full_report)
  @latest_step = args[:latest_step] if args.key?(:latest_step)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @partial_trajectories = args[:partial_trajectories] if args.key?(:partial_trajectories)
  @partial_trajectory_steps = args[:partial_trajectory_steps] if args.key?(:partial_trajectory_steps)
  @request = args[:request] if args.key?(:request)
end