Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to analyze conversation data using agentic workflows. This RPC triggers a complex analysis process that may involve several steps of reasoning and tool execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsRequest.



20055
20056
20057
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dry_runBoolean Also known as: dry_run?

Optional. If true, the request will be validated and a simulation of the analysis will be performed without actually executing the task. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


19993
19994
19995
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19993

def dry_run
  @dry_run
end

#filterString

Optional. AIP-160 compliant filter for selecting target conversations. Corresponds to the JSON property filter

Returns:

  • (String)


19999
20000
20001
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19999

def filter
  @filter
end

#full_reportBoolean Also known as: full_report?

Optional. If true, the agent will generate a full diagnostic report for all sub-agents. Corresponds to the JSON property fullReport

Returns:

  • (Boolean)


20005
20006
20007
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20005

def full_report
  @full_report
end

#instructionsString

Optional. Specific instructions for the agent. Corresponds to the JSON property instructions

Returns:

  • (String)


20011
20012
20013
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20011

def instructions
  @instructions
end

#max_stepsFixnum

Optional. The maximum number of steps the agent can take during the execution of the task. Defaults to 10. Corresponds to the JSON property maxSteps

Returns:

  • (Fixnum)


20017
20018
20019
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20017

def max_steps
  @max_steps
end

#metric_typeString

Optional. The type of metric being diagnosed. Corresponds to the JSON property metricType

Returns:

  • (String)


20022
20023
20024
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20022

def metric_type
  @metric_type
end

#output_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainOutputConfig

Configuration for where to export or return the analysis findings. Corresponds to the JSON property outputConfig



20027
20028
20029
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20027

def output_config
  @output_config
end

#parentString

Required. The parent resource where the analysis will be performed. Corresponds to the JSON property parent

Returns:

  • (String)


20032
20033
20034
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20032

def parent
  @parent
end

#request_idString

Optional. Required. A unique ID that identifies the request. If the service receives two DiagnoseConversationsRequests with the same request_id, then the second request will be ignored; instead, the response of the first request will be returned. The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters. Corresponds to the JSON property requestId

Returns:

  • (String)


20041
20042
20043
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20041

def request_id
  @request_id
end

#task_queryString

Optional. A natural language description of the analysis goal or question. Corresponds to the JSON property taskQuery

Returns:

  • (String)


20046
20047
20048
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20046

def task_query
  @task_query
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If true, the request will only be validated (permissions, filter syntax, etc.) without actually triggering the analysis. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


20052
20053
20054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20052

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20060
20061
20062
20063
20064
20065
20066
20067
20068
20069
20070
20071
20072
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20060

def update!(**args)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @filter = args[:filter] if args.key?(:filter)
  @full_report = args[:full_report] if args.key?(:full_report)
  @instructions = args[:instructions] if args.key?(:instructions)
  @max_steps = args[:max_steps] if args.key?(:max_steps)
  @metric_type = args[:metric_type] if args.key?(:metric_type)
  @output_config = args[:output_config] if args.key?(:output_config)
  @parent = args[:parent] if args.key?(:parent)
  @request_id = args[:request_id] if args.key?(:request_id)
  @task_query = args[:task_query] if args.key?(:task_query)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end