Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The response from a DiagnoseConversations request.
Instance Attribute Summary collapse
-
#answer ⇒ String
Output only.
-
#export_uri ⇒ String
Output only.
-
#full_trajectories ⇒ Array<String>
Output only.
-
#full_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse.
21010 21011 21012 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer ⇒ String
Output only. Deprecated: Output only. The final, high-level answer or
diagnostic summary returned by the Sherlock worker is deprecated. The
persistent analysis summary is stored inside the Diagnostic resource instead.
Corresponds to the JSON property answer
20988 20989 20990 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20988 def answer @answer end |
#export_uri ⇒ String
Output only. Deprecated: Output only. If an external destination was requested,
the URI of the exported data is deprecated. The persistent diagnostic details
are stored inside the Diagnostic resource instead.
Corresponds to the JSON property exportUri
20995 20996 20997 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20995 def export_uri @export_uri end |
#full_trajectories ⇒ Array<String>
Output only. Deprecated: Use full_trajectory_steps instead. Output only. The
complete sequence of thoughts and actions (full trajectory).
Corresponds to the JSON property fullTrajectories
21001 21002 21003 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21001 def full_trajectories @full_trajectories end |
#full_trajectory_steps ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>
Output only. Deprecated: Output only. The complete sequence of thoughts and
actions taken by the agent is deprecated under LRO response completions. Use
the persistent details inside the Diagnostic resource instead.
Corresponds to the JSON property fullTrajectorySteps
21008 21009 21010 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21008 def full_trajectory_steps @full_trajectory_steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21015 21016 21017 21018 21019 21020 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21015 def update!(**args) @answer = args[:answer] if args.key?(:answer) @export_uri = args[:export_uri] if args.key?(:export_uri) @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories) @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps) end |