Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The response from a DiagnoseConversations request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse

Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnoseConversationsResponse.



20102
20103
20104
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

Output only. The final, high-level answer or diagnostic summary returned by the Sherlock worker. Corresponds to the JSON property answer

Returns:

  • (String)


20083
20084
20085
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20083

def answer
  @answer
end

#export_uriString

Output only. If an external destination was requested, the URI of the exported data. Corresponds to the JSON property exportUri

Returns:

  • (String)


20089
20090
20091
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20089

def export_uri
  @export_uri
end

#full_trajectoriesArray<String>

Output only. Deprecated: Use full_trajectory_steps instead. The complete sequence of thoughts and actions (full trajectory). Corresponds to the JSON property fullTrajectories

Returns:

  • (Array<String>)


20095
20096
20097
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20095

def full_trajectories
  @full_trajectories
end

#full_trajectory_stepsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep>

Output only. The complete sequence of thoughts and actions taken by the agent. Corresponds to the JSON property fullTrajectorySteps



20100
20101
20102
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20100

def full_trajectory_steps
  @full_trajectory_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20107
20108
20109
20110
20111
20112
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20107

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @export_uri = args[:export_uri] if args.key?(:export_uri)
  @full_trajectories = args[:full_trajectories] if args.key?(:full_trajectories)
  @full_trajectory_steps = args[:full_trajectory_steps] if args.key?(:full_trajectory_steps)
end