Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A diagnostic report containing aggregate metrics and intent breakdowns.
Instance Attribute Summary collapse
-
#conversation_slices ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportConversationSlice>
Output only.
-
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportIntentStats>
Output only.
-
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern>
Output only.
-
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue>
Output only.
-
#report ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnosticReport
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDiagnosticReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnosticReport
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnosticReport.
21053 21054 21055 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_slices ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportConversationSlice>
Output only. A map of conversation slices used in the report.
Corresponds to the JSON property conversationSlices
21030 21031 21032 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21030 def conversation_slices @conversation_slices end |
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportIntentStats>
Output only. Deprecated: Intent breakdowns are no longer used.
Corresponds to the JSON property intentStats
21035 21036 21037 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21035 def intent_stats @intent_stats end |
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern>
Output only. A list of loss patterns identified for the entire project/dataset.
Corresponds to the JSON property lossPatterns
21040 21041 21042 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21040 def loss_patterns @loss_patterns end |
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue>
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metrics
21046 21047 21048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21046 def metrics @metrics end |
#report ⇒ String
Output only. The final report in markdown format.
Corresponds to the JSON property report
21051 21052 21053 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21051 def report @report end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21058 21059 21060 21061 21062 21063 21064 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21058 def update!(**args) @conversation_slices = args[:conversation_slices] if args.key?(:conversation_slices) @intent_stats = args[:intent_stats] if args.key?(:intent_stats) @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns) @metrics = args[:metrics] if args.key?(:metrics) @report = args[:report] if args.key?(:report) end |