Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A diagnostic report containing aggregate metrics and intent breakdowns.
Instance Attribute Summary collapse
-
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportIntentStats>
Output only.
-
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern>
Output only.
-
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnosticReport
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDiagnosticReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDiagnosticReport
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDiagnosticReport.
20135 20136 20137 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#intent_stats ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDiagnosticReportIntentStats>
Output only. A breakdown of metrics grouped by intent.
Corresponds to the JSON property intentStats
20122 20123 20124 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20122 def intent_stats @intent_stats end |
#loss_patterns ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern>
Output only. A list of loss patterns identified for the entire project/dataset.
Corresponds to the JSON property lossPatterns
20127 20128 20129 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20127 def loss_patterns @loss_patterns end |
#metrics ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue>
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metrics
20133 20134 20135 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20133 def metrics @metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20140 20141 20142 20143 20144 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20140 def update!(**args) @intent_stats = args[:intent_stats] if args.key?(:intent_stats) @loss_patterns = args[:loss_patterns] if args.key?(:loss_patterns) @metrics = args[:metrics] if args.key?(:metrics) end |