Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimension
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimension
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A dimension determines the grouping key for the query. In SQL terms, these would be part of both the "SELECT" and "GROUP BY" clauses.
Instance Attribute Summary collapse
-
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionAgentDimensionMetadata
Metadata about the agent dimension.
-
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
-
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
-
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
-
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
-
#dimension_key ⇒ String
The key of the dimension.
-
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionIssueDimensionMetadata
Metadata about the issue dimension.
-
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionLabelDimensionMetadata
Metadata about conversation labels.
-
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
-
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension.
-
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
-
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDimension
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainDimension
Returns a new instance of GoogleCloudContactcenterinsightsV1mainDimension.
18015 18016 18017 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionAgentDimensionMetadata
Metadata about the agent dimension.
Corresponds to the JSON property agentDimensionMetadata
17957 17958 17959 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17957 def @agent_dimension_metadata end |
#client_sentiment_category_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
Corresponds to the JSON property clientSentimentCategoryDimensionMetadata
17962 17963 17964 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17962 def @client_sentiment_category_dimension_metadata end |
#conversation_profile_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
Corresponds to the JSON property conversationProfileDimensionMetadata
17967 17968 17969 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17967 def @conversation_profile_dimension_metadata end |
#conversational_agents_playbook_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
Corresponds to the JSON property conversationalAgentsPlaybookDimensionMetadata
17972 17973 17974 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17972 def @conversational_agents_playbook_dimension_metadata end |
#conversational_agents_tool_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
Corresponds to the JSON property conversationalAgentsToolDimensionMetadata
17977 17978 17979 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17977 def @conversational_agents_tool_dimension_metadata end |
#dimension_key ⇒ String
The key of the dimension.
Corresponds to the JSON property dimensionKey
17982 17983 17984 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17982 def dimension_key @dimension_key end |
#issue_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionIssueDimensionMetadata
Metadata about the issue dimension.
Corresponds to the JSON property issueDimensionMetadata
17987 17988 17989 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17987 def @issue_dimension_metadata end |
#label_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionLabelDimensionMetadata
Metadata about conversation labels.
Corresponds to the JSON property labelDimensionMetadata
17992 17993 17994 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17992 def @label_dimension_metadata end |
#medium_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
Corresponds to the JSON property mediumDimensionMetadata
17997 17998 17999 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17997 def @medium_dimension_metadata end |
#qa_question_answer_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension. This is useful for showing
the answer distribution for questions for a given scorecard.
Corresponds to the JSON property qaQuestionAnswerDimensionMetadata
18003 18004 18005 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18003 def @qa_question_answer_dimension_metadata end |
#qa_question_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
Corresponds to the JSON property qaQuestionDimensionMetadata
18008 18009 18010 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18008 def @qa_question_dimension_metadata end |
#qa_scorecard_dimension_metadata ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
Corresponds to the JSON property qaScorecardDimensionMetadata
18013 18014 18015 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18013 def @qa_scorecard_dimension_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18020 18021 18022 18023 18024 18025 18026 18027 18028 18029 18030 18031 18032 18033 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18020 def update!(**args) @agent_dimension_metadata = args[:agent_dimension_metadata] if args.key?(:agent_dimension_metadata) @client_sentiment_category_dimension_metadata = args[:client_sentiment_category_dimension_metadata] if args.key?(:client_sentiment_category_dimension_metadata) @conversation_profile_dimension_metadata = args[:conversation_profile_dimension_metadata] if args.key?(:conversation_profile_dimension_metadata) @conversational_agents_playbook_dimension_metadata = args[:conversational_agents_playbook_dimension_metadata] if args.key?(:conversational_agents_playbook_dimension_metadata) @conversational_agents_tool_dimension_metadata = args[:conversational_agents_tool_dimension_metadata] if args.key?(:conversational_agents_tool_dimension_metadata) @dimension_key = args[:dimension_key] if args.key?(:dimension_key) @issue_dimension_metadata = args[:issue_dimension_metadata] if args.key?(:issue_dimension_metadata) @label_dimension_metadata = args[:label_dimension_metadata] if args.key?(:label_dimension_metadata) @medium_dimension_metadata = args[:medium_dimension_metadata] if args.key?(:medium_dimension_metadata) @qa_question_answer_dimension_metadata = args[:qa_question_answer_dimension_metadata] if args.key?(:qa_question_answer_dimension_metadata) @qa_question_dimension_metadata = args[:qa_question_dimension_metadata] if args.key?(:qa_question_dimension_metadata) @qa_scorecard_dimension_metadata = args[:qa_scorecard_dimension_metadata] if args.key?(:qa_scorecard_dimension_metadata) end |