Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEntity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The data for an entity annotation. Represents a phrase in the conversation that is a known entity, such as a person, an organization, or location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainEntity

Returns a new instance of GoogleCloudContactcenterinsightsV1mainEntity.



19281
19282
19283
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The representative name for the entity. Corresponds to the JSON property displayName

Returns:

  • (String)


19253
19254
19255
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19253

def display_name
  @display_name
end

#metadataHash<String,String>

Metadata associated with the entity. For most entity types, the metadata is a Wikipedia URL (wikipedia_url) and Knowledge Graph MID (mid), if they are available. For the metadata associated with other entity types, see the Type table below. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


19261
19262
19263
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19261

def 
  @metadata
end

#salienceFloat

The salience score associated with the entity in the [0, 1.0] range. The salience score for an entity provides information about the importance or centrality of that entity to the entire document text. Scores closer to 0 are less salient, while scores closer to 1.0 are highly salient. Corresponds to the JSON property salience

Returns:

  • (Float)


19269
19270
19271
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19269

def salience
  @salience
end

#sentimentGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData

The data for a sentiment annotation. Corresponds to the JSON property sentiment



19274
19275
19276
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19274

def sentiment
  @sentiment
end

#typeString

The entity type. Corresponds to the JSON property type

Returns:

  • (String)


19279
19280
19281
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19279

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19286
19287
19288
19289
19290
19291
19292
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19286

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metadata = args[:metadata] if args.key?(:metadata)
  @salience = args[:salience] if args.key?(:salience)
  @sentiment = args[:sentiment] if args.key?(:sentiment)
  @type = args[:type] if args.key?(:type)
end