Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEntity
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainEntity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The data for an entity annotation. Represents a phrase in the conversation that is a known entity, such as a person, an organization, or location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The representative name for the entity.
-
#metadata ⇒ Hash<String,String>
Metadata associated with the entity.
-
#salience ⇒ Float
The salience score associated with the entity in the [0, 1.0] range.
-
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
-
#type ⇒ String
The entity type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainEntity
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainEntity
Returns a new instance of GoogleCloudContactcenterinsightsV1mainEntity.
21822 21823 21824 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The representative name for the entity.
Corresponds to the JSON property displayName
21794 21795 21796 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21794 def display_name @display_name end |
#metadata ⇒ Hash<String,String>
Metadata associated with the entity. For most entity types, the metadata is a
Wikipedia URL (wikipedia_url) and Knowledge Graph MID (mid), if they are
available. For the metadata associated with other entity types, see the Type
table below.
Corresponds to the JSON property metadata
21802 21803 21804 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21802 def @metadata end |
#salience ⇒ Float
The salience score associated with the entity in the [0, 1.0] range. The
salience score for an entity provides information about the importance or
centrality of that entity to the entire document text. Scores closer to 0 are
less salient, while scores closer to 1.0 are highly salient.
Corresponds to the JSON property salience
21810 21811 21812 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21810 def salience @salience end |
#sentiment ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSentimentData
The data for a sentiment annotation.
Corresponds to the JSON property sentiment
21815 21816 21817 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21815 def sentiment @sentiment end |
#type ⇒ String
The entity type.
Corresponds to the JSON property type
21820 21821 21822 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21820 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21827 21828 21829 21830 21831 21832 21833 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21827 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @salience = args[:salience] if args.key?(:salience) @sentiment = args[:sentiment] if args.key?(:sentiment) @type = args[:type] if args.key?(:type) end |