Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for an export insights operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata.



21754
21755
21756
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_export_countFixnum

The number of conversations that were exported successfully. Corresponds to the JSON property completedExportCount

Returns:

  • (Fixnum)


21726
21727
21728
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21726

def completed_export_count
  @completed_export_count
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21731
21732
21733
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21731

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


21736
21737
21738
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21736

def end_time
  @end_time
end

#failed_export_countFixnum

The number of conversations that failed to be exported. Corresponds to the JSON property failedExportCount

Returns:

  • (Fixnum)


21741
21742
21743
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21741

def failed_export_count
  @failed_export_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Partial errors during export operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



21747
21748
21749
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21747

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest

The request to export insights. Corresponds to the JSON property request



21752
21753
21754
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21752

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21759
21760
21761
21762
21763
21764
21765
21766
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21759

def update!(**args)
  @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
end