Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for an export insights operation.
Instance Attribute Summary collapse
-
#completed_export_count ⇒ Fixnum
The number of conversations that were exported successfully.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#failed_export_count ⇒ Fixnum
The number of conversations that failed to be exported.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during export operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest
The request to export insights.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata.
18499 18500 18501 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_export_count ⇒ Fixnum
The number of conversations that were exported successfully.
Corresponds to the JSON property completedExportCount
18471 18472 18473 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18471 def completed_export_count @completed_export_count end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
18476 18477 18478 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18476 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
18481 18482 18483 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18481 def end_time @end_time end |
#failed_export_count ⇒ Fixnum
The number of conversations that failed to be exported.
Corresponds to the JSON property failedExportCount
18486 18487 18488 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18486 def failed_export_count @failed_export_count end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during export operation that might cause the operation output
to be incomplete.
Corresponds to the JSON property partialErrors
18492 18493 18494 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18492 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest
The request to export insights.
Corresponds to the JSON property request
18497 18498 18499 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18497 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18504 18505 18506 18507 18508 18509 18510 18511 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18504 def update!(**args) @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |