Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Metadata for an export insights operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataMetadata.



15205
15206
15207
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_export_countFixnum

The number of conversations that were exported successfully. Corresponds to the JSON property completedExportCount

Returns:

  • (Fixnum)


15177
15178
15179
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15177

def completed_export_count
  @completed_export_count
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15182
15183
15184
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15182

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


15187
15188
15189
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15187

def end_time
  @end_time
end

#failed_export_countFixnum

The number of conversations that failed to be exported. Corresponds to the JSON property failedExportCount

Returns:

  • (Fixnum)


15192
15193
15194
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15192

def failed_export_count
  @failed_export_count
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Partial errors during export operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



15198
15199
15200
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15198

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest

The request to export insights. Corresponds to the JSON property request



15203
15204
15205
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15203

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15210

def update!(**args)
  @completed_export_count = args[:completed_export_count] if args.key?(:completed_export_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @failed_export_count = args[:failed_export_count] if args.key?(:failed_export_count)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
end