Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to export insights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequest.



15257
15258
15259
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_destinationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination

A BigQuery Table Reference. Corresponds to the JSON property bigQueryDestination



15227
15228
15229
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15227

def big_query_destination
  @big_query_destination
end

#export_schema_versionString

Optional. Version of the export schema. Corresponds to the JSON property exportSchemaVersion

Returns:

  • (String)


15232
15233
15234
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15232

def export_schema_version
  @export_schema_version
end

#filterString

A filter to reduce results to a specific subset. Useful for exporting conversations with specific properties. Corresponds to the JSON property filter

Returns:

  • (String)


15238
15239
15240
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15238

def filter
  @filter
end

#kms_keyString

A fully qualified KMS key name for BigQuery tables protected by CMEK. Format: projects/project/locations/location/keyRings/keyring/cryptoKeys/key/ cryptoKeyVersions/version Corresponds to the JSON property kmsKey

Returns:

  • (String)


15245
15246
15247
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15245

def kms_key
  @kms_key
end

#parentString

Required. The parent resource to export data from. Corresponds to the JSON property parent

Returns:

  • (String)


15250
15251
15252
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15250

def parent
  @parent
end

#write_dispositionString

Options for what to do if the destination table already exists. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


15255
15256
15257
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15255

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15262
15263
15264
15265
15266
15267
15268
15269
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15262

def update!(**args)
  @big_query_destination = args[:big_query_destination] if args.key?(:big_query_destination)
  @export_schema_version = args[:export_schema_version] if args.key?(:export_schema_version)
  @filter = args[:filter] if args.key?(:filter)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @parent = args[:parent] if args.key?(:parent)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end