Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A BigQuery Table Reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination

Returns a new instance of GoogleCloudContactcenterinsightsV1mainExportInsightsDataRequestBigQueryDestination.



15296
15297
15298
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetString

Required. The name of the BigQuery dataset that the snapshot result should be exported to. If this dataset does not exist, the export call returns an INVALID_ARGUMENT error. Corresponds to the JSON property dataset

Returns:

  • (String)


15281
15282
15283
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15281

def dataset
  @dataset
end

#project_idString

A project ID or number. If specified, then export will attempt to write data to this project instead of the resource project. Otherwise, the resource project will be used. Corresponds to the JSON property projectId

Returns:

  • (String)


15288
15289
15290
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15288

def project_id
  @project_id
end

#tableString

The BigQuery table name to which the insights data should be written. If this table does not exist, the export call returns an INVALID_ARGUMENT error. Corresponds to the JSON property table

Returns:

  • (String)


15294
15295
15296
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15294

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15301
15302
15303
15304
15305
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15301

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table = args[:table] if args.key?(:table)
end