Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFeedbackLabel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFeedbackLabel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Represents a conversation, resource, and label provided by the user. Can take the form of a string label or a QaAnswer label. QaAnswer labels are used for Quality AI example conversations. String labels are used for Topic Modeling. AgentAssistSummary labels are used for Agent Assist Summarization.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#label ⇒ String
String label used for Topic Modeling.
-
#labeled_resource ⇒ String
Name of the resource to be labeled.
-
#name ⇒ String
Immutable.
-
#qa_answer_label ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue
Message for holding the value of a QaAnswer.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainFeedbackLabel
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainFeedbackLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainFeedbackLabel
Returns a new instance of GoogleCloudContactcenterinsightsV1mainFeedbackLabel.
19659 19660 19661 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time of the label.
Corresponds to the JSON property createTime
19625 19626 19627 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19625 def create_time @create_time end |
#label ⇒ String
String label used for Topic Modeling.
Corresponds to the JSON property label
19630 19631 19632 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19630 def label @label end |
#labeled_resource ⇒ String
Name of the resource to be labeled. Supported resources are: * projects/
project/locations/location/qaScorecards/scorecard/revisions/revision/
qaQuestions/question* `projects/`project`/locations/`location`/issueModels/
`issue_model * projects/project/locations/location/generators/
generator_id`
Corresponds to the JSON propertylabeledResource`
19639 19640 19641 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19639 def labeled_resource @labeled_resource end |
#name ⇒ String
Immutable. Resource name of the FeedbackLabel. Format: projects/project/
locations/location/conversations/conversation/feedbackLabels/
feedback_label
Corresponds to the JSON property name
19646 19647 19648 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19646 def name @name end |
#qa_answer_label ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines
the possible answer values for a question.
Corresponds to the JSON property qaAnswerLabel
19652 19653 19654 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19652 def qa_answer_label @qa_answer_label end |
#update_time ⇒ String
Output only. Update time of the label.
Corresponds to the JSON property updateTime
19657 19658 19659 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19657 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19664 19665 19666 19667 19668 19669 19670 19671 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19664 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @label = args[:label] if args.key?(:label) @labeled_resource = args[:labeled_resource] if args.key?(:labeled_resource) @name = args[:name] if args.key?(:name) @qa_answer_label = args[:qa_answer_label] if args.key?(:qa_answer_label) @update_time = args[:update_time] if args.key?(:update_time) end |