Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFeedbackLabel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Represents a conversation, resource, and label provided by the user. Can take the form of a string label or a QaAnswer label. QaAnswer labels are used for Quality AI example conversations. String labels are used for Topic Modeling. AgentAssistSummary labels are used for Agent Assist Summarization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainFeedbackLabel

Returns a new instance of GoogleCloudContactcenterinsightsV1mainFeedbackLabel.



21117
21118
21119
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time of the label. Corresponds to the JSON property createTime

Returns:

  • (String)


21083
21084
21085
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21083

def create_time
  @create_time
end

#labelString

String label used for Topic Modeling. Corresponds to the JSON property label

Returns:

  • (String)


21088
21089
21090
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21088

def label
  @label
end

#labeled_resourceString

Name of the resource to be labeled. Supported resources are: * projects/ project/locations/location/qaScorecards/scorecard/revisions/revision/ qaQuestions/question* `projects/`project`/locations/`location`/issueModels/ `issue_model * projects/project/locations/location/generators/ generator_id` Corresponds to the JSON propertylabeledResource`

Returns:

  • (String)


21097
21098
21099
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21097

def labeled_resource
  @labeled_resource
end

#nameString

Immutable. Resource name of the FeedbackLabel. Format: projects/project/ locations/location/conversations/conversation/feedbackLabels/ feedback_label Corresponds to the JSON property name

Returns:

  • (String)


21104
21105
21106
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21104

def name
  @name
end

#qa_answer_labelGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property qaAnswerLabel



21110
21111
21112
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21110

def qa_answer_label
  @qa_answer_label
end

#update_timeString

Output only. Update time of the label. Corresponds to the JSON property updateTime

Returns:

  • (String)


21115
21116
21117
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21115

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21122
21123
21124
21125
21126
21127
21128
21129
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21122

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @label = args[:label] if args.key?(:label)
  @labeled_resource = args[:labeled_resource] if args.key?(:labeled_resource)
  @name = args[:name] if args.key?(:name)
  @qa_answer_label = args[:qa_answer_label] if args.key?(:qa_answer_label)
  @update_time = args[:update_time] if args.key?(:update_time)
end