Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A Cloud Storage source of conversation data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainGcsSource.



21147
21148
21149
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_uriString

Cloud Storage URI that points to a file that contains the conversation audio. Corresponds to the JSON property audioUri

Returns:

  • (String)


21139
21140
21141
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21139

def audio_uri
  @audio_uri
end

#transcript_uriString

Immutable. Cloud Storage URI that points to a file that contains the conversation transcript. Corresponds to the JSON property transcriptUri

Returns:

  • (String)


21145
21146
21147
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21145

def transcript_uri
  @transcript_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21152
21153
21154
21155
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21152

def update!(**args)
  @audio_uri = args[:audio_uri] if args.key?(:audio_uri)
  @transcript_uri = args[:transcript_uri] if args.key?(:transcript_uri)
end