Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscript
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscript
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The conversation transcript for the chart.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
The conversation id of the chart.
-
#create_time ⇒ String
Output only.
-
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscript
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscript
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscript.
21182 21183 21184 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
The conversation id of the chart.
Corresponds to the JSON property conversationId
21165 21166 21167 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21165 def conversation_id @conversation_id end |
#create_time ⇒ String
Output only. The create time of the conversation.
Corresponds to the JSON property createTime
21170 21171 21172 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21170 def create_time @create_time end |
#messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage>
Ordered list of messages, including user inputs and system responses.
Corresponds to the JSON property messages
21175 21176 21177 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21175 def @messages end |
#update_time ⇒ String
Output only. The update time of the conversation.
Corresponds to the JSON property updateTime
21180 21181 21182 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21180 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21187 21188 21189 21190 21191 21192 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21187 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @create_time = args[:create_time] if args.key?(:create_time) @messages = args[:messages] if args.key?(:messages) @update_time = args[:update_time] if args.key?(:update_time) end |