Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The message in the conversation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#message_id ⇒ String
The message id of the message.
-
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
-
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage.
20022 20023 20024 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. For user messages, this is the time at which the system received
the message. For system messages, this is the time at which the system
generated the message.
Corresponds to the JSON property createTime
20005 20006 20007 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20005 def create_time @create_time end |
#message_id ⇒ String
The message id of the message.
Corresponds to the JSON property messageId
20010 20011 20012 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20010 def @message_id end |
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
Corresponds to the JSON property systemMessageWrapper
20015 20016 20017 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20015 def @system_message_wrapper end |
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Corresponds to the JSON property userMessage
20020 20021 20022 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20020 def @user_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20027 20028 20029 20030 20031 20032 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20027 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @message_id = args[:message_id] if args.key?(:message_id) @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper) @user_message = args[:user_message] if args.key?(:user_message) end |