Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The message in the conversation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#message_id ⇒ String
The message id of the message.
-
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
-
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage.
19769 19770 19771 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. For user messages, this is the time at which the system received
the message. For system messages, this is the time at which the system
generated the message.
Corresponds to the JSON property createTime
19752 19753 19754 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19752 def create_time @create_time end |
#message_id ⇒ String
The message id of the message.
Corresponds to the JSON property messageId
19757 19758 19759 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19757 def @message_id end |
#system_message_wrapper ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
A wrapper for system messages per turn.
Corresponds to the JSON property systemMessageWrapper
19762 19763 19764 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19762 def @system_message_wrapper end |
#user_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage
The user message.
Corresponds to the JSON property userMessage
19767 19768 19769 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19767 def @user_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19774 19775 19776 19777 19778 19779 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19774 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @message_id = args[:message_id] if args.key?(:message_id) @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper) @user_message = args[:user_message] if args.key?(:user_message) end |