Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The message in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessage.



21221
21222
21223
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. For user messages, this is the time at which the system received the message. For system messages, this is the time at which the system generated the message. Corresponds to the JSON property createTime

Returns:

  • (String)


21204
21205
21206
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21204

def create_time
  @create_time
end

#message_idString

The message id of the message. Corresponds to the JSON property messageId

Returns:

  • (String)


21209
21210
21211
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21209

def message_id
  @message_id
end

#system_message_wrapperGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages

A wrapper for system messages per turn. Corresponds to the JSON property systemMessageWrapper



21214
21215
21216
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21214

def system_message_wrapper
  @system_message_wrapper
end

#user_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageUserMessage

The user message. Corresponds to the JSON property userMessage



21219
21220
21221
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21219

def user_message
  @user_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21226
21227
21228
21229
21230
21231
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21226

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @message_id = args[:message_id] if args.key?(:message_id)
  @system_message_wrapper = args[:system_message_wrapper] if args.key?(:system_message_wrapper)
  @user_message = args[:user_message] if args.key?(:user_message)
end