Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage

Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage.



22204
22205
22206
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_specHash<String,Object>

Chart spec from LLM Corresponds to the JSON property chartSpec

Returns:

  • (Hash<String,Object>)


22182
22183
22184
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22182

def chart_spec
  @chart_spec
end

#generated_sql_queryString

Raw SQL from LLM, before templatization Corresponds to the JSON property generatedSqlQuery

Returns:

  • (String)


22187
22188
22189
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22187

def generated_sql_query
  @generated_sql_query
end

#text_messageGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessageTextOutput

A text output message from the system. Corresponds to the JSON property textMessage



22192
22193
22194
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22192

def text_message
  @text_message
end

#user_provided_chart_specHash<String,Object>

Optional. User provided chart spec Corresponds to the JSON property userProvidedChartSpec

Returns:

  • (Hash<String,Object>)


22197
22198
22199
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22197

def user_provided_chart_spec
  @user_provided_chart_spec
end

#user_provided_sql_queryString

Optional. User provided SQL query Corresponds to the JSON property userProvidedSqlQuery

Returns:

  • (String)


22202
22203
22204
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22202

def user_provided_sql_query
  @user_provided_sql_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22209
22210
22211
22212
22213
22214
22215
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22209

def update!(**args)
  @chart_spec = args[:chart_spec] if args.key?(:chart_spec)
  @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query)
  @text_message = args[:text_message] if args.key?(:text_message)
  @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec)
  @user_provided_sql_query = args[:user_provided_sql_query] if args.key?(:user_provided_sql_query)
end