Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A message from the system in response to the user. This message can also be a message from the user as historical context for multiturn conversations with the system.
Instance Attribute Summary collapse
-
#chart_spec ⇒ Hash<String,Object>
Chart spec from LLM Corresponds to the JSON property
chartSpec. -
#generated_sql_query ⇒ String
Raw SQL from LLM, before templatization Corresponds to the JSON property
generatedSqlQuery. -
#text_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessageTextOutput
A text output message from the system.
-
#user_provided_chart_spec ⇒ Hash<String,Object>
Optional.
-
#user_provided_sql_query ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage.
18949 18950 18951 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_spec ⇒ Hash<String,Object>
Chart spec from LLM
Corresponds to the JSON property chartSpec
18927 18928 18929 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18927 def chart_spec @chart_spec end |
#generated_sql_query ⇒ String
Raw SQL from LLM, before templatization
Corresponds to the JSON property generatedSqlQuery
18932 18933 18934 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18932 def generated_sql_query @generated_sql_query end |
#text_message ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessageTextOutput
A text output message from the system.
Corresponds to the JSON property textMessage
18937 18938 18939 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18937 def @text_message end |
#user_provided_chart_spec ⇒ Hash<String,Object>
Optional. User provided chart spec
Corresponds to the JSON property userProvidedChartSpec
18942 18943 18944 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18942 def user_provided_chart_spec @user_provided_chart_spec end |
#user_provided_sql_query ⇒ String
Optional. User provided SQL query
Corresponds to the JSON property userProvidedSqlQuery
18947 18948 18949 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18947 def user_provided_sql_query @user_provided_sql_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18954 18955 18956 18957 18958 18959 18960 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18954 def update!(**args) @chart_spec = args[:chart_spec] if args.key?(:chart_spec) @generated_sql_query = args[:generated_sql_query] if args.key?(:generated_sql_query) @text_message = args[:text_message] if args.key?(:text_message) @user_provided_chart_spec = args[:user_provided_chart_spec] if args.key?(:user_provided_chart_spec) @user_provided_sql_query = args[:user_provided_sql_query] if args.key?(:user_provided_sql_query) end |