Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A wrapper for system messages per turn.
Instance Attribute Summary collapse
-
#system_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage>
A message from the system in response to the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages
Returns a new instance of GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessages.
18997 18998 18999 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#system_messages ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainGenerativeInsightConversationTranscriptMessageSystemMessage>
A message from the system in response to the user.
Corresponds to the JSON property systemMessages
18995 18996 18997 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 18995 def @system_messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19002 19003 19004 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19002 def update!(**args) @system_messages = args[:system_messages] if args.key?(:system_messages) end |