Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to import an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest.



22458
22459
22460
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_new_modelBoolean Also known as: create_new_model?

Optional. If set to true, will create an issue model from the imported file with randomly generated IDs for the issue model and corresponding issues. Otherwise, replaces an existing model with the same ID as the file. Corresponds to the JSON property createNewModel

Returns:

  • (Boolean)


22445
22446
22447
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22445

def create_new_model
  @create_new_model
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainImportIssueModelRequestGcsSource

Google Cloud Storage Object URI to get the issue model file from. Corresponds to the JSON property gcsSource



22451
22452
22453
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22451

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource of the issue model. Corresponds to the JSON property parent

Returns:

  • (String)


22456
22457
22458
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22456

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22463
22464
22465
22466
22467
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22463

def update!(**args)
  @create_new_model = args[:create_new_model] if args.key?(:create_new_model)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
end