Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to import an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest.



21519
21520
21521
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_new_modelBoolean Also known as: create_new_model?

Optional. If set to true, will create an issue model from the imported file with randomly generated IDs for the issue model and corresponding issues. Otherwise, replaces an existing model with the same ID as the file. Corresponds to the JSON property createNewModel

Returns:

  • (Boolean)


21506
21507
21508
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21506

def create_new_model
  @create_new_model
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainImportIssueModelRequestGcsSource

Google Cloud Storage Object URI to get the issue model file from. Corresponds to the JSON property gcsSource



21512
21513
21514
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21512

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource of the issue model. Corresponds to the JSON property parent

Returns:

  • (String)


21517
21518
21519
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21517

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21524
21525
21526
21527
21528
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21524

def update!(**args)
  @create_new_model = args[:create_new_model] if args.key?(:create_new_model)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
end