Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Request to import an issue model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainImportIssueModelRequest.



19203
19204
19205
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_new_modelBoolean Also known as: create_new_model?

Optional. If set to true, will create an issue model from the imported file with randomly generated IDs for the issue model and corresponding issues. Otherwise, replaces an existing model with the same ID as the file. Corresponds to the JSON property createNewModel

Returns:

  • (Boolean)


19190
19191
19192
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19190

def create_new_model
  @create_new_model
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainImportIssueModelRequestGcsSource

Google Cloud Storage Object URI to get the issue model file from. Corresponds to the JSON property gcsSource



19196
19197
19198
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19196

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource of the issue model. Corresponds to the JSON property parent

Returns:

  • (String)


19201
19202
19203
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19201

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19208
19209
19210
19211
19212
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19208

def update!(**args)
  @create_new_model = args[:create_new_model] if args.key?(:create_new_model)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
end