Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an IngestConversations operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadata.



22544
22545
22546
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22515
22516
22517
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22515

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


22520
22521
22522
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22520

def end_time
  @end_time
end

#ingest_conversations_statsGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats

Statistics for IngestConversations operation. Corresponds to the JSON property ingestConversationsStats



22525
22526
22527
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22525

def ingest_conversations_stats
  @ingest_conversations_stats
end

#partial_errorsArray<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>

Output only. Partial errors during ingest operation that might cause the operation output to be incomplete. Corresponds to the JSON property partialErrors



22531
22532
22533
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22531

def partial_errors
  @partial_errors
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest

The request to ingest conversations. Corresponds to the JSON property request



22536
22537
22538
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22536

def request
  @request
end

#sampled_conversationsArray<String>

Output only. Stores the conversation resources produced by ingest sampling operations. Corresponds to the JSON property sampledConversations

Returns:

  • (Array<String>)


22542
22543
22544
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22542

def sampled_conversations
  @sampled_conversations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22549
22550
22551
22552
22553
22554
22555
22556
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22549

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @ingest_conversations_stats = args[:ingest_conversations_stats] if args.key?(:ingest_conversations_stats)
  @partial_errors = args[:partial_errors] if args.key?(:partial_errors)
  @request = args[:request] if args.key?(:request)
  @sampled_conversations = args[:sampled_conversations] if args.key?(:sampled_conversations)
end