Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Statistics for IngestConversations operation.
Instance Attribute Summary collapse
-
#duplicates_skipped_count ⇒ Fixnum
Output only.
-
#failed_ingest_count ⇒ Fixnum
Output only.
-
#processed_object_count ⇒ Fixnum
Output only.
-
#successful_ingest_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsMetadataIngestConversationsStats.
21647 21648 21649 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duplicates_skipped_count ⇒ Fixnum
Output only. The number of objects skipped because another conversation with
the same transcript uri had already been ingested.
Corresponds to the JSON property duplicatesSkippedCount
21628 21629 21630 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21628 def duplicates_skipped_count @duplicates_skipped_count end |
#failed_ingest_count ⇒ Fixnum
Output only. The number of objects which were unable to be ingested due to
errors. The errors are populated in the partial_errors field.
Corresponds to the JSON property failedIngestCount
21634 21635 21636 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21634 def failed_ingest_count @failed_ingest_count end |
#processed_object_count ⇒ Fixnum
Output only. The number of objects processed during the ingest operation.
Corresponds to the JSON property processedObjectCount
21639 21640 21641 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21639 def processed_object_count @processed_object_count end |
#successful_ingest_count ⇒ Fixnum
Output only. The number of new conversations added during this ingest
operation.
Corresponds to the JSON property successfulIngestCount
21645 21646 21647 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21645 def successful_ingest_count @successful_ingest_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21652 21653 21654 21655 21656 21657 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21652 def update!(**args) @duplicates_skipped_count = args[:duplicates_skipped_count] if args.key?(:duplicates_skipped_count) @failed_ingest_count = args[:failed_ingest_count] if args.key?(:failed_ingest_count) @processed_object_count = args[:processed_object_count] if args.key?(:processed_object_count) @successful_ingest_count = args[:successful_ingest_count] if args.key?(:successful_ingest_count) end |