Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to ingest conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest.



20253
20254
20255
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig

Configuration that applies to all conversations. Corresponds to the JSON property conversationConfig



20209
20210
20211
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20209

def conversation_config
  @conversation_config
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource

Configuration for Cloud Storage bucket sources. Corresponds to the JSON property gcsSource



20214
20215
20216
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20214

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource for new conversations. Corresponds to the JSON property parent

Returns:

  • (String)


20219
20220
20221
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20219

def parent
  @parent
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



20230
20231
20232
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20230

def redaction_config
  @redaction_config
end

#sample_sizeFixnum

Optional. If set, this fields indicates the number of objects to ingest from the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless they are first deleted, conversations produced through sampling won't be ingested by subsequent ingest requests. Corresponds to the JSON property sampleSize

Returns:

  • (Fixnum)


20238
20239
20240
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20238

def sample_size
  @sample_size
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



20246
20247
20248
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20246

def speech_config
  @speech_config
end

#transcript_object_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestTranscriptObjectConfig

Configuration for processing transcript objects. Corresponds to the JSON property transcriptObjectConfig



20251
20252
20253
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20251

def transcript_object_config
  @transcript_object_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20258
20259
20260
20261
20262
20263
20264
20265
20266
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20258

def update!(**args)
  @conversation_config = args[:conversation_config] if args.key?(:conversation_config)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @sample_size = args[:sample_size] if args.key?(:sample_size)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config)
end