Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to ingest conversations.
Instance Attribute Summary collapse
-
#conversation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig
Configuration that applies to all conversations.
-
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource
Configuration for Cloud Storage bucket sources.
-
#parent ⇒ String
Required.
-
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#sample_size ⇒ Fixnum
Optional.
-
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSpeechConfig
Speech-to-Text configuration.
-
#transcript_object_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestTranscriptObjectConfig
Configuration for processing transcript objects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest.
22800 22801 22802 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig
Configuration that applies to all conversations.
Corresponds to the JSON property conversationConfig
22756 22757 22758 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22756 def conversation_config @conversation_config end |
#gcs_source ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource
Configuration for Cloud Storage bucket sources.
Corresponds to the JSON property gcsSource
22761 22762 22763 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22761 def gcs_source @gcs_source end |
#parent ⇒ String
Required. The parent resource for new conversations.
Corresponds to the JSON property parent
22766 22767 22768 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22766 def parent @parent end |
#redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property redactionConfig
22777 22778 22779 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22777 def redaction_config @redaction_config end |
#sample_size ⇒ Fixnum
Optional. If set, this fields indicates the number of objects to ingest from
the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless
they are first deleted, conversations produced through sampling won't be
ingested by subsequent ingest requests.
Corresponds to the JSON property sampleSize
22785 22786 22787 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22785 def sample_size @sample_size end |
#speech_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSpeechConfig
Speech-to-Text configuration. Speech-to-Text settings are applied to
conversations ingested from the UploadConversation and IngestConversations
endpoints, including conversation coming from CCAI Platform. They are not
applied to conversations ingested from the CreateConversation endpoint.
Corresponds to the JSON property speechConfig
22793 22794 22795 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22793 def speech_config @speech_config end |
#transcript_object_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestTranscriptObjectConfig
Configuration for processing transcript objects.
Corresponds to the JSON property transcriptObjectConfig
22798 22799 22800 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22798 def transcript_object_config @transcript_object_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22805 22806 22807 22808 22809 22810 22811 22812 22813 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22805 def update!(**args) @conversation_config = args[:conversation_config] if args.key?(:conversation_config) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @parent = args[:parent] if args.key?(:parent) @redaction_config = args[:redaction_config] if args.key?(:redaction_config) @sample_size = args[:sample_size] if args.key?(:sample_size) @speech_config = args[:speech_config] if args.key?(:speech_config) @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config) end |