Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The request to ingest conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequest.



19395
19396
19397
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig

Configuration that applies to all conversations. Corresponds to the JSON property conversationConfig



19351
19352
19353
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19351

def conversation_config
  @conversation_config
end

#gcs_sourceGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource

Configuration for Cloud Storage bucket sources. Corresponds to the JSON property gcsSource



19356
19357
19358
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19356

def gcs_source
  @gcs_source
end

#parentString

Required. The parent resource for new conversations. Corresponds to the JSON property parent

Returns:

  • (String)


19361
19362
19363
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19361

def parent
  @parent
end

#redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property redactionConfig



19372
19373
19374
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19372

def redaction_config
  @redaction_config
end

#sample_sizeFixnum

Optional. If set, this fields indicates the number of objects to ingest from the Cloud Storage bucket. If empty, the entire bucket will be ingested. Unless they are first deleted, conversations produced through sampling won't be ingested by subsequent ingest requests. Corresponds to the JSON property sampleSize

Returns:

  • (Fixnum)


19380
19381
19382
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19380

def sample_size
  @sample_size
end

#speech_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSpeechConfig

Speech-to-Text configuration. Speech-to-Text settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint. Corresponds to the JSON property speechConfig



19388
19389
19390
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19388

def speech_config
  @speech_config
end

#transcript_object_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestTranscriptObjectConfig

Configuration for processing transcript objects. Corresponds to the JSON property transcriptObjectConfig



19393
19394
19395
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19393

def transcript_object_config
  @transcript_object_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19400
19401
19402
19403
19404
19405
19406
19407
19408
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19400

def update!(**args)
  @conversation_config = args[:conversation_config] if args.key?(:conversation_config)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @parent = args[:parent] if args.key?(:parent)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @sample_size = args[:sample_size] if args.key?(:sample_size)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @transcript_object_config = args[:transcript_object_config] if args.key?(:transcript_object_config)
end