Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configuration that applies to all conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestConversationConfig.



20292
20293
20294
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_channelFixnum

Optional. Indicates which of the channels, 1 or 2, contains the agent. Note that this must be set for conversations to be properly displayed and analyzed. Corresponds to the JSON property agentChannel

Returns:

  • (Fixnum)


20277
20278
20279
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20277

def agent_channel
  @agent_channel
end

#agent_idString

Optional. An opaque, user-specified string representing a human agent who handled all conversations in the import. Note that this will be overridden if per-conversation metadata is provided through the metadata_bucket_uri. Corresponds to the JSON property agentId

Returns:

  • (String)


20284
20285
20286
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20284

def agent_id
  @agent_id
end

#customer_channelFixnum

Optional. Indicates which of the channels, 1 or 2, contains the agent. Note that this must be set for conversations to be properly displayed and analyzed. Corresponds to the JSON property customerChannel

Returns:

  • (Fixnum)


20290
20291
20292
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20290

def customer_channel
  @customer_channel
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20297
20298
20299
20300
20301
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20297

def update!(**args)
  @agent_channel = args[:agent_channel] if args.key?(:agent_channel)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @customer_channel = args[:customer_channel] if args.key?(:customer_channel)
end