Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configuration for Cloud Storage bucket sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource.



21815
21816
21817
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bucket_uriString

Optional. The Cloud Storage path to the conversation audio file. Note that: [1] Audio files will be transcribed if not already. [2] Audio files and transcript files must be in separate buckets / folders. [3] A source file and its corresponding audio file must share the same name to be properly ingested, E.g. gs://bucket/transcript/conversation1.json and gs://bucket/audio/ conversation1.mp3. Corresponds to the JSON property audioBucketUri

Returns:

  • (String)


21774
21775
21776
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21774

def audio_bucket_uri
  @audio_bucket_uri
end

#bucket_object_typeString

Optional. Specifies the type of the objects in bucket_uri. Avoid passing this. This is inferred from the transcript_bucket_uri, audio_bucket_uri. Corresponds to the JSON property bucketObjectType

Returns:

  • (String)


21780
21781
21782
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21780

def bucket_object_type
  @bucket_object_type
end

#bucket_uriString

Optional. The Cloud Storage bucket containing source objects. Avoid passing this. Pass this through one of transcript_bucket_uri or audio_bucket_uri. Corresponds to the JSON property bucketUri

Returns:

  • (String)


21786
21787
21788
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21786

def bucket_uri
  @bucket_uri
end

#custom_metadata_keysArray<String>

Optional. Custom keys to extract as conversation labels from metadata files in metadata_bucket_uri. Keys not included in this field will be ignored. Note that there is a limit of 100 labels per conversation. Corresponds to the JSON property customMetadataKeys

Returns:

  • (Array<String>)


21793
21794
21795
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21793

def 
  @custom_metadata_keys
end

#metadata_bucket_uriString

Optional. The Cloud Storage path to the conversation metadata. Note that: [1] Metadata files are expected to be in JSON format. [2] Metadata and source files (transcripts or audio) must be in separate buckets / folders. [3] A source file and its corresponding metadata file must share the same name to be properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/ metadata/conversation1.json. Corresponds to the JSON property metadataBucketUri

Returns:

  • (String)


21803
21804
21805
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21803

def 
  @metadata_bucket_uri
end

#transcript_bucket_uriString

Optional. The Cloud Storage path to the conversation transcripts. Note that: [ 1] Transcript files are expected to be in JSON format. [2] Transcript, audio, metadata files must be in separate buckets / folders. [3] A source file and its corresponding metadata file must share the same name to be properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/metadata/ conversation1.json. Corresponds to the JSON property transcriptBucketUri

Returns:

  • (String)


21813
21814
21815
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21813

def transcript_bucket_uri
  @transcript_bucket_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21820

def update!(**args)
  @audio_bucket_uri = args[:audio_bucket_uri] if args.key?(:audio_bucket_uri)
  @bucket_object_type = args[:bucket_object_type] if args.key?(:bucket_object_type)
  @bucket_uri = args[:bucket_uri] if args.key?(:bucket_uri)
  @custom_metadata_keys = args[:custom_metadata_keys] if args.key?(:custom_metadata_keys)
  @metadata_bucket_uri = args[:metadata_bucket_uri] if args.key?(:metadata_bucket_uri)
  @transcript_bucket_uri = args[:transcript_bucket_uri] if args.key?(:transcript_bucket_uri)
end