Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Configuration for Cloud Storage bucket sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIngestConversationsRequestGcsSource.



15910
15911
15912
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bucket_uriString

Optional. The Cloud Storage path to the conversation audio file. Note that: [1] Audio files will be transcribed if not already. [2] Audio files and transcript files must be in separate buckets / folders. [3] A source file and its corresponding audio file must share the same name to be properly ingested, E.g. gs://bucket/transcript/conversation1.json and gs://bucket/audio/ conversation1.mp3. Corresponds to the JSON property audioBucketUri

Returns:

  • (String)


15869
15870
15871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15869

def audio_bucket_uri
  @audio_bucket_uri
end

#bucket_object_typeString

Optional. Specifies the type of the objects in bucket_uri. Avoid passing this. This is inferred from the transcript_bucket_uri, audio_bucket_uri. Corresponds to the JSON property bucketObjectType

Returns:

  • (String)


15875
15876
15877
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15875

def bucket_object_type
  @bucket_object_type
end

#bucket_uriString

Optional. The Cloud Storage bucket containing source objects. Avoid passing this. Pass this through one of transcript_bucket_uri or audio_bucket_uri. Corresponds to the JSON property bucketUri

Returns:

  • (String)


15881
15882
15883
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15881

def bucket_uri
  @bucket_uri
end

#custom_metadata_keysArray<String>

Optional. Custom keys to extract as conversation labels from metadata files in metadata_bucket_uri. Keys not included in this field will be ignored. Note that there is a limit of 100 labels per conversation. Corresponds to the JSON property customMetadataKeys

Returns:

  • (Array<String>)


15888
15889
15890
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15888

def 
  @custom_metadata_keys
end

#metadata_bucket_uriString

Optional. The Cloud Storage path to the conversation metadata. Note that: [1] Metadata files are expected to be in JSON format. [2] Metadata and source files (transcripts or audio) must be in separate buckets / folders. [3] A source file and its corresponding metadata file must share the same name to be properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/ metadata/conversation1.json. Corresponds to the JSON property metadataBucketUri

Returns:

  • (String)


15898
15899
15900
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15898

def 
  @metadata_bucket_uri
end

#transcript_bucket_uriString

Optional. The Cloud Storage path to the conversation transcripts. Note that: [ 1] Transcript files are expected to be in JSON format. [2] Transcript, audio, metadata files must be in separate buckets / folders. [3] A source file and its corresponding metadata file must share the same name to be properly ingested, E.g. gs://bucket/audio/conversation1.mp3 and gs://bucket/metadata/ conversation1.json. Corresponds to the JSON property transcriptBucketUri

Returns:

  • (String)


15908
15909
15910
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15908

def transcript_bucket_uri
  @transcript_bucket_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15915
15916
15917
15918
15919
15920
15921
15922
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15915

def update!(**args)
  @audio_bucket_uri = args[:audio_bucket_uri] if args.key?(:audio_bucket_uri)
  @bucket_object_type = args[:bucket_object_type] if args.key?(:bucket_object_type)
  @bucket_uri = args[:bucket_uri] if args.key?(:bucket_uri)
  @custom_metadata_keys = args[:custom_metadata_keys] if args.key?(:custom_metadata_keys)
  @metadata_bucket_uri = args[:metadata_bucket_uri] if args.key?(:metadata_bucket_uri)
  @transcript_bucket_uri = args[:transcript_bucket_uri] if args.key?(:transcript_bucket_uri)
end