Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for initializing a location-level encryption specification.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata.
20435 20436 20437 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
20417 20418 20419 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20417 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
20422 20423 20424 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20422 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation
output to be incomplete.
Corresponds to the JSON property partialErrors
20428 20429 20430 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20428 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Corresponds to the JSON property request
20433 20434 20435 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20433 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20440 20441 20442 20443 20444 20445 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20440 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |