Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Metadata for initializing a location-level encryption specification.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation output to be incomplete.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecMetadata.
15982 15983 15984 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
15964 15965 15966 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15964 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
15969 15970 15971 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15969 def end_time @end_time end |
#partial_errors ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus>
Partial errors during initializing operation that might cause the operation
output to be incomplete.
Corresponds to the JSON property partialErrors
15975 15976 15977 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15975 def partial_errors @partial_errors end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainInitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
Corresponds to the JSON property request
15980 15981 15982 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15980 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15987 15988 15989 15990 15991 15992 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 15987 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @partial_errors = args[:partial_errors] if args.key?(:partial_errors) @request = args[:request] if args.key?(:request) end |