Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssue

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssue.



20572
20573
20574
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20543
20544
20545
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20543

def create_time
  @create_time
end

#display_descriptionString

Representative description of the issue. Corresponds to the JSON property displayDescription

Returns:

  • (String)


20548
20549
20550
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20548

def display_description
  @display_description
end

#display_nameString

The representative name for the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


20553
20554
20555
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20553

def display_name
  @display_name
end

#nameString

Immutable. The resource name of the issue. Format: projects/project/ locations/location/issueModels/issue_model/issues/issue Corresponds to the JSON property name

Returns:

  • (String)


20559
20560
20561
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20559

def name
  @name
end

#sample_utterancesArray<String>

Output only. Resource names of the sample representative utterances that match to this issue. Corresponds to the JSON property sampleUtterances

Returns:

  • (Array<String>)


20565
20566
20567
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20565

def sample_utterances
  @sample_utterances
end

#update_timeString

Output only. The most recent time that this issue was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


20570
20571
20572
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20570

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20577
20578
20579
20580
20581
20582
20583
20584
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20577

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_description = args[:display_description] if args.key?(:display_description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances)
  @update_time = args[:update_time] if args.key?(:update_time)
end