Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The issue resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssue

Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssue.



22969
22970
22971
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which this issue was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22940
22941
22942
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22940

def create_time
  @create_time
end

#display_descriptionString

Representative description of the issue. Corresponds to the JSON property displayDescription

Returns:

  • (String)


22945
22946
22947
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22945

def display_description
  @display_description
end

#display_nameString

The representative name for the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


22950
22951
22952
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22950

def display_name
  @display_name
end

#nameString

Immutable. The resource name of the issue. Format: projects/project/ locations/location/issueModels/issue_model/issues/issue Corresponds to the JSON property name

Returns:

  • (String)


22956
22957
22958
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22956

def name
  @name
end

#sample_utterancesArray<String>

Output only. Resource names of the sample representative utterances that match to this issue. Corresponds to the JSON property sampleUtterances

Returns:

  • (Array<String>)


22962
22963
22964
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22962

def sample_utterances
  @sample_utterances
end

#update_timeString

Output only. The most recent time that this issue was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


22967
22968
22969
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22967

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22974
22975
22976
22977
22978
22979
22980
22981
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22974

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_description = args[:display_description] if args.key?(:display_description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances)
  @update_time = args[:update_time] if args.key?(:update_time)
end