Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_description ⇒ String
Representative description of the issue.
-
#display_name ⇒ String
The representative name for the issue.
-
#name ⇒ String
Immutable.
-
#sample_utterances ⇒ Array<String>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssue
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssue
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssue.
19714 19715 19716 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue was created.
Corresponds to the JSON property createTime
19685 19686 19687 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19685 def create_time @create_time end |
#display_description ⇒ String
Representative description of the issue.
Corresponds to the JSON property displayDescription
19690 19691 19692 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19690 def display_description @display_description end |
#display_name ⇒ String
The representative name for the issue.
Corresponds to the JSON property displayName
19695 19696 19697 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19695 def display_name @display_name end |
#name ⇒ String
Immutable. The resource name of the issue. Format: projects/project/
locations/location/issueModels/issue_model/issues/issue
Corresponds to the JSON property name
19701 19702 19703 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19701 def name @name end |
#sample_utterances ⇒ Array<String>
Output only. Resource names of the sample representative utterances that match
to this issue.
Corresponds to the JSON property sampleUtterances
19707 19708 19709 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19707 def sample_utterances @sample_utterances end |
#update_time ⇒ String
Output only. The most recent time that this issue was updated.
Corresponds to the JSON property updateTime
19712 19713 19714 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19712 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19719 19720 19721 19722 19723 19724 19725 19726 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 19719 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_description = args[:display_description] if args.key?(:display_description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @sample_utterances = args[:sample_utterances] if args.key?(:sample_utterances) @update_time = args[:update_time] if args.key?(:update_time) end |