Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue model resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The representative name for the issue model.
-
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
Configs for the input data used to create the issue model.
-
#issue_count ⇒ Fixnum
Output only.
-
#language_code ⇒ String
Language of the model.
-
#model_type ⇒ String
Type of the model.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
Aggregated statistics about an issue model.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModel
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIssueModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModel
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModel.
20694 20695 20696 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue model was created.
Corresponds to the JSON property createTime
20646 20647 20648 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20646 def create_time @create_time end |
#display_name ⇒ String
The representative name for the issue model.
Corresponds to the JSON property displayName
20651 20652 20653 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20651 def display_name @display_name end |
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
Configs for the input data used to create the issue model.
Corresponds to the JSON property inputDataConfig
20656 20657 20658 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20656 def input_data_config @input_data_config end |
#issue_count ⇒ Fixnum
Output only. Number of issues in this issue model.
Corresponds to the JSON property issueCount
20661 20662 20663 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20661 def issue_count @issue_count end |
#language_code ⇒ String
Language of the model.
Corresponds to the JSON property languageCode
20666 20667 20668 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20666 def language_code @language_code end |
#model_type ⇒ String
Type of the model.
Corresponds to the JSON property modelType
20671 20672 20673 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20671 def model_type @model_type end |
#name ⇒ String
Immutable. The resource name of the issue model. Format: projects/project/
locations/location/issueModels/issue_model
Corresponds to the JSON property name
20677 20678 20679 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20677 def name @name end |
#state ⇒ String
Output only. State of the model.
Corresponds to the JSON property state
20682 20683 20684 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20682 def state @state end |
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
Aggregated statistics about an issue model.
Corresponds to the JSON property trainingStats
20687 20688 20689 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20687 def training_stats @training_stats end |
#update_time ⇒ String
Output only. The most recent time at which the issue model was updated.
Corresponds to the JSON property updateTime
20692 20693 20694 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20692 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20699 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @input_data_config = args[:input_data_config] if args.key?(:input_data_config) @issue_count = args[:issue_count] if args.key?(:issue_count) @language_code = args[:language_code] if args.key?(:language_code) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @training_stats = args[:training_stats] if args.key?(:training_stats) @update_time = args[:update_time] if args.key?(:update_time) end |