Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModel
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The issue model resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The representative name for the issue model.
-
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
Configs for the input data used to create the issue model.
-
#issue_count ⇒ Fixnum
Output only.
-
#language_code ⇒ String
Language of the model.
-
#model_type ⇒ String
Type of the model.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
Aggregated statistics about an issue model.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModel
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIssueModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModel
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModel.
23091 23092 23093 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this issue model was created.
Corresponds to the JSON property createTime
23043 23044 23045 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23043 def create_time @create_time end |
#display_name ⇒ String
The representative name for the issue model.
Corresponds to the JSON property displayName
23048 23049 23050 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23048 def display_name @display_name end |
#input_data_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelInputDataConfig
Configs for the input data used to create the issue model.
Corresponds to the JSON property inputDataConfig
23053 23054 23055 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23053 def input_data_config @input_data_config end |
#issue_count ⇒ Fixnum
Output only. Number of issues in this issue model.
Corresponds to the JSON property issueCount
23058 23059 23060 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23058 def issue_count @issue_count end |
#language_code ⇒ String
Language of the model.
Corresponds to the JSON property languageCode
23063 23064 23065 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23063 def language_code @language_code end |
#model_type ⇒ String
Type of the model.
Corresponds to the JSON property modelType
23068 23069 23070 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23068 def model_type @model_type end |
#name ⇒ String
Immutable. The resource name of the issue model. Format: projects/project/
locations/location/issueModels/issue_model
Corresponds to the JSON property name
23074 23075 23076 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23074 def name @name end |
#state ⇒ String
Output only. State of the model.
Corresponds to the JSON property state
23079 23080 23081 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23079 def state @state end |
#training_stats ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
Aggregated statistics about an issue model.
Corresponds to the JSON property trainingStats
23084 23085 23086 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23084 def training_stats @training_stats end |
#update_time ⇒ String
Output only. The most recent time at which the issue model was updated.
Corresponds to the JSON property updateTime
23089 23090 23091 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23089 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23096 23097 23098 23099 23100 23101 23102 23103 23104 23105 23106 23107 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23096 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @input_data_config = args[:input_data_config] if args.key?(:input_data_config) @issue_count = args[:issue_count] if args.key?(:issue_count) @language_code = args[:language_code] if args.key?(:language_code) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @training_stats = args[:training_stats] if args.key?(:training_stats) @update_time = args[:update_time] if args.key?(:update_time) end |