Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Aggregated statistics about an issue model.
Instance Attribute Summary collapse
-
#analyzed_conversations_count ⇒ Fixnum
Number of conversations the issue model has analyzed at this point in time.
-
#issue_stats ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats>
Statistics on each issue.
-
#unclassified_conversations_count ⇒ Fixnum
Number of analyzed conversations for which no issue was applicable at this point in time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats
Returns a new instance of GoogleCloudContactcenterinsightsV1mainIssueModelLabelStats.
16321 16322 16323 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analyzed_conversations_count ⇒ Fixnum
Number of conversations the issue model has analyzed at this point in time.
Corresponds to the JSON property analyzedConversationsCount
16308 16309 16310 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16308 def analyzed_conversations_count @analyzed_conversations_count end |
#issue_stats ⇒ Hash<String,Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainIssueModelLabelStatsIssueStats>
Statistics on each issue. Key is the issue's resource name.
Corresponds to the JSON property issueStats
16313 16314 16315 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16313 def issue_stats @issue_stats end |
#unclassified_conversations_count ⇒ Fixnum
Number of analyzed conversations for which no issue was applicable at this
point in time.
Corresponds to the JSON property unclassifiedConversationsCount
16319 16320 16321 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16319 def unclassified_conversations_count @unclassified_conversations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16326 16327 16328 16329 16330 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16326 def update!(**args) @analyzed_conversations_count = args[:analyzed_conversations_count] if args.key?(:analyzed_conversations_count) @issue_stats = args[:issue_stats] if args.key?(:issue_stats) @unclassified_conversations_count = args[:unclassified_conversations_count] if args.key?(:unclassified_conversations_count) end |