Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A loss pattern of a virtual agent and suggested fixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainLossPattern

Returns a new instance of GoogleCloudContactcenterinsightsV1mainLossPattern.



23330
23331
23332
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idsArray<String>

Output only. A list of conversation IDs that match this loss pattern. Corresponds to the JSON property conversationIds

Returns:

  • (Array<String>)


23293
23294
23295
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23293

def conversation_ids
  @conversation_ids
end

#descriptionString

Output only. A markdown description of the loss pattern. Corresponds to the JSON property description

Returns:

  • (String)


23298
23299
23300
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23298

def description
  @description
end

#display_nameString

Output only. The display name of the loss pattern. Corresponds to the JSON property displayName

Returns:

  • (String)


23303
23304
23305
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23303

def display_name
  @display_name
end

#examplesString

Output only. A markdown of loss pattern examples. Corresponds to the JSON property examples

Returns:

  • (String)


23308
23309
23310
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23308

def examples
  @examples
end

#idString

Output only. The unique identifier for the loss pattern. Corresponds to the JSON property id

Returns:

  • (String)


23313
23314
23315
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23313

def id
  @id
end

Output only. A list of links to conversations or bot instructions. Corresponds to the JSON property links



23318
23319
23320
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23318

def links
  @links
end

#percentageFloat

Output only. The percentage of conversations that match this loss pattern. Corresponds to the JSON property percentage

Returns:

  • (Float)


23323
23324
23325
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23323

def percentage
  @percentage
end

#suggested_fixesString

Output only. A markdown description of the suggested fixes. Corresponds to the JSON property suggestedFixes

Returns:

  • (String)


23328
23329
23330
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23328

def suggested_fixes
  @suggested_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23335
23336
23337
23338
23339
23340
23341
23342
23343
23344
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23335

def update!(**args)
  @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @links = args[:links] if args.key?(:links)
  @percentage = args[:percentage] if args.key?(:percentage)
  @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes)
end