Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPattern

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A loss pattern of a virtual agent and suggested fixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainLossPattern

Returns a new instance of GoogleCloudContactcenterinsightsV1mainLossPattern.



22386
22387
22388
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idsArray<String>

Output only. A list of conversation IDs that match this loss pattern. Corresponds to the JSON property conversationIds

Returns:

  • (Array<String>)


22354
22355
22356
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22354

def conversation_ids
  @conversation_ids
end

#descriptionString

Output only. A markdown description of the loss pattern. Corresponds to the JSON property description

Returns:

  • (String)


22359
22360
22361
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22359

def description
  @description
end

#display_nameString

Output only. The display name of the loss pattern. Corresponds to the JSON property displayName

Returns:

  • (String)


22364
22365
22366
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22364

def display_name
  @display_name
end

#examplesString

Output only. A markdown of loss pattern examples. Corresponds to the JSON property examples

Returns:

  • (String)


22369
22370
22371
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22369

def examples
  @examples
end

#idString

Output only. The unique identifier for the loss pattern. Corresponds to the JSON property id

Returns:

  • (String)


22374
22375
22376
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22374

def id
  @id
end

#percentageFloat

Output only. The percentage of conversations that match this loss pattern. Corresponds to the JSON property percentage

Returns:

  • (Float)


22379
22380
22381
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22379

def percentage
  @percentage
end

#suggested_fixesString

Output only. A markdown description of the suggested fixes. Corresponds to the JSON property suggestedFixes

Returns:

  • (String)


22384
22385
22386
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22384

def suggested_fixes
  @suggested_fixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22391
22392
22393
22394
22395
22396
22397
22398
22399
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22391

def update!(**args)
  @conversation_ids = args[:conversation_ids] if args.key?(:conversation_ids)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @percentage = args[:percentage] if args.key?(:percentage)
  @suggested_fixes = args[:suggested_fixes] if args.key?(:suggested_fixes)
end