Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainLossPatternLink

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A link to a conversation or bot instruction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainLossPatternLink

Returns a new instance of GoogleCloudContactcenterinsightsV1mainLossPatternLink.



23381
23382
23383
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

A link to a bot instruction. Corresponds to the JSON property botInstructionLink



23354
23355
23356
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23354

def bot_instruction_link
  @bot_instruction_link
end

A link to a conversation. Corresponds to the JSON property conversationLink



23359
23360
23361
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23359

def conversation_link
  @conversation_link
end

#end_byte_indexFixnum

The end byte index of the highlighted text (exclusive). Corresponds to the JSON property endByteIndex

Returns:

  • (Fixnum)


23364
23365
23366
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23364

def end_byte_index
  @end_byte_index
end

#highlighted_textString

The text that is highlighted. (populated for debugging purposes) Corresponds to the JSON property highlightedText

Returns:

  • (String)


23369
23370
23371
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23369

def highlighted_text
  @highlighted_text
end

#location_typeString

The location type. Corresponds to the JSON property locationType

Returns:

  • (String)


23374
23375
23376
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23374

def location_type
  @location_type
end

#start_byte_indexFixnum

The start byte index of the highlighted text (inclusive). Corresponds to the JSON property startByteIndex

Returns:

  • (Fixnum)


23379
23380
23381
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23379

def start_byte_index
  @start_byte_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23386
23387
23388
23389
23390
23391
23392
23393
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23386

def update!(**args)
  @bot_instruction_link = args[:bot_instruction_link] if args.key?(:bot_instruction_link)
  @conversation_link = args[:conversation_link] if args.key?(:conversation_link)
  @end_byte_index = args[:end_byte_index] if args.key?(:end_byte_index)
  @highlighted_text = args[:highlighted_text] if args.key?(:highlighted_text)
  @location_type = args[:location_type] if args.key?(:location_type)
  @start_byte_index = args[:start_byte_index] if args.key?(:start_byte_index)
end