Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainMetricValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Deprecated: MetricValue is no longer used for diagnostics.
Instance Attribute Summary collapse
-
#conversations ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Output only.
-
#hit_count ⇒ Fixnum
Output only.
-
#metric_type ⇒ String
Output only.
-
#source_id ⇒ String
Output only.
-
#total_count ⇒ Fixnum
Output only.
-
#value ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainMetricValue
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainMetricValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainMetricValue
Returns a new instance of GoogleCloudContactcenterinsightsV1mainMetricValue.
22446 22447 22448 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversations ⇒ Array<String>
Output only. The list of conversation names that contributed to this metric (
hits). Format: projects/project/locations/location/conversations/
conversation`
Corresponds to the JSON propertyconversations`
22411 22412 22413 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22411 def conversations @conversations end |
#display_name ⇒ String
Output only. The user-visible name of the metric (e.g., "Containment Rate").
Corresponds to the JSON property displayName
22416 22417 22418 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22416 def display_name @display_name end |
#hit_count ⇒ Fixnum
Output only. The number of positive matches (hits) for this metric.
Corresponds to the JSON property hitCount
22421 22422 22423 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22421 def hit_count @hit_count end |
#metric_type ⇒ String
Output only. Deprecated: The type of the metric. Metrics for Outcome Based
Insights derived from QueryMetrics.
Corresponds to the JSON property metricType
22427 22428 22429 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22427 def metric_type @metric_type end |
#source_id ⇒ String
Output only. The resource name of the underlying Insights primitive (e.g., Tag
or QaQuestion) used to calculate this metric.
Corresponds to the JSON property sourceId
22433 22434 22435 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22433 def source_id @source_id end |
#total_count ⇒ Fixnum
Output only. The total number of items evaluated for this metric.
Corresponds to the JSON property totalCount
22438 22439 22440 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22438 def total_count @total_count end |
#value ⇒ Float
Output only. The calculated value of the metric (usually a ratio or rate 0.0 -
1.0).
Corresponds to the JSON property value
22444 22445 22446 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22444 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22451 22452 22453 22454 22455 22456 22457 22458 22459 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22451 def update!(**args) @conversations = args[:conversations] if args.key?(:conversations) @display_name = args[:display_name] if args.key?(:display_name) @hit_count = args[:hit_count] if args.key?(:hit_count) @metric_type = args[:metric_type] if args.key?(:metric_type) @source_id = args[:source_id] if args.key?(:source_id) @total_count = args[:total_count] if args.key?(:total_count) @value = args[:value] if args.key?(:value) end |