Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An answer to a QaQuestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaAnswer

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaAnswer.



16507
16508
16509
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource>

Lists all answer sources containing one or more answer values of a specific source type, e.g., all system-generated answer sources, or all manual edit answer sources. Corresponds to the JSON property answerSources



16477
16478
16479
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16477

def answer_sources
  @answer_sources
end

#answer_valueGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property answerValue



16483
16484
16485
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16483

def answer_value
  @answer_value
end

#conversationString

The conversation the answer applies to. Corresponds to the JSON property conversation

Returns:

  • (String)


16488
16489
16490
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16488

def conversation
  @conversation
end

#qa_questionString

The QaQuestion answered by this answer. Corresponds to the JSON property qaQuestion

Returns:

  • (String)


16493
16494
16495
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16493

def qa_question
  @qa_question
end

#question_bodyString

Question text. E.g., "Did the agent greet the customer?" Corresponds to the JSON property questionBody

Returns:

  • (String)


16498
16499
16500
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16498

def question_body
  @question_body
end

#tagsArray<String>

User-defined list of arbitrary tags. Matches the value from QaScorecard. ScorecardQuestion.tags. Used for grouping/organization and for weighting the score of each answer. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


16505
16506
16507
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16505

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16512

def update!(**args)
  @answer_sources = args[:answer_sources] if args.key?(:answer_sources)
  @answer_value = args[:answer_value] if args.key?(:answer_value)
  @conversation = args[:conversation] if args.key?(:conversation)
  @qa_question = args[:qa_question] if args.key?(:qa_question)
  @question_body = args[:question_body] if args.key?(:question_body)
  @tags = args[:tags] if args.key?(:tags)
end