Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A question may have multiple answers from varying sources, one of which becomes the "main" answer above. AnswerSource represents each individual answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource.



20992
20993
20994
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_valueGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property answerValue



20985
20986
20987
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20985

def answer_value
  @answer_value
end

#source_typeString

What created the answer. Corresponds to the JSON property sourceType

Returns:

  • (String)


20990
20991
20992
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20990

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20997
20998
20999
21000
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20997

def update!(**args)
  @answer_value = args[:answer_value] if args.key?(:answer_value)
  @source_type = args[:source_type] if args.key?(:source_type)
end