Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A question may have multiple answers from varying sources, one of which becomes the "main" answer above. AnswerSource represents each individual answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerSource.



23709
23710
23711
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_valueGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question. Corresponds to the JSON property answerValue



23702
23703
23704
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23702

def answer_value
  @answer_value
end

#source_typeString

What created the answer. Corresponds to the JSON property sourceType

Returns:

  • (String)


23707
23708
23709
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23707

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23714
23715
23716
23717
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23714

def update!(**args)
  @answer_value = args[:answer_value] if args.key?(:answer_value)
  @source_type = args[:source_type] if args.key?(:source_type)
end