Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#key ⇒ String
A short string used as an identifier.
-
#na_value ⇒ Boolean
(also: #na_value?)
A value of "Not Applicable (N/A)".
-
#normalized_score ⇒ Float
Output only.
-
#num_value ⇒ Float
Numerical value.
-
#potential_score ⇒ Float
Output only.
-
#score ⇒ Float
Output only.
-
#skip_value ⇒ Boolean
(also: #skip_value?)
Output only.
-
#str_value ⇒ String
String value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue.
21054 21055 21056 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
21005 21006 21007 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21005 def bool_value @bool_value end |
#key ⇒ String
A short string used as an identifier. Matches the value used in QaQuestion.
AnswerChoice.key.
Corresponds to the JSON property key
21012 21013 21014 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21012 def key @key end |
#na_value ⇒ Boolean Also known as: na_value?
A value of "Not Applicable (N/A)". Should only ever be true.
Corresponds to the JSON property naValue
21017 21018 21019 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21017 def na_value @na_value end |
#normalized_score ⇒ Float
Output only. Normalized score of the questions. Calculated as score /
potential_score.
Corresponds to the JSON property normalizedScore
21024 21025 21026 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21024 def normalized_score @normalized_score end |
#num_value ⇒ Float
Numerical value.
Corresponds to the JSON property numValue
21029 21030 21031 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21029 def num_value @num_value end |
#potential_score ⇒ Float
Output only. The maximum potential score of the question.
Corresponds to the JSON property potentialScore
21034 21035 21036 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21034 def potential_score @potential_score end |
#score ⇒ Float
Output only. Numerical score of the answer.
Corresponds to the JSON property score
21039 21040 21041 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21039 def score @score end |
#skip_value ⇒ Boolean Also known as: skip_value?
Output only. A value of "Skip". If provided, this field may only be set to
true. If a question receives this answer, it will be excluded from any score
calculations. This would mean that the question was not evaluated.
Corresponds to the JSON property skipValue
21046 21047 21048 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21046 def skip_value @skip_value end |
#str_value ⇒ String
String value.
Corresponds to the JSON property strValue
21052 21053 21054 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21052 def str_value @str_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21059 21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21059 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @key = args[:key] if args.key?(:key) @na_value = args[:na_value] if args.key?(:na_value) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @num_value = args[:num_value] if args.key?(:num_value) @potential_score = args[:potential_score] if args.key?(:potential_score) @score = args[:score] if args.key?(:score) @skip_value = args[:skip_value] if args.key?(:skip_value) @str_value = args[:str_value] if args.key?(:str_value) end |