Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for holding the value of a QaAnswer. QaQuestion.AnswerChoice defines the possible answer values for a question.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaAnswerAnswerValue.



20196
20197
20198
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


20147
20148
20149
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20147

def bool_value
  @bool_value
end

#keyString

A short string used as an identifier. Matches the value used in QaQuestion. AnswerChoice.key. Corresponds to the JSON property key

Returns:

  • (String)


20154
20155
20156
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20154

def key
  @key
end

#na_valueBoolean Also known as: na_value?

A value of "Not Applicable (N/A)". Should only ever be true. Corresponds to the JSON property naValue

Returns:

  • (Boolean)


20159
20160
20161
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20159

def na_value
  @na_value
end

#normalized_scoreFloat

Output only. Normalized score of the questions. Calculated as score / potential_score. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


20166
20167
20168
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20166

def normalized_score
  @normalized_score
end

#num_valueFloat

Numerical value. Corresponds to the JSON property numValue

Returns:

  • (Float)


20171
20172
20173
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20171

def num_value
  @num_value
end

#potential_scoreFloat

Output only. The maximum potential score of the question. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


20176
20177
20178
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20176

def potential_score
  @potential_score
end

#scoreFloat

Output only. Numerical score of the answer. Corresponds to the JSON property score

Returns:

  • (Float)


20181
20182
20183
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20181

def score
  @score
end

#skip_valueBoolean Also known as: skip_value?

Output only. A value of "Skip". If provided, this field may only be set to true. If a question receives this answer, it will be excluded from any score calculations. This would mean that the question was not evaluated. Corresponds to the JSON property skipValue

Returns:

  • (Boolean)


20188
20189
20190
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20188

def skip_value
  @skip_value
end

#str_valueString

String value. Corresponds to the JSON property strValue

Returns:

  • (String)


20194
20195
20196
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20194

def str_value
  @str_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20201
20202
20203
20204
20205
20206
20207
20208
20209
20210
20211
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20201

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @key = args[:key] if args.key?(:key)
  @na_value = args[:na_value] if args.key?(:na_value)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @num_value = args[:num_value] if args.key?(:num_value)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @score = args[:score] if args.key?(:score)
  @skip_value = args[:skip_value] if args.key?(:skip_value)
  @str_value = args[:str_value] if args.key?(:str_value)
end