Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResult.



22865
22866
22867
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


22809
22810
22811
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22809

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


22814
22815
22816
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22814

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22819
22820
22821
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22819

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


22825
22826
22827
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22825

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


22831
22832
22833
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22831

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


22837
22838
22839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22837

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



22842
22843
22844
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22842

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


22847
22848
22849
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22847

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



22852
22853
22854
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22852

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


22858
22859
22860
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22858

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



22863
22864
22865
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22863

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22870
22871
22872
22873
22874
22875
22876
22877
22878
22879
22880
22881
22882
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22870

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end