Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The results of scoring a single conversation against a QaScorecard. Contains a collection of QaAnswers and aggregate score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResult

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResult.



20328
20329
20330
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

ID of the agent that handled the conversation. Corresponds to the JSON property agentId

Returns:

  • (String)


20272
20273
20274
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20272

def agent_id
  @agent_id
end

#conversationString

The conversation scored by this result. Corresponds to the JSON property conversation

Returns:

  • (String)


20277
20278
20279
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20277

def conversation
  @conversation
end

#create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20282
20283
20284
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20282

def create_time
  @create_time
end

#nameString

Identifier. The name of the scorecard result. Format: projects/project/ locations/location/qaScorecardResults/qa_scorecard_result Corresponds to the JSON property name

Returns:

  • (String)


20288
20289
20290
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20288

def name
  @name
end

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Any manual edits are included if they exist. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


20294
20295
20296
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20294

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


20300
20301
20302
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20300

def potential_score
  @potential_score
end

#qa_answersArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaAnswer>

Set of QaAnswers represented in the result. Corresponds to the JSON property qaAnswers



20305
20306
20307
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20305

def qa_answers
  @qa_answers
end

#qa_scorecard_revisionString

The QaScorecardRevision scored by this result. Corresponds to the JSON property qaScorecardRevision

Returns:

  • (String)


20310
20311
20312
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20310

def qa_scorecard_revision
  @qa_scorecard_revision
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



20315
20316
20317
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20315

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result, incorporating any manual edits if they exist. Corresponds to the JSON property score

Returns:

  • (Float)


20321
20322
20323
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20321

def score
  @score
end

#score_sourcesArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource>

List of all individual score sets. Corresponds to the JSON property scoreSources



20326
20327
20328
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20326

def score_sources
  @score_sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20333
20334
20335
20336
20337
20338
20339
20340
20341
20342
20343
20344
20345
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20333

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @conversation = args[:conversation] if args.key?(:conversation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_answers = args[:qa_answers] if args.key?(:qa_answers)
  @qa_scorecard_revision = args[:qa_scorecard_revision] if args.key?(:qa_scorecard_revision)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @score_sources = args[:score_sources] if args.key?(:score_sources)
end