Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.
Instance Attribute Summary collapse
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result.
-
#source_type ⇒ String
What created the score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource.
21275 21276 21277 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
Corresponds to the JSON property normalizedScore
21252 21253 21254 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21252 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
21258 21259 21260 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21258 def potential_score @potential_score end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
21263 21264 21265 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21263 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result.
Corresponds to the JSON property score
21268 21269 21270 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21268 def score @score end |
#source_type ⇒ String
What created the score.
Corresponds to the JSON property sourceType
21273 21274 21275 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21273 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21280 21281 21282 21283 21284 21285 21286 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21280 def update!(**args) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @source_type = args[:source_type] if args.key?(:source_type) end |