Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource.



22954
22955
22956
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


22931
22932
22933
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22931

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


22937
22938
22939
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22937

def potential_score
  @potential_score
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



22942
22943
22944
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22942

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result. Corresponds to the JSON property score

Returns:

  • (Float)


22947
22948
22949
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22947

def score
  @score
end

#source_typeString

What created the score. Corresponds to the JSON property sourceType

Returns:

  • (String)


22952
22953
22954
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22952

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22959
22960
22961
22962
22963
22964
22965
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22959

def update!(**args)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @source_type = args[:source_type] if args.key?(:source_type)
end