Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.
Instance Attribute Summary collapse
-
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
-
#potential_score ⇒ Float
The maximum potential overall score of the scorecard.
-
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>
Collection of tags and their scores.
-
#score ⇒ Float
The overall numerical score of the result.
-
#source_type ⇒ String
What created the score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource.
20417 20418 20419 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#normalized_score ⇒ Float
The normalized score, which is the score divided by the potential score.
Corresponds to the JSON property normalizedScore
20394 20395 20396 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20394 def normalized_score @normalized_score end |
#potential_score ⇒ Float
The maximum potential overall score of the scorecard. Any questions answered
using na_value are excluded from this calculation.
Corresponds to the JSON property potentialScore
20400 20401 20402 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20400 def potential_score @potential_score end |
#qa_tag_results ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>
Collection of tags and their scores.
Corresponds to the JSON property qaTagResults
20405 20406 20407 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20405 def qa_tag_results @qa_tag_results end |
#score ⇒ Float
The overall numerical score of the result.
Corresponds to the JSON property score
20410 20411 20412 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20410 def score @score end |
#source_type ⇒ String
What created the score.
Corresponds to the JSON property sourceType
20415 20416 20417 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20415 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20422 20423 20424 20425 20426 20427 20428 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20422 def update!(**args) @normalized_score = args[:normalized_score] if args.key?(:normalized_score) @potential_score = args[:potential_score] if args.key?(:potential_score) @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results) @score = args[:score] if args.key?(:score) @source_type = args[:source_type] if args.key?(:source_type) end |