Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above. A ScoreSource represents each individual set of scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQaScorecardResultScoreSource.



16828
16829
16830
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#normalized_scoreFloat

The normalized score, which is the score divided by the potential score. Corresponds to the JSON property normalizedScore

Returns:

  • (Float)


16805
16806
16807
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16805

def normalized_score
  @normalized_score
end

#potential_scoreFloat

The maximum potential overall score of the scorecard. Any questions answered using na_value are excluded from this calculation. Corresponds to the JSON property potentialScore

Returns:

  • (Float)


16811
16812
16813
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16811

def potential_score
  @potential_score
end

#qa_tag_resultsArray<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQaScorecardResultQaTagResult>

Collection of tags and their scores. Corresponds to the JSON property qaTagResults



16816
16817
16818
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16816

def qa_tag_results
  @qa_tag_results
end

#scoreFloat

The overall numerical score of the result. Corresponds to the JSON property score

Returns:

  • (Float)


16821
16822
16823
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16821

def score
  @score
end

#source_typeString

What created the score. Corresponds to the JSON property sourceType

Returns:

  • (String)


16826
16827
16828
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16826

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16833
16834
16835
16836
16837
16838
16839
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16833

def update!(**args)
  @normalized_score = args[:normalized_score] if args.key?(:normalized_score)
  @potential_score = args[:potential_score] if args.key?(:potential_score)
  @qa_tag_results = args[:qa_tag_results] if args.key?(:qa_tag_results)
  @score = args[:score] if args.key?(:score)
  @source_type = args[:source_type] if args.key?(:source_type)
end