Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A data point contains the metric values mapped to an interval.
Instance Attribute Summary collapse
-
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
-
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
-
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint.
21673 21674 21675 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
Corresponds to the JSON property conversationMeasure
21658 21659 21660 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21658 def conversation_measure @conversation_measure end |
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
Corresponds to the JSON property dialogflowInteractionMeasure
21663 21664 21665 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21663 def dialogflow_interaction_measure @dialogflow_interaction_measure end |
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
21671 21672 21673 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21671 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21678 21679 21680 21681 21682 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21678 def update!(**args) @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure) @dialogflow_interaction_measure = args[:dialogflow_interaction_measure] if args.key?(:dialogflow_interaction_measure) @interval = args[:interval] if args.key?(:interval) end |