Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A data point contains the metric values mapped to an interval.
Instance Attribute Summary collapse
-
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
-
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
-
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint.
24137 24138 24139 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
The measure related to conversations.
Corresponds to the JSON property conversationMeasure
24122 24123 24124 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24122 def conversation_measure @conversation_measure end |
#dialogflow_interaction_measure ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointDialogflowInteractionMeasure
The measure related to dialogflow interactions.
Corresponds to the JSON property dialogflowInteractionMeasure
24127 24128 24129 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24127 def dialogflow_interaction_measure @dialogflow_interaction_measure end |
#interval ⇒ Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
24135 24136 24137 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24135 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24142 24143 24144 24145 24146 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24142 def update!(**args) @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure) @dialogflow_interaction_measure = args[:dialogflow_interaction_measure] if args.key?(:dialogflow_interaction_measure) @interval = args[:interval] if args.key?(:interval) end |