Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

A data point contains the metric values mapped to an interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint

Returns a new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPoint.



20556
20557
20558
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_measureGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure

The measure related to conversations. Corresponds to the JSON property conversationMeasure



20541
20542
20543
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20541

def conversation_measure
  @conversation_measure
end

#dialogflow_interaction_measureGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointDialogflowInteractionMeasure

The measure related to dialogflow interactions. Corresponds to the JSON property dialogflowInteractionMeasure



20546
20547
20548
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20546

def dialogflow_interaction_measure
  @dialogflow_interaction_measure
end

#intervalGoogle::Apis::ContactcenterinsightsV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



20554
20555
20556
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20554

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20561
20562
20563
20564
20565
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 20561

def update!(**args)
  @conversation_measure = args[:conversation_measure] if args.key?(:conversation_measure)
  @dialogflow_interaction_measure = args[:dialogflow_interaction_measure] if args.key?(:dialogflow_interaction_measure)
  @interval = args[:interval] if args.key?(:interval)
end