Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The measure related to conversations.
Instance Attribute Summary collapse
-
#average_agent_sentiment_score ⇒ Float
The average agent's sentiment score.
-
#average_client_sentiment_score ⇒ Float
The average client's sentiment score.
-
#average_customer_satisfaction_rating ⇒ Float
The average customer satisfaction rating.
-
#average_duration ⇒ String
The average duration.
-
#average_qa_normalized_score ⇒ Float
The average normalized QA score for a scorecard.
-
#average_qa_question_normalized_score ⇒ Float
Average QA normalized score averaged for questions averaged across all revisions of the parent scorecard.
-
#average_silence_percentage ⇒ Float
The average silence percentage.
-
#average_turn_count ⇒ Float
The average turn count.
-
#conversation_count ⇒ Fixnum
The conversation count.
-
#qa_tag_scores ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasureQaTagScore>
Average QA normalized score for all the tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure
Returns a new instance of GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasure.
17033 17034 17035 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_agent_sentiment_score ⇒ Float
The average agent's sentiment score.
Corresponds to the JSON property averageAgentSentimentScore
16980 16981 16982 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16980 def average_agent_sentiment_score @average_agent_sentiment_score end |
#average_client_sentiment_score ⇒ Float
The average client's sentiment score.
Corresponds to the JSON property averageClientSentimentScore
16985 16986 16987 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16985 def average_client_sentiment_score @average_client_sentiment_score end |
#average_customer_satisfaction_rating ⇒ Float
The average customer satisfaction rating.
Corresponds to the JSON property averageCustomerSatisfactionRating
16990 16991 16992 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16990 def @average_customer_satisfaction_rating end |
#average_duration ⇒ String
The average duration.
Corresponds to the JSON property averageDuration
16995 16996 16997 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 16995 def average_duration @average_duration end |
#average_qa_normalized_score ⇒ Float
The average normalized QA score for a scorecard. When computing the average
across a set of conversations, if a conversation has been evaluated with
multiple revisions of a scorecard, only the latest revision results will be
used. Will exclude 0's in average calculation. Will be only populated if the
request specifies a dimension of QA_SCORECARD_ID.
Corresponds to the JSON property averageQaNormalizedScore
17004 17005 17006 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17004 def average_qa_normalized_score @average_qa_normalized_score end |
#average_qa_question_normalized_score ⇒ Float
Average QA normalized score averaged for questions averaged across all
revisions of the parent scorecard. Will be only populated if the request
specifies a dimension of QA_QUESTION_ID.
Corresponds to the JSON property averageQaQuestionNormalizedScore
17011 17012 17013 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17011 def average_qa_question_normalized_score @average_qa_question_normalized_score end |
#average_silence_percentage ⇒ Float
The average silence percentage.
Corresponds to the JSON property averageSilencePercentage
17016 17017 17018 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17016 def average_silence_percentage @average_silence_percentage end |
#average_turn_count ⇒ Float
The average turn count.
Corresponds to the JSON property averageTurnCount
17021 17022 17023 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17021 def average_turn_count @average_turn_count end |
#conversation_count ⇒ Fixnum
The conversation count.
Corresponds to the JSON property conversationCount
17026 17027 17028 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17026 def conversation_count @conversation_count end |
#qa_tag_scores ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainQueryMetricsResponseSliceDataPointConversationMeasureQaTagScore>
Average QA normalized score for all the tags.
Corresponds to the JSON property qaTagScores
17031 17032 17033 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17031 def qa_tag_scores @qa_tag_scores end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17038 def update!(**args) @average_agent_sentiment_score = args[:average_agent_sentiment_score] if args.key?(:average_agent_sentiment_score) @average_client_sentiment_score = args[:average_client_sentiment_score] if args.key?(:average_client_sentiment_score) @average_customer_satisfaction_rating = args[:average_customer_satisfaction_rating] if args.key?(:average_customer_satisfaction_rating) @average_duration = args[:average_duration] if args.key?(:average_duration) @average_qa_normalized_score = args[:average_qa_normalized_score] if args.key?(:average_qa_normalized_score) @average_qa_question_normalized_score = args[:average_qa_question_normalized_score] if args.key?(:average_qa_question_normalized_score) @average_silence_percentage = args[:average_silence_percentage] if args.key?(:average_silence_percentage) @average_turn_count = args[:average_turn_count] if args.key?(:average_turn_count) @conversation_count = args[:conversation_count] if args.key?(:conversation_count) @qa_tag_scores = args[:qa_tag_scores] if args.key?(:qa_tag_scores) end |