Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainRedactionConfig

Returns a new instance of GoogleCloudContactcenterinsightsV1mainRedactionConfig.



22180
22181
22182
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deidentify_templateString

The fully-qualified DLP deidentify template resource name. Format: projects/ project/deidentifyTemplates/template` Corresponds to the JSON propertydeidentifyTemplate`

Returns:

  • (String)


22172
22173
22174
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22172

def deidentify_template
  @deidentify_template
end

#inspect_templateString

The fully-qualified DLP inspect template resource name. Format: projects/ project/locations/location/inspectTemplates/template` Corresponds to the JSON propertyinspectTemplate`

Returns:

  • (String)


22178
22179
22180
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22178

def inspect_template
  @inspect_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22185
22186
22187
22188
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22185

def update!(**args)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
end