Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation.



24947
24948
24949
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


24880
24881
24882
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24880

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



24885
24886
24887
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24885

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



24890
24891
24892
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24890

def article_suggestion
  @article_suggestion
end

#ces_end_session_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesEndSessionAnnotation

The CES end session annotation. Corresponds to the JSON property cesEndSessionAnnotation



24895
24896
24897
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24895

def ces_end_session_annotation
  @ces_end_session_annotation
end

#ces_turn_annotationGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainCesTurnAnnotation

The CES diagnostic information. Corresponds to the JSON property cesTurnAnnotation



24900
24901
24902
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24900

def ces_turn_annotation
  @ces_turn_annotation
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



24905
24906
24907
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24905

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24910
24911
24912
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24910

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



24915
24916
24917
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24915

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



24920
24921
24922
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24920

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



24925
24926
24927
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24925

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



24930
24931
24932
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24930

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



24935
24936
24937
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24935

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



24940
24941
24942
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24940

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



24945
24946
24947
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24945

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24952
24953
24954
24955
24956
24957
24958
24959
24960
24961
24962
24963
24964
24965
24966
24967
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24952

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @ces_end_session_annotation = args[:ces_end_session_annotation] if args.key?(:ces_end_session_annotation)
  @ces_turn_annotation = args[:ces_turn_annotation] if args.key?(:ces_turn_annotation)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end