Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An annotation that was generated during the customer and agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation

Returns a new instance of GoogleCloudContactcenterinsightsV1mainRuntimeAnnotation.



17227
17228
17229
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_idString

The unique identifier of the annotation. Format: projects/project/locations/ location/conversationDatasets/dataset/conversationDataItems/data_item/ conversationAnnotations/annotation Corresponds to the JSON property annotationId

Returns:

  • (String)


17170
17171
17172
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17170

def annotation_id
  @annotation_id
end

#answer_feedbackGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnswerFeedback

The feedback that the customer has about a certain answer in the conversation. Corresponds to the JSON property answerFeedback



17175
17176
17177
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17175

def answer_feedback
  @answer_feedback
end

#article_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainArticleSuggestionData

Agent Assist Article Suggestion data. Corresponds to the JSON property articleSuggestion



17180
17181
17182
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17180

def article_suggestion
  @article_suggestion
end

#conversation_summarization_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainConversationSummarizationSuggestionData

Conversation summarization suggestion data. Corresponds to the JSON property conversationSummarizationSuggestion



17185
17186
17187
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17185

def conversation_summarization_suggestion
  @conversation_summarization_suggestion
end

#create_timeString

The time at which this annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17190
17191
17192
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17190

def create_time
  @create_time
end

#dialogflow_interactionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDialogflowInteractionData

Dialogflow interaction data. Corresponds to the JSON property dialogflowInteraction



17195
17196
17197
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17195

def dialogflow_interaction
  @dialogflow_interaction
end

#end_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property endBoundary



17200
17201
17202
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17200

def end_boundary
  @end_boundary
end

#faq_answerGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainFaqAnswerData

Agent Assist frequently-asked-question answer data. Corresponds to the JSON property faqAnswer



17205
17206
17207
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17205

def faq_answer
  @faq_answer
end

#smart_compose_suggestionGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData

Agent Assist Smart Compose suggestion data. Corresponds to the JSON property smartComposeSuggestion



17210
17211
17212
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17210

def smart_compose_suggestion
  @smart_compose_suggestion
end

#smart_replyGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartReplyData

Agent Assist Smart Reply data. Corresponds to the JSON property smartReply



17215
17216
17217
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17215

def smart_reply
  @smart_reply
end

#start_boundaryGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainAnnotationBoundary

A point in a conversation that marks the start or the end of an annotation. Corresponds to the JSON property startBoundary



17220
17221
17222
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17220

def start_boundary
  @start_boundary
end

#user_inputGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRuntimeAnnotationUserInput

Explicit input used for generating the answer Corresponds to the JSON property userInput



17225
17226
17227
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17225

def user_input
  @user_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17232
17233
17234
17235
17236
17237
17238
17239
17240
17241
17242
17243
17244
17245
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17232

def update!(**args)
  @annotation_id = args[:annotation_id] if args.key?(:annotation_id)
  @answer_feedback = args[:answer_feedback] if args.key?(:answer_feedback)
  @article_suggestion = args[:article_suggestion] if args.key?(:article_suggestion)
  @conversation_summarization_suggestion = args[:conversation_summarization_suggestion] if args.key?(:conversation_summarization_suggestion)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dialogflow_interaction = args[:dialogflow_interaction] if args.key?(:dialogflow_interaction)
  @end_boundary = args[:end_boundary] if args.key?(:end_boundary)
  @faq_answer = args[:faq_answer] if args.key?(:faq_answer)
  @smart_compose_suggestion = args[:smart_compose_suggestion] if args.key?(:smart_compose_suggestion)
  @smart_reply = args[:smart_reply] if args.key?(:smart_reply)
  @start_boundary = args[:start_boundary] if args.key?(:start_boundary)
  @user_input = args[:user_input] if args.key?(:user_input)
end