Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Statistics for SampleConversations operation.
Instance Attribute Summary collapse
-
#failed_sample_count ⇒ Fixnum
Output only.
-
#successful_sample_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
Returns a new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats.
23869 23870 23871 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_sample_count ⇒ Fixnum
Output only. The number of objects which were unable to be sampled due to
errors. The errors are populated in the partial_errors field.
Corresponds to the JSON property failedSampleCount
23861 23862 23863 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23861 def failed_sample_count @failed_sample_count end |
#successful_sample_count ⇒ Fixnum
Output only. The number of new conversations added during this sample
operation.
Corresponds to the JSON property successfulSampleCount
23867 23868 23869 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23867 def successful_sample_count @successful_sample_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23874 23875 23876 23877 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23874 def update!(**args) @failed_sample_count = args[:failed_sample_count] if args.key?(:failed_sample_count) @successful_sample_count = args[:successful_sample_count] if args.key?(:successful_sample_count) end |