Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Statistics for SampleConversations operation.
Instance Attribute Summary collapse
-
#failed_sample_count ⇒ Fixnum
Output only.
-
#successful_sample_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats
Returns a new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsMetadataSampleConversationsStats.
17341 17342 17343 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_sample_count ⇒ Fixnum
Output only. The number of objects which were unable to be sampled due to
errors. The errors are populated in the partial_errors field.
Corresponds to the JSON property failedSampleCount
17333 17334 17335 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17333 def failed_sample_count @failed_sample_count end |
#successful_sample_count ⇒ Fixnum
Output only. The number of new conversations added during this sample
operation.
Corresponds to the JSON property successfulSampleCount
17339 17340 17341 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17339 def successful_sample_count @successful_sample_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17346 17347 17348 17349 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17346 def update!(**args) @failed_sample_count = args[:failed_sample_count] if args.key?(:failed_sample_count) @successful_sample_count = args[:successful_sample_count] if args.key?(:successful_sample_count) end |