Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleConversationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The request to sample conversations to a dataset.
Instance Attribute Summary collapse
-
#destination_dataset ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset
Dataset resource represents a collection of conversations that may be bounded ( Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic) Corresponds to the JSON property
destinationDataset. -
#parent ⇒ String
Required.
-
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleRule
Message for sampling conversations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsRequest
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleConversationsRequest
Returns a new instance of GoogleCloudContactcenterinsightsV1mainSampleConversationsRequest.
17373 17374 17375 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_dataset ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainDataset
Dataset resource represents a collection of conversations that may be bounded (
Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic
Dataset, e.g. live traffic, or agent training traffic)
Corresponds to the JSON property destinationDataset
17361 17362 17363 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17361 def destination_dataset @destination_dataset end |
#parent ⇒ String
Required. The parent resource of the dataset.
Corresponds to the JSON property parent
17366 17367 17368 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17366 def parent @parent end |
#sample_rule ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleRule
Message for sampling conversations.
Corresponds to the JSON property sampleRule
17371 17372 17373 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17371 def sample_rule @sample_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17378 17379 17380 17381 17382 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17378 def update!(**args) @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset) @parent = args[:parent] if args.key?(:parent) @sample_rule = args[:sample_rule] if args.key?(:sample_rule) end |