Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSampleRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Message for sampling conversations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSampleRule

Returns a new instance of GoogleCloudContactcenterinsightsV1mainSampleRule.



23954
23955
23956
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_filterString

To specify the filter for the conversions that should apply this sample rule. An empty filter means this sample rule applies to all conversations. Corresponds to the JSON property conversationFilter

Returns:

  • (String)


23934
23935
23936
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23934

def conversation_filter
  @conversation_filter
end

#dimensionString

Optional. Group by dimension to sample the conversation. If no dimension is provided, the sampling will be applied to the project level. Current supported dimensions is 'quality_metadata.agent_info.agent_id'. Corresponds to the JSON property dimension

Returns:

  • (String)


23941
23942
23943
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23941

def dimension
  @dimension
end

#sample_percentageFloat

Percentage of conversations that we should sample based on the dimension between [0, 100]. Corresponds to the JSON property samplePercentage

Returns:

  • (Float)


23947
23948
23949
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23947

def sample_percentage
  @sample_percentage
end

#sample_rowFixnum

Number of the conversations that we should sample based on the dimension. Corresponds to the JSON property sampleRow

Returns:

  • (Fixnum)


23952
23953
23954
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23952

def sample_row
  @sample_row
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23959
23960
23961
23962
23963
23964
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23959

def update!(**args)
  @conversation_filter = args[:conversation_filter] if args.key?(:conversation_filter)
  @dimension = args[:dimension] if args.key?(:dimension)
  @sample_percentage = args[:sample_percentage] if args.key?(:sample_percentage)
  @sample_row = args[:sample_row] if args.key?(:sample_row)
end