Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSherlockStep
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
A step in the agent's reasoning process (Trajectory Step).
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Output only.
-
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#state_deltas ⇒ Array<Hash<String,Object>>
Output only.
-
#step_id ⇒ String
Output only.
-
#text_input ⇒ Array<String>
Output only.
-
#thought ⇒ String
Output only.
-
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainToolCall>
Output only.
-
#tool_output ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSherlockStep
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainSherlockStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSherlockStep
Returns a new instance of GoogleCloudContactcenterinsightsV1mainSherlockStep.
25083 25084 25085 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Output only. The ID of the agent that produced/received this content.
Corresponds to the JSON property agentId
25044 25045 25046 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25044 def agent_id @agent_id end |
#content ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
25051 25052 25053 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25051 def content @content end |
#state_deltas ⇒ Array<Hash<String,Object>>
Output only. List of state changes caused by this specific turn.
Corresponds to the JSON property stateDeltas
25056 25057 25058 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25056 def state_deltas @state_deltas end |
#step_id ⇒ String
Output only. Unique ID for this specific turn.
Corresponds to the JSON property stepId
25061 25062 25063 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25061 def step_id @step_id end |
#text_input ⇒ Array<String>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property textInput
25066 25067 25068 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25066 def text_input @text_input end |
#thought ⇒ String
Output only. Deprecated: Use content instead.
Corresponds to the JSON property thought
25071 25072 25073 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25071 def thought @thought end |
#tool_calls ⇒ Array<Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainToolCall>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolCalls
25076 25077 25078 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25076 def tool_calls @tool_calls end |
#tool_output ⇒ Hash<String,Object>
Output only. Deprecated: Use content instead.
Corresponds to the JSON property toolOutput
25081 25082 25083 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25081 def tool_output @tool_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25088 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @content = args[:content] if args.key?(:content) @state_deltas = args[:state_deltas] if args.key?(:state_deltas) @step_id = args[:step_id] if args.key?(:step_id) @text_input = args[:text_input] if args.key?(:text_input) @thought = args[:thought] if args.key?(:thought) @tool_calls = args[:tool_calls] if args.key?(:tool_calls) @tool_output = args[:tool_output] if args.key?(:tool_output) end |