Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

Agent Assist Smart Compose suggestion data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData

Returns a new instance of GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData.



24071
24072
24073
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The system's confidence score that this suggestion is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


24052
24053
24054
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24052

def confidence_score
  @confidence_score
end

#metadataHash<String,String>

Map that contains metadata about the Smart Compose suggestion and the document from which it originates. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


24058
24059
24060
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24058

def 
  @metadata
end

#query_recordString

The name of the answer record. Format: projects/project/locations/location/ answerRecords/answer_record Corresponds to the JSON property queryRecord

Returns:

  • (String)


24064
24065
24066
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24064

def query_record
  @query_record
end

#suggestionString

The content of the suggestion. Corresponds to the JSON property suggestion

Returns:

  • (String)


24069
24070
24071
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24069

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24076
24077
24078
24079
24080
24081
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24076

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @metadata = args[:metadata] if args.key?(:metadata)
  @query_record = args[:query_record] if args.key?(:query_record)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end