Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Agent Assist Smart Compose suggestion data.
Instance Attribute Summary collapse
-
#confidence_score ⇒ Float
The system's confidence score that this suggestion is a good match for this conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely certain).
-
#metadata ⇒ Hash<String,String>
Map that contains metadata about the Smart Compose suggestion and the document from which it originates.
-
#query_record ⇒ String
The name of the answer record.
-
#suggestion ⇒ String
The content of the suggestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData
Returns a new instance of GoogleCloudContactcenterinsightsV1mainSmartComposeSuggestionData.
17506 17507 17508 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_score ⇒ Float
The system's confidence score that this suggestion is a good match for this
conversation, ranging from 0.0 (completely uncertain) to 1.0 (completely
certain).
Corresponds to the JSON property confidenceScore
17487 17488 17489 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17487 def confidence_score @confidence_score end |
#metadata ⇒ Hash<String,String>
Map that contains metadata about the Smart Compose suggestion and the document
from which it originates.
Corresponds to the JSON property metadata
17493 17494 17495 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17493 def @metadata end |
#query_record ⇒ String
The name of the answer record. Format: projects/project/locations/location/
answerRecords/answer_record
Corresponds to the JSON property queryRecord
17499 17500 17501 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17499 def query_record @query_record end |
#suggestion ⇒ String
The content of the suggestion.
Corresponds to the JSON property suggestion
17504 17505 17506 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17504 def suggestion @suggestion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17511 17512 17513 17514 17515 17516 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 17511 def update!(**args) @confidence_score = args[:confidence_score] if args.key?(:confidence_score) @metadata = args[:metadata] if args.key?(:metadata) @query_record = args[:query_record] if args.key?(:query_record) @suggestion = args[:suggestion] if args.key?(:suggestion) end |