Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
An error that occurred during correlation for a specific conversation.
Instance Attribute Summary collapse
-
#conversation ⇒ String
The conversation resource name that had an error during correlation.
-
#status ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError
Returns a new instance of GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError.
22728 22729 22730 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation ⇒ String
The conversation resource name that had an error during correlation.
Corresponds to the JSON property conversation
22716 22717 22718 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22716 def conversation @conversation end |
#status ⇒ Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
22726 22727 22728 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22726 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22733 22734 22735 22736 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22733 def update!(**args) @conversation = args[:conversation] if args.key?(:conversation) @status = args[:status] if args.key?(:status) end |