Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

An error that occurred during correlation for a specific conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError

Returns a new instance of GoogleCloudContactcenterinsightsV1mainTestCorrelationConfigMetadataFullConversationCorrelationStatsConversationCorrelationError.



24251
24252
24253
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversationString

The conversation resource name that had an error during correlation. Corresponds to the JSON property conversation

Returns:

  • (String)


24239
24240
24241
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24239

def conversation
  @conversation
end

#statusGoogle::Apis::ContactcenterinsightsV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



24249
24250
24251
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24249

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24256
24257
24258
24259
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 24256

def update!(**args)
  @conversation = args[:conversation] if args.key?(:conversation)
  @status = args[:status] if args.key?(:status)
end