Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for an UploadConversation operation.
Instance Attribute Summary collapse
-
#analysis_operation ⇒ String
Output only.
-
#applied_redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationRequest
Request to upload a conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata.
22762 22763 22764 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_operation ⇒ String
Output only. The operation name for a successfully created analysis operation,
if any.
Corresponds to the JSON property analysisOperation
22734 22735 22736 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22734 def analysis_operation @analysis_operation end |
#applied_redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property appliedRedactionConfig
22745 22746 22747 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22745 def applied_redaction_config @applied_redaction_config end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
22750 22751 22752 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22750 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
22755 22756 22757 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22755 def end_time @end_time end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationRequest
Request to upload a conversation.
Corresponds to the JSON property request
22760 22761 22762 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22760 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22767 def update!(**args) @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation) @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @request = args[:request] if args.key?(:request) end |