Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
The metadata for an UploadConversation operation.
Instance Attribute Summary collapse
-
#analysis_operation ⇒ String
Output only.
-
#applied_redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig
DLP resources used for redaction while ingesting conversations.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationRequest
Request to upload a conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
constructor
A new instance of GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata
Returns a new instance of GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata.
25567 25568 25569 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25567 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_operation ⇒ String
Output only. The operation name for a successfully created analysis operation,
if any.
Corresponds to the JSON property analysisOperation
25539 25540 25541 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25539 def analysis_operation @analysis_operation end |
#applied_redaction_config ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig
DLP resources used for redaction while ingesting conversations. DLP settings
are applied to conversations ingested from the UploadConversation and
IngestConversations endpoints, including conversation coming from CCAI
Platform. They are not applied to conversations ingested from the
CreateConversation endpoint or the Dialogflow / Agent Assist runtime
integrations. When using Dialogflow / Agent Assist runtime integrations,
redaction should be performed in Dialogflow / Agent Assist.
Corresponds to the JSON property appliedRedactionConfig
25550 25551 25552 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25550 def applied_redaction_config @applied_redaction_config end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
25555 25556 25557 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25555 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
25560 25561 25562 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25560 def end_time @end_time end |
#request ⇒ Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationRequest
Request to upload a conversation.
Corresponds to the JSON property request
25565 25566 25567 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25565 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25572 25573 25574 25575 25576 25577 25578 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 25572 def update!(**args) @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation) @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @request = args[:request] if args.key?(:request) end |