Class: Google::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The metadata for an UploadConversation operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata

Returns a new instance of GoogleCloudContactcenterinsightsV1mainUploadConversationMetadata.



21886
21887
21888
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_operationString

Output only. The operation name for a successfully created analysis operation, if any. Corresponds to the JSON property analysisOperation

Returns:

  • (String)


21858
21859
21860
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21858

def analysis_operation
  @analysis_operation
end

#applied_redaction_configGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainRedactionConfig

DLP resources used for redaction while ingesting conversations. DLP settings are applied to conversations ingested from the UploadConversation and IngestConversations endpoints, including conversation coming from CCAI Platform. They are not applied to conversations ingested from the CreateConversation endpoint or the Dialogflow / Agent Assist runtime integrations. When using Dialogflow / Agent Assist runtime integrations, redaction should be performed in Dialogflow / Agent Assist. Corresponds to the JSON property appliedRedactionConfig



21869
21870
21871
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21869

def applied_redaction_config
  @applied_redaction_config
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21874
21875
21876
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21874

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


21879
21880
21881
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21879

def end_time
  @end_time
end

#requestGoogle::Apis::ContactcenterinsightsV1::GoogleCloudContactcenterinsightsV1mainUploadConversationRequest

Request to upload a conversation. Corresponds to the JSON property request



21884
21885
21886
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21884

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21891
21892
21893
21894
21895
21896
21897
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 21891

def update!(**args)
  @analysis_operation = args[:analysis_operation] if args.key?(:analysis_operation)
  @applied_redaction_config = args[:applied_redaction_config] if args.key?(:applied_redaction_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @request = args[:request] if args.key?(:request)
end