Class: Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleRpcStatus

Returns a new instance of GoogleRpcStatus.



23324
23325
23326
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The status code, which should be an enum value of google.rpc.Code. Corresponds to the JSON property code

Returns:

  • (Fixnum)


23309
23310
23311
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23309

def code
  @code
end

#detailsArray<Hash<String,Object>>

A list of messages that carry the error details. There is a common set of message types for APIs to use. Corresponds to the JSON property details

Returns:

  • (Array<Hash<String,Object>>)


23315
23316
23317
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23315

def details
  @details
end

#messageString

A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client. Corresponds to the JSON property message

Returns:

  • (String)


23322
23323
23324
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23322

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23329
23330
23331
23332
23333
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 23329

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
end