Class: Google::Apis::ContactcenterinsightsV1::GoogleRpcStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb

Overview

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleRpcStatus

Returns a new instance of GoogleRpcStatus.



22454
22455
22456
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The status code, which should be an enum value of google.rpc.Code. Corresponds to the JSON property code

Returns:

  • (Fixnum)


22439
22440
22441
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22439

def code
  @code
end

#detailsArray<Hash<String,Object>>

A list of messages that carry the error details. There is a common set of message types for APIs to use. Corresponds to the JSON property details

Returns:

  • (Array<Hash<String,Object>>)


22445
22446
22447
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22445

def details
  @details
end

#messageString

A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client. Corresponds to the JSON property message

Returns:

  • (String)


22452
22453
22454
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22452

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22459
22460
22461
22462
22463
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 22459

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
end