Class: Google::Apis::ContactcenterinsightsV1::GoogleTypeExpr
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleTypeExpr
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#expression ⇒ String
Textual representation of an expression in Common Expression Language syntax.
-
#location ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeExpr
constructor
A new instance of GoogleTypeExpr.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeExpr
Returns a new instance of GoogleTypeExpr.
26188 26189 26190 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the expression. This is a longer text which describes
the expression, e.g. when hovered over it in a UI.
Corresponds to the JSON property description
26169 26170 26171 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26169 def description @description end |
#expression ⇒ String
Textual representation of an expression in Common Expression Language syntax.
Corresponds to the JSON property expression
26174 26175 26176 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26174 def expression @expression end |
#location ⇒ String
Optional. String indicating the location of the expression for error reporting,
e.g. a file name and a position in the file.
Corresponds to the JSON property location
26180 26181 26182 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26180 def location @location end |
#title ⇒ String
Optional. Title for the expression, i.e. a short string describing its purpose.
This can be used e.g. in UIs which allow to enter the expression.
Corresponds to the JSON property title
26186 26187 26188 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26186 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26193 26194 26195 26196 26197 26198 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26193 def update!(**args) @description = args[:description] if args.key?(:description) @expression = args[:expression] if args.key?(:expression) @location = args[:location] if args.key?(:location) @title = args[:title] if args.key?(:title) end |