Class: Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenterinsightsV1::GoogleTypeInterval
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenterinsights_v1/classes.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb,
lib/google/apis/contactcenterinsights_v1/representations.rb
Overview
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeInterval
constructor
A new instance of GoogleTypeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeInterval
Returns a new instance of GoogleTypeInterval.
26220 26221 26222 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. Exclusive end of the interval. If specified, a Timestamp matching
this interval will have to be before the end.
Corresponds to the JSON property endTime
26212 26213 26214 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26212 def end_time @end_time end |
#start_time ⇒ String
Optional. Inclusive start of the interval. If specified, a Timestamp matching
this interval will have to be the same or after the start.
Corresponds to the JSON property startTime
26218 26219 26220 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26218 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26225 26226 26227 26228 |
# File 'lib/google/apis/contactcenterinsights_v1/classes.rb', line 26225 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |